Drexel Law Review, no. Vol. 14, no 4
Thursday, December 22, 2022 13887 mots, p. 819(40)

FERTILITY CARE: ESSENTIAL OR NON-ESSENTIAL? LESSONS FROM THE COVID-19 PANDEMIC.

At the beginning of the COVID-19 pandemic, in an effort to allocate medical resources towards the anticipated influx of patients infected with the novel virus, many non-essential healthcare services were temporarily paused. The American Society of Reproductive Medicine led the move to halt infertility care in all but the most extreme cases. This cessation of infertility care, compounded by the unknown duration of this recommendation, added to the already high level of stress and anxiety that fertility patients experience and in cases of advanced maternal age or diminished ovarian reserve potentially resulted in suboptimal clinical outcomes. There was vocal disagreement amongst infertility care providers regarding the urgency and essential nature of fertility care and how this balanced with the pandemic. Ultimately there has been a full resumption of fertility care with a new emphasis on fertility preservation. It should be the goal of all professionals in the field of infertility medicine to establish fertility care as essential within the greater field of medicine to assure the protection of their patients in times of future healthcare crisis.

    TABLE OF CONTENTS
    INTRODUCTION 820
    I. PAUSE OF NON-ESSENTIAL HEALTHCARE DURING THE
     PANDEMIC 821
    II. FERTILITY CLINIC CLOSURE AND TREATMENT GUIDANCE
     DURING THE PANDEMIC 828
    III. IMPACT & PERSPECTIVES ON FERTILITY CLINIC CLOSURES 845
    IV. POLICY: FERTILITY CARE IS ESSENTIAL CARE 854
    CONCLUSION 858

INTRODUCTION

In the United States, 12.2% of women between the ages of fifteen and forty-nine have utilized infertility services to get or stay pregnant. (1) The nature of infertility treatment as either essential or non-essential came under heavy debate in the medical field at the beginning of the COVID-19 pandemic. (2) Ample data affirms that stress plays a factor in the success of fertility treatment. (3) However, many providers, responding to the guidance of their professional society, paused fertility treatment during the pandemic, adding stress and uncertainty to the fertility process. (4)

Disagreement amongst infertility care providers in the United States led to open debate regarding the essential or non-essential nature of fertility treatment. (5) The World Health Organization reiterates that infertility is a disease and that women should maintain control of their reproductive planning, even during a healthcare crisis. (6) Many employers recognize the essential nature of fertility treatment and are offering fertility benefits as a means of retaining employees during the pandemic driven worker shortage. (7)

Part I of this Article begins with an examination of non-essential healthcare that was ceased during the beginning months of the pandemic. Part II summarizes through each stage of the American Society of Reproductive Medicine's guidance on treatment during the pandemic. Part III introduces the unique impacts that the pandemic had on both infertility patients and on infertility care providers. This Article concludes in Part IV with the recommendation that fertility care be classified as essential care for all future purposes.

I. PAUSE OF NON-ESSENTIAL HEALTHCARE DURING THE PANDEMIC

In March of 2020, the reality of a global pandemic struck the United States healthcare system in multiple ways. Most notably, hospitals were tasked with preparing for the large volumes of critically ill patients whose influx was predicted to strain the medical system. (8) The increased case volume during the pandemic spawned discussions of resource allocation including hospital beds, critical care space, personal protective equipment, ventilators, and staff shortages. (9) Two of the most common responses within the healthcare system were to cancel or postpone non-urgent care and to move as much patient contact to telemedicine as possible. (10) On April 7, 2020, the Centers for Medicare and Medicaid Services (CMS) released guidance on treatment according to level of acuity. (11) For all medical treatment and services that are considered low acuity, CMS recommended either postponing or using remote interactions such as telehealth. (12) The American Hospital Association (AHA), citing the tiered framework presented by CMS, gave guidance on elective surgeries. (13) Both CMS and the AHA recommended leaving the decision in the hands of the local healthcare systems who could best factor the regional resources and COVID-19 outbreak status in their area. (14) The American College of Surgeons used the St. Louis University Elective Surgery Acuity Scale to categorize procedure acuity levels. (15) The St. Louis Scale defines low and intermediate acuity procedures as those that can be delayed safely, meaning postponement of the procedure would not present a substantial risk to the patient. (16) The American College of Surgeons advised that procedures of low and intermediate acuity should be considered for postponement in conjunction with the patient's individual medical needs and the regional status of the pandemic at the time. (17) The United States was not alone in this recommendation; there was a global consensus among healthcare providers that postponing elective and non-essential procedures was appropriate. (18)

Throughout the field of medicine there were active discussions about providing non-essential treatment in different specialties, often focused on elective surgery. (19) On April 17, 2020, the American College of Surgeons, the American Society of Anesthesiologists, the Association of periOperative Registered Nurses, and the American Hospital Association released a joint statement titled Roadmap to Resuming Elective Surgery after COVID-19 Pandemic. (20) This statement acknowledged that, under the guidance of CMS and the U.S. Surgeon General, many non-essential surgical procedures were postponed at the outset of the pandemic. (21) This statement also recognized that after the first wave of the pandemic, the American healthcare system would potentially experience an overwhelming caseload to catch-up the backlog of postponed patients. (22) The drafters intended for the joint statement to provide guidance for practitioners regarding when it will be appropriate to resume procedures and how to do so safely. (23) The joint statement relied heavily on the status of the COVID-19 pandemic in different localities, advising practitioners to wait for a fourteen-day reduction in local cases, guidance from local public health authorities, and facility staffing capabilities to determine when non-essential procedures should resume. (24) The joint statement goes on to provide guidance on how to resume surgical procedures safely, with an emphasis on COVID-19 testing, appropriate personal protective equipment (PPE) for the healthcare team, case prioritization, and scheduling. (25)

During the first twelve weeks of the pandemic, it is estimated that more than 28 million surgical procedures were cancelled worldwide. (26) To catch up on missed surgeries, surgical volume would have to be increased by twenty percent beyond standard operating levels for forty-five weeks. (27) These staggering numbers raised the question of how and when to resume non-essential services while simultaneously working to protect patients from nosocomial infection, practitioners from exposure and potential infection, and the needs of the greater healthcare system during a pandemic.

Concern for patient wellbeing in the face of a novel infectious virus must be considered when resuming operative practices for non-essential care. At this time in the pandemic, it was known that the virus transmitted via aerosol, but it was not yet proven that fomite transmission was insignificant. (28) Contracting COVID-19 in the perioperative stage was understood to have a high potential for mortality, (29) but the direct effects of COVID-19 on the surgical patient were unknown. (30) Some pathological changes in COVID-19 patients were known to lead to negative outcomes among surgical patients. (31) Negative outcomes included inflammatory responses, (32) coagulopathy, (33) and single or multiple organ failure. (34) Despite these risks, a resumption of surgical services was deemed appropriate. (35)

Though healthcare practitioners know that their chosen profession contains some level of inherent risk, appropriate precautions can minimize that risk. Healthcare practitioners with appropriate personal protective equipment (PPE) are at an 11.6% greater risk of testing positive for COVID-19 than the general population, (36) while those without access to appropriate PPE are at a 23% greater risk of testing positive for COVID-19. (37) In addition, healthcare workers have been found to be seven times more likely to have severe infection than other non-essential workers. (38) One research group postulates that there is a unique and increased risk of exposure for all members of the surgical care team, and it should therefore be assumed that the entire operating room is contaminated. (39) The researchers recommend an approach to minimize this risk which includes communicating frequently, wearing effective personal protective equipment, adopting COVID-19 specific surgical techniques, and donning and doffing using a buddy system. (40) The United States Centers for Disease Control offers guidance on the PPE that should be used, and how to use it. (41) A joint statement by British medical societies--including the Association of Anaesthetists, the Centre for Perioperative Care, the Federation of Surgical Specialty Associations, the Royal College of Anaesthetists and the Royal College of Surgeons of England--offered strategies for how to manage surgery in patients previously infected with COVID-19. (42) The World Health Organization also published guidelines on the use of PPE during the pandemic. (43)

When resuming non-essential surgery, factors to be considered must include the current COVID-19 burden on local health systems, and consequently, limited staffing resources. Nurses with experience in either anesthesia or the operating room have skills that are transferable to the critical care nursing necessary for COVID-19 patients. (44) During times of high COVID-19 infection rates, nurses assigned to surgical teams performing elective procedures, may need to be temporarily re-assigned to care for COVID-19 patients. (45) In addition to staffing considerations, healthcare systems must consider the financial ramifications of cancelling elective surgeries, which are often very lucrative and a large portion of a facility's anticipated revenue. (46) According to a 2020 study, elective surgical procedures are responsible for 78% of the total gross surgical revenue, both inpatient and outpatient. (47) Additional research demonstrates that the need to provide acute care postoperatively to patients receiving elective surgeries is consistent and predictable. (48) Thus, resuming non-essential surgeries both provides financial stability for individual healthcare entities and allows those entities to engage in contingency planning.

There are a variety of considerations in stopping and restarting non-essential surgical procedures during a pandemic. Some factors to consider include a patient's desire for the procedure and the healthcare facility's ability to provide the procedure safely, while minimizing risk of COVID-19 transmission to both the patient and the providers. Other systemic factors include drawing resources from the greater healthcare system, the current burdens placed on that healthcare system by the pandemic, and the financial burdens of restricting income to the greater healthcare system. The decision to resume non-essential surgical procedures must be made at the local institutional and provider levels, with input from public health authorities best familiar with the current state of the pandemic in that specific region.

II. FERTILITY CLINIC CLOSURE AND TREATMENT GUIDANCE DURING THE PANDEMIC

On March 11, 2020, Tedros Adhanom Ghebreyesus, the Director-General of the World Health Organization, gave a public speech in which he declared COVID-19 to be upgraded to a pandemic. (49) He announced that there were more than 118,000 cases in 114 countries and 4,291 people had already died of the coronavirus. (50) On March 13, 2020, President Donald J. Trump, in White House Proclamation 9994, declared a national emergency in accordance with the National Emergencies Act. (51) On March 17, 2020 the American Society for Reproductive Medicine (ASRM) released an advisory titled "Patient Management and Clinical Recommendations During the Coronavirus (COVID-19) Pandemic," which offered guidance on five key issues in the area of fertility treatment during the COVID-19 pandemic: (52)

(1) Suspend initiation of new treatment cycles, including ovulation induction, intrauterine inseminations (IUIs), in vitro fertilization (IVF) including retrievals and frozen embryo transfers, as well as non-urgent gamete cryopreservation.

(2) Strongly consider cancellation of all embryo transfers whether fresh or frozen.

(3) Continue to care for patients who are currently "in-cycle" or who require urgent stimulation and cryopreservation.

(4) Suspend elective surgeries and non-urgent diagnostic procedures.

(5) Minimize in-person interactions and increase utilization of telehealth. (53)

The ASRM developed a group of reproductive endocrinology and infertility specialists that comprised the Coronavirus/COVID-19 Task Force (Task Force). (54) This Task Force drafted the guidance document and its subsequent iterations, and released them with the approval of the ASRM Executive Committee. (55) The Task Force expressed the competing interests of proactively protecting healthcare systems' needs during a pandemic and the time-sensitive nature of pregnancy. (56) In addition to treatment and travel for treatment, the guidance document discusses practice management, including laboratory management and the psychological health of both clinic staff and patients. (57)

On March 19, 2020, the European Society of Human Reproduction and Embryology (ESHRE) released its first statement on fertility treatment during the pandemic, which mirrored the guidance from the ASRM. (58) ESHRE advised caution in proceeding with pregnancy based on the limited knowledge of how COVID-19 infection affects pregnancy. (59) The guidance document, with recognition of the overloaded healthcare system and an obligation to not add additional stress in that system, echoed the statements from ASRM's Task Force. (60)

At the time of this Article's publication, the Task Force has published twenty updates to its original guidance document. (61) Each update provided guidance based on the scientific knowledge and understanding of the pandemic at that given time, as well as periodic commentary on the essential nature of fertility care. (62) The remainder of this section details the individual guidance document updates and concludes with a summary in table format. (63)

The first update covered the period of time from March 30, 2020 through April 13, 2020. (64) This update affirmed the five key issues detailed in the original guidance document. (65) The Task Force relied on emerging scientific data in the literature and on governmental regulations, in addition to guidelines from other medical organizations such as the American Ambulatory Surgery Association and the American College of Surgeons. (66) The Task Force identified elective surgery as "surgery that can be delayed for a period of time without undue risk to the patient," and stated that "infertility care is not elective." (67) The Task Force also advised that as pandemic restrictions continued, practitioners must work in collaboration with their patients to determine what is urgent versus non-urgent care. (68)

The second update covered the period of time from April 13, 2020 through April 27, 2020. (69) At the time of this update, there were 1.9 million COVID-19 cases globally, more than 570,000 of which were in the United States. (70) Further, there were no available antivirals; molecular testing for the presence of the disease was expanding, but serologic testing was not yet available, and vaccines were predicted to be twelve to eighteen months away. (71) The second update again affirmed the five key issues detailed in the original guidance document and also acknowledged that an increasing number of jurisdictions were "appropriately recognizing infertility care as essential services." (72) The Task Force again acknowledged the risks of exposure for both staff and patients and urged analysis of the risks and benefits on an individual basis. (73)

The third update covered the period of time from April 24, 2020 through May 11, 2020. (74) At the time of this update there were 2.7 million COVID-19 cases globally, and more than 880,000 cases in the United States. (75) The Task Force reaffirmed their prior statement that fertility care is essential care, but expressed the need for a balance between providing fertility care and the risk of contracting COVID-19. (76) The third update was the first to give guidance on a gradual and judicious resumption of reproductive healthcare in the United States. (77) The Task Force advised that local situations be assessed for key criteria. (78) Local cases should show sustained reduction and hospitals in the area should not be resorting to crisis standards to safely treat the patient population. (79) Additionally, each individual practice must prepare to limit the risks to patients, staff, and providers. (80) The third update detailed performance standards and documented risk assessment as well as risk mitigation. (81) It relied on guidance from multiple authorities, including the Center for Disease Control (CDC), (82) the Occupational Health and Safety Administration (OSHA), (83) and the Society for Assisted Reproductive Technology (SART). (84) The update also introduced the discussion of PPE. (85)

The fourth update covered the period of time from May 11, 2020 through June 8, 2020. (86) At that time, there were nearly four million COVID-19 cases globally, over 1.3 million of which were in the United States. (87) In this update, the Task Force acknowledged the lack of vaccines and treatment for SARS-CoV-2 infection, as well as the unpredictability of the natural ebb and flow of infection rates. (88) Given the lack of knowledge about how fertility treatment and early pregnancy were affected by SARS-CoV-2 infection, the Task Force, on behalf of the ASRM, encouraged both patient and practitioner participation in research. (89) In addition, the ASRM added questions on COVID-19 to the Clinic Outcome Reporting System (CORS) that is managed by SART. (90) The fourth update also offered information on the state of testing for COVID-19, as well as an update on what was known about COVID-19 and pregnancy at that time. (91) Limited information showed that mothers infected with COVID-19 who deliver full term did well. (92) Contrarily, mothers infected with COVID-19 who were not yet full term could experience premature labor and early delivery. (93) There were no observed instances of vertical transmission from mother to fetus of COVID-19, but it was still believed to be possible. (94) There was no evidence that indicated how a SARS-CoV-2 infection during the first and second trimesters would affect the mother, fetus, or resulting child. (95) This is the first guidance document in which the Task Force addressed third-party reproduction, specifically gamete donors and gestational carriers. (96) Testing for SARS-CoV-2 was limited and gamete transmission information was ambiguous. (97) Clinics were advised to incorporate additional counseling into their standard practices for donors, carriers, and intended parents. (98) Finally, this iteration of the guidance document provided an updated PPE chart for different fertility treatments. (99)

The fifth update covered the period of time from June 8, 2020 through July 6, 2020. (100) At that time, there were 6.5 million COVID-19 cases globally, over 1.9 million of which were in the United States. (101) This was the first update to address the presence of partners during fertility treatment. (102) The Task Force recommended that only the individual receiving treatment be present in the treatment room, but it advised that other means of participation, such as telephone or video, should be considered for the patient's partner. (103) This update focused on the resumption of reproductive surgery, including oocyte harvest, in accordance with the Society for Reproductive Surgeons. (104) The Task Force reiterated its previously stated recommendations concerning local disease prevalence, patient and staff PPE, and COVID-19 testing. (105)

The sixth updated guidance document covered the period of time from July 10, 2020 through August 10, 2020. (106) At the time, the United States saw a 90% increase in cases from the prior four weeks, bringing cases in the United States to surpass three million. (107) This update again addressed third-party reproduction but focused on new studies that provided information regarding pregnancy and COVID-19. (108) A number of studies cited by the Task Force demonstrated that pregnant women were at greater risk for hospitalization, intensive care unit stay, mechanical ventilation, cesarean section, and ultimately death if determined to be SARS-CoV-2 positive in the late-second or third trimesters. (109) There was still no data on the effects of SARS-CoV-2 infection during the first and second trimesters. (110) Vertical transmission remained possible but the data was unclear and conflicting. (111)

The seventh update covered the period of time from August 10, 2020 through September 7, 2020; (112) the eighth update covered the period of time from September 8, 2020 through October 5, 2020; (113) and the ninth update covered the period of time from October 6, 2020 through November 9, 2020. (114) These three updates offered no substantial changes nor additional relevant information.

The tenth update was published on November 17, 2020. (115) At that time, there were nearly 11 million cases of COVID-19 in the United States. (116) In this update, the Task Force addressed clinic management in the face of the current surge while urging clinics to re-evaluate their risk and mitigation strategies. (117) It discussed details of the CDC recommendations for isolation and quarantine, as well as the CDC's definition of "close contact." (118) In addition, the guidance provided guidelines for previously infected healthcare workers to return to work, addressing both a symptom-based strategy and a test-based strategy. (119) It also advocated again for the use of telehealth as a means of protecting both patients and practitioners. (120) The Task Force addressed the new information regarding COVID-19 illness, fertility care, and pregnancy. (121) Though the evidence was limited, data at the time showed that the COVID-19 virus was not thought to infect gametes or embryos. (122) Most notably, two meta-analyses found that pregnant women are at significantly increased risk for admission to intensive care units and ventilatory support compared to their age-adjusted non-pregnant peers. (123) On December 11, 2020 the Food and Drug Administration (FDA) issued an Emergency Use Approval (EUA) for the Pfizer-BioNTech COVID-19 Vaccine for use in people who are sixteen years of age and older. (124)

The eleventh update to the Task Force's guidance was published on December 16, 2020. It stated that the "Task Force does not recommend withholding the vaccine from patients who are planning to conceive, who are currently pregnant, or who are lactating." (125) This statement concurred with ASRM's peer societies, including the American College of Obstetrics and Gynecology (126) and the Society for Maternal-Fetal Medicine. (127) This recommendation was based on the identification of pregnancy as a factor in severe COVID-19 disease (128) and on the fact that the vaccine does not contain live virus.

On December 17, 2020, the FDA issued an EUA for the Moderna COVID-19 vaccine for people ages eighteen and older.

The twelfth update to the Task Force's guidance was published on January 18, 2021. (129) By that time, COVID-19 cases in the United States exceeded 24 million. (130) This guidance addressed long-term effects of COVID-19, new variants of the virus, and a statement of confirmed scientific information that the Task Force termed 'truths' regarding both testing and vaccines. (131) In this document, the Task Force addressed delaying elective surgical procedures after COVID-19 infection, provided information on vaccine hesitancy, and called upon healthcare providers to be leaders by encouraging vaccination. (132)

The thirteenth update was published on February 22, 2021. (133) At this time, known COVID-19 cases in the United States exceeded 28 million and some estimates suggested actual infections were closer to 100 million people. (134) The guidance document reiterated previously stated concerns about increased risk for severe disease if COVID-19 infection occurred during pregnancy. (135) Concerns included increased risk of pre-term labor, (136) fetal death, (137) and placental injury. (138)

The fourteenth update to the Task Force's guidance was published on March 23, 2021. (139) The Task Force used this document to combat vaccine hesitancy and misinformation. (140) The fifteenth update was published on May 19, 2021, (141) and it reiterated the need for vaccination, masking, and testing. (142) The sixteenth update was published on July 23, 2021, (143) and it provided a summary of reproductive facts with regards to the vaccine. (144) The seventeenth update was published on August 20, 2021, (145) and it provided another summary on vaccination and vaccine hesitancy. (146)

The Task Force published its eighteenth update on November 12, 2021. (147) The Task Force used this update to again address vaccination and fertility care. (148) In addition to restating the need to vaccinate pregnant women due to the increased risk of severe COVID-19 during pregnancy, the Task Force overtly stated that, "[t]here are no fertility-related reasons for a vaccine exemption." (149) In a discussion of requests for medical letters of exemption, the Task Force again reiterated that, "neither infertility nor pregnancy are reasons for exemptions." (150) This update also stated that pregnant and recently pregnant patients should receive the vaccine booster shot on schedule. (151)

The Task Force published its nineteenth updated guidance document on December 17, 2021. (152) At that time, the Omicron variant was surging, and the United States had seen more than 50 million cases of COVID-19. (153) The Task Force again addressed the challenges to the American healthcare system and the issue of fertility surgery. (154) It stated that delaying surgical fertility treatment may have negative consequences for a patient's overall fertility outcomes. (155) It also advised that surgical procedures performed in response to pain or bleeding are essential treatment based on the joint statement produced by gynecologic societies. (156) The Task Force highly recommended vaccination and booster shots for all individuals who are pregnant or seeking to become pregnant, (157) in accordance with the ASRM, ACOG, SMFM, and CDC. (158) The nineteenth update concluded with a brief discussion of the current treatments for COVID-19, including monoclonal antibodies and oral antiviral therapy. (159)

On April 22, 2022 the Task Force published its twentieth and final update to the guidance document and titled it, "Summary Statement Two Years Out." (160) This update provided no new information but rather reviewed and summarized core recommendations presented over the last two years including epidemiology, vaccination and telemedicine use. (161) This is followed by a summary of how to continue fertility practice operations in the context of endemic COVID-19 including surveillance, screening, action and staying informed. (162) The conclusion notes that this will be the last scheduled update but that the Task Force will re-convene if necessary. (163)

III. IMPACT & PERSPECTIVES ON FERTILITY CLINIC CLOSURES

Fertility clinic closures at the beginning of the pandemic, while recommended by the American Society of Reproductive Medicine (ASRM), had a ripple effect in the field of reproductive medicine. Though the pause on fertility care may have prevented healthcare-acquired infections in patients and clinic staff, it created significant psychological strain (165) and potentially led to negative impacts on treatment outcomes, particularly for women of advanced maternal age. (166) Early data from the SART's Clinic Outcome Reporting System indicated that approximately the same number of in vitro fertilization (IVF) cycles were run in 2019 and 2020, leading to the conclusion that cycles may have been delayed but not cancelled. (167) Given the steep increase in women freezing their eggs for fertility preservation during the pandemic, (168) it is also possible that the similar quantity of IVF cycles could simply indicate a shift in fertility clinic clientele. An Italian study with 1,482 participants found that just over one third (37.3%) who were planning to have a child changed their minds in the pandemic in favor of not procreating, while only 11.5% of those who previously did not intend to have a child changed their minds in favor of procreation. (169) It is therefore possible that those whose cycles were cancelled early in the pandemic never completed their fertility treatment, and the patient volume was replaced with fertility preservation patients.

At its most fundamental level, fertility treatment comes with an inherent uncertainty that often leads to anxiety and depression. (170) The uncertainty introduced by the pandemic combined with the pause of fertility care added additional layers of uncertainty to an already stressful process. This additional stress was demonstrated in a study that found that 50% of survey respondents had fertility treatments cancelled or postponed, and nearly three quarters of these respondents expressed some level of increased distress. (171) Their distress was evidenced by severe sleep disturbances, feeling anxious, mood disturbances, and having depressive thoughts. (172) A similar study found that a number of factors played into the severity of a patient's emotional distress. (173) More distress was exhibited by older patients and single patients. (174) Additionally, patients who expressed that suspending treatments was unjustified exhibited greater distress and felt a sense of helplessness. (175) The results of yet another study concurred that a sense of loss of control was derived from both the treatment delays of unknown length and the questions these delays raise about the individual's future procreation. (176) The study reported that almost all respondents experienced negative emotions that outweighed positive emotions, demonstrating increased stress, frustration, and worry. (177) In discussions of postponing fertility treatment, some point out that the element of choice was removed from the patient's control. (178) In other words, clinics ceased to offer fertility care, which prevented each individual patient from factoring for themselves where the crux of the balance is between delaying their fertility care and risking nosocomial infection.

The additional stress that the pandemic added to fertility treatment was managed in a variety of ways by different patients. Some couples sought professional counseling through virtual platforms. (179) Others resorted to social media to share their distress, seeking updates on clinic openings and closings, forming support webinars, and engaging with fellow fertility patients through Instagram Live. (180) A study from the Mayo Clinic found that fertility patients with interrupted care identified an increased need for psychological support. (181) Experts in the field confirmed the Mayo Clinic's findings, indicating that patients with delayed treatment experienced both increased anxiety and increased emotional distress as compared to fertility patients who did not experience delays in treatment. (182) They further found that the psychological effects were more significant in patients with longer histories of infertility, and they ultimately concluded that the psychological consequences of postponed fertility care due to the pandemic must not be undervalued. (183) Another study identified the five most frequently used coping skills by fertility patients whose treatment was on hold during the pandemic. (184) These five skills were, "establishing a daily routine, going outside regularly, exercising, maintaining social connection via phone, social media or Zoom and continuing to work. (185)

For many, the distress of pausing fertility treatments was compounded by the inequitable distribution of clinic closures and durations of closure. The guidelines published by ASRM were merely guidelines. (186) As a professional advisory body, the ASRM has no ability to enforce its guidance in the professional sphere beyond collegial peer-pressure. (187) This inability to enforce the ASRM guidance resulted in significant variability of infertility treatment between clinics and regions. For example, at one extreme, every fertility clinic in the city of Cincinnati ceased providing care entirely for up to twelve weeks at the beginning of the pandemic. (188) At the other extreme were organizations like Reproductive Medical Associates, which operates nineteen fertility clinics in the United States, that declared its facilities would stay open and operate at full capacity. (189) Many found a middle ground of practice. For example, organizations like the Colorado Center for Reproductive Medicine, with ten fertility centers in the United States and two in Canada, opted to continue egg retrievals and gamete and embryo cryopreservation, but paused embryo and sperm transfers. (190) In other words, they continued with fertility preservation but did not perform procedures intended to initiate pregnancy. Some clinics were creative in their methods of providing care. The Center for Human Reproduction categorized certain cases as urgent, specifically women over forty years of age, women with diminished ovarian reserve, and women with impending cancer treatments, and proceeded with their care. (191) Additionally, the Center for Human Reproduction initiated an "Online Second Opinion Program" designed to provide review of individual patient cases in preparation for restarting fertility when the pandemic allowed. (192) This varied approach to clinic management during the beginning of the pandemic left many patients wondering why some could access continued fertility care while others could not. (193)

Practitioners have also exhibited varied responses to the initial guidance released by ASRM's Task Force. Most notable was the formation of the Fertility Providers Alliance (the "Alliance") to provide an alternative association for fertility specialists. (194) The Alliance, "was established by providers of reproductive medicine on behalf of the tens of thousands of patients [they] collectively serve." (195) Its "goals are to expand access to care, deliver high quality fertility services, and continuously advocate for [its] patients." (196) The Alliance is comprised of over 425 fertility care providers, representing nearly fifty medical practices, including the large fertility clinics such as Boston IVF and Reproductive Medicine Associates. (197) The members section of the Alliance's website has recruiting statements for fertility provider membership that solicit members of, "the reproductive medicine field to join [its] alliance and help [it] continue to give a stronger voice to [its] patients." (198) The Alliance also formed a task force to address the issue of fertility center operations during the beginning of the pandemic. (199) Members of this task force include prominent reproductive endocrinologists, such as a co-founder of Boston IVF, the director of NYU Langone Fertility Center, the founder and medical director of Colorado Center for Reproductive Medicine, the co-founder of Shady Grove Fertility, and the chief executive officer of Reproductive Medical Associates. (200)

On April 2, 2020 the Alliance's Task Force released the first of two public statements regarding the provision of fertility care during the pandemic. (201) The Task Force stated that it shared with the ASRM their concerns about the recommendations made in the initial guidance document, (202) while simultaneously applauding the ASRM for recognizing infertility as a disease. (203) On April 24, 2020, the Alliance released a second public statement, which included the "FPA Toolkit." (204) The FPA Toolkit is intended to be used alongside resources provided by other national health authorities, and includes general COVID-19 consent forms, general disclaimers, and strategies for practicing ART during COVID-19. (205) These documents, along with the press release, show a clear intent on behalf of the Alliance to guide fertility clinics in providing the full range of reproductive care during the pandemic. (206) No further advisories or guidance documents have been released by the Alliance and its website has not been updated since. (207)

The Alliance wrote an undated public letter to Ricardo Azziz, the then Chief Executive Officer of ASRM and the ASRM Task Force, which was not published on the Alliance website. (208) A copy of this letter was published by Dr. Norbert Gleicher, the Medical Director of the Center for Human Reproduction, in his online blog titled, The Voice. (209) In its letter, the Alliance requested to discuss the ASRM Task Force's Guidance Document. (210) They provided an agenda compromised of the following three issues, "first, the actual public health burden created by the continuation of fertility care: second, the classification of infertility treatment as 'non-urgent' or elective; and third, the harmful consequences of an indeterminate delay in access to care." (211) The letter went on to discuss details of these three topics, explaining that most fertility care is provided in clinics and independent surgical centers, and therefore, their continued operation would not impact hospital capacity during the pandemic. (212) Dr. Gleicher goes on to interpret the meaning and intent of the Alliance's letter, denoting a financially driven intent from private sector fertility care. (213) He noted that the Alliance was formed, and its task force was created, specifically to counter the ASRM's Task Force and refers to that as, "a quite frightening scam the investor-driven IVF-world is trying to pull off." (214) Gleicher also offered his own interpretation of the ASRM's Task Force Guidance. (215) He differentiates his clinic as an IVF center that treats older patients (citing that the average fertility patient age is thirty-six, although the Center for Human Reproduction identifies the average fertility patient age as forty-three) and patients with premature ovarian aging. (216) He interprets his patients' treatment as urgent because these conditions make a three month delay in treatment due to the ASRM guidance critical for his patients. (217) He goes on to state that other clinics' primary populations are younger and therefore would not meet such a qualification. (218) In a second blog post, Dr. Gleicher acknowledged the tone change between the first and second press releases from the Alliance. (219) He credited this change to the shift from the identified Alliance representative being the CEO of a large IVF company to being two physicians representing IVF clinics. (220) The sentiment of concern about the financial motivations of investment-driven decision making is neither new nor confined to the bounds of the pandemic. (221)

Fertility care providers are divided regarding whether treatments should have been paused at the beginning of the pandemic. (222) The sheer volume of reproductive endocrinologists who endorsed either the ASRM or the Alliance shows the rift in the medical community regarding the urgency and essential nature of different fertility treatments. (223) Although there is some consensus on fertility preservation for cancer patients, (224) beyond that, there is no agreement. (225) For example, the results of a 2020 study demonstrated that pausing fertility care for one month in the United States would result in 369 fewer live births, (226) while another study concluded that pausing fertility treatment for 180 days did not alter the live-birth rate. (227) From contradicting studies to conflicting professional opinions based on training and experience, it is easy to see how the fertility community fractured into two separate professional societies as the pandemic exposed the unique challenges of providing healthcare during a global public health emergency.

IV. POLICY: FERTILITY CARE IS ESSENTIAL CARE

The COVID-19 pandemic provided many lasting lessons in the field of healthcare, ranging from resource allocation to public health structure and prioritization. The field of infertility medicine is no exception to these lessons learned, the most valuable of which is the need to clarify infertility as a disease and therefore infertility care as essential healthcare. The need to consider infertility care as essential is emphasized by the implications of the American Society of Reproductive Medicine's guidance documents. (228) The newly formed Fertility Providers Alliance stresses the same need to classify infertility care as essential. (229) As additional waves of the COVID-19 pandemic or other public health crises befall society, it is the obligation of healthcare systems to recognize the essential role that time plays in the treatment of a fertility patient. Postponing treatment has the potential to undermine the efficacy of that treatment and to result in suboptimal outcomes. These postponements have negative ramifications on the mental health of the patients seeking treatment. (230) Furthermore, postponing treatment raised serious concerns of treatment dropout without return, (231) though there is evidence of increased fertility preservation patients. (232)

Within the field of medicine there are a plethora of definitions for essential care. As a result, what qualifies as essential care during a time of crisis varies by perspective. Many of the arguments in favor of postponing non-essential care were founded in the need to protect the greater healthcare system and the ability to respond to the influx of pandemic patients. (233) Pausing non-essential care that draws from resources which may be re-allocated to treat pandemic patients is logical to preserve those resources. (234) For example, significant medical procedures such as joint replacements, spinal fusions, and bariatric procedures were temporarily paused in most cases because the resources necessary to perform these invasive procedures overlap with the resources necessary to treat the increasing number of COVID-19 patients. (235) These resources included critical care nurse staff, ventilators, and hospital bed space. (236) Infertility care, even at its most invasive stages such as egg harvest or hysteroscopy, does not utilize the same hospital resources. (237) In many cases, private fertility clinics either have their own operating suites or contract with outpatient surgical centers. Even in most academic infertility practices, the operating and recovery rooms are separate from critical care rooms used for high acuity patients. Therefore, it is not necessary to pause fertility treatment to preserve resources in the greater healthcare system.

The practice of infertility, particularly egg harvest procedures, is best analogized to ophthalmic care, which continued in many cases throughout the pandemic. (238) Though the American Academy of Ophthalmology recommended pausing all care that was not urgent or emergent, it left the definition of urgent and emergent to the individual ophthalmologist. (239) Both ophthalmic and infertility care are timely and life altering for the patient receiving the treatment.

In addition, both surgical interventions are minimally invasive, performed under a range of light or twilight sedation, requiring minimal supervision during recovery. Most significantly, with the exception of some academic practices, both cataract surgery and egg harvest are performed at facilities outside a hospital that would not otherwise be used for critical patients. Given that cataract surgery was considered essential and continued throughout the pandemic for many, infertility interventions such as egg harvest should have been treated the same way.

The arguments to pause infertility treatment as non-essential had two origins. The first argument was to protect and preserve limited healthcare resources during a time of crisis with the looming threat of systemic overload. Given the independent nature of infertility care and the lack of overlap with critical care, this argument is not valid. The second argument was concern for the safety of both the patients and practitioners, (240) but it stands to reason that if patients receiving care considered to be essential can be treated in a safe environment, all patients can receive care under an umbrella of safety. (241) Furthermore, given that the next crisis that limits the provision of infertility care may not be a communicable disease but rather a natural disaster or military conflict, it is important to establish that infertility care is essential and should continue.

The lines between essential and non-essential care are poorly defined and blurred by the bias of the party giving the definition. Organizations internal to the field have an inherent bias, hence the fracture between the ASRM and the Alliance. There should be a national governing body, such as the American Medical Association, that determines which areas of healthcare are essential and which are not. This would allow for universal application of rules in a time of crisis, removing some of the ambiguity that caused additional moral distress from the kaleidoscope of treatment practices during the COVID-19 pandemic.

It should be the goal of all professionals in the field of fertility medicine and their professional organizations to establish infertility care as essential medicine within the greater field of healthcare to protect future patients seeking critical and time-sensitive fertility treatment.

CONCLUSION

In the early months of the COVID-19 pandemic, in an effort to protect the larger healthcare system, services deemed to be non-essential were halted with indeterminate duration. The field of infertility medicine was one such area of healthcare, resulting in the temporary pause of fertility treatments for many patients. The inability for many to access fertility treatment added significant psychological strain to an already high-stress process and for women of advanced maternal age or diminished ovarian reserve, potentially led to a suboptimal outcome. Infertility care providers publicly expressed disagreement regarding the status of fertility treatment as essential and thus compounded the distress patients experienced by implementing inequitable and disproportionate pauses in practice. Moving forward all professionals who practice infertility medicine should uniformly present fertility care as essential medicine in the context of the field of healthcare.

Rebecca S. Feinberg (*)

(*) Rebecca Feinberg is a Teaching Associate Professor in the College of Science and Health and a Lecturer in Law in the College of Law at DePaul University. Thank you to my colleagues Michael Sinha of Saint Louis University School of Law and Danielle Pacia of the Hastings Center for reading and providing feedback on drafts of this article. A huge thank you to the Drexel Law Review team, specifically Kelcie Ouillette, for the invaluable feedback she provided on multiple drafts of this article.

(1.) See Infertility, CDC, https://www.cdc.gov/nchs/fastats/infertility.htm (last visited June 4, 2022).

(2.) See Shailin A. Thomas & Arthur L. Caplan, Are Infertility Treatments 'Essential'? How To Ethically Determine What Kind of Care Must Go On Amid Covid-19, STAT (Apr. 30, 2020), https://www.statnews.com/2020/04/30/infertility-treatments-essential-or-not-during-covid-19-pandemic/; see also Natalie Lampert, Fertility Clinics Stay Open Despite Unclear Guidelines, N.Y. TIMES, https://www.nytimes.com/2020/05/01/parenting/fertility-clinics-coronavirus.html (May 4, 2020).

(3.) Shilpa Prasad, Meenakshi Tiwari, Ashutosh N. Pandey, Tulsidas G. Shrivastav & Shail K. Chaube, Impact of Stress on Oocyte Quality and Reproductive Outcome, 23 J. BIOMEDICAL SCIS. 36 (2016); Kristin L. Rooney & Alice D. Domar, The Relationship Between Stress and Infertility, 20 DIALOGUES CLINICAL NEUROSCIENCE 41, 42 (2018).

(4.) See Gabriela Weigel, Alina Salganicoff & Usha Ranji, Potential Impacts of Delaying "Non-Essential" Reproductive Health Care, KAISER FAM. FOUND. (June 24, 2020), https://www.kff.org/womens-health-policy/issue-brief/potential-impacts-of-delaying-non-essential-reproductive-health-care/.

(5.) See Maria do Carmo Borges de Souza, Hitomi Nakagawa, Paulo Franco Taitson, Emerson Barchi Cordts & Roberto Azevedo Antunes, Management of ART and COVID-19: Infertility in Times of Pandemic. What Now?, 24 JBRA ASSISTED REPROD. 231, 231 (2020).

(6.) WHO, WHO CONSOLIDATED GUIDELINE ON SELF-CARE INTERVENTIONS FOR HEALTH: SEXUAL AND REPRODUCTIVE HEALTH AND RIGHTS 140, 5-6 (2019), https://apps.who.int/iris/bitstream/handle/10665/325480/9789241550550-eng.pdf.

(7.) See, e.g., Megan Leonhardt, Companies Are Scrambling to Get Ahead of the Great Resignation by Beefing Up Fertility Benefits. Here's What They're Offering., FORTUNE (Jan. 31, 2022, 3:53 PM), https://fortune.com/2022/01/31/companies-fertility-benefits-great-resignation/.

(8.) See OFF. OF INSPECTOR GEN., DEP'T OF HEALTH AND HUM. SERVS., HOSPITAL EXPERIENCES RESPONDING TO THE COVID-19 PANDEMIC: RESULTS OF A NATIONAL PULSE SURVEY MARCH 23-27, 2020, at 5 (2020), https://oig.hhs.gov/oei/reports/oei-06-20-00300.pdf [hereinafter HOSPITAL EXPERIENCES].

(9.) See Ezekiel J. Emanuel, Govind Persad, Ross Upshur, Beatriz Thome, Michael Parker, Aaron Glickman, Cathy Zhang, Connor Boyle, Maxwell Smith & James P. Phillips, Fair Allocation of Scarce Medical Resources in the Time of Covid-19, 382 NEW ENG. J. MED. 2049, 2050 (2020); HOSPITAL EXPERIENCES, supra note 8, at 1-5.

(10.) See Lisa M. Koonin, Brooke Hoots, Clarisse A. Tsang, Zanie Leroy, Kevin Farris, B. Tilman Jolly, Peter Antall, Bridget McCabe, Cynthia B.R. Zelis, Ian Tong & Aaron M. Harris, Trends in the Use of Telehealth During the Emergence of the COVID-19 Pandemic--United States, January--March 2020, CTRS. FOR DISEASE CONTROL AND PREVENTION (Oct. 30, 2020), https://www.cdc.gov/mmwr/volumes/69/wr/mm6943a3.htm; Hallie Golden, US Hospitals Postpone Non-Emergency Procedures Amid Coronavirus Pandemic, GUARDIAN (Mar. 25, 2020, 3:27 PM), https://www.theguardian.com/world/2020/mar/25/us-hospitals-coronavirus-pandemic-postpone-elective-surgery-procedures.

(11.) See Non-Emergent, Elective Medical Services, and Treatment Recommendations, CTRS. FOR MEDICARE & MEDICAID SERVS. (Apr. 7, 2020), https://www.cms.gov/files/document/cms-non-emergent-elective-medical-recommendations.pdf.

(12.) Id.

(13.) New Information on Elective Surgery, PPE Conservation and Additional COVID-19 Issues, AM. HOSPITAL ASS'N (Mar. 19, 2020), https://www.aha.org/system/files/media/file/2020/03/new-information-on-elective-surgery-ppe-conservation-additional-covid-19-issues-3-18-2020.pdf.

(14.) Id.

(15.) COVID-19: Guidance for Triage of Non-Emergent Surgical Procedures, AM. COLL. OF SURGEONS (Mar. 17, 2020), https://www.facs.org/covid-19/clinical-guidance/triage.

(16.) Id.

(17.) Id.

(18.) See COVIDSurg Collaborative, Global Guidance for Surgical Care During the COVID-19 Pandemic, 107 BRIT. J. SURGERY 1097, 1098 (2020); Gareth Iacobucci, Covid-19: All Non-Urgent Elective Surgery Is Suspended for At Least Three Months in England, BMJ (Mar. 18, 2020), https://www.bmj.com/content/bmj/368/bmj.m1106.full.pdf.

(19.) See Ken Wu, Craig R. Smith, Bradley T. Lembcke & Tanira B.D. Ferreira, Elective Surgery During the Covid-19 Pandemic, 383 NEW ENG. J. MED. 1787, 1787-90 (2020); Caroline V. Gona, Letter to the Editor, Cancellation of Elective Surgery During the COVID-19 Pandemic, 25 E. & CENT. AFR. J. SURGERY 33, 33 (2020); J. Wayne Meredith, Kevin P. High & Julie Ann Freischlag, Preserving Elective Surgeries in the COVID-19 Pandemic and the Future, 324 J. AM. MED. ASS'N 1725, 1725-26 (2020). For an example of such discussions in other specialties, see Thomas & Caplan, supra note 2.

(20.) See Joint Statement: Roadmap for Resuming Elective Surgery After COVID-19 Pandemic, AM. SOC'Y OF ANESTHESIOLOGISTS (Apr. 17, 2020), https://www.asahq.org/about-asa/newsroom/news-releases/2020/04/joint-statement-on-elective-surgery-after-covid-19-pandemic.

(21.) Id.

(22.) Id.

(23.) Id.

(24.) Id.

(25.) Id.

(26.) Helene Charbonneau, Segolene Mrozek, Benjamin Pradere, Jean-Nicolas Cornu & Vincent Misrai, How to Resume Elective Surgery in Light of COVID-19 Post-Pandemic Propofol Shortage: The Common Concern of Anaesthesists and Surgeons, 39 ANAESTHESIA CRITICAL CARE & PAIN MED. 593, 593 (2020).

(27.) COVIDSurg Collaborative, Elective Surgery Cancellations Due to the COVID-19 Pandemic: Global Predictive Modelling to Inform Surgical Recovery Plans, 107 BRIT. J. SURGERY 1440, 1440 (2020).

(28.) See Knvul Sheikh, Derek Watkins, Jin Wu & Mika Grondahl, How Bad Will the Coronavirus Outbreak Get? Here Are 6 Key Factors, N.Y. TIMES, https://www.nytimes.com/interactive/2020/world/asia/china-coronavirus-contain.html (Feb. 28, 2020) (providing key facts surrounding Covid-19, as it was understood in late February 2020, such as the virus's ability to spread through the air, but making no mention of fomite transmission).

(29.) Ali Aminian, Saeed Safari, Abdolali Razeghian-Jahromi, Mohammad Ghorbani & Conor P. Delaney, COVID-19 Outbreak and Surgical Practice: Unexpected Fatality in Perioperative Period, 272 ANNALS OF SURGERY e27, e27 (2020); see Shaoqing Lei, Fang Jiang, Wating Su, Chang Chen, Jingli Chen, Wei Mei, Li-Ying Zhan, Yifan Jia, Liangqing Zhang, Danyong Liu, Zhong-Yuan Xia & Zhengyuan Xia, Clinical Characteristics and Outcomes of Patients Undergoing Surgeries During the Incubation Period of COVID-19 Infection, 21 ECLINICALMEDICINE 1, 7 (2020).

(30.) See Lei et al., supra note 29, at 2.

(31.) See Chuan Qin, Luoqi Zhou, Ziwei Hu, Shuoqi Zhang, Sheng Yang, Yu Tao, Cuihong Xie, Ke Ma, Ke Shang, Wei Wang & Dai-Shi Tian, Dysregulation of Immune Response in Patients with Coronavirus 2019 (COVID-19) in Wuhan, China, 71 CLINICAL INFECTIOUS DISEASES 762, 767 (2020).

(32.) See id.

(33.) See Huan Han, Lan Yang, Rui Liu, Fang Liu, Kai-lang Wu, Jie Li, Xing-hui Liu & Cheng-liang Zhu, Prominent Changes in Blood Coagulation of Patients with SARS-CoV-2 Infection, 58 CLINICAL CHEMISTRY & LAB'Y MED. 1116, 1119 (2020).

(34.) See Tianbing Wang, Zhe Du, Fengxue Zhu, Zhaolong Cao, Youzhong An, Yan Gao & Baoguo Jiang, Comorbidities and Multi-Organ Injuries in the Treatment of COVID-19, 395 LANCET e52, e52 (2020); K. Soreide, J. Hallet, J. B. Matthews, A. A. Schnitzbauer, P. D. Line, P. B. S. Lai, J. Otero, D. Callegaro, S. G. Warner, N. N. Baxter, C. S. C. Teh, J. Ng-Kamstra, J. G. Meara, L. Hagander & L. Lorenzon, Immediate and Long-Term Impact of the COVID-19 Pandemic on Delivery of Surgical Services, 107 BRIT. J. SURGERY 1250, 1255 (2020).

(35.) Soreide et al., supra note 34, at 1255.

(36.) COPE Consortium, Risk of COVID-19 Among Frontline Healthcare Workers and the General Community: A Prospective Cohort Study, NAT'L INSTS. OF HEALTH (May 25, 2020), https://www-ncbi-nlm-nih-gov.univ-eiffel.idm.oclc.org/pmc/articles/PMC7273299/.

(37.) Id.

(38.) Healthcare Workers 7 Times as Likely to Have Severe COVID-19 as Other Workers, BMJ (Aug. 12, 2020), https://www.bmj.com/company/newsroom/healthcare-workers-7-times-as-likely-to-have-severe-covid-19-as-other-workers/.

(39.) Gabriel A. Brat, Sean Hersey, Karan Chhabra, Alok Gupta & John Scott, Protecting Surgical Teams During the COVID-19 Outbreak: A Narrative Review and Clinical Considerations, ANNALS OF SURGERY, Apr. 17, 2020, at 3.

(40.) Id.

(41.) See Personal Protective Equipment: Questions and Answers, CTRS. FOR DISEASE CONTROL & PREVENTION, https://www.cdc.gov/coronavirus/2019-ncov/hcp/respirator-use-faq.html (Apr. 9, 2022).

(42.) K. El-Boghdadly, T.M. Cook, T. Goodacre, J. Kua, L. Blake, S. Denmark, S. McNally, N. Mercer, S.R. Moonesinghe & D.J. Summerton, SARS-CoV-2 Infection, COVID-19 and Timing of Elective Surgery, 76 ANAESTHESIA 940 (2021).

(43.) World Health Org. [WHO], Rational Use of Personal Protective Equipment for Coronavirus Disease 2019 (COVID-19), WHO Doc. WHO/2019-nCov/IPC PPE_use/2020.1 (Feb. 27, 2020), https://apps.who.int/iris/bitstream/handle/10665/331215/WHO-2019-nCov-IPCPPE_use-2020.1-eng.pdf.

(44.) Nick Evans, Elective Care: Catching Up and Staying COVID-Free, 35 NURSING STANDARD 67, 67 (2020).

(45.) See id.

(46.) See id. at 67-68.

(47.) Joseph E. Tonna, Heidi A. Hanson, Jessica N. Cohan, Marta L. McCrum, Joshua J. Horns, Benjamin S. Brooke, Rupam Das, Brenna C. Kelly, Alexander John Campbell & James Hotaling, Balancing Revenue Generation with Capacity Generation: Case Distribution, Financial Impact and Hospital Capacity Changes from Cancelling or Resuming Elective Surgeries in the US During COVID-19, 20 BMC HEALTH SERVS. RSCH., 1119, 1121-22 (2020).

(48.) Vijay Krishnamoorthy, Tetsu Ohnuma, Raquel Bartz, Matthew Fuller, Nita Khandelwal, Krista Haines, Charles Scales & Karthik Raghunathan, Acute Care Resource Use After Elective Surgery in the United States: Implications During the COVID-19 Pandemic, 30 AM. J. CRITICAL CARE 320, 320-23 (2021).

(49.) Tedros Adhanom Ghebreyesus, Dir. Gen., World Health Org., Opening Remarks at the Media Briefing on COVID-19 (Mar. 11, 2020), https://www.who.int/director-general/speeches/detail/who-director-general-s-opening-remarks-at-the-media-briefing-on-covid-19--11-march-2020.

(50.) Id.

(51.) Proclamation No. 9994, 85 Fed. Reg. 15337 (Mar. 18, 2020); see 50 U.S.C. [section] 1621.

(52.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC 1 (2020), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforce.pdf.

(53.) Id. It should be noted that this document and each subsequent update raised the issue of mental health for both providers and patients. See id. at 5-7; COVID-19 Updates and Resources, AM. SOC'Y FOR REPROD. MED., https://www.asrm.org/news-and-publications/covid-19/ (last visited June 4, 2022).

(54.) AM. SOC'Y FOR REPROD. MED., supra note 52, at 2; COVID, Reproductive Health, and Public Policy: Lessons Learned after Two Years of the Ongoing Pandemic, AM. SOC'Y FOR REPROD. MED., (Mar. 2, 2022), https://www.asrm.org/news-and-publications/news-and-research/announcements/covid-reproductive-health-and-public-policy-lessons-learned-after-two-years-of-the-ongoing-pandemic-from-the-asrm-covid-19-task-force/ (describing the makeup of the Task Force).

(55.) AM. SOC'Y FOR REPROD. MED., supra note 52, at 2.

(56.) Id. at 1-2.

(57.) Id. at 5-7.

(58.) See Coronavirus Covid-19: ESHRE Statement on Pregnancy and Conception, EUR. SOC'Y OF HUM. REPROD. & EMBRYOLOGY (Mar. 19, 2020), https://www.eshre.eu/Europe/Position-statements/COVID19.

(59.) Id.; see also Huan Liang & Ganesh Acharya, Novel Corona Virus Disease (COVID-19) in Pregnancy: What Clinical Recommendations to Follow?, 99 ACTA OBSTETRICIA ET GYNECOLOGICA SCANDINAVICA 4, 439-42 (2020); David A. Schwartz & Ashley L. Graham, Potential Maternal and Infant Outcomes from (Wuhan) Coronavirus 2019-nCoV Infecting Pregnant Women: Lessons from SARS, MERS, and Other Human Coronavirus Infection, 12 VIRUSES 194 (2020).

(60.) Id.; AM. SOC'Y FOR REPROD. MED., supra note 52, at 3-7.

(61.) COVID-19 Updates and Resources, supra note 53.

(62.) See infra pp. 10-20; see also COVID-19 Updates and Resources, supra note 53.

(63.) See infra pp. 843-845.

(64.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC: UPDATE #1 (MARCH 30, 2020 THROUGH APRIL 13, 2020) 1 (2020), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate1.pdf.

(65.) Id.

(66.) Id. at 2.

(67.) Id.

(68.) Id.

(69.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC: UPDATE #2 (APRIL 13, 2020 THROUGH APRIL 27, 2020) 1 (2020), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate2.pdf.

(70.) Id.

(71.) Id.

(72.) Id. at 1-2.

(73.) See id. at 2.

(74.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC: UPDATE # 3 (APRIL 24, 2020 THROUGH MAY 11, 2020) 1 (2020), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate3.pdf [hereinafter ASRM, UPDATE #3].

(75.) Id.

(76.) Id. at 2.

(77.) See id.

(78.) See id.

(79.) Id. at 3. The Task Force suggested that a reduction in cases for a period of at least fourteen days would be considered "sustained." Id.

(80.) See id.

(81.) See id. at 3-6.

(82.) Id. at 4, 8 tbl.1.

(83.) Id.; OCCUPATIONAL SAFETY & HEALTH ADMIN., U.S. DEP'T OF LAB., GUIDANCE ON PREPARING WORKPLACES FOR COVID-19 1 (2020), https://www.osha.gov/sites/default/files/publications/OSHA3990.pdf.

(84.) ASRM, UPDATE #3, supra note 74, at 9 tbl.1; SOC'Y FOR ASSISTED REPROD. TECH., SART COVID-19 TOOLKIT 1 (2020), https://www.sart.org/globalassets/__sart/covid-19/tips-for-resuming-care/sart-covid-19-toolkit.pdf.

(85.) See ASRM, UPDATE #3, supra note 74, at 6.

(86.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC: UPDATE #4 (MAY 11, 2020 THROUGH JUNE 8, 2020) 1 (2020), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate4.pdf [hereinafter ASRM, UPDATE #4].

(87.) Id. at 2.

(88.) See id.

(89.) Id.; see, e.g., Heather Huddleston, Assessing the Safety of Pregnancy in the Co[r]onavirus (COVID-19) Pand[e]mic, UCSF CLINICAL TRIALS, https://clinicaltrials.ucsf.edu/trial/NCT04388605 (last visited Apr. 4, 2022).

(90.) ASRM, UPDATE #4, supra note 86, at 2.

(91.) See id. at 3-6.

(92.) See Wissam Shalish, Satyanarayana Lakshminrusimha, Paolo Manzoni, Martin Keszler & Guilherme M. Sant'Anna, COVID-19 and Neonatal Respiratory Care: Current Evidence and Practical Approach, 37 AM. J. PERINATOLOGY 780, 780 (2020).

(93.) See Yangli Liu, Haihong Chen, Kejing Tang & Yubiao Guo, Clinical Manifestations and Outcomes of SARS-Cov-2 Infection During Pregnancy, 82 J. INFECT. e9, e9-e10 (2021).

(94.) See Huijun Chen, Juanjuan Guo, Chen Wang, Fan Luo, Xuechen Yu, Wei Zhang, Jiafu Li, Dongchi Zhao, Dan Xu, Qing Gong, Jing Liao, Huixia Yang, Wei Hou & Yuanzhen Zhang, Clinical Characteristics and Intrauterine Vertical Transmission Potential of COVID-19 Infection in Nine Pregnant Women: A Retrospective Review of Medical Records, 395 LANCET 809, 810, 814 (2020).

(95.) See ASRM, UPDATE #4, supra note 86, at 3-5.

(96.) Id. at 6-7.

(97.) Id. at 5.

(98.) Id. at 7.

(99.) Id. at 8.

(100.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC, UPDATE #5 (JUNE 8, 2020 THROUGH JULY 6, 2020), 1 (2020), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate5.pdf [hereinafter ASRM, UPDATE #5].

(101.) Id. at 2.

(102.) See id. at 4-5.

(103.) Id.

(104.) Id. at 3.

(105.) Id.

(106.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC UPDATE #6 (JULY 10, 2020 THROUGH AUGUST 10, 2020), 1 (2020), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate6.pdf

[hereinafter ASRM, UPDATE #6].

(107.) Id. at 2.

(108.) Id. at 2-5.

(109.) Id.; Matthew J. Blitz, Burton Rochelson, Howard Minkoff, Natalie Meirowitz, Lakha Prasannan, Viktoriya London, Timothy J. Rafael, Shruti Chakravarthy, Luis A. Bracero, Shane W. Wasden, Sarah L. Pachtman Shetty, Orlando Santandreu, Frank A. Chervenak, Benjamin M. Schwartz & Michael Nimaroff, Maternal Mortality Among Women with Coronavirus Disease 2019 Admitted to the Intensive Care Unit, 223 AM. J. OBSTETRIC GYNECOLOGY 595 (2020); Sascha Ellington, Penelope Strid, Van T. Tong, Kate Woodworth, Romeo R. Galang, Laura D. Zambrano, John Nahabedian, Kayla Anderson & Suzanne M. Gilboa, Characteristics of Women of Reproductive Age with Laboratory-Confirmed SARS-CoV-2 Infection by Pregnancy Status--United States, January 22-June 7, 2020, 69 MORBIDITY MORTALITY WKLY. REP. 769-775 (2020); Rasha Khoury, Peter S. Bernstein, Chelsea Debolt, Joanne Stone, Desmond M. Sutton, Lynn L. Simpson, Meghana A. Limaye, Ashley S. Roman, Melissa Fazzari, Christina A. Penfield, Lauren Ferrara, Calvin Lambert, Lisa Nathan, Rodney Wright, Angela Bianco, Brian Wagner, Dena Goffman, Cynthia Gyamfi-Bannerman, William E. Schweizer, Karina Avila, Bijan Khaksari, Meghan Proehl, Fabiano Heitor, Johanna Monro, David L. Keefe, Mary E. D'Alton, Michael Brodman, Sharmila K. Makhija & Siobhan M. Dolan, Characteristics and Outcomes of 241 Births to Women with Severe Acute Respiratory Syndrome Coronavirus 2 (SARS-CoV-2) Infection at Five New York City Medical Centers, 136 OBSTETRICS & GYNECOLOGY 273-282 (2020); Marian Knight, Kathryn Bunch, Nicola Vousden, Edward Morris, Nigel Simpson, Chris Gale, Patrick O'Brien, Maria Quigley, Peter Brocklehurst & Jennifer J Kurinczuk, Characteristics and Outcomes of Pregnant Women Admitted to Hospital with Confirmed SARS-CoV-2 Infection in UK: National Population-Based Cohort Study, 369 BMJ 2107 (2020); Reem Matar, Layan Alrahmani, Nasser Monzer, Labib G Debiane, Elie Berbari, Jawad Fares, Fidelma Fitzpatrick & Mohammad H. Murad, Clinical Presentation and Outcomes of Pregnant Women with Coronavirus Disease 2019: A Systematic Review and Meta-Analysis, 72 CLINICAL INFECTIOUS DISEASES 521-33 (2021).

(110.) See Blitz et al., supra note 109 at 596; Miranda J. Delahoy, Michael Whitaker, Alissa O'Halloran, Shua J. Chai, Pam Daily Kirley, Nisha Alden, Breanna Kawasaki, James Meek, Kimberly Yousey-Hindes, Evan J. Anderson, Kyle P. Openo, Maya L. Monroe, Patricia A. Ryan, Kimberly Fox, Sue Kim, Ruth Lynfield, Samantha Siebman, Sarah Shrum Davis, Daniel M. Sosin, Grant Barney, Alison Muse, Nancy M. Bennett, Christina B. Felsen, Laurie M. Billing, Jessica Shiltz, Melissa Sutton, Nicole West, William Schaffner, H. Keipp Talbot, Andrea George, Melanie Spencer, Sascha Ellington, Romeo R. Galang, Suzanne M. Gilboa, Van T. Tong, Alexandra Piasecki, Lynnette Brammer, Alicia M. Fry, Aron J. Hall, Jonathan M. Wortham, Lindsay Kim & Shikha Garg, Characteristics and Maternal and Birth Outcomes of Hospitalized Pregnant Women with Laboratory-Confirmed COVID-19--COVID-NET, 13 States, March 1--August 22, 2020, 69 MORBIDITY MORTALITY WKLY. REP. 1347-48 (2020).

(111.) See Gabriela N. Algarroba, Patricia Rekawek, Sevan A. Vahanian, Poonam Khullar, Thomas Palaia, Morgan R. Peltier, Martin R. Chavez & Anthony M. Vintzileos, Visualization of Severe Acute Respiratory Syndrome Coronavirus 2 Invading the Human Placenta Using Electron Microscopy, 223 AM. J. OBSTETRICS & GYNECOLOGY 2, 275-278 (2020); David Baud, Gilbert Greub, Guillaume Favre, Carole Gengler, Katia Jaton, Estelle Dubruc & Leo Pomar, Second-Trimester Miscarriage in a Pregnant Woman with SARS-CoV-2 Infection, 323 JAMA 21, 2198-2200 (2020); Lan Dong, Jinhua Tian, Songming He, Chuchao Zhu, Jian Wang, Chen Liu & Jing Yang, Possible Vertical Transmission of SARS-CoV-2 From an Infected Mother to Her Newborn, 323 JAMA 21, 1846-48 (2020); Koen Grimminck, Lindy Anne Maria Santegoets, Frederike Charlotte Siemens, Pieter Leendert Alex Fraaij, Irwin Karl Marcel Reiss & Sam Schoenmakers, No Evidence of Vertical Transmission of SARS-CoV-2 After Induction of Labour in an Immune-Suppressed SARS-CoV-2-Positive Patient, 13 BMS CASE REP. 6 (2020); Wissman Shalish, Satyanarayana Lakshminrusimha, Paolo Manzoni, Martin Keszler & Guilherme M. Sant'Anna, COVID-19 and Neonatal Respiratory Care: Current Evidence and Practical Approach, 37 AM J. PERINATOLOGY 08, 780-91 (2020).

(112.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC UPDATE #7, 1 (2020), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate7.pdf [hereinafter ASRM, UPDATE #7].

(113.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC UPDATE #8, 1 (2020), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate8.pdf [hereinafter ASRM, UPDATE #8].

(114.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC UPDATE #9, 1 (2020), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate9.pdf.

(115.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC UPDATE #10, 1 (2020), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate10.pdf.

(116.) Id.

(117.) Id. at 2.

(118.) Id. at 4.

(119.) Id.

(120.) Id.

(121.) Id.

(122.) See M. Barragan, N. Martin-Palomino, A. Rodriguez & R. Vassena, Undetectable Viral RNA in Oocytes from SARS-CoV-2 Positive Women, 36 HUM. REPROD. 390 (2020); Yajun Ruan, Bintao Hu, Zhuo Liu, Kang Liu, Hongyang Jiang, Hao Li, Rui Li, Yang Luan, Xiaming Liu, Gan Yu, Shengfei Xu, Xiaoyi Yuan, Shaogang Wang, Weimin Yang, Zhangqun Ye, Jihong Liu & Tao Wang, No Detection of SARS-CoV-2 from Urine, Expressed Prostatic Secretions and Semen in 74 Recovered COVID-19 Male Patients: A perspective and Urogenital Evaluation, 9 ANDROLOGY 99, 100 (2020).

(123.) John Allotey, Elena Stallings, Mercedes Bonet, Magnus Yap, Shaunak Chatterjee, Tania Kew, Luke Debenham, Anna Clave Llavall, Anushka Dixit, Dengyi Zhou, Rishab Balaji, Siang Ing Lee, Xiu Qiu, Mingyang Yuan, Dyuti Coomar, Jameela Sheikh, Heidi Lawson, Kehkashan Ansari, Madelon van Wely, Elizabeth van Leeuwen, Elena Kostova, Heinke Kunst, Asma Khalil, Simon Tiberi, Vanessa Brizuela, Nathalie Broutet, Edna Kara, Caron Rahn Kim, Anna Thorson, Ramon Escuriet, Olufemi T Oladapo, Lynne Mofenson, Javier Zamora & Shakila Thangaratinam, PregCOV-19 Living Systematic Review Consortium. Clinical Manifestations, Risk Factors, and Maternal and Perinatal Outcomes of Coronavirus Disease 2019 in Pregnancy: Living Systematic Review and Meta-Analysis, BMJ 1, 7 (2020); Laura Zambrano, Laura D. Zambrano, Sascha Ellington, Penelope Strid, Romeo R. Galang, Titilope Oduyebo, Van T. Tong, Kate R. Woodworth, John F. Nahabedian III, Eduardo Azziz-Baumgartner, Suzanne M. Gilboa & Dana Meaney-Delman, Update: Characteristics of Symptomatic Women of Reproductive Age with Laboratory-Confirmed SARS-CoV-2 Infection by Pregnancy Status--United States, January 22--October 3, 2020, 69 MORBIDITY & MORTALITY WKLY. REP. 1641, 1646 (2020).

(124.) AM. SOC'Y OF REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC UPDATE NO. 11 (2020), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate11.pdf [hereinafter ASRM, UPDATE #11]; see also FDA News Release, FDA Takes Additional Action in Fight Against COVID-19 By Issuing Emergency Use Authorization for Second COVID-19 Vaccine (Dec. 18, 2020), https://www.fda.gov/news-events/press-announcements/fda-takes-additional-action-fight-against-covid-19-issuing-emergency-use-authorization-second-covid.

(125.) See ASRM, UPDATE #11, supra note 124.

(126.) ACOG, VACCINATING PREGNANT AND LACTATING PATIENTS AGAINST COVID-19 (2020), http://www.aofog.net/pdf/Vaccinating%20Pregnant%20and%20Lactating%20Patients%20Against%20COVID-19%20_%20ACOG.pdf.

(127.) SMFM, SOCIETY FOR MATERNAL-FETAL MEDICINE (SMFM) STATEMENT: SARS-COV-2 VACCINATION IN PREGNANCY (2020), https://s3.amazonaws.com/cdn.smfm.org/media/2591/SMFM_Vaccine_Statement_12-1-20_(final).pdf.

(128.) Julius Collin, Emma Bystrom, AnnaSara Carnahan & Malin Ahrne, Public Health Agency of Sweden's Brief Report: Pregnant and Postpartum Women with Severe Acute Respiratory Syndrome Coronavirus 2 Infection in Intensive Care in Sweden, 99 ACTA OBSTET. GYNECOL. SCAND. 819, 819(2020); Miranda J. Delahoy et al., Characteristics and Maternal and Birth Outcomes of Hospitalized Pregnancy Women with Laboratory-Confirmed COVID-19--COVID-NET, 13 States, March 1--August 22, 2020, 69 MORBIDITY MORTAL WKLY. REP. 1347, 1347, 1351-53 (2020); Lakshmi Panagiotakopoulos, Tanya R. Myers, Julianne Gee, Heather S. Lipkind, Elyse O. Kharbanda, Denison S. Ryan, Joshua T.B. Williams, Allison L. Naleway, Nicola P. Klein, Simon J. Hambidge, Steven J. Jacobsen, Jason M. Glanz, Lisa A. Jackson, Tom T. Shimabukuro, Eric S. Weintraub, SARS-Cov-2 Infection Among Hospitalized Pregnant Women: Reasons for Admission and Pregnancy Characteristics--Eight U.S. Health Care Centers, March 1--May 30, 2020, 69 MORBIDITY MORTAL WKLY. REP. 1355, 1355, 1356 (2020).

(129.) ASRM, TESTING AND VACCINE TRUTHS (2021), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate12.pdf.

(130.) Id.

(131.) Id.

(132.) Id.

(133.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC, UPDATE #13 (2021), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate13.pdf.

(134.) Id.

(135.) Id.

(136.) See John Allotey, Elena Stallings, Mercedes Bonet, Magnus Yap, Shaunak Chatterjee, Tania Kew, Luke Debenham, Anna Clave Llavall, Anushka Dixit, Dengyi Zhou, Rishab Balaji, Siang Ing Lee, Xiu Qiu, Mingyang Yuan, Dyuti Coomar, Jameela Sheikh, Heidi Lawson, Kehkashan Ansari, Madelon van Wely, Elizabeth van Leeuwen, Elena Kostova, Heinke Kunst, Asma Khalil, Simon Tiberi, Vanessa Brizuela, Nathalie Broutet, Edna Kara, Caron Rahn Kim, Anna Thorson, Ramon Escuriet, Olufemi T Oladapo, Lynne Mofenson, Javier Zamora & Shakila Thangaratinam, Clinical Manifestations, Risk Factors, and Maternal and Perinatal Outcomes of Coronavirus Disease 2019 in Pregnancy: Living Systematic Review and Meta-Analysis, BMJ (Sept. 1, 2020), https://www.bmj.com/content/bmj/370/bmj.m3320.full.pdf.

(137.) See Elizabeth V. Kingston, High Rates of Stillbirth and Preterm Delivery in Women with Covid-19 and the Efficacy of ECMO in Pregnancy, BMJ (July 27, 2020), https://www.bmj.com/content/bmj/370/bmj.m2921.full.pdf.

(138.) See J. Justin Mulvey, Cynthia M. Magro, Lucy X. Ma, Gerard J. Nuovo & Rebecca N. Baergen, Analysis of Complement Deposition and Viral RNA in Placentas of COVID-19 Patients, 46 ANNALS DIAGNOSTIC PATHOLOGY (2020), https://www-sciencedirect-com.univ-eiffel.idm.oclc.org/science/article/pii/S109291342030071X?via%3Dihub; see also Alice Lu-Culligan, Arun R. Chavan, Pavithra Vijayakumar, Lina Irshaid, Edward M. Courchaine, Kristin M. Milano, Zhonghua Tang, Scott D. Pope, Eric Song, Chantal B.F. Vogels, William J. Lu-Culligan, Katherine H. Campbell, Arnau Casanovas-Massana, Santos Bermejo, Jessica M. Toothaker, Hannah J. Lee, Feimei Liu, Wade Schulz, John Fournier, M. Catherine Muenker, Adam J. Moore, Yale IMPACT Team, Liza Konnikova, Karla M. Neugebauer, Aaron Ring, Nathan D. Grubaugh, Albert I. Ko, Raffaella Morotti, Seth Guller, Harvey J. Kliman, Akiko Iwasaki & Shelli F. Farhadian, SARS-Cov-2 Infection in Pregnancy is Associated with Robust Inflammatory Response at the Maternal-Fetal Interface, MEDRXIV (2021), https://www-ncbi-nlm-nih-gov.univ-eiffel.idm.oclc.org/pmc/articles/PMC7852242/.

(139.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC, UPDATE #14 (2021), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate14.pdf.

(140.) Id.

(141.) Am. Soc'y for Reprod. Med. Press Release, ASMR Covid-19 Task Force Update #15 (May 19, 2021), https://www.asrm.org/news-and-publications/news-and-research/press-releases-and-bulletins/asrm-covid-19-task-force-update-15.

(142.) Id.

(143.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC UPDATE #16, (2021), https://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate16.pdf.

(144.) Id.

(145.) AM. SOC'Y FOR REPROD. MED., PATIENT MANAGEMENT AND CLINICAL RECOMMENDATIONS DURING THE CORONAVIRUS (COVID-19) PANDEMIC, UPDATE #17 (2021), http://www.asrm.org/globalassets/asrm/asrm-content/news-and-publications/covid-19/covidtaskforceupdate17.pdf.

(146.) Id.

(147.) Am. Soc'y for Reprod. Med. Press Release, UPDATE No. 18 - COVID-19: Vaccination, Booster Shots and Reproductive Health Care (Nov. 12, 2021), https://www.asrm.org/news-and-publications/news-and-research/press-releases-and-bulletins/update-no-18-covid-19-vaccination-booster-shots-and-reproductive-health-care.

(148.) Id.

(149.) Id.

(150.) Id.

(151.) Id.

(152.) Am. Soc'y for Reprod. Med. Press Release, UPDATE No. 19--Awareness of Complexity in Uncertain Times (Dec. 17, 2021), https://www.asrm.org/news-and-publications/news-and-research/press-releases-and-bulletins/update-no.-19--awareness-of-complexity-in-uncertain-times-covid-19.

(153.) Id.

(154.) Id.

(155.) Id.

(156.) Id.

(157.) Id.

(158.) Id.

(159.) Id.

(160.) Am. Soc'y for Reprod. Med. Press Release, ASRM COVID-19 Task Force Issues Update No. 20 (Apr. 20, 2022), https://www.asrm.org/news-and-publications/news-and-research/press-releases-and-bulletins/asrm-covd-19-task-force-issues-update-no.-20/

(161.) Id.

(162.) Id.

(163.) Id.

(164.) See discussion supra pp. 831-843.

(165.) Olivia Solon, 'Adding Insult to Injury': Couples Struggle with IVF Cancellations Amid Coronavirus Pandemic, NBC NEWS (Apr. 1, 2021, 6:00 AM), https://www.nbcnews.com/health/health-news/adding-insult-injury-couples-struggle-ivf-cancellations-amid-coronavirus-pandemic-n1173256 (recounting interviews with ten women and some of their partners about the impact of coronavirus-related disruptions in IVF treatment cycles have had on their mental states).

(166.) Covid Delays in IVF Treatment Has Biggest Impact on Women Over 40, UNIV. OF ABERDEEN (Jan. 20, 2021), https://www.abdn.ac.uk/news/14623/.

(167.) Austin D. Schirmer, Jennifer F. Kawwass & Eli Y. Adashi, Fertility Care Amidst the COVID19 Pandemic: The American Experience, J. OVARIAN RSCH. 1, 2-3 (2021).

(168.) Eliana Dockterman, Data Show More Women Are Freezing Their Eggs During the Pandemic, Defying Doctors' Expectations, TIME (Jan. 13, 2021, 1:52PM), https://time.com/5927516/egg-freezing-covid-19-pandemic/; Anne E. Martini, Samad Jahandideh, Ali Williams, Kate Decine, Erica A. Widra, Micah J. Hill, Alan H. DeCherney & Jeanne E. O'Brien, Trends In Elective Egg Freezing Before and After the COVID-19 Pandemic, 116 FERTILITY & STERILITY e220, 264 (2021); Mary Plfum, Egg Freezing Has Boomed During The Pandemic, As Women Opt To Wait Out Family Life, NBC NEWS (Apr. 24, 2021, 6:00AM), https://www.nbcnews.com/business/business-news/egg-freezing-has-boomed-during-pandemic-women-opt-wait-out-n1264211.

(169.) Elisabetta Micelli, Gianmartin Cito, Andrea Cocci, Gaia Polloni, Giorgio I. Russo, Andrea Minervini, Marco Carini, Alessandro Natali & Maria E. Coccia, Desire for Parenthood at the Time of COVID-19 Pandemic: An Insight into the Italian Situation, 41 J. PSYCHOSOMATIC OBSTETRICS GYNAECOLOGY 183, 185-86 (2020).

(170.) C.M. Verhaak, J.M.J Smeenk, A. van Minnen, J.A.M. Kremer & F.W. Kraaimaat, A Longitudinal, Prospective Study on Emotional Adjustment Before, During and After Consecutive Fertility Treatment Cycles, 20 HUM. REPROD. 2253, 2253 (2005).

(171.) Harpreet Kaur, Gautham T. Pranesh, & Kamini A. Rao, Emotional Impact of Delay in Fertility Treatment Due To COVID-19 Pandemic, 13 J. HUM. REPROD. SCI. 317, 319 (2020).

(172.) Id. at 320.

(173.) Reut Ben-Kimhy, Michal Youngster, Tamar R. Medina-Artom, Sarit Avraham, Itai Gat, Lilach M. Haham, Ariel Hourvitz & Alon Kedem, Fertility Patients Under COVID-19: Attitudes, Perceptions and Psychological Reactions, 35 HUM. REPROD. 2774, 2774-83 (2020).

(174.) Id. at 2777.

(175.) Id.

(176.) J. Boivin, C. Harrison, R. Mathur, G. Burns, A. Pericleous-Smith & S. Gameiro, Patient Experiences of Fertility Clinic Closure During The COVID-19 Pandemic: Appraisals, Coping and Emotions, 35 HUM. REPROD. 2556, 2556 (2020); see also David B. Seifer, William D. Petok, Alisha Agrawal, Tanya L. Glenn, Arielle H. Bayer, Barry R. Witt, Blair D. Burgin & Harry J. Lieman, Psychological Experience and Coping Strategies of Patients in the Northeast US Delaying Care for Infertility During the COVID-19 Pandemic, 19 REPROD. BIOLOGY & ENDOCRINOLOGY 1, 2 (2021).

(177.) Boivin et al., supra note 176, at 2556-57, 2561.

(178.) Nadia Muhaidat, Mohammad A. Alshrouf, Abdulrahman M. Karam & Mohammed Elfalah, Infertility Management Disruption During the COVID-19 Outbreak in a Middle-Income Country: Patients' Choices, Attitudes, and Concerns, 15 PATIENT PREFERENCE & ADHERENCE 2279, 2284 (Oct. 5, 2020), https://www-ncbi-nlm-nih-gov.univ-eiffel.idm.oclc.org/pmc/articles/PMC8502047/pdf/ppa-15-2279.pdf.

(179.) Fatemeh Hamidi, Farzaneh Babapour & Zeinab Hamzehgardeshi, Infertility Distress Management in Couples Treated with Assisted Reproductive Techniques (ART) in COVID-19 Pandemic, 21 J. REPROD. INFERTILITY 312, 312-13 (2020).

(180.) See Julie Morgan, Andreia Trigo & Kate Davies, Assessing the Change in Infertility Patient's Social Media Use During COVID-19 Related to Clinic Closures, 114 FERTILITY & STERILITY, P-987, P-987 (2020).

(181.) Karen Dsouza, Minerva Orellana, Alessandra Ainsworth, Kirsten Riggan, Chandra Shenoy & Megan Allyse, Patient Perceptions of COVID-19 Impact on their Fertility Care, 5 J. CLINICAL & TRANSLATIONAL SCI. 85, 85 (2021).

(182.) See Veronica Esposito, Erika Rania, Daniela Lico, Sara Pedri, Alessia Fiorenza, Maria Francesca Strati, Alessandro Conforti, Vincenzo Marrone, Andrea Carosso, Alberto Revelli, Fulvia Zullo, Costantino Di Carlo & Roberta Venturella, Influence of COVID-19 Pandemic on the Psychological Status of Infertile Couples, 253 EUR. J. OF OBSTETRICS & GYNECOLOGY & REPROD. BIOLOGY 148, 149-150 (2020).

(183.) Id. at 152.

(184.) Seifer, supra note 176.

(185.) Id.

(186.) See generally discussion supra Part II (noting documents released by ASRM are merely for guidance).

(187.) See id.

(188.) Alissa Greenberg, The Pandemic Disrupted Tens of Thousands of IVF Cycles, PBS: NOVA (May 14, 2021), https://www.pbs.org/wgbh/nova/article/ivf-covid-pandemic-infertility/.

(189.) Natalie Lampert, Fertility Clinics Stay Open Despite Unclear Guidelines, NY TIMES, https://www.nytimes.com/2020/05/01/parenting/fertility-clinics-coronavirus.html (last updated May 4, 2020).

(190.) CCRM Fertility to Remain Open for Select Fertility Treatments as a Commitment to Patient Health and Safety, CCRM FERTILITY (Mar. 16, 2020), https://www.ccrmivf.com/news-events/remains-open/; Hannam Fertility Centre is a CCRM Network Clinic, CCRM FERTILITY, https://www.ccrmivf.com/toronto/ (last visited April 5, 2020).

(191.) Norbert Gleicher, IVF During COVID-19: CHR's Always-Up-To-Date Guide, CTR. FOR HUM REPROD., https://www.centerforhumanreprod.com/blog/ivf-during-covid-19-chrs-always-up-to-date-guide (last updated Nov. 13, 2020).

(192.) Id.

(193.) See generally Fertility Providers Alliance Issues Comprehensive Tool Kit Designed to Help Fertility Practices Navigate Care in a COVID-19 World, FERTILITY PROVIDERS ALL. (Apr 24, 2020), https://www.fertilityprovidersalliance.com/blogs/fpa_releases_covid_19_toolkit#article (discussing that FPA's Toolkit was "[d]esigned to be used in conjunction with other resources provided by ASRM") [hereinafter Fertility Providers Alliance Tool Kit].

(194.) See generally Our Story Starts with You, FERTILITY PROVIDERS ALL., https://www.fertilityprovidersalliance.com/index.html (last visited Apr. 7, 2022).

(195.) Id.

(196.) Id.

(197.) Id.

(198.) Id.

(199.) Anna Louie Sussman, Is Getting Pregnant "Medically Necessary" Right Now?, MIT TECH. REV. (May 7, 2020), https://www.technologyreview.com/2020/05/07/1000473/ivf-covid-fertility-prelude-inception-asrm/.

(200.) Our Story Starts with You, supra note 194.

(201.) See FPA Applauds ASRM for Revised Recommendations on Fertility Care During Pandemic, FERTILITY PROVIDERS ALL. (Apr. 2, 2020), https://www.fertilityprovidersalliance.com/blogs/fpa_applauds_asrm.

(202.) See discussion of ASRM's initial guidance supra pp. 828-830.

(203.) See Norbert Gleicher, Fertility Providers' Alliance (FPA) Reframes ASRM's Reaffirmation of COVID-19 Guidelines, CTR. FOR HUM. REPROD. (Apr. 6, 2020), https://www.centerforhumanreprod.com/blog/fertility-providers-alliance-fpa-reframes-asrms-reaffirmation-of-covid-19-guidelines.

(204.) Fertility Providers Alliance Tool Kit, supra note 193.

(205.) Id.

(206.) See id.

(207.) See The Latest News and Events from the Fertility Providers Alliance, FERTILITY PROVIDERS ALL., https://www.fertilityprovidersalliance.com/news.html (last visited Mar. 17, 2022).

(208.) See id.

(209.) Norbert Gleicher, What the "Controversy" Over ASRM COVID-19 Task Force's Recommendation is All About, CTR. FOR HUM. REPROD. (Apr. 2, 2020), https://www.centerforhumanreprod.com/blog/what-the-controversy-over-asrm-covid-19-task-forces-recommendation-is-all-about [hereinafter What the "Controversy" Over ASRM COVID-19 Task Force's Recommendations is All About].

(210.) Id.

(211.) Id.

(212.) See id.

(213.) Id.

(214.) Id.

(215.) See id.

(216.) Id.

(217.) Id.

(218.) Id.

(219.) See What the "Controversy" Over ASRM COVID-19 Task Force's Recommendations is All About, supra note 209.

(220.) Id.

(221.) See, e.g., Alexander Borsa, Joseph Bruch & Sarah S. Richardson, When Private Equity Firms Invest in Women's Health Clinics, Who Benefits?, STAT (Sept. 14, 2020), https://www.statnews.com/2020/09/14/private-equity-firms-invest-womens-health-clinics-who-benefits/; Patrick Krause, Industry Voices--Fertility Clinics Offer Big Potential for Investors and Physician Practices, FIERCE HEALTHCARE (Sept. 26, 2019, 12:00 PM), https://www.fiercehealthcare.com/hospitals-health-systems/industry-voices-fertility-clinics-offer-big-potential-for-investors-and; Alexander Borsa & Joseph Dov Bruch, Prevalence and Performance of Private Equity-Affiliated Fertility Practices in the United States, 117 FERTILITY & STERILITY 124, 124-25, 128 (2022).

(222.) See What the "Controversy" Over ASRM COVID-19 Task Force's Recommendations is All About, supra note 209.

(223.) Id.

(224.) See Miriam Dellino, Carla Minoia, Angelo Virgilio Paradisio, Raffaella De Palo & Erica Silvestris, Fertility Preservation in Cancer Patients During the Coronvirus (COVID-19) Pandemic, 10 FRONTIERS IN ONCOLOGY 1, 3 (2020); Bhawna Sirohi, Tanya Buckshee Rohatgi & Matteo Lambertini, Oncofertility and COVID-19--Cancer Does Not Wait, 14 ECANCER 1, 2 (2020).

(225.) See Andrew Smith, Piotr Gromski, Karema Al Rashid, Kate Tilling, Deborah Lawlor & Scott Nelson, Population Implications of Cessation of IVF During the COVID-19 Pandemic, 41 REPROD. BIOMED ONLINE 428, 430 (2020).

(226.) Id. at 429.

(227.) Phillip A. Romanski, Pietro Bortoletto, Zev Rosenwaks & Glenn L. Schattman, Delay in IVF Treatment Up to 180 Days Does Not Affect Pregnancy Outcomes in Women with Diminished Ovarian Reserve, 35 HUM. REPROD. 1630, 1634 (2020).

(228.) See AM. SOC'Y FOR REPROD. MED., supra note 52, at 2, 6.

(229.) See Our Story Starts with You, supra note 194.

(230.) Jenna M. Turocy, Alex Robles, Daniel Hercz, Mary D'Alton, Eric J. Forman & Zev Williams, The Emotional Impact of the ASRM Guidelines on Fertility Patients During the COVID-19 Pandemic, 114 FERTILITY AND STERILITY e63, e63 (2020).

(231.) Laura C. Gemmell, Zev Williams & Eric J. Forman, Considerations on the Restriction of Assisted Reproductive Technology (ART) Due to COVID-19, SEMINARS IN PERINATOLOGY, Nov. 2020, at 1, 1.

(232.) Beth Zhou, Ammar Joudeh, Milli J. Desai, Brian Kwan, Vinit Nalawade, Brian W. Whitcomb & H. Irene Su, Trends in Infertility Care Among Commercially Insured US Women During the COVID-19 Pandemic, JAMA NETWORK OPEN, Oct. 6, 2021, at 1, 3.

(233.) See, e.g. COVID-19: Recommendations for Management of Elective Surgical Procedures, AM. COLL. OF SURGEONS (Mar. 13, 2020), https://www.facs.org/for-medical-professionals/covid-19/clinical-guidance/elective-surgery/.

(234.) See CMS, NON-EMERGENT, ELECTIVE MEDICAL SERVICES, AND TREATMENT RECOMMENDATIONS 1 (2020), https://www.cms.gov/files/document/cms-non-emergent-elective-medical-recommendations.pdf.

(235.) Krishnamoorthy, et al., supra note 48, at 321-22.

(236.) Id. at 322.

(237.) See, e.g., In Vitro Fertilization (IVF), MAYO CLINIC (Sept. 10, 2021), https://www.mayoclinic.org/tests-procedures/in-vitro-fertilization/about/pac-20384716 (discussing the process of IVF at an outpatient clinic, with no mention of the utilization of hospital resources); Hysteroscopy, MOUNT SINAI, https://www.mountsinai.org/health-library/surgery/hysteroscopy (Dec. 3, 2020) (explaining that a hysteroscopy may be done in a hospital, outpatient surgery center, or provider's office, but patients typically go home the same day).

(238.) See Matthew R. Starr, Rachel Israilevich, Michael Zhitnitsky, Qianqian E. Cheng, Rebecca R. Soares, Luv G. Patel, Michael J. Ammar, M. Ali Khan, Yoshihiro Yonekawa, Allen C. Ho, Michael N. Cohen, Jayanth Sridhar & Ajay E. Kuriyan, Practice Patterns and Responsiveness to Simulated Common Ocular Complaints Among US Ophthalmology Centers During the COVID-19 Pandemic, 138 JAMA OPHTHALMOLOGY 981, 985-86 (2020).

(239.) Recommendations for Urgent and Nonurgent Patient Care, AM. ACAD. OF OPHTHALMOLOGY (Mar. 18, 2020), https://www.aao.org/headline/new-recommendations-urgent-nonurgent-patient-care.

(240.) See Boivin, et al., supra note 176, at 2557.

(241.) See Thomas & Caplan, supra note 2.

    Table 1
    ASRM TASK FORCE GUIDANCE (164)
    Update Time Period
    Number Covered or
     Date Published
     1 March 30 -
     April 13, 2020
     2 April 13 - April
     27, 2020
     3 April 24 - May
     11, 2020
     4 May 11 - June 8,
     2020
     5 June 8 - July 6,
     2020
     6 July 10 -
     August 10, 2020
     7 August 10 -
     September 7,
     2020
     8 September 8 -
     October 5, 2020
     9 October 6 -
     November 9,
     2020
    10 November 17,
     2020
    11 December 16,
     2020
    12 January 18, 2021
    13 February 22,
     2021
    14 March 23, 2021
    15 May 19, 2021
    16 July 23, 2021
    17 August 20, 2021
    18 November 12,
     2021
    19 December 17,
     2021
    20 April 22, 2022
    Update Summary of Update
    Number
     1 Affirmed the five key issues and clinical
     recommendations associated with fertility
     during the COVID-19 pandemic; stated
     that infertility care is not elective.
     2 Acknowledged that an increasing number
     of jurisdictions appropriately recognized
     infertility care as an essential service.
     3 Expressed the need for balance between
     providing fertility care and risk of
     contracting COVID-19; first update to
     provide guidance on gradual resumption
     of reproductive services.
     4 Encouraged patient and practitioner
     participation in research due to lack of
     knowledge about effects of COVID-19 on
     fertility treatment and early pregnancy;
     provided update on current knowledge of
     effects on pregnancy.
     5 Focused on resumption of reproductive
     surgery; advised that partners should not
     be present in treatment room.
     6 Discussed emerging data on negative
     effects of more severe COVID-19 cases
     during pregnancy.
     7 No substantial changes.
     8 No substantial changes.
     9 No substantial changes.
    10 Addressed clinic management and urged
     clinics to re-evaluate risk and mitigation
     strategies; advocated for use of telehealth;
     addressed new data regarding COVID-19
     and fertility care and pregnancy.
    11 Stated that it does not recommend
     withholding COVID-19 vaccines from
     pregnant, soon-to-be pregnant, or
     lactating patients.
    12 Addressed long-term effects of COVID-
     19, variants, and confirmed information
     regarding testing and vaccines.
    13 Reiterated concerns about increased risk
     for severe disease if infected during
     pregnancy.
    14 Provided information to counter vaccine
     hesitancy and misinformation.
    15 Reiterated need for vaccination, masking,
     and testing.
    16 Summarized reproductive facts regarding
     vaccination.
    17 Provided additional information on
     vaccination and vaccine hesitancy.
    18 Explicitly stated that there are no fertility
     or pregnancy related reasons for vaccine
     exemption.
    19 Discussed negative effects on
     reproductive outcome if surgical
     intervention is delayed.
    20 Summarized recommendations issued
     during the prior two years; offered
     guidance on the provision of fertility care
     in the context of the continuing
     pandemic.

Note(s):

At the beginning of the COVID-19 pandemic, in an effort to allocate medical resources towards the anticipated influx of patients infected with the novel virus, many non-essential healthcare services were temporarily paused. The American Society of Reproductive Medicine led the move to halt infertility care in all but the most extreme cases. This cessation of infertility care, compounded by the unknown duration of this recommendation, added to the already high level of stress and anxiety that fertility patients experience and in cases of advanced maternal age or diminished ovarian reserve potentially resulted in suboptimal clinical outcomes. There was vocal disagreement amongst infertility care providers regarding the urgency and essential nature of fertility care and how this balanced with the pandemic. Ultimately there has been a full resumption of fertility care with a new emphasis on fertility preservation. It should be the goal of all professionals in the field of infertility medicine to establish fertility care as essential within the greater field of medicine to assure the protection of their patients in times of future healthcare crisis.

Loughborough Echo (UK)
News, Wednesday, December 28, 2022 4632 mots, p. 16

VILLAGES.

East Leake Mike Elliott 0115 937 6506 [email protected]

PAVILION PROVING POPULAR. As the new PS1m sports pavilion at East Leake comes into use, early bookings show it is going to be well used, not just for sports events but general use as well.

The pavilion -- provided in a scheme established by the parish council -- on the edge of the Costock Road sports ground, has a main central hall that looks set to be a winner for village social and other events.

Funding for the new facility has been not only from local sources but also from, the Premier football league, the Football; Association and Government through the Football Foundation. The parish council have assisted cash wise as have Rushcliffe Borough Council through its Community Infrastructure Levy.

As well as the public space in the new building, there are of course facilities for kts main use, sport, including showers, toilets, modern changing rooms, a kitchen and bar area and two club rooms that have disabled access. Two football pitches are provided on the playing fields as well as a rugby pitch and a cricket pitch.

GROWTH BOARDS. East Leake remains a part of the Growth Boards established in Rushcliffe alongside West Bridgford, Bingham and Radcliffe-on-Trent.

At its last meeting the East Leake group looked at a number of points of local interest including an update from Severn Trent Water on infrastructure schemes, East Leake Traders Association and the High Street consultant updated on their joint

initiatives, an update from the Parish Council on welcome back funding spend and an update on Health Centre plans.

The Growth Board groups are made up of public sector partners, local representatives of the community and business sectors who are working together to agree, plan and implement a long term vision for their area.

The facility ensures the areas concerned have the support and infrastructure in place to meet the needs of the existing and future residents as these settlements grow in the coming years.

Anyone can find out more about the items and local issues the Boards have addressed so far and hear of updates following their regular meetings at https:// www.rushcliffe.gov.uk/ business/growthboards/ The Borough is growing significantly over the next decade with 13,150 new homes planned by 2028, and the Growth Boards are an integral part of ensuring they proactively plan to create communities that will be desirable to live, work and play in.

Coun. Andy Edyvean, Cabinet Portfolio Holder for Economic Growth and

Business says : "This area of our website is now a central point for all enquiries for the latest in each of our Growth Board areas.

"It is important that we are keeping people informed of the work of the growth boards and how their plans are progressing and developing.

"Updates will be posted on the webpage following each quarterly meeting so we would encourage residents to look out for further updates."

Activity undertaken across all of the Growth Board areas so far includes a retail health check of each area to

understand the challenges and opportunities within Rushcliffe's high streets and accompanying workshops for local businesses.

Rushcliffe is part of the WDYT --What do you think? -- campaign which measures the Digital Influence of 1,300 UK high streets and help them improve them for their local communities.

Coun. Edyvean says the WDYT social media campaign last year was also used to encourage more small independent retailers to adopt the use of social media and drive up footfall on the high street.

Shop front improvement grants have been introduced to support local retailers and the Great British High Street social media campaign championed Rushcliffe's local high streets, which has evolved into a High Street Heroes campaign to further highlight their initiatives.

Examples of some of the activity that has taken place in East Leake includes work to support and enhance the village centre including a meeting with NCC Highways to explore options for the T junction, sewerage and drainage, and completion of capacity assessment by Severn Trent Water to assess the impact of the housing growth in East Leake.

The Group have already held an action planning workshop which has resulted in the production of an action plan to help guide the groups work..

FESTIVE SERVICES. After staging a successful and well supported Nativity service with local brownies taking part, East Leake Methodist Church held a Christmas Eve Midnight service and then on Christmas Day while not having their own service some members sent to other Methodist churches in the

area including Shepshed where they had been given a special invitation.

TOOLS WITH A MISSION. Residents in East Leake are being reminded that the parish church of St Mary's are still looking for donations of any unwanted but usable tools, to make available in Africa where they could transform someone's life.

The church, as a base in the village for the Tools with a Mission charity. say they can accept agricultural and gardening, builders, and carpenters tools, as well as electricians tools along with mechanics, plumbers and power tools. In addition they would also be happy to

accept sewing and knitting machines, haberdashery and full working computers.

A collection point is arranged on the first Saturday of each month at The Rectory at 3 Bateman Road between 9am and 11am when donations can be handed in.

The charity is based in Ipswich with centres around the country. They send around 18 containers a year to Africa and say the scheme is a wonderful chanced to get those unused tools out of the shed put them to good use.

Mr Roy Bates was behind the start up of the scheme at East Leake which has proved to be very successful and which has already seen at least 12 sewing machines handed in for sending off.

WI. Keen to increase its membership, East Leake Womens Institute invite newcomers -- and all others as well of course - to the village to visit the Institutes page on the village website for a copy of the full programme of the very varied list of meetings and other activities.

The branch assure new members they will be given a

warm welcome as they join into find out details of what happens at the monthly gathering in the village hall.

Membership secretary is Carolyn Barnett and she will be happy to give out information to anyone seeking it.

FOLK CLUB. Formed over 10 years ago, East Leake Folk Club continue tio meet regularly on the first and third Tuesdays of each month in the room, at the rear of the N ags Head public house on Main Street.

The sessions start at 8pm and everyone m is welcome to be there.

The meetings take the form of a sing song accompanied by musicians and there is also an opportunity for anyone attending to give a solo as well.

Anyone interested in joining or seeking further information can email Ray at [email protected] MARKET SUCCESS. With the East Leake Christmas Market earlier this month being another successful festive event it confirmed the effectiveness of the parish council's programme to introduce the regular event to the village programme of activities.

Since the introduction of the market, its popularity has grown tremendously and the number and variety of stalls continues to grow.

The parish council have given their thanks to the stall holders and traders who attend the market and who often remark on the warm atmosphere in the village and the friendliness of the people.

Add the council in a message to the event supporters: "They truly value your custom and support especially through another tough year."

The council are also thanking the volunteer marshalls who readily give up their free time to lend a hand on market days. The market operates from 3pm to 8pm.

Sutton Bonington Mike Elliott 0115 937 6506

[email protected]

MUSIC SOCIETY. The popular and hugely successful Music Society based at the Sutton Bonington campus of Nottingham University -- its slogan is Led By Students, For All! - is open for membership to local residents as well as Uni students.

The group say they are a non-auditioned society, with members from the staffand student bodies of UoN, and members of the community from the areas surrounding Sutton Bonington.

"Become a member to join our ensembles, access our Private Music Room and join in with socials!" is their message to thew students and the general public.

They run four official ensembles, with weekly rehearsals for each group all year round and say they also run lots of different types of socials, with a wide range of performance opportunities, including Open Mic Nights, Jazz in the Barn, a Christmas Concert, Songs in Spring, Carol Services, Farmers' Market, Dining Ins and more!

The message sent out by the Group is "Get involved" adding that you play an instrument, or like singing, get in touch on Facebook, or with committee or conductors and follow their Facebook page for updates on concert dates and other exciting news!

SCHOOL ADMISSIONS. Admissions for a full time place at Sutton Bonington Primary School are governed by the local authority, Nottinghamshire County Council and parents need to apply directly to Nottinghamshire County Council to request a place at the school.

Please contact the school office on 01509 672661 if you would like further information, or to request a visit prior to application. A copy of the determined admission arrangements for 2023-2024 is available at: https://www.nottinghamshire. gov.uk/media/4320509/ admissionarrangements202324. pdf TENNIS CLUB. Despite weather problems that exist each Winter causing difficulties

for some sports and sports clubs, Sutton Bonington tennis club still play all year round on their LED floodlit courts and make a success of it as well.

The club say they are continuing the popular Monday group coaching sessions, which are for various age groups including adults, with all standards welcome, as well as two junior sessions every Saturday between 9.30 and 10.30 for under-nine's and 10-30- to 11.30 and players ten years and over. Further information on the sessions can be obtained from Jo at [email protected] The club also hold weekly social club evenings as well as plenty of opportunity for team tennis, with lots of fixtures continuing through the winter months. Contact here for information is Josh at ash. [email protected] or drop into the club on a Tuesday evening.

ADVENT FAIR. The Advent Fair held at Sutton Bonington St

Michaesl Church held earlier this month raised a profit of PS760 for funds.

The event,. held in the church, included a raffle, a bric a Brac stall; and others selling sweets, toys, tombola, cakes, Christmas cards and books. Alcohol free mulled wine and mince pies were also on offer as well as soup and rolls.

An illustrated history of the church was on display and drew interest from many of the visitors.

SCHOOL OPEN DAY. Sutton Bonington Primary School welcomed a good number of visitors last month for its Open Day morning when visitors were able to visit each classroom and learn about the curriculum and the enrichment activities that the school offers its pupils, including the Forest School, extra-curricular activities, pastoral care, having a vibrant PTA and good community links and on site independently run both before and after school provision and a buddy system to welcome new starters.

DISPESNSARY CLOSURE. The Village Health Group covering Sutton Bonington have announced the closure of dispensary services in the village.

The group, in a statement to the village, say they have taken the difficult decision to stop providing dispensary services from their premises in Sutton Bonington and have notified the National Health Service the system will cease as from Friday January 27 in the New Year.

Village residents and patients who use the current system can obtain more information on how to get their prescription from a pharmacy of their choice or nominate the pharmacy which they would like to dispense their electronic prescriptions by visiting a special link that has been set up at https://www.nhs-app/ nhs-app-help-and-support/ presriptions-in-the-nhs-app/ nominating-a-pharmacy or by visiting the health group website at www.villagehealthgroup.co.uk The Health Group say they would like to wish all of their patients and staffa very Merry Christmas and a Happy New Year MEMORIAL SERVICE. After a break of three years because of the coronavirus situation, Sutton Bonington St Anne's church were able earlier this month to stage its popular Memorial Service which again included a time for family and friends to light a candle in memory of a loved one.

Tea and biscuits were served after the service at which a total of 88 candles were lit.

Kegworth Mike Elliott 0115 937 6506 [email protected]

CHRISTMAS MARKET. Kegworth's festive season got offto a fine start thanks to the success of the Christmas Market held in what was a busy Market Place with several hundred people turning out to support the annual event.

The four hours of entertainment that was provided on the day began soon after lunch with many varied attractons, including the tradiional ceremony to switch on the village centre

festive lights.

Youngsters took opportnity of a visit to Santa's Grotto

while the adults had plenty of opportuniit to look round the stalsl offeriong food, drinks and general festive and other festive shopping.

Residents were invited to go down to the Market Place to hear the West Bridgford School band playing next to the village Christmas Tree., and they did in their numbers.

Another of the attractions was the annual appearance of two live reindeer - Boris and Mischa -- and then some 90 minutes later of Father Christmas. Kegworth Primary School were singing at 4.00 leading up to the tree lights ceremony 15 minutes later.

There were round 25 sideshows and stalls - outside Oaklands, Market Place and behind Soar Trading - supporting the local shops and between them creating a friendly and super festive atmosphere for the visitors to and around the Market Place.

The Days attractions and Market opened at 1pm festive music and an hour later the West Bridgford High School Band put in their contribution to herald the arrival of Father Christmas and kept playing in stages for nearly two hours. And with darkness looming children from the Primary School were back on scene to sing again to herald the festive tree lighting, followed by carols to music from the Band. Bells at the Parish church began ringing just before the market ended.

SCHOOL UPDATE. Confirmation has been given that the new school being built on Rempstone Road at East Leake to help provide much needed spaces for the influx of new scholars as the village continues to grow should be open in September 2023.

It is understood the new provision will be costing in the region of PS13million and will provide places for 210 primary school children along with a 26-place nursery.

In recent years

development of new housing in the village has outstripped what is available as far as school places go, and the extra accommodation need has been acknowledged by both Notts County Council and Rushcliffe Borough Council.

Without additional provision, dozens of parents have feared their children would not be able to be accommodated for schooling purposes in their own village and would have to travel to school elsewhere.

The Rempstone road development is not the only new schooling provision currently on the cards, and Rushcliffe Borough Council have given their support for a temporary school 'village' which is due to open in September next year, again to meet the growing need for education places in East Leake. This temporary site will accommodate an initial

120 children.

At their recent meeting Notts County Council's policy committee confirmed the costings and the timeframe for the new permanent school and Coun. Keith Girling, the conservative chairman of the economic development and asset management committee, told members that the school will cost PS13.62 million to provide. He admitted to the committee that current increasing demands for primary school places, the existing schools cannot meet what is required.

This will be split between Section 106 developer contributions from the property companies on Rempstone Road, and through support from the Government's Basic Needs programme The proposed the new primary school will be built on land provided by two housing developers as part of their Section 106 contributions, and to meet the demand it is proposed accommodation is provided in the temporary village from September next year..

It is understood a community group will be set up in Rushcliffe to share its views on the school's development and it will It will support the integration of the primary school into Rushcliffe's network of existing sites, many of which are rated good and outstanding by Ofsted.

Normanton on Soar

CHRISTMAS IN NORMANTON ON SOAR. It was good to be able to hold a number of events over the Christmas period.

First of all, there was an excellent turn-out for the switching-on of the Normanton on Soar Christmas Lights, with carols sung at the old conker tree and mulled wine and mince pies being enjoyed by all. A week later, the Candlelit Christmas Concert was held in St James Church and the following day, the Village and Soar Boating Club Carol Service took place, led by The Revd Canon Michael Knight. At this service, a cheque was presented to Wenlo Riding for the Disabled Group (based here in the village), which was St James Charity of the Year 2022. On Christmas Day, a service of Holy Communion was once again led by The Revd Canon Michael Knight.

NEW YEAR SERVICES AT ST JAMES' CHURCH. On New Year's Day, Jan Bonser will lead us in a service of Morning Prayer to greet the New Year.

Willoughby on the Wolds

BREAKFAST. The popular Willoughby on the Wolds Breakfast event returns to the village hall on Sunday January 8. Food will be served between 9.30and 11.30am and everyone will be welcome.

Long Whatton

and Diseworth CHURCH DEAL FALLS THROUGH. Long Whatton Methodist Church has now been closed for two years, although Methodism in the village can be traced back over 200 years. Efforts to purchase the building on behalf of the village have fallen through.

The 19th Century saw a huge rise in the number of practising Methodists, or Wesleyans as they were called, across England and the tiny villages in North West Leicestershire were no exception.

In 1829 a Chapel was built in Long Whatton behind the site of the existing church and throughout the century a large congregation was built up with a flourishing Sunday School. Church accounts record expenses for music for their Anniversaries, Clothing Clubs, Sunday School prizes, printing of hymn sheets etc. However by 1900 the little chapel was in a state of serious disrepair and an appeal was made for a new church describing the current premises as 'an old square dilapidated Chapel absolutely destitute of vestry and schoolroom and almost lost up a well nigh inaccessible yard.

A site on the Main Street was found and ambitious plans drawn up. An appeal was made throughout the Methodist circuit for subscriptions, a Great Circuit Bazaar was organised and with the sale of the existing chapel and land the funds were raised On 4th October 1911 the President of the Conference, Rev. John Hornabrook from Central Building, Manchester signed the official form for the sale of the old chapel and site with the proviso that 'of taking all possible means against being used for the manufacture or sale of intoxicating liquors, or as a theatre or dancing or music hall.'

The Early Days Methodism in Long

Whatton can be traced back over 200 years. The 19th Century saw a huge rise in the number of practising Methodists, or Wesleyans as they were called, across England and the tiny villages in North West Leicestershire were no exception.

In 1829 a Chapel was built in Long Whatton behind the site of the existing church and throughout the century a large congregation was built up with a flourishing Sun-day School. Church accounts record expenses for music for their Anniversaries, Clothing Clubs, Sunday School prizes, printing of hymn sheets etc. However by 1900 the little chapel was in a state of serious disrepair and an appeal was made for a new church describing the current premises as 'an old square dilapidated Chapel absolutely destitute of vestry and schoolroom and almost lost up a well nigh inaccessible yard.

A site on the Main Street was found and ambitious plans drawn up. An appeal was made throughout the Methodist circuit for subscriptions, a Great Circuit Bazaar was organised and with the sale of the existing chapel and land the funds were raised On 4th October 1911 the President of the Conference, Rev. John Hornabrook from Central Building, Manchester signed the official form for the sale of the old chapel and site with the proviso that 'of taking all possible means against being used for the manufacture or sale of intoxicating liquors, or as a theatre or dancing or music hall.'

In 1912 the new Church with Entrance Vestibule, organ, vestry, kitchen and large schoolroom was built to the delight of the congregation, the village and the Circuit. The Twentieth Century saw the

continuation of a very successful Sunday School with records showing large numbers of young people registering each week. Electricity was extended through the Church,

alterations took place to include a new kitchen and toilets and generally improve the building. The Church played its part during the WW2. A minute from the Annual Trustees meeting of February 1940 notes 'proposed and seconded, that Caretaker should be increased by one shilling per week during winter months on account of schoolroom being Ambulance fort and First Aid post.

By 1946 it was decided to raise the caretaker's salary by PS2 making it PS12.0.0 per year.

There are many references of thanks to church members who performed the task of organ blowing and in November 1948 the Trustees 'resolved in view of the generous gift of PS105 by Mr Eli Lester for the purposes of providing an electric blower for the organ, the trustees accepted unanimously the estimate for cleaning and making necessary improvements to the organ. It was resolved that a small plate be placed on the organ with words stating that the organ blower was the personal gift of Mr Eli Lester in memory of his mother and father'.

In January 1953 a request was made to rent the Schoolroom every Tuesday afternoon for a Darby and Joan Club meeting. The trustees decided to check the Standing Orders of the Methodist Church as regards 'what could and could not be done'. Unfortunately by the Annual Meeting following year it was noted that the Darby and Joan Club had 'fixed up their premises elsewhere' The meeting the following year, Mr Boultbee was asked at a fee of five shillings a

week to do the stoking of the boiler.

In 1955 water had been laid on and the copper in the scullery removed and an electric copper installed. New sink and draining board, also electric fire in the vestry.

In 1957 the Methodist Church balance sheet was 'in a favourable position' and

agreed that PS1.0.0 should be given towards extensions at Trinity Hall Girls School.

In 1961 it was resolved that the Trust should be renewed and new trustees added to the existing list bringing the number to 20. A year later a committee was formed to look into the 'various jobs that should be done to the chapel and material to be obtained and inquiries made of work to be carried out before the 50th Anniversary. Quotations were received for cleaning walls of the Chapel and the Sunday School, painting of ceilings and exterior cleaning.

The organ was removed from the front of the Chapel to the side. Following the Anniversary Celebration on 25th August 1962 the trustees recorded 'Everyone was very pleased with the result of the Chapel Anniversary both spiritually and financially and for the large attendances for the Services and the approximate figure of 100 for tea in the National School'.

In 2012 the Church celebrated the Centenary of the Church with an exhibition and tea.

The parish council say as previously reported the Long Whatton Methodist Church, based on its great historical significance within the village, was registered as an Asset of Community Value (ACV). This meant that once the asset was put up for sale, a notification had to be made to trigger the legal procedure attached to this policy.

However, as this didn't

happen first time around the Long Whatton Community Association (CA) and Long Whatton and Diseworth Parish Council (PC) were given the opportunity to review their project to buy it and rebid for the purchase; the ACV rules gave the community six months for the process to acquire the asset.

Obtaining the building for the benefit of the people of the parish for community use in perpetuity was considered important enough for the CA and PC to work together on a new bid. A plan was agreed and once permission was received from the Secretary of State a revised offer was tabled to the Selling Agent.

A council spokesman said: "Unfortunately, the new offer, that was more than double that previous put forward, was again unsuccessful. We have been advised that although the CA/PC bid was positive the community charity law dictates that the building had to be sold to the highest bidder, irrespective of any other consideration.

"On behalf of everyone involved, I would just like to thank you all for your continued help, support and efforts during this lengthy process; it's not the outcome we wanted, but we are sure the team could not have done more on your behalf."

Gotham BIRD PLEA. Gotham parish council have put out a message to residents to remember to put out food for the birds during spells of cold and bad weather.

In the message they say the birds need a reliable supply of supplementary food to get through the difficult winter months, so try to ensure you offer them a regular delivery service, refill feeders promptly and twice a day if required when the weather is really bad.

The appeal says: "When the

weather is really bad, birds need to refuel quickly after very snowy conditions " SCOUTS. Members oi the 1st Gotham Scout troop Explorer Scouts are working towards their Bronze Duke of Edinburgh Awards.

Tehre are four key activities in the DoE Challenge, volunteering is aimed at giving back to the community, physical for building endurance, Skills learning to

adapt to new challenges, expedition is for practical experience in outdoor activities.

Widmerpool

CLERK APPOINTED. Emma Goodman of Tollerton is the new clerk of Widmerpool Parish Council. She can be contacted by email at clerk@ widmerpool.parish.email

Mountsorrel MEETINGS OF THE PARISH COUNCIL/COMMITTEES: Monday January 9, 2023 Planning & Policy committee meeting at 7pm at the Memorial Centre, Monday January 16: Full Council meeting (including Budget setting) at 7pm in the Parish Room; Monday January 23: Projects & Amenities committee meeting at 7pm in the Parish Room EVENTS AT MOUNTSORREL MEMORIAL

CENTRE (MMC): Friday January 27, 2023: Motown, Soul & Northern Soul - PS8.

For more information about these events please contact the MMC by telephone 0116 230 4877 or email reception@ mountsorrelmc.co.uk

Wysall CORONATION PLANS. Plans are being formulated by the village Social Committee at Wysall for a Picnic in the Park event in May to celebrate the Coronation of King Charles III.

CAPTION(S):

Long Whatton Methodist Church.

Note(s):

ISSN: 0966-1948

Reports - Telecommunication - ENISA

Publication date: October 19, 2023 85633 mots

Threat Landscape - Download - fullReport

161 pages

Please note : This extract may not display a well formed paragraph

... EUROPEAN UNION AGENCY FOR CYBERSECURITY OCTOBER 2023 ENISA THREAT LANDSCAPE 2023 July 2022 to June 2023 ENISA THREAT LANDSCAPE 2023 October 2023 1 ABOUT ENISA The European Union Agency for Cybersecurity...

Full report:
https://www.enisa.europa.eu/publications/enisa-threat-landscape-2023/@@download/fullReport
Yahoo! Finance France (site web réf.) - Yahoo! Finance (FR)
November 10, 2023 7678 mots
Qurate Retail, Inc. (NASDAQ:QRTEA) Q3 2023 Earnings Call Transcript

Qurate Retail, Inc. (NASDAQ:QRTEA) Q3 2023 Earnings Call Transcript November 3, 2023 Operator: Welcome to the Qurate Retail, Inc. 2023 Q3 Earnings Call. [Operator Instructions] As a reminder, this conference... Voir l'article

Ce document référence un lien URL de site non hébergé par Cision.

PLoS ONE, no. Vol. 17, no 12
Research Article, Wednesday, December 28, 2022 6293 mots, p. e0279569

Coming together in a digital age: Community twitter responses in the wake of a campus shooting.

10.1371/journal.pone.0279569 Campus mass shootings have become a pressing policy and public health matter. Twitter is a platform used for processing events among interested community members. Examining the responses of invested community members to a mass shooting on a college campus provides evidence for how this type of violence affects the immediate community and the larger public. These responses may reflect either content (e.g. context-specific) or emotions (e.g. humor). Aims Using Twitter data, we analyzed the emotional responses as well as the nature of non-affective short-term reactions, in response to the April 2019 shooting at UNC Charlotte. Methods Drawn from a pool of tweets between 4/30/19-5/7/19, we analyzed 16,749 tweets using keywords related to the mass shooting (e.g. "shooting," "gun violence," "UNC Charlotte"). A coding team manually coded the tweets using content and sentiment analyses. Results Overall, 7,148 (42.67%) tweets contained negative emotions (e.g. anger, sadness, disgust, anxiety), 5,088 (30.38%) contained positive emotions (e.g. humor, hope, appreciation), 14,892 (88.91%) were communal responses to the shooting (e.g. prayers, healing, victim remembrance), 8,329 (49.73%) were action-oriented (e.g. action taken, policy advocacy), and 15,498 (92.53%) included information (e.g. death/injury, news). All tweets except positive emotions peaked one day following the incident. Conclusions Our findings point to peaks in most emotions in the 24 hours following the event, with the exception of positive emotions which peaked one day later. Social media responses to a campus shooting suggest college preparedness for immediate deployment of supportive responses in the case of campus violence is needed.

Author(s): Jessamyn Bowling 1,*, Erika Montanaro 1, Sarai Guerrero Ordonez 1, Sean McCabe 1, Shayna Farris 1, Neielle Saint-Cyr 1, Wade Glaser 2, Robert J. Cramer 1, Jennifer Langhinrichsen-Rohling 1, Annelise Mennicke 1

Introduction

Mass shootings on college campuses have multiplied in frequency since the 2007 Virginia Tech campus shooting. One survey found that 76 US gun violence incidents happened on college campuses between 2013 and 2016, leading to over 100 casualties [1]. There are direct effects of experiencing campus shootings, including injury, death, and mental health disorders such as post-traumatic stress disorder and depression [2]. Additionally, campus shootings receive disproportionate media coverage [3], raising concerns about secondary effects on the affected community as well as on contagion effects to others at risk for violence or mental health concerns [4].

As many Twitter posts seek affiliation with others [5], this type of social media can be used for communal responses. Twitter is commonly used during crises and natural disasters to disseminate information, call for assistance, mobilize resources, and process complex emotions [6]. Few studies have harnessed this publicly available data in the aftermath of a mass shooting on a college campus to examine content of tweets. Unfortunately, in April 2019, a former student of the University of North Carolina at Charlotte went to campus and shot and killed two students and injured four others [7]. The present study analyzed Twitter data in the week following the mass shooting for content and affect.

The role of social media in the aftermath of mass casualty events

Jones et al. [8] reviewed the state of the literature concerning use of social media, and specifically Twitter, for mass casualty events. They noted that natural disasters and disaster communications are commonly the subject of social media data analyses. For example, one study looked at social media use during natural disasters, such as a historic flood in South Carolina, finding that Twitter was widely used to alert others of weather conditions, devastation description, and resource distribution [9]. Brandt et al. [9] provide evidence of Twitter's potential to aid in recovery of natural disasters by providing important and tailored information at different stages of the event to users.

Jones et al. [8] also noted that community violence studies employing Twitter analysis in prior work have focused on traumatic responses related to country-level homicide rates [10] and the aftermath of the Sandy Hook shooting [11]. In their Twitter analysis of three separate mass shooting events, these authors found that general negative emotional content, as well as campus shooting event-related negative emotion, increased following the event [8]. Effects were small across case studies (campus shootings in Isla Vista, CA, Flagstaff, AZ, and Roseburg, OR).

Research on Twitter data may focus on the content of messages, frequency of posts, interactions with posts, and networks of users [12]. In one systematic review, over half (56%) of Twitter studies included content analyses and 15% included sentiment analyses [12]. Given the large volume of data available on Twitter, researchers have often used computational linguistic methods or algorithms to analyze tweets [e.g. 13] with some exceptions using smaller samples [e.g. 14,15]. However, a reliance on algorithms may preclude nuanced understandings of Twitter content.

Affective responses to mass shooting

Traumatic sequalae are one of the most well-documented impacts of campus shootings. For instance, following the seminal 2007 Virginia Tech shooting, students on campus during this tragic event demonstrated a variety of notable trauma symptoms including re-experiencing, lack of joy, and heightened physiological reactivity within one year of the event [16]. Closer proximity to the shooting was associated with greater post-traumatic stress symptomology, depression, anxiety, anger, and disconnection in students, faculty, and staff [17-19]; this phenomenon was explained by the occurrence of specific thinking styles-negative cognitions and problematic patterns of rumination-following campus shootings [18,19]. In addition, a study of 44 shootings found that students exposed to school shooting fatalities had increased and persistent antidepressant use within two years of the shooting event [20].

Some survivors experience post-traumatic growth after campus shootings. This phenomena was associated with emotional proximity to the shooting via deliberate efforts to engage in healthy thinking patterns [19], highlighting the interplay of emotional connection to the event, affect, and cognition. We also know that a relationship exists between traumatic stressors, negative affect, and social media use [21], so negative emotions and cognitive reactions to campus shootings, expressed via Twitter may be predictive of larger mental health concerns [22]. These findings suggest a fuller understanding of people's emotional and cognitive responses to a campus shooting is warranted.

Gaps in the literature and purpose

Prior studies using Twitter data are limited because they track only a generic category of negative affective tweets due to the inherent restrictions of the computational approach employed; the present study addresses this limitation through a detailed qualitative coding of the affective content of tweets, thereby allowing for a more nuanced understanding of emotional responses to campus mass shootings as portrayed on Twitter. Although we focus on a specific shooting incident, the implications for this study apply to other college contexts as we examine national responses to this shooting.

On April 30, 2019, a former student shot and killed two students and injured four others on University of North Carolina at Charlotte's (UNC Charlotte) campus [7]. The current study examines Twitter responses from the invested national community to that campus shooting with the following goals. First, in light of prior studies highlighting traumatic and negative emotions following mass casualty events, we sought to identify the negative emotional content of messages following the UNC Charlotte mass shooting. Second, given that protective factors (e.g., community connectedness) and positive outcomes (e.g., post-traumatic growth) may result from campus shootings, we sought to understand the presence and nature of positive affect as expressed through Tweets following the UNC Charlotte campus shooting. Finally, Twitter can serve as an informational resource after a mass casualty event as well as a backchannel to hold continued dialogue about an event of interest [23,24]. Calls for prevention and policy are increasing in response to the rise in campus events. For these reasons, we sought to answer the following research question: 1) What is the nature of non-affective short-term reactions to the UNC Charlotte campus shooting?; 1a) How do the reactions fluctuate in the week following the shooting?.

A priori, we expected that the majority of negative affective reactions expressed on Twitter in the immediate aftermath of a school shooting would portray fear, anxiety or worry. Secondarily, we expected a large portion of tweets to express anger at the perpetrator.

Methods

An initial sample of 2,246,000 tweets was gathered from the day of the UNC Charlotte shooting on April 30, 2019 until May 7, 2019. Data for this research consisted solely of publicly available tweets and was not considered human subjects research by our university's Institutional Review Board. We used Twitter streaming application program interface (API) to collect tweets [25]. These tweets incorporated the keywords "UNCC", "shooting", "shooter", "mass shooting", "gun", "gun violence", "ninerstrong", "charlottestrong", and "UNC Charlotte". Next, a subset of tweets were reviewed to help ensure the coded tweets were specifically related to the UNC Charlotte shooting and were not related to other national incidents of gun violence. Tweets discussing current events at the time such at #SanDiegoSynagogue and #TeenMom as well as related keywords (e.g., "gun girl") were removed. Additionally, tweets were also removed if they utilized the word shoot/shooting but were unrelated to gun violence or UNC Charlotte (e.g., "I refused to let this video of Chris Evans successfully shooting his shot with a black girl die"). In total, 713,262 tweets were removed. Of the remaining 1,532,738 tweets, we then extracted a random sample of 75,000 from the initial pool. The 75,000 tweets were divided among four coders and evaluated for relevancy to UNC Charlotte shooting, Charlotte, NC, national policies, and other incidents of gun violence. From this, a total of 16,749 tweets fit the criteria in the initial sort.

We conducted directed content analysis of tweets, with categories stemming in part from the existing literature rather than only emerging from the data [26]. Concurrently, we conducted manual emotion analysis, which analyzes emotional classes contained in a text. A preliminary codebook was created based on literature searches and preliminary analyses of the most common themes that appeared during the initial sort. Our emotional classes began with basic emotions in the wheel of emotions (joy, sadness, trust, disgust, fear, anger, surprise, and anticipation) [27,28] which were then refined based on preliminary analyses of emotions present in our sample (e.g., removal of joy, addition of numbness/tiredness). Each tweet could receive multiple codes, no codes (this did not occur in our sample as non-relevant codes were discarded beforehand). Coders were instructed to contact the team for questionable tweets, which were discussed in weekly meetings during the coding period.

Utilizing the preliminary codebook (see S1 Table), two coders coded a random subsample of tweets (n = 500) and included only those that were relevant to Charlotte (n = 294). We conducted Fleiss' multirater kappas [29] for codes by the two coders (S2 Table). Overall agreement ranged from adequate-to-good for nine codes (i.e., anger, sadness, humor, appreciation, thoughts/prayers, healing/communal response, victim remembrance/honor, blame/responsibility, and policy advocacy; kappas ranged from.52 to 1.00). Rarer codes had less agreement (e.g., hope, disbelief/shock, need support, uncertainty/confusion; kappas ranged from -0.01 to.38). Codes with fewer occurrences are subject to more extreme kappa values [30]. Therefore, in lieu of relying solely on quantitative inter-rater agreement metrics, we subsequently tabulated the overall percent agreement for each code. Such a strategy is consistent with prior literature under coding conditions using a binary coding scheme and rarely endorsed occurrences of an affirmative content category [31]. The overall percent agreement between the two primary coders from the Charlotte-specific Tweets ranged from 95-100%. After coding the initial sample, the two lead coders met with two additional student coders and the project PI faculty member to identify sample tweets which would help to refine and clarify codebook descriptions, add additional emerging codes to the codebook (e.g. "Shooter" for information related to the shooter), and ensure common team understandings [32]. This team re-coded tweets with initial rater discrepancies; the refined codebook was then used for all subsequent analyses. Each of the student coders coded a random subsample of approximately 3,600 tweets and the PI coded 1,953 tweets. Table 1 shows the emotions coded in the tweets and their corresponding descriptions. It should be noted that tweets may include several categories. For example, the tweet: "ENOUGH !!! If you do not believe we have a problem , then fine , but get out of the way. If you believe more guns are the solution , you are wrong. We have a problem in this country and if you argue with that , you are part of the problem " was categorized as displaying negative affect and a communal response.

Results

Frequency and prevalence of categories tweeted after UNC Charlotte shooting

Of the available 16,749 tweets, 7,148 (42.67%) contained negative emotions, 5,088 (30.38%) contained positive emotions, 14,892 (88.91%) were communal responses to the shooting, 8,329 (49.73%) were action-oriented, and 15,498 (92.53%) included information. Most of the tweets (n = 14,571, 86.99%) were coded with more than one code.

Categories by day

Fig 1 depicts the total tweets per day by type of category. Note that the shooting occurred at 5:40PM on April 30, 2019. Of the 7,148 negative affect categorized tweets, 4,228 (59.15%) occurred on May 1, 2019. Similarly, of the 14,892 communal response tweets 6,742 (45.27%) were tweeted on May 1, 2019. A majority of the action-oriented tweets (N = 4,188; 50.28%) were posted on May 1, 2019. Information tweets also peaked on May 1, 2019 (N = 6,739, 43.48%). Positive affect tweets peaked a day later, on May 2, 2019: 38.95% (N = 1,982) of all positive tweets occurred then.

Fig 1. Total tweets per day by type. [see PDF for image]

Within the peak day for negative affect tweets (May 1, 2019), disgust/contempt was the mostly frequently displayed affect (N = 1,453; 29.50%) followed by numbness (19.75%), anger (16.59%), and then sadness/grief (15.37%). Unexpectedly, fear and anxiety/worry were coded less frequently (less than 5%).

Victim remembrance occurred most often within the communal response category (N = 1,723; 25.56%). Action-oriented tweets were most frequently coded as general action recommendations (N = 1,825; 43.58%) and peaked on May 1, 2019. Within the information category, death/injury (N = 2,400; 35.61%) was most often tweeted. Finally, appreciation was most frequently coded (N = 1,948; 98.28%) within the positive affect category and typically occurred on May 2, 2019. See Table 2 for a complete report and examples of each category coded.

Discussion

Leveraging social media data (i.e., tweets), we sought to describe the emotional responses as well as the nature of non-affective short-term reactions, in response to the April 2019 shooting at UNC Charlotte. We did so by employing an intensive qualitative coding process allowing for detailed examination of tweets by subcategory across the days immediately following the campus violence. Two key findings emerged from our analysis. First, we were able to code social media responses into five categories: negative affect, positive affect, communal response, action, and information. Second, all categories but positive affect peaked within one day of the shooting. We consider each set of primary findings in turn.

Negative versus positive affect in social media responses to a campus shooting

As expected, tweets with negative affect greatly outnumbered tweets with positive affect (humor/sarcasm, appreciation, hope). The timeline of the affect-related communications also differed with tweets with negative affect peaking sharply within 24 hours, followed by positive affect tweets peaking slowly over the second day. This pattern can be interpreted in a variety of ways including being consistent with responses related to the survival instinct (fight/flight/fear first; gratitude and higher order processing second), or the characteristics of this particular social media platform (as a forum for quick dissemination of information and strong [often negative] immediate reactions to on-going events rather than longer term adaptation).

The nature of coded negative tweets was unexpected, however. A priori it was anticipated that a significant percentage of the coded negative affect would include fear, worry, or anxiety as these emotions are typically considered prerequisite experiences for traumatic reactions (DSM-5). However, it is possible that these types of emotions, which may signal immediate and situational vulnerability, may be atypical for Twitter; these feelings may also be hard to express via a tweet during or immediately following the traumatic event. It is also possible that the relatively quick resolution of this shooting event (approximately 15 minutes from shooting to arrest, though campus lockdown lasted much longer) and the time of day in which it occurred (post end of business day) truncated a more robust expression of fear. Understanding the unique affective tone of Twitter, and considering the expression of types of affect in reference to characteristics of a particular trauma will be an important step for future research. It will also be important to determine if those users who expressed fear are more likely to develop negative emotional health sequelae over time.

Contempt was the most common emotional tone conveyed in tweets with negative affect. Contempt is a complex negative emotion that includes the perception that something is beneath consideration or below one's own position. Tweets in this category included at least two distinct types of content: contempt for the shooter and his behavior versus contempt for the university's ability to keep the campus safe or our country's ability to prevent gun violence and protect our children and young adults. Both instances of contempt fit with the empirically-derived nature of the construct which has been reported to characterized by repudiation and socially excluding the target of the contempt [34]. That is, social media may serve as an outlet for rejection and efforts to exclude the perpetrators of the violence, as well as rejection of the institution's failures to protect its members. This later line of tweets suggests that Twitter provides an outlet for policy-related distress and discouragement as well. Given that Twitter also reaches a large audience, this finding highlights the further need for policy-makers and public health professionals to meaningfully engage social media communities in the aftermath of violent events. The relatively large prevalence of tweets falling into this group suggests a broad awareness of the need for systemic change; this is directly reflected in some tweets that explicitly call out lawmakers to do more to prevent gun violence.

It is also noteworthy that relatively few tweets were categorized as expressing confusion. There seems to be a shift from questioning "why" these events are happening toward expressing, distain and/or distress that policy makers and others have not acted more forcefully to prevent these tragedies. This conclusion is further supported by the substantial number of tweets categorized as angry/aggressive as well as the many positive tweets that were coded as sarcastic humor. Importantly, expressions of aggressive humor (e.g., sarcasm) may actually be a sign of need for help given that such humor styles may be associated with a variety of negative health outcomes [e.g., 35,36]. Taken as a whole, the affective tweets highlight the diverse nature of the emotional responses occurring in the immediate wake of the UNC Charlotte campus shooting. Moreover, given the peak in negatively valanced Twitter responses in the immediate hours after the event, campus administrators, police, and first responders may need to have prior plans in place to be able to address diverse emotional needs in a time-sensitive manner. The varied responses also support the need for access to well-trained mental health providers in communities affected by gun violence; further research considering how particular early emotional responses relate to long-term adaptation or resiliency is warranted.

Communal response in social media responses to a campus shooting

The variety of communal response, action and information themes observed in post-shooting Tweets also provide insight into community needs post-shooting. For instance, communal responses highlight the importance of remembering victims, as well as assessing or assigning blame for the shooting and seeking justice. From a public health perspective, to the extent these issues extend beyond the short-term matters, they highlight topics that campuses should be prepared to handle as part of a comprehensive postvention (handling the aftermath of a severe public health event) plan [37]. Although traditionally applied to the topic of suicide [38], postvention planning is necessary for any campus violence-related event. Study findings also inform how campus and community members may be consuming information. That is, information coming from official campus entities was not the most frequently tweeted. Instead, themes of death/injury as well as retweets from off-campus news organizations were more common, perhaps indicating that more people were turning to the news rather than consuming UNC Charlotte official responses. As such, campus communication teams should be working more closely with the local or regional community news outlets for accurate and timely information communication.

Previous research related to mass shootings found local news outlets providing space for grieving and community connection [39]. This may have motivated some of the preponderance of news story sharing, as we saw a variety of news stories from victim remembrance to sharing details of the shooter and other topics. More research is needed to analyze whether the news stories shared were more likely to contain communal grieving spaces or other purposes, such as sharing updates on the facts of the event.

Time analyses

The fact that most social media response categories trailed off after 24-48 hours is informative. The short-lived nature of social media reactions to the UNC Charlotte campus shooting may reflect a broader shift toward a shortened media cycle. Indeed, it has been hypothesized that the rise in access to 24-hour news and information has resulted in shortened community-level attention paid to even the most intense or tragic events [40]. The short-term nature of social media responses to the UNC Charlotte shooting pale in comparison to the scope of the 2007 Virginia Tech shooting, which at the time drew intense international coverage and long-term media speculation, in part, due to the novelty of the event [41]. No matter the explanation, the short time span of community-level attention afforded such events may point to a missed opportunity for those left behind. As such, one lesson that can be drawn from our findings is the need to prepare immediate response plans to deal with a complex affective and cognitive response to campus shootings that, at first may be expressed through social media but, over time, may recede, resulting in impacted persons falling through the cracks. Formal response plans often, but not always, exist on college campuses in the form of threat assessment teams or post-event protocols involving law enforcement and counseling services [42]. However, they often lack nuance and face a number of implementation challenges (e.g., lack of staff training in postvention; barriers to effective community-wide notification [43]). A more comprehensive approach needs to include best practices such as educating campus community about risk factors/warning signs of violent behavior, making a singular easily identifiable anonymous reporting system available, and a campus-wide team approach involving numerous professionals and departments [44].

Strengths and limitations

This study incorporated a large pool of tweets and the use of manual coding techniques increasing the reliability of findings. Meetings between the coding team assisted our evolving understandings of concepts and increased team agreement. Due to the limitations in our approach, we may not have captured tweets that did not include our key words or hashtags but were in reference to the UNC Charlotte shooting. Further, in light of the impact of low endorsement of some content codes on formal metrics of inter-rater agreement, we relied in part on overall percent agreement between coders instead. Thus, caution should be applied when interpreting or generalizing findings, especially involving codes with low frequency endorsement. Furthermore, we acknowledge that Twitter users are predominantly younger, wealthier, and more educated compared to the general US population [45]. With our focus on college campuses, the relevant audiences may be inherently more educated. Future research may need to include multiple platforms or communication methods to obtain a more nationally representative portrait.

Limitations to this study should be noted. First, Twitter is a discrete social media platform that tends to be used in particular ways. For example, Twitter is often used for news and high-frequency users often post regarding politics [45-47]. Given the political focus and college students using Twitter may be more socially connected than those using other platforms [48], Twitter may provide early indications of campus climate trends. The volume of tweets suggests that university response needs to include a diverse array of social media platforms. Releasing information on Twitter is likely going to serve a large group that is having a strong, primarily negative, immediate response to campus events.

Conclusion

We find dense social media posts of negative affect and calling for general action within a relatively short window after a mass shooting. To meet needs implied by this trend, campus responses for student support must be prepared for immediate deployment. The high proportion of tweets with disgust/contempt, numbness, and anger may reflect the use of Twitter for outward-facing messaging or relate to societal attitude shifts of mass shootings.

Supporting information

S1 Table Preliminary codebook. (DOCX)

S2 Table Inter-rater reliability with Fleiss multirater kappas. (DOCX)

References

1. Saha K, De Choudhury M. Modeling stress with social media around incidents of gun violence on college campuses. Proceedings of the ACM on Human-Computer Interaction. 2017;1(CSCW):1-27.

2. Children's Hospital of Philadelphia Research Institute-Center for Violence Prevention. School Shootings Philadelphia, PA2020 [cited 2021 February 23]. Available from: https://violence.chop.edu/types-violence/school-shootings#.Xx8L7y-z29Y.

3. Silva JR, Capellan JA. A Comparative Analysis of Media Coverage of Mass Public Shootings: Examining Rampage, Disgruntled Employee, School, and Lone-Wolf Terrorist Shootings in the United States. Criminal Justice Policy Review. 2018;30(9):1312-41. doi: 10.1177/0887403418786556

4. Lee KJ. Mass shootings and media contagion theory: Social media's influence on frequency of incidents. Elon Journal of Undergraduate Research in Communications. 2018;9(2):27-35.

5. Zappavigna M. Discourse of Twitter and social media: How we use language to create affiliation on the web. Hyland K, editor. New York: Continuum; 2012.

6. Leong CML, Pan SL, Ractham P, Kaewkitipong L. ICT-enabled community empowerment in crisis response: Social media in Thailand flooding 2011. Journal of the Association for Information Systems. 2015;16(3):1.

7. Marusak J, Clasen-Kelly F, Douglas A, Janes T. 'May he rot in hell': Sentence for UNC Charlotte gunman splits victims, prosecutors. Charlotte Observer. 2019 September 19.

8. Jones NM, Wojcik SP, Sweeting J, Silver RC. Tweeting negative emotion: An investigation of Twitter data in the aftermath of violence on college campuses. Psychological methods. 2016;21(4):526. doi: 10.1037/met0000099 27918180

9. Brandt HM, Turner-McGrievy G, Friedman DB, Gentile D, Schrock C, Thomas T, et al. Examining the role of Twitter in response and recovery during and after historic flooding in South Carolina. Journal of public health management and practice. 2019;25(5):E6-E12. doi: 10.1097/PHH.0000000000000841 31348171

10. De Choudhury M, Monroy-Hernandez A, Mark G, editors. "Narco" emotions: affect and desensitization in social media during the Mexican drug war. Proceedings of the SIGCHI conference on Human Factors in Computing Systems; 2014; New York.

11. Glasgow K, Fink C, Boyd-Graber J, editors. "Our Grief is Unspeakable'': Automatically Measuring the Community Impact of a Tragedy. Proceedings of the International AAAI Conference on Web and Social Media; 2014.

12. Sinnenberg L, Buttenheim AM, Padrez K, Mancheno C, Ungar L, Merchant RM. Twitter as a Tool for Health Research: A Systematic Review. American Journal of Public Health. 2017;107(1):e1-e8. doi: 10.2105/AJPH.2016.303512 27854532.

13. Giachanou A, Crestani F. Like it or not: A survey of Twitter sentiment analysis methods. ACM Computing Surveys (CSUR). 2016;49(2):1-41.

14. Armstrong CL, Fangfang G. Now Tweet This: How News Organizations Use Twitter. Electronic News. 2010;4(4):218-35. doi: 10.1177/1931243110389457

15. Borgmann H, Woelm J-H, Merseburger A, Nestler T, Salem J, Brandt MP, et al. Qualitative Twitter analysis of participants, tweet strategies, and tweet content at a major urologic conference. Can Urol Assoc J. 2016;10(1-2):39-44. doi: 10.5489/cuaj.3322 26977205.

16. Mancini AD, Littleton HL, Grills AE, Jones PJ. Posttraumatic Stress Disorder Near and Far: Symptom Networks From 2 to 12 Months After the Virginia Tech Campus Shootings. Clinical Psychological Science. 2019;7(6):1340-54. doi: 10.1177/2167702619859333

17. May CL, Wisco BE. Defining trauma: How level of exposure and proximity affect risk for posttraumatic stress disorder. Psychological Trauma: Theory, Research, Practice, and Policy. 2016;8(2):233-40. doi: 10.1037/tra0000077 26390110

18. Boykin DM, Dunn QT, Orcutt HK. Cumulative Trauma and Adjustment in Women Exposed to a Campus Shooting: Examining the Role of Appraisals and Social Support. Journal of Interpersonal Violence. 2020;35(17-18):3601-21. Epub 2018/01/04. doi: 10.1177/0886260517710483 29294766.

19. Wozniak JD, Caudle HE, Harding K, Vieselmeyer J, Mezulis AH. The effect of trauma proximity and ruminative response styles on posttraumatic stress and posttraumatic growth following a university shooting. Psychol Trauma. 2020;12(3):227-34. Epub 2019/08/16. doi: 10.1037/tra0000505 31414869.

20. Rossin-Slater M, Schnell M, Schwandt H, Trejo S, Uniat L. Local exposure to school shootings and youth antidepressant use. Proceedings of the National Academy of Sciences. 2020;117(38):23484-9. doi: 10.1073/pnas.2000804117 32900924

21. Zhao N, Zhou G. Social Media Use and Mental Health during the COVID-19 Pandemic: Moderator Role of Disaster Stressor and Mediator Role of Negative Affect. Applied Psychology: Health and Well-Being. 2020;12(4):1019-38. doi: 10.1111/aphw.12226 32945123

22. Seabrook EM, Kern ML, Fulcher BD, Rickard NS. Predicting depression from language-based emotion dynamics: longitudinal analysis of Facebook and Twitter status updates. Journal of medical Internet research. 2018;20(5):e168. doi: 10.2196/jmir.9267 29739736

23. Lipizzi C, Iandoli L, Ramirez Marquez JE. Extracting and evaluating conversational patterns in social media: A socio-semantic analysis of customers' reactions to the launch of new products using Twitter streams. International Journal of Information Management. 2015;35(4):490-503. https://doi-org.univ-eiffel.idm.oclc.org/10.1016/j.ijinfomgt.2015.04.001.

24. Jenkins EM, Zaher Z, Tikkanen SA, Ford JL. Creative identity (re)Construction, creative community building, and creative resistance: A qualitative analysis of queer ingroup members' tweets after the Orlando Shooting. Computers in Human Behavior. 2019;101:14-21. https://doi-org.univ-eiffel.idm.oclc.org/10.1016/j.chb.2019.07.004.

25. Makice K. Twitter API: Up and running. Sebastopol, CA: O'Reilly Media, Inc.; 2009.

26. Hsieh H-F, Shannon SE. Three approaches to qualitative content analysis. Qualitative health research. 2005;15(9):1277-88. doi: 10.1177/1049732305276687 16204405

27. Shiraishi N, Reilly J. Content analysis of the emotions affecting caregivers of relatives with schizophrenia. Current Psychology. 2020. doi: 10.1007/s12144-020-01185-2

28. Plutchik R. Emotion: A psychoevolutionary synthesis. New York: Harper and Row; 1980.

29. Fleiss JL. Measuring nominal scale agreement among many raters. Psychological bulletin. 1971;76(5):378.

30. Krippendorff K. Commentary: A dissenting view on so-called paradoxes of reliability coefficients. Annals of the International Communication Association. 2013;36(1):481-99.

31. Wu SM, Whiteside U, Neighbors C. Differences in Inter-Rater Reliability and Accuracy for a Treatment Adherence Scale. Cognitive Behaviour Therapy. 2007;36(4):230-9. doi: 10.1080/16506070701584367 18049948

32. Richards KAR, Hemphill MA. A practical guide to collaborative qualitative data analysis. Journal of Teaching in Physical Education. 2018;37(2):225-31.

33. Mohammad SM. Sentiment analysis: Detecting valence, emotions, and other affectual states from text. Emotion measurement: Elsevier; 2016. p. 201-37.

34. Fischer AH, Roseman IJ. Beat them or ban them: The characteristics and social functions of anger and contempt. Journal of Personality and Social Psychology. 2007;93(1):103-15. doi: 10.1037/0022-3514.93.1.103 17605592

35. Kaniuka AR, Oakey-Frost N, Moscardini EH, Tucker RP, Rasmussen S, Cramer RJ. Grit, humor, and suicidal behavior: Results from a comparative study of adults in the United States and United Kingdom. Personality and Individual Differences. 2020;163. doi: 10.1016/j.paid.2020.110047

36. Fritz HL. Why are humor styles associated with well-being, and does social competence matter? Examining relations to psychological and physical well-being, reappraisal, and social support. Personality and Individual Differences. 2020;154:109641. https://doi-org.univ-eiffel.idm.oclc.org/10.1016/j.paid.2019.109641.

37. Suicide Prevention Resource Center. Provide for Immediate and Long-Term Postvention. Oklahoma City, OK: Suicide Prevention Resource Center, 2020.

38. Erbacher TA, Singer JB, Poland S. Suicide in schools: A practitioner's guide to multi-level prevention, assessment, intervention, and postvention. New York: Routledge; 2014.

39. McWhorter C. VB Strong: how local news stations created a platform for a community to mourn victims of a mass shooting. Atlantic Journal of Communication. 2021:1-14. doi: 10.1080/15456870.2021.1891900

40. Rosenberg H, Feldman CS. No time to think: The menace of media speed and the 24-hour news cycle. New York: Continuum; 2008.

41. Hawdon J, Agnich LE, Ryan J. Media framing of a tragedy: A content analysis of print media coverage of the Virginia Tech tragedy. Traumatology. 2014;20(3):199-208. doi: 10.1037/h0099400

42. Deisinger ERD, Scalora MJ. Threat assessment and management in higher education in the United States: A review of the 10 years since the mass casualty incident at Virginia Tech. Journal of Threat Assessment and Management. 2016;3:186-99. doi: 10.1037/tam0000074

43. Rompalo S, Parks R, Taylor A. Suicide Postvention: A Growing Challenge for Higher Education Administrators. College and University. 2021;96(1):63-70.

44. Hollister BA, Scalora MJ. Broadening campus threat assessment beyond mass shootings. Aggression and Violent Behavior. 2015;25:43-53. https://doi-org.univ-eiffel.idm.oclc.org/10.1016/j.avb.2015.07.005.

45. Wojcik S, Hughes A. Sizing Up Twitter Users. Washington, DC: Pew Research, 2019.

46. Posegga O, Jungherr A, editors. Characterizing political talk on Twitter: A comparison between public agenda, media agendas, and the Twitter agenda with regard to topics and dynamics. Proceedings of the 52nd Hawaii International Conference on System Sciences; 2019.

47. Shearer E, Matsa KE. News Use Across Social Media Platforms 2018. Washington, DC: Pew Research, 2018.

48. Shane-Simpson C, Manago A, Gaggi N, Gillespie-Lynch K. Why do college students prefer Facebook, Twitter, or Instagram? Site affordances, tensions between privacy and self-expression, and implications for social capital. Computers in Human Behavior. 2018;86:276-88. https://doi-org.univ-eiffel.idm.oclc.org/10.1016/j.chb.2018.04.041.

Author Roles:

Jessamyn Bowling: Conceptualization, Data curation, Formal analysis, Methodology, Project administration, Supervision, Writing - original draft, Writing - review & editing

Erika Montanaro: Conceptualization, Visualization, Writing - original draft, Writing - review & editing

Sarai Guerrero Ordonez: Formal analysis, Methodology, Supervision, Writing - original draft, Writing - review & editing

Sean McCabe: Formal analysis

Shayna Farris: Formal analysis

Neielle Saint-Cyr: Formal analysis

Wade Glaser: Formal analysis, Visualization

Robert J. Cramer: Conceptualization, Writing - original draft, Writing - review & editing

Jennifer Langhinrichsen-Rohling: Conceptualization, Writing - original draft, Writing - review & editing

Annelise Mennicke: Conceptualization, Writing - original draft, Writing - review & editing

Author Affiliation:

1 University of North Carolina at Charlotte, Charlotte, NC, United States of America, 2 Gaston Day School, Gastonia, NC, United States of America

Corresponding Author: * E-mail: [email protected]

Editor: Nabeel Al-Yateem, University of Sharjah, UNITED ARAB EMIRATES

Article History:

Received Date: 11/1/2021

Accepted Date: 12/9/2022

Published Date: 12/28/2022

Copyright: © 2022 Bowling et al

This is an open access article distributed under the terms of the Creative Commons Attribution License, which permits unrestricted use, distribution, and reproduction in any medium, provided the original author and source are credited.

Data Availability: https://doi-org.univ-eiffel.idm.oclc.org/10.6084/m9.figshare.19448210.v1.

Funding: The authors received no specific funding for this work.

Competing interests: The authors have declared that no competing interests exist.

DOI: 10.1371/journal.pone.0279569

Note(s):

ISSN: 1932-6203

10.1371/journal.pone.0279569 Campus mass shootings have become a pressing policy and public health matter. Twitter is a platform used for processing events among interested community members. Examining the responses of invested community members to a mass shooting on a college campus provides evidence for how this type of violence affects the immediate community and the larger public. These responses may reflect either content (e.g. context-specific) or emotions (e.g. humor). Aims Using Twitter data, we analyzed the emotional responses as well as the nature of non-affective short-term reactions, in response to the April 2019 shooting at UNC Charlotte. Methods Drawn from a pool of tweets between 4/30/19-5/7/19, we analyzed 16,749 tweets using keywords related to the mass shooting (e.g. "shooting," "gun violence," "UNC Charlotte"). A coding team manually coded the tweets using content and sentiment analyses. Results Overall, 7,148 (42.67%) tweets contained negative emotions (e.g. anger, sadness, disgust, anxiety), 5,088 (30.38%) contained positive emotions (e.g. humor, hope, appreciation), 14,892 (88.91%) were communal responses to the shooting (e.g. prayers, healing, victim remembrance), 8,329 (49.73%) were action-oriented (e.g. action taken, policy advocacy), and 15,498 (92.53%) included information (e.g. death/injury, news). All tweets except positive emotions peaked one day following the incident. Conclusions Our findings point to peaks in most emotions in the 24 hours following the event, with the exception of positive emotions which peaked one day later. Social media responses to a campus shooting suggest college preparedness for immediate deployment of supportive responses in the case of campus violence is needed.

Reports - Defence - Defense CAN

Publication date: November 9, 2023 69640 mots

Departmental Results Report 2022-2023 - Download the PDF version [PDF - 3.7 MB] - 2022-23-departmental-results-report.pdf

156 pages

Please note : This extract may not display a well formed paragraph

... 2022-23 DEPARTMENTAL RESULTS REPORT DEPARTMENT OF NATIONAL DEFENCE AND CANADIAN ARMED FORCES | i DEPARTMENT OF NATIONAL DEFENCE AND CANADIAN ARMED FORCES 2022-23 DEPARTMENTAL RESULTS REPORT The Honourable Bill Blair...

Full report:
https://www.canada.ca/content/dam/dnd-mdn/documents/reports/2023/2022-23-departmental-results-report.pdf
FOX News (web site ref.) - Fox News
October 16, 2023 92416 mots
Deadline expires for Palestinians to flee Gaza as Israeli troops amass at border

incoming update… President Biden has postponed his planned visit to Colorado on Monday and will instead remain at the White House as Israeli forces appear poised to invade Northern Gaza. President... Voir l'article

Ce document référence un lien URL de site non hébergé par Cision.

Reports - Telecommunication - FCC

Publication date: November 2, 2023 92330 mots

- pdf - FCC-23-86A1.pdf

144 pages

Please note : This extract may not display a well formed paragraph

... Federal Communications Commission FCC 23-86 Before the Federal Communications Commission Washington, D.C. 20554 In the Matter of Unlicensed Use of the 6 GHz Band Expanding Flexible Use in Mid...

Full report:
https://docs.fcc.gov/public/attachments/FCC-23-86A1.pdf
FOX News (web site ref.) - Fox News
October 15, 2023 84813 mots
Deadline expires for Palestinians to flee Gaza as Israeli troops amass at border

incoming update… Former Israeli special operator Aaron Cohen says the delay of Israel's ground invasion may be due to new intelligence regarding the state of hostages taken by Hamas in... Voir l'article

Ce document référence un lien URL de site non hébergé par Cision.

FOX News (web site ref.) - Fox News
October 14, 2023 76544 mots
Israel gives Palestinians deadline to flee Gaza as troops amass at border

incoming update… IDF spokesman Daniel Hagari said Friday the Israeli army recovered the bodies of several Israelis who have been missing since the Oct. 7 surprise attack by Hamas and notified... Voir l'article

Ce document référence un lien URL de site non hébergé par Cision.

EDGAR Online-Prospectus and Proxies
Thursday, October 19, 2023 55960 mots, p. NA
Aussi paru dans

15 septembre 2023 | - | EDGAR Online-8-K Glimpse

S-1/A: Nexscient, Inc.

(EDGAR Online via COMTEX) -- As filed with the Securities and Exchange Commission on October 19, 2023.

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

Delaware 7372 92-2915192 (State or other (Primary Standard Industrial (I.R.S. Employer jurisdiction of Classification Code Number) Identification incorporation or Number) organization)

    UNITED STATES

    UNITED STATES

    UNITED STATES

(Address, including zip code, and telephone number, including

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

Approximate date of commencement of proposed sale to the public: As soon as practicable after this registration statement is declared effective.

If any of the securities being registered on this Form are to be offered on a delayed or continuous basis pursuant to Rule 415 under the Securities Act of 1933, check the following box. ?.

If this Form is filed to register additional securities for an offering pursuant to Rule 462(b) under the Securities Act, check the following box and list the Securities Act registration statement number of the earlier effective registration statement for the same offering. ?

If this Form is a post-effective amendment filed pursuant to Rule 462(c) under the Securities Act, check the following box and list the Securities Act registration statement number of the earlier effective registration statement for the same offering. ?

If this Form is a post-effective amendment filed pursuant to Rule 462(d) under the Securities Act, check the following box and list the Securities Act registration statement number of the earlier effective registration statement for the same offering. ?

Indicate by check mark whether the registrant is a large accelerated filer, an accelerated filer, a non-accelerated filer, smaller reporting company, or an emerging growth company. See the definitions of "large accelerated filer," "accelerated filer," "smaller reporting company," and "emerging growth company" in Rule 12b-2 of the Exchange Act.):

Large accelerated filer ? Accelerated filer ? Non-accelerated filer ? Smaller reporting company ? Emerging growth company ?

If an emerging growth company, indicate by check mark if the registrant has elected not to use the extended transition period for complying with any new or revised financial accounting standards provided pursuant to Section 7(a)(2)(B) of the Securities Act. ?

This Offering is being conducted on a "best efforts/no minimum" basis, meaning that no aggregate minimum offering amount is required to be raised by us in this Offering and accordingly, no assurance can be given that any shares being offered in this Offering will be sold.

The registrant hereby amends this registration statement on such date or dates as may be necessary to delay its effective date until the registrant shall file a further amendment which specifically states that this registration statement shall thereafter become effective in accordance with Section 8(a) of the Securities Act of 1933 or until the registration statement shall become effective on such date as the Securities and Exchange Commission acting pursuant to such Section 8(a), may determine.

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

(4) Direct Public Offering.

(5) The filing fee is calculated based upon the fee rate of $0.00011020.

THE REGISTRANT HEREBY AMENDS THIS REGISTRATION STATEMENT ON SUCH DATE OR DATES AS MAY BE NECESSARY TO DELAY ITS EFFECTIVE DATE UNTIL THE REGISTRANT SHALL FILE A FURTHER AMENDMENT WHICH SPECIFICALLY STATES THAT THIS REGISTRATION STATEMENT SHALL THEREAFTER BECOME EFFECTIVE IN ACCORDANCE WITH SECTION 8(A) OF THE SECURITIES ACT OF 1933, AS AMENDED, OR UNTIL THE REGISTRATION STATEMENT SHALL BECOME EFFECTIVE ON SUCH DATE AS THE SECURITIES AND EXCHANGE COMMISSION, ACTING PURSUANT TO SAID SECTION 8(A), MAY DETERMINE.

    UNITED STATES

Table of Contents

THE INFORMATION IN THIS PROSPECTUS IS NOT COMPLETE AND MAY BE CHANGED. THESE SECURITIES MAY NOT BE SOLD UNTIL THE REGISTRATION STATEMENT FILED WITH THE SECURITIES AND EXCHANGE COMMISSION IS EFFECTIVE. THIS PROSPECTUS IS NOT AN OFFER TO SELL THESE SECURITIES AND IT IS NOT SOLICITING AN OFFER TO BUY THESE SECURITIES IN ANY STATE WHERE THE OFFER OR SALE IS NOT PERMITTED.

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

There is no minimum number of shares that must be sold by us for the Offering to proceed, and we will retain the proceeds from the sale of any of the offered shares, except that we will not receive any proceeds from the sale of shares by Selling Shareholders. This Offering is being conducted on a "best efforts/no minimum" basis, meaning that no aggregate minimum offering amount is required to be raised by us in this Offering. As such, the actual public offering amount and proceeds to us, if any, are not presently determinable and net proceeds may be substantially less than the total maximum offering set forth above. The Offering is being self-underwritten, which means our officers and directors will attempt to sell the shares directly to friends, family members and business acquaintances. Our officers and directors will not receive commissions or any other remuneration from any such sales. In offering the securities on our behalf, our officers and directors will rely on the "safe harbor" provisions of SEC Rule 3a4-1, promulgated under the Securities Exchange Act of 1934, as amended (the "Exchange Act"). Generally speaking, Rule 3a4-1 provides an exemption from the broker-dealer registration requirements of the Exchange Act for persons associated with an issuer that participate in the sale of the securities of such issuer. We are an "emerging growth company" under applicable Securities and Exchange Commission rules and will be subject to reduced public company reporting requirements.

The shares will be offered for sale at a fixed price of $0.75 per share for a period of one hundred and eighty (180) days from the effective date of this Prospectus, unless extended by our Board of Directors for an additional 90 days. If all of the shares offered by us are purchased, the gross proceeds to us will be $3,000,000. All funds raised hereunder will become immediately available to the Company and will be used in accordance with the Company's intended "Use of Proceeds" as set forth herein. Investors are advised that they will not be entitled to a refund and could lose their entire investment.

The Company is a development stage company and currently has limited operations. Any investment in the shares offered herein involves a high degree of risk. You should only purchase shares if you can afford a loss of your investment. Our independent registered public accountant has issued an audit opinion for the Company, which includes a statement expressing substantial doubt as to our ability to continue as a going concern.

This Prospectus covers the primary public offering by the Company of 4,000,000 shares of Common Stock. The Company is concurrently conducting a resale offering for 7,682,980 shares of Common Stock, which is covered in a separate Resale Prospectus.

THE PURCHASE OF THE SECURITIES OFFERED THROUGH THIS PROSPECTUS INVOLVES A HIGH DEGREE OF RISK. YOU SHOULD CAREFULLY READ AND CONSIDER THE SECTION OF THIS PROSPECTUS ENTITLED "RISK FACTORS" BEFORE BUYING ANY SHARES OF NEXSCIENT'S COMMON STOCK.

NEITHER THE SECURITIES AND EXCHANGE COMMISSION NOR ANY STATE SECURITIES COMMISSION HAS APPROVED OR DISAPPROVED OF THESE SECURITIES OR PASSED UPON THE ADEQUACY OR ACCURACY OF THIS PROSPECTUS. ANY REPRESENTATION TO THE CONTRARY IS A CRIMINAL OFFENSE.

    UNITED STATES

Table of Contents

No dealer, salesperson or any other person is authorized to give any information or make any representations in connection with this offering other than those contained in this Prospectus and, if given or made, the information or representations must not be relied upon as having been authorized by us. This Prospectus does not constitute an offer to sell or a solicitation of an offer to buy any security other than the securities offered by this Prospectus, or an offer to sell or a solicitation of an offer to buy any securities by anyone in any jurisdiction in which the offer or solicitation is not authorized or is unlawful.

    UNITED STATES

    UNITED STATES

This Registration Statement contains two prospectuses, as set forth below.

    UNITED STATES

    UNITED STATES

The Resale Prospectus is substantively identical to the Public Offering Prospectus, except for the following principal points:

? they contain different outside and inside front covers; ? they contain different Offering sections; ? they contain different Use of Proceeds sections; ? a Selling Shareholders section is included in the Resale Prospectus; ? they contain different Plan of Distribution sections; ? the Dilution section is deleted from the Resale Prospectus; ? they contain different outside back covers.

The Registrant has included in this Registration Statement, after the financial statements, a set of alternate pages to reflect the foregoing differences of the Resale Prospectus as compared to the Public Offering Prospectus.

    UNITED STATES

Table of Contents

    UNITED STATES

    UNITED STATES

You should rely only on the information contained or incorporated by reference to this prospectus in deciding whether to purchase our common stock. We have not authorized anyone to provide you with information different from that contained or incorporated by reference to this prospectus. Under no circumstances should the delivery to you of this prospectus or any sale made pursuant to this prospectus create any implication that the information contained in this prospectus is correct as of any time after the date of this prospectus. To the extent that any facts or events arising after the date of this prospectus, individually or in the aggregate, represent a fundamental change in the information presented in this prospectus, this prospectus will be updated to the extent required by law.

    UNITED STATES

Table of Contents

    UNITED STATES

The following summary highlights material information contained elsewhere in this prospectus. This summary does not contain all of the information you should consider before investing in our common stock. Before making an investment decision, you should read the entire prospectus carefully, including the "Risk Factors" section, the "Management's Discussion and Analysis of Financial Condition and Results of Operations" section, the financial statements and the notes to the financial statements. You should also review the other available information referred to in the section entitled "Where You Can Find More Information" in this prospectus and any amendment or supplement hereto. Unless otherwise indicated, the terms the "Company," "Nexscient," "we," "us," and "our" refer and relate to Nexscient, Inc.

Corporate History and General Information about the Company

Nexscient, Inc. (the "Company") is an early-stage company, which was incorporated in the State of Delaware on March 14, 2023. Our fiscal year-end is June 30. We are a development stage enterprise. The Company is engaged in the business of developing and commercializing a Software as a Service platform that exploits Industrial Internet-of-Things (IIoT), Artificial Intelligence (AI), and Cloud-computing technologies to deliver an innovative solution for manufacturers and continuous production facilities in the industrial automation sector that helps reduce equipment failures, avoid unscheduled downtimes, decrease equipment maintenance costs, and improve overall equipment efficiencies.

The Company has not yet developed its software platform and generated no revenues to date. Most of management's time, and the Company's limited resources have been spent on research and development of the Company's condition monitoring and predictive analytics platform and developing its business strategy.

Our principal office is located at 2029 Century Park East, Suite 400, Los Angeles, CA 90067. Our telephone number is (310) 494-6620 and our e-mail contact is [email protected]. Our website can be viewed at https://nexscient.com/. The Company has not filed for bankruptcy, receivership or any similar proceedings nor is in the process of filing for bankruptcy, receivership or any similar proceedings.

Company Overview

The Company was incorporated in the State of Delaware on March 14, 2023. We intend to offer of a continuous, remote condition-based monitoring solution for manufacturers and continuous production facilities seeking to implement a Predictive Maintenance (PdM) program. Our platform intends to leverage the latest IIoT technology with edge processing, machine-learning/AI algorithms, and Cloud computing infrastructure to collect, diagnose and transmit critical information about machine health and performance. Unlike other condition-monitoring programs on the market today, we plan to take a unique approach by offering a remote, continuous monitoring solution that is autonomous and machine agnostic with no equipment purchase requirement. Designed as a scalable, stand-alone solution, our solution does not depend on integration with any control or IT system for its data source. Our design plans to utilize a mesh network of data collection nodes that are externally-mounted to the outer casing of the equipment being monitored and data is collected via three on-board sensors, including acoustic, vibration and temperature. Compatible with virtually all rotating machinery, regardless of age, make, model or condition, the nodes collect and securely transmit pertinent data from the on-board sensors via a secure gateway to our Cloud-based analytics platform for processing and diagnosis.

Nexscient Cloud software intends to use rule-based logic, which incorporates anomaly detection and domain-level expertise to analyze the data and deliver immediate actionable insights and corrective recommendations without the reliance upon a large historical data set. Our initial deployment of the system will rely primarily on rule-based anomaly detection. Critical information about the machine's health and performance are processed and analyzed in real-time. Advance-warning alerts of impending issues are generated and transmitted to select maintenance personnel with recommended corrective procedures delivered as work orders.

Contemporaneously, the data collected from each Nexscient Node will be processed and stored in our data lake so that over time we will have aggregated sufficient amounts of data to train machine learning algorithms to build predictive models that can be used in the future releases as an enhancement to our service offering. Future enhancements to the Nexscient system will leverage our machine learning/AI models to perform long-term assessments, such as root cause analysis and estimate remaining useful life.

An intuitive user interface displaying detailed information about alert conditions can be viewed for further investigation, via a Web browser or mobile device. Our distinct advantage is realized through our ability to rapidly deploy a continuous remote monitoring solution that produces actionable insights with highly accurate predictions of incipient failures well in advance of their occurrence.

We believe Nexscient will offer significant improvements and innovations to be brought to the growing market for predictive maintenance by substantially improving efficacy, safety and cost. We expect to drastically simplify the implementation of Predictive Maintenance programs by offering its machine health monitoring solution as a subscription-based service. We intend to generate revenues initially through our subscription service and may generate additional revenues from premium service offerings as well as consulting services that will be offered directly to customers.

The proceeds of the Offering will largely be utilized for development and commercialization of the Nexscient Predictive Maintenance Platform, marketing of the service and software platform, and payroll expenses. The Company plans to retain five full time staff and lease nominal executive office facilities in Los Angeles, California. All legal, accounting, and shareholder relations may be outsourced to consultants as needed. Business development is limited to developing and maintaining a website presence, and nominal travel and business expenses.

    UNITED STATES

Table of Contents

Competition

We compete with an array of established and emerging vendors of condition-based monitoring products and services and IIOT-equipped devices. As organizations increasingly embrace predictive maintenance, IIoT and other new industrial automation technologies, an increasing number of companies offering machine monitoring products and services strive could result to fill the growing demand. The introduction of new technologies and market entrants will continue to fuel an intense competitive environment as companies seek solutions to predicting equipment failures and maintaining equipment performance. Our competitors include condition-based monitoring equipment vendors, diversified diagnostic equipment and services vendors, and providers of machine monitoring products that compete with some of the features present in our solution such as Fluke, Emerson, and Augury. We compete based on several factors, including product functionality; scope of offerings; performance; brand, reputation, and customer satisfaction; ease of implementation, use and service; price, scalability, reliability, and security. We believe that we will compete favorably with respect to these factors and are well positioned as an emerging provider of predictive maintenance solution, data analysis, and professional services.

Background

The Company had its genesis in Spring 2022 when our team of seasoned entrepreneurs and engineers with relevant backgrounds and experience in engineering, finance, and wireless communications, came together for the purpose of developing and commercializing a monitoring solution to exploit the benefits of acoustic and vibration analysis coupled with Industrial Internet of Things (IIOT), wireless mesh communications, Machine Learning/Artificial Intelligence (AI), and Cloud computing to address unmet needs of predictive equipment maintenance.

Industrial Internet of Things (IIoT)

The Internet of Things (IoT) refers to the network of physical objects or "things" embedded with sensors, software, and other technologies, interconnected through various communication protocols, networks, and cloud-based platforms. These interconnected objects collect and exchange data, enabling them to interact with the external environment or other systems in an intelligent manner. The Industrial Internet of Things (IIoT) is a transformative manufacturing strategy that integrates advanced digital technologies into the industrial sector to enhance operational efficiencies, improve performance, and create new revenue models. IIoT is an extension of the Internet of Things (IoT) paradigm, specifically tailored to industrial contexts, encompassing sectors including manufacturing, energy, oil and gas, and transportation.

Artificial Intelligence (AI) & Machine Learning (ML)

Artificial Intelligence (AI) is a branch of computer science focused on creating systems capable of performing tasks that would typically require human intelligence. These tasks include, but are not limited to, problem-solving, understanding natural language, perception (such as vision or speech recognition), and decision-making. AI systems are designed to mimic or simulate human cognitive functions, and they can operate either based on predefined rules (via algorithms) or by learning from data. Machine Learning is a subset of AI that provides systems the ability to learn and improve from experience without being explicitly programmed. In essence, ML focuses on the development of algorithms that can process vast amounts of data, derive patterns from this data, and then make decisions or predictions based on it.

Cloud Computing

Cloud computing is a technology paradigm that provides scalable, on-demand computing resources, delivered as a service over the internet. Instead of owning and maintaining physical data centers and servers, businesses can rent access to anything from applications to storage from a cloud service provider. This offers flexibility, cost-effectiveness, and the ability to scale services according to the need of the user. In the case of Nexscient, we intend to leverage cloud computing to offer Software as a Service (SaaS) to deliver our software solution over the Internet on a subscription basis, which will be hosted and maintained "in the cloud," thus eliminating the need for users to install or maintain the software locally.

While vibration analysis offered tremendous benefits for identifying potential problems with rotating machinery, we found that the vast majority of products on the market require a sizable capital investment with the purchase of diagnostic equipment and accessories; licensing, installation and upkeep of proprietary software; and specialized training of personnel. Furthermore, because of the manual nature of route-based, condition monitoring systems currently utilized methods, maintenance staff must patrol the factory on a regular basis, typically in 30 to 40-day intervals to manually collect measurement readings from the machines and then has to spend time for reviewing and analyzing the collected data.

Realizing the shortcomings of most existing products on the market and understanding that significant benefits of condition monitoring can truly be realized through an efficient, streamlined, and cost-effective solution, we decided to take a unique approach by developing a continuous monitoring solution as a subscription-based service - one that not only offered all of the benefits of condition-based monitoring diagnostic system through vibration and acoustic analysis, but also offered those benefits with (i) no upfront capital expense of equipment and software purchases; (ii) no need to update and maintain and update purchased diagnostic equipment and software, (iii) no requirement for specialized training of maintenance personnel; and (iv) no need for licensing, maintaining, and updating software. From a financial perspective, our solution is more affordable because it does not require upfront investment and shifts what would be a capital expenditure to an operating expense for the customer. For the Company, our business model provides a pathway to profitability through recurring stream of revenues that can be realized through a growing base of subscribers and subscriptions.

Our Growth Strategy

We believe the Nexscient Predictive Maintenance solution will be viewed by businesses as a cost-effective way to reduce maintenance costs while increasing productivity, giving them advance warning of potential machine failure allowing them to properly schedule maintenance and better manage their resources. One of the key differentiators in our marketing strategy is to emphasize the "no up-front cost" subscription feature because we provide all of the monitoring sensors as part of the subscription service, thereby eliminating a capital expenditure to the business's balance sheet. Management will emphasize speed in penetrating selected markets and implementing advertising and public relations campaigns. Financial results will be compiled and reported weekly so that gross and net margins can be reviewed and benchmarked against the competition. Marketing will be continually monitored and adjusted as needed to maximize market penetration and profitability. Cost control and brand management will be critical to the overall strategy.

Large untapped markets in Asia-Pacific and Middle East could offer growth opportunities to market players. The condition-based monitoring market in Asia-Pacific is displaying strong growth due to continuous infrastructure development and business expansions, especially in emerging countries, mainly China and India. The deregulation policy and a substantial increase in foreign direct investments (FDIs) in Asian countries also triggered the establishment of new businesses across many industries in the Asia-Pacific region. Moreover, the countries in the Middle East, primarily Saudi Arabia and Qatar, are also increasing the use of condition-based monitoring in the oil and gas sector.

    UNITED STATES

Table of Contents

Recent Developments

On July 12, 2023, the Board appointed Mr. Michael J. Portera as a director and Chief Financial Officer of the Company.

Risks and Uncertainties facing the Company

As an early-stage company with a limited operating history, the Company has experienced losses since its inception. The Company's independent auditors have issued a report questioning the Company's ability to continue as a going concern. That is, the Company needs to create a source of revenue or locate additional financing in order to continue its developmental plans. As a development stage company, management of the Company has experience in developing technology similar to that planned by the Company but limitation in marketing and distributing such services and products on a broad scale.

One of the biggest challenges facing the Company is the ability to increase its sales revenue and raise adequate capital to develop and execute project opportunities.

Due to financial constraints, the Company has to date conducted limited operations. If the Company were unable to develop strong and reliable sources of funding for future growth opportunities, it is unlikely that the Company could develop its operations to return revenue sufficient to further develop its business plan. Moreover, the above assumes that the Company's efforts are met with customer satisfaction in the marketplace and exhibit steady adoption of its solutions amongst the potential base of customers, neither of which are currently known or guaranteed.

Due to these and other factors, the Company's need for additional capital, the Company's independent auditors have issued a report raising substantial doubt of the Company's ability to continue as a going concern.

Trading Market

Currently, there is no trading market for the securities of the Company. The Company intends to initially apply for admission to quotation of its securities on the OTC Bulletin Board as soon as possible, which may be while this offering is still in process. There can be no assurance that the Company will qualify for quotation of its securities on the OTC Bulletin Board. See "RISK FACTORS" and "DESCRIPTION OF SECURITIES".

    UNITED STATES

Table of Contents

    UNITED STATES

The Issuer Nexscient, Inc.

Securities being Up to 4,000,000 shares of Common Stock is being offered for offered sale by the Company, this collectively represents approximately 16.7% of the currently issued and outstanding shares of the Company's Common Stock, if the offering is fully subscribed. Our Common Stock is described in further detail in the section of this prospectus titled "DESCRIPTION OF SECURITIES."

Per Share $0.75 Offering Price

Duration of The Shares are offered for a period of one hundred and eighty Offering (180) days from the effective date of this Prospectus, unless extended by our Board of Directors.

Common stock There are 19,955,980 shares of Common Stock issued and outstanding outstanding. before the Offering Assuming we sell only shares of common stock in this Offering, there will be 23,955,980 shares of Common Stock issued and Common stock outstanding. outstanding after the Offering

Net Proceeds to We will receive net proceeds of $3,000,000 if the offering is the Company fully subscribed for all 4,000,000 shares of Common Stock at an offering price of $0.75 per Share. The full subscription price will be payable at the time of subscription and accordingly, funds received from subscribers in this Offering will be released to the Company when subscriptions are received and accepted. No assurance can be given that the net proceeds from the total number of shares offered hereby or any lesser net amount will be sufficient to accomplish our goals. If proceeds from this offering are insufficient, we may be required to seek additional capital. No assurance can be given that we will be able to obtain such additional capital, or even if available, that such additional capital will be available on terms acceptable to us.

    UNITED STATES

    UNITED STATES

    UNITED STATES

Table of Contents

    UNITED STATES

An investment in our Common Stock involves a high degree of risk. You should carefully consider the risks described below and the other information in this Prospectus before investing in our Common Stock. If any of these risks actually occur, our business, financial condition and results of operations could be materially and adversely affected and we may not be able to achieve our goals, the value of our securities could decline and you could lose some or all of your investment. Currently, shares of our Common Stock are not publicly traded. In the event that shares of our Common Stock become publicly traded, the trading price of our Common Stock could decline due to any of these risks, and you may lose all or part of your investment. In the event our Common Stock fails to become publicly traded, you may lose all or part of your investment. Additional risks not presently known to us or that we currently believe are immaterial may also significantly impair our business operations. Some statements in this prospectus, including statements in the following risk factors, constitute forward-looking statements. Please refer to the section titled "Cautionary Statement Regarding Forward-Looking Statements."

    UNITED STATES

Investing in the Company is a highly speculative investment and could result in the loss of your entire investment.

A purchase of the offered securities is significantly speculative and involves significant risks. The offered securities should not be purchased by any person who cannot afford the loss of his or her entire purchase price. The business objectives of the Company are also speculative, and we may be unable to satisfy those objectives. The stockholders of the Company may be unable to realize a substantial return on their purchase of the offered securities, or any return whatsoever, and may lose their entire investment in the Company. For this reason, each prospective purchaser of the offered securities should read this prospectus and all of its exhibits carefully and consult with their attorney, business advisor and/or investment advisor.

The offering price of the offered securities has been arbitrarily determined by the Company and such offering price should not be used by an investor as an indicator of the fair market value of the offered securities.

Currently there is no public market for the Company's common stock. The offering price for the offered Shares has been arbitrarily determined by the Company and does not necessarily bear any direct relationship to the assets, operations, book, or other established criteria of value of the Company. Thus, an investor should be aware that the offering price does not reflect the fair market price of the offered securities.

As there is no minimum for our offering, if only a few persons purchase shares, they could lose their investment.

Since there is no minimum with respect to the number of securities to be sold directly by the Company in this Offering, if only a few Shares are sold, we may not have enough capital to sustain our business. In such an event, it is highly likely that any investment would be lost. As such, proceeds from this Offering may not be sufficient to meet the objectives we state in this Prospectus, other corporate milestones that we may set, or to avoid a "going concern" modification in future reports of our auditors as to uncertainty with respect to our ability to continue as a going concern. If we fail to raise sufficient capital, we expect to have to significantly decrease operating expenses, which will curtail the growth of our business.

The Company's management has full discretion in allocating net proceeds from the Offering.

We have allocated the net proceeds of the Offering in the sum of $3,000,000 (assuming the sale of all 4,000,000 shares of Common Stock) to working capital and operational expenses of the Company. As to such funds, investors will be relying on the judgment and discretion of the Company's management without specific information as to the uses, which are proposed to be made of such funds. Further, we may use any portion of the net proceeds of the Offering to acquire and/or invest in businesses related to the business of the Company (see "Use of Proceeds").

Investors in the offering will experience immediate dilution of the value of their shares.

Purchasers of the Shares will experience immediate dilution in the value of their Shares. Dilution represents the difference between the price per share paid by investors and the net tangible book value per share immediately after completion of the Offering (see "Dilution"). Net tangible book value per share is the net tangible assets of the Company (total assets less total liabilities less intangible assets), divided by the number of shares of common stock outstanding. As of June 30, 2023, the Company's net tangible book value before the Offering was $0.01 per share. Thus, if at some other time, shares had been sold by the Company at a price less than the $0.75 paid by purchasers of the Shares or had been issued by the Company for services or as other non-cash consideration, then the value of such investor Shares immediately after purchase would be less than the purchase price. The Company has issued shares prior to the date of this Prospectus at a price less than $0.75. In addition to the dilution described above, further dilution may result if additional shares of Common Stock are sold or issued in the future, including shares issued in connection with any subsequent financing or initial public offering.

10

Table of Contents

There is no firm commitment underwriting for the Offering.

We do not have a firm commitment underwriting for the Offering. The Company is offering its Shares for sale through its officers and directors on a "self-underwritten", "best efforts" basis without compensation. Accordingly, there is no assurance that we will sell the maximum Shares offered or any amount. If all of the Shares offered hereby are not sold, the Company will be limited in its ability to conduct its business.

    UNITED STATES

We have a limited history of operations and unless we are able to successfully execute our business plan, our business and operating results will suffer, resulting in the complete failure of our business.

Nexscient, Inc. is a start-up company with limited assets and limited operating history. As such, we face the risks and problems associated with any business in its early stages with a limited operating history on which an evaluation of its prospects can be made. The likelihood of our success must be considered in light of the risks, problems, expenses and delays frequently encountered in connection with the formation of a new business in general, as well as the highly competitive environment in which the business is operating. To address these risks, we must, among other things, continue to respond to competitive developments, attract, retain and motivate qualified personnel, commercialize products, and implement and successfully execute our marketing strategy and advertising sales strategy. There can be no assurance that we will be successful in addressing such risks.

Our ability to operate the business successfully is dependent, in part, on a variety of factors, including our ability to expand our operations into new geographic areas as well as into existing and/or new market niches within our industry. In addition, the rate of growth may be dependent upon our ability to identify and negotiate favorable deals with strategic partners that will assist the Company in the development, marketing and sales of its products and services. There can be no assurance regarding whether or when we will implement the business plan successfully or that we will achieve profitability.

The Company has limited operating history of its own, and as such, any prospective investor can only assess the Company's profitability or performance on a limited basis to date.

Because the Company is an early-stage company with limited operating history, it is impossible for an investor to assess the performance of the Company or to determine whether the Company will meet its projected business plan. The Company has limited financial results upon which an investor may judge its potential. As a development-stage company, the Company may in the future experience under-capitalization, shortages, setbacks and many of the problems, delays and expenses encountered by any early-stage business. An investor will be required to make an investment decision based solely on the Company management's history and its projected operations in light of the risks, expenses and uncertainties that may be encountered by engaging in the Company's industry.

The Company has no revenues to date.

The Company has generated no revenues to date. Most of management's time, and the Company's limited resources have been spent on research and development of the Company's condition monitoring and predictive analytics platform and developing its business strategy. Most of the activity has been centered in the following areas: researching potential opportunities, preparing a business model, hiring software development consultants and programmers, working with software developers and programmers, working with engineers and manufacturers of sensors and related hardware apparatus, selecting professional advisors, bookkeeping, accounting, corporate record keeping, seeking capital for the Company, and preparing this registration statement.

The proposed operations of the Company are speculative; there are no assurances that we will receive any revenue.

The success of the proposed business plan of the Company will depend to a great extent on the operations, financial condition, and management of the Company. Although the Company has a business plan and intends to execute its overall business strategy, limited operations have been conducted to date and the proposed operations of the Company remain speculative. Technology development generally may continue for years before any revenue is realized or generated, if at all.

11

Table of Contents

Our current research and development efforts may not produce successful products or enhancements to our platform that result in significant revenue, cost savings or other benefits in the near future, if at all.

We must continue to dedicate significant financial and other resources to our research and development efforts if we are to maintain our competitive position. However, developing products and enhancements to our platform is expensive and time consuming, and there is no assurance that such activities will result in significant new marketable products or enhancements to our platform, design improvements, cost savings, revenue, or other expected benefits. If we spend significant resources on research and development and are unable to generate an adequate return on our investment, our business and results of operations may be materially and adversely affected.

The Company depends on its management team and employees to operate its business effectively.

The Company's future success is dependent in large part upon its ability to understand and develop the business plan and to attract and retain highly skilled management, operational and executive personnel. In particular, due to the relatively early stage of the Company's business, its future success is highly dependent on its officers, to provide the necessary experience and background to execute the Company's business plan. We presently expect each of our officers and directors to devote such amount of time as they reasonably believe is necessary to our business; our officers are currently working full time for the Company. We do not know if we would be able to replace the key executives and personnel with equally competent people in the event their services become unavailable (see "Management"). The loss of any officer's services could impede, particularly initially as the Company builds a record and reputation, its ability to develop its objectives, particularly in its ability to develop, commercialize and further its business and products.

The Company's business also depends on its ability to attract and retain talented software developers, engineers, product marketing and sales professionals. Any loss of key members of the team and the customer relationship associated with the member can impact the business significantly.

The Company expects to incur additional expenses and may ultimately never be profitable.

The Company is a development-stage company and it has limited operations to date. The Company will need to continue to generate revenue to achieve and maintain profitability. To become profitable, the Company must successfully develop its product sales and operate its business. These processes involve many factors that are beyond the Company's control, including the type of competition that the Company may encounter. Ultimately, in spite of the Company's best or reasonable efforts, the Company may never actually generate revenues sufficient to cover operating expenses or become profitable.

Costs associated with our business, including software development and programming costs are not fixed and might increase, creating uncertainty about our ability to meet our plan of operations.

We have not established long-term contracts with our consultants or other third-party suppliers we intend to rely on. The lack of long-term contracts could result in an increase in what we pay these individuals for their services. An increase in the development costs will reduce our margins and might make our projects uneconomical, leading to the failure of our business.

We are in the development stage and have conducted no market research on the viability of our products or services. There is no guarantee that we will be able to sell enough of our products or services to generate a profit, and failure to become profitable will result in the failure of our business.

The market for our products and services is limited in scope and there is no assurance that our products or services will generate market acceptance and result in revenue. We are developing our products and services with no market research and there is no assurance that we will be able to respond to the rapidly evolving markets in the industrial automation market. The inability to sell our products or services will result in the failure of our business.

No assurance of market acceptance.

Even if the Company successfully markets, sells, and distributes its technology, products and services, there can be no assurance that the market reception will be positive for the Company or its offerings. The widespread adoption and use of the Company's condition monitoring products and services will represent fundamental change in the industrial automation industry. As with any new technology, there is a substantial risk that potential customers may not accept the potential benefits of the Company's products or services. Market acceptance of Company's products will depend, in large part, upon the ability of Company to demonstrate the performance advantages and cost-effectiveness of its products over competing products. There can be no assurance that Company will be able to market its technology successfully on a widespread basis or that any of Company's current or future products or services will be accepted in the marketplace. Furthermore, Company intends to develop products and systems and sell them at a price assumed by Company sufficient to generate a profit. Even if Company's products and services are accepted in the industry, the market for its products may not be able to support Company's pricing structure.

12

Table of Contents

If the prices we charge for our services are unacceptable to our customers, our operating results will be harmed.

As the market for our services matures, or as new or existing competitors introduce new products or services that compete with ours, we may experience pricing pressure and be unable to renew our agreements with existing customers or attract new customers at prices that are consistent with our pricing model and operating budget. If this were to occur, it is possible that we would have to change our pricing model or reduce our prices, which could harm our revenue, gross margin, and operating results.

If the Company is unable to develop and introduce new products and improvements, the Company may be unable to compete in the marketplace.

The market for the Company's condition monitoring products and services is characterized by evolving industry requirements. Accordingly, the Company's future performance depends on a number of factors, including its ability to identify emerging technological trends in its target markets, to develop and maintain competitive products, to enhance its products by adding innovative features that differentiate the Company's products from those of its competitors, and to manufacture and bring products to market quickly at cost-effective prices. There can be no assurance, however, that the Company will successfully complete the development of any products, that such products will achieve market acceptance that such products will receive regulatory approvals where required, that any required regulatory approvals will be received in a timely manner, or that such products can be produced at competitive prices, or at all. In the event that its products are not timely developed, do not gain market acceptance or cannot be manufactured at competitive prices, the Company's business could be materially adversely affected.

Rapid growth will place a significant strain on our managerial, operational, and financial resources.

If we grow as planned, our growth will place a significant strain on our managerial, operational, and financial resources. To accommodate this growth, we must implement new or upgraded operating and financial systems, procedures and controls. We may not succeed in these efforts. Our failure to expand and integrate these areas in an efficient manner could have a material adverse effect on our business, financial condition, and results of operations. To develop our products and achieve success, we may need to identify, recruit, hire, and train a significant number of employees, particularly employees with relevant technical, marketing and sales backgrounds. These individuals are in high demand. We may not be able to attract such personnel. This could have a material adverse effect on the Company's business, financial condition, and results of operations.

The Company's growth strategy through acquisitions may present additional risks.

From time-to-time Nexscient may undertake acquisitions consistent with its stated growth strategy. The successful implementation of acquisitions will depend on a range of factors including funding arrangements, geographic issues, staff continuity, compatibility of equipment and infrastructure and regulatory requirements. To the extent that acquisitions are not successfully integrated with the Company's then existing businesses, the financial position and performance of the Company could be adversely affected. Depending on various factors affecting our business at the time of any future acquisition such as the Company's share price, its financial position and performance and the nature of the acquisition, management may decide that it is in the best interests of the Company and its shareholders to fund the acquisition through the issue of further shares. If this were to occur, it may result in dilution of the ownership interests of its shareholders.

We may need to acquire licensing rights to certain proprietary technologies.

The Company may acquire licensing rights to certain technologies protected by patents and patents pending as part of its product development business plan. Our success will depend in significant part on our ability to obtain and maintain meaningful licenses for such patented and proprietary technologies. Patent law relating to the scope of claims in the technology fields in which we will license is still evolving. The degree of future protection for our licensed proprietary rights is uncertain. We will rely on license agreements to protect a significant part of the licensed intellectual property and to enhance our competitive position. While, we presently do not hold any licenses to patents or technologies pending patent applications, there is no assurance that will be able to obtain such licenses on terms acceptable to the Company. If we fail to obtain licenses for proprietary technologies, our ability to be commercially competitive will be materially impaired.

Production and manufacturing of our Nodes will be outsourced to a third-party contract manufacturer. We are also exploring other potential joint venture options for sourcing Nodes. If we don't secure such contract manufacturer or establish a joint venture arrangement with a supplier to produce and deliver Nodes in a timely manner for any reason, our business, prospects, financial condition and results of operation could be materially harmed.

13

Table of Contents

While we initially intend to integrate nodes purchased from a third-party supplier, we plan to design and integrate our nodes at some point in the future. When we do, we expect to outsource the manufacturing of the Nexscient Nodes to a third-party contract manufacturer, which we may heavily rely upon. We are also exploring other potential joint venturing options with suppliers of nodes, in addition to the contract manufacturer. Collaboration with third parties, including joint ventures, for the manufacturing of Nodes is subject to risks that may be outside of our control. While we have a preliminary verbal understanding with a third-party contract manufacturer and joint venture partner, we have not entered into a legally binding definitive agreement with either the contract manufacturer or such joint venture partner. Failure to reach a memorandum of understanding and cooperation agreement or pursue other commercial arrangements (such as contract manufacturing or sale agreement) on terms acceptable to the Company at any time before any definitive agreements are signed may limit or have a material adverse effect on the Company and its ability to offer its services.

In addition, we may experience delays if such third-party contract manufacturing or joint venture partner does not meet agreed upon timelines or experiences capacity constraints. There is risk of potential disputes with business partners, and the Company could be affected by adverse publicity related to its business partners, whether or not such publicity is related to their collaboration with the Company. Our ability to successfully build a premium brand could also be adversely affected by perceptions if the quality of the third-contract manufacturing partners or joint venture's products not related to the Company's products are questioned. Furthermore, there can be no assurance that the Company will successfully ensure its manufacturing partners or joint ventures maintain appropriate quality standards, with any failure to do so adversely affecting quality, function, and customers' perceptions of the Company's products and services.

If we experience delays, disputes or other difficulties with third-party manufacturers or joint ventures partners that the Company outsources orders to, there can be no assurance that it would be able to engage other third parties or to establish or expand its own production capacity to meet the needs of its customers in a timely manner or on acceptable terms, or at all. The expense and time required to complete any transition, and to assure that Nexscient Nodes manufactured at facilities of new manufacturers comply with the Company's design standards and other requirements may be greater than anticipated. Any of the foregoing could adversely affect our business, results of operations, financial condition and prospects.

To date, we have not generated revenues from operations, and we may have additional capital requirements to continue our operations, but they might not be available to us on favorable terms or at all, and if unavailable our ability to run our business will be impaired.

As of the date of this registration statement, we have limited working capital. As a result, it is impossible to expand our operations and we are totally dependent upon this Offering to sustain and grow our business. Although this registration statement contemplates raising $3,000,000, there is no assurance that this amount can be raised. If we were to only receive the minimum amount for this Offering, we would not have sufficient capital to fully implement our business strategy and would have to stagger our development. This Offering is being conducted on a "best efforts/no minimum" basis, meaning that no aggregate minimum offering amount is required to be raised by us in this Offering in order for the Offering to proceed. Assuming the sale of all 4,000,000 shares of common stock hereunder, the proceeds will be utilized over the next twelve months as specified in "Use of Proceeds." We will require additional capital and resources to implement the growth strategies set forth in this registration statement. Adequate funds for the Company's future operating or capital needs, whether from additional financing, collaborative arrangements with joint venture partners, or other sources, may not be available when needed or on favorable terms, which would severely limit the company's growth. If we are unable to generate sufficient revenues to cover operating expenses or raise additional funds, we are unlikely establish or maintain our business operations. We currently have no other plans or arrangements to raise capital for our business except for this Offering.

The Company's success is dependent on current management, who may be unable to devote sufficient time to the development of the Company's business plan, which could cause the business to fail.

The Company is heavily dependent on the management experience of our officers and directors. Currently there are no employment contracts by and between any officer/director/employee of the Company. If the Company lost any of its officers or directors, it would negatively impact and delay operations and there is no assurance that suitable replacements could be found. Currently, our officers are devoted full-time to the Company, but may not be able to continue to devote their full-time to the development of the Company's business plan unless this Offering is successful. If management is required to find outside employment, they may not have sufficient time to devote to the Company and we would be unable to develop our business plan, resulting in the failure of our business.

Some of our officers and directors presently have additional interest or affiliation to other businesses, and accordingly, may have conflicts of interest in their determination as to how much time to devote to our affairs.

Some of our officers and directors will allocate their time to other businesses thereby causing conflicts of interest in their determination as to how much time to devote to our affairs. This conflict of interest could have a negative impact on our ability to conduct our business.

14

Table of Contents

The Company has a correspondingly small financial and accounting organization. Being a public company may strain the Company's resources, divert management's attention and affect its ability to attract and retain qualified officers and directors.

The Company is an early-stage company with no developed finance and accounting organization and the rigorous demands of being a public company require a structured and developed finance and accounting group. Once it becomes a public reporting company, the Company will become subject to the reporting requirements of the Securities Act of 1933 and Securities Exchange Act of 1934, under which we intend to register in the future and regulations promulgated thereunder, which entail significant accounting, legal and financial compliance costs which may be prohibitive to the Company as it develops its business plan, services and scope. These costs have made, and will continue to make, some activities more difficult, time consuming or costly and may place significant strain on its personnel, systems and resources.

The Securities Exchange Act requires, among other things, that companies maintain effective disclosure controls and procedures and internal control over financial reporting. In order to maintain the requisite disclosure controls and procedures and internal control over financial reporting, significant resources and management oversight are required. As a result, management's attention may be diverted from other business concerns, which could have a material adverse effect on the development of the Company's business, financial condition and results of operations.

These rules and regulations may also make it difficult and expensive for the Company to obtain director and officer liability insurance. If the Company is unable to obtain adequate director and officer insurance, its ability to recruit and retain qualified officers and directors, especially those directors who may be deemed independent, will be significantly curtailed.

The Company's independent auditors have issued a report raising a substantial doubt of the Company's ability to continue as a going concern.

In their audited financial report, the Company's independent auditors have issued added an explanatory paragraph that unless the Company is able to generate sufficient cash flows from operations and/or obtain additional financing, there is a substantial doubt as to its ability to continue as a going concern. The Company anticipates that it would need substantial capital over the next 12 months to continue as a going concern to expand its operations in accordance with its current business plan.

The Company may not be able to continue as a going concern.

The ability of the Company to continue as a going concern is dependent on the Company's ability to fund future operations through additional financing from investors and/or lenders or through the sale of its securities or through development of its operations. Due to these and other factors, there is substantial doubt of the Company's ability to continue as a going concern.

We will incur increased costs and demands upon management as a result of complying with the laws and regulations affecting public companies, which could harm our operating results.

As a public company, we will incur significant additional legal, accounting and other expenses that we did not incur as a private company, including costs associated with public company reporting requirements. We also will incur costs associated with current corporate governance requirements, including requirements under Section 404 and other provisions of the Sarbanes-Oxley Act, as well as rules implemented by the Securities and Exchange Commission, or SEC, and the exchange on which we list our shares of common stock issued in this Offering. The expenses incurred by public companies for reporting and corporate governance purposes have increased dramatically in recent years. We expect these rules and regulations to substantially increase our legal and financial compliance costs and to make some activities more time consuming and costly. We are unable to currently estimate these costs with any degree of certainty. We also expect these new rules and regulations may make it more difficult and more expensive for us to obtain director and officer liability insurance, and we may be required to accept reduced policy limits and coverage or incur substantially higher costs to obtain the same or similar coverage previously available. As a result, it may be more difficult for us to attract and retain qualified individuals to serve on our board of directors or as our executive officers. Currently we do not have a system of checks and balances in place covering our financial operations and investors will bear the economic risk associated with the lack such oversight.

Because we do not have an audit committee, shareholders will have to rely on the directors, who are not independent, to perform these functions.

We do not have an audit or compensation committee comprised of independent directors. These functions are performed by the board of directors as a whole. Most members of the Board of Directors are not independent directors. Thus, there is a potential conflict in that the board members are also engaged in management and participates in decisions concerning management compensation and audit issues that may affect management performance.

15

Table of Contents

Early failures would impair our ability to attract additional capital.

Our business model contemplates success from the development and deployment of the Company's SaaS-delivered condition monitoring solutions. That is, we are anticipating revenue from these services to support the Company's operations. In the event that our product and service offerings are not profitable, we will need to raise additional capital from outside investment. There are no guarantees that we will be able to raise such capital, or that if we are able to, that it will be on favorable terms. Early failures are likely to make such additional financing more "expensive" because investors are not likely to be willing to pay for "past mistakes."

Government regulation could negatively impact the business.

The Company's business segments may be subject to various government regulations in the jurisdictions in which they operate. Due to the potential wide scope of the Company's operations, the Company could be subject to regulation by various political and regulatory entities, including various local and municipal agencies and government sub-divisions. The Company may incur increased costs necessary to comply with existing and newly adopted laws and regulations or penalties for any failure to comply. The Company's operations could be adversely affected, directly or indirectly, by existing or future laws and regulations relating to its business or industry.

The Company's election not to opt out of JOBS Act extended accounting transition period may not make its financial statements easily comparable to other companies.

Pursuant to the JOBS Act of 2012, as an emerging growth company the Company can elect to opt out of the extended transition period for any new or revised accounting standards that may be issued by the PCAOB or the SEC. The Company has elected not to opt out of such extended transition period which means that when a standard is issued or revised and it has different application dates for public or private companies, the Company, as an emerging growth company, can adopt the standard for the private company. This may make comparison of the Company's financial statements with any other public company which is not either an emerging growth company nor an emerging growth company which has opted out of using the extended transition period difficult or impossible as possible different or revised standards may be used.

The recently enacted JOBS Act will also allow the Company to postpone the date by which it must comply with certain laws and regulations intended to protect investors and to reduce the amount of information provided in reports filed with the SEC.

The recently enacted JOBS Act is intended to reduce the regulatory burden on "emerging growth companies. The Company meets the definition of an emerging growth company and so long as it qualifies as an "emerging growth company," it will, among other things: be exempt from the provisions of Section 404(b) of the Sarbanes-Oxley Act requiring that its independent registered public accounting firm provide an attestation report on the effectiveness of its internal control over financial reporting; be exempt from the "say on pay" provisions (requiring a non-binding shareholder vote to approve compensation of certain executive officers) and the "say on golden parachute" provisions (requiring a non-binding shareholder vote to approve golden parachute arrangements for certain executive officers in connection with mergers and certain other business combinations) of the Dodd-Frank Act and certain disclosure requirements of the Dodd-Frank Act relating to compensation of its chief executive officer; be permitted to omit the detailed compensation discussion and analysis from proxy statements and reports filed under the Securities Exchange Act of 1934 and instead provide a reduced level of disclosure concerning executive compensation; and be exempt from any rules that may be adopted by the Public Company Accounting Oversight Board requiring mandatory audit firm rotation or a supplement to the auditor's report on the financial statements.

Although the Company is still evaluating the JOBS Act, it currently intends to take advantage of some or all of the reduced regulatory and reporting requirements that will be available to it so long as it qualifies as an "emerging growth company". The Company has elected not to opt out of the extension of time to comply with new or revised financial accounting standards available under Section 102(b) of the JOBS Act. Among other things, this means that the Company's independent registered public accounting firm will not be required to provide an attestation report on the effectiveness of the Company's internal control over financial reporting so long as it qualifies as an emerging growth company, which may increase the risk that weaknesses or deficiencies in the internal control over financial reporting go undetected. Likewise, so long as it qualifies as an emerging growth company, the Company may elect not to provide certain information, including certain financial information and certain information regarding compensation of executive officers that would otherwise have been required to provide in filings with the SEC, which may make it more difficult for investors and securities analysts to evaluate the Company. As a result, investor confidence in the Company and the market price of its common stock may be adversely affected.

16

Table of Contents

If we are unable to sell additional products, subscriptions, and services, as well as renewals of our subscriptions and services, to our customers, our future revenue and operating results will be harmed.

As existing customers that purchase our platform subscriptions have limited contractual obligation to renew their subscriptions and support services after the initial contract period, and given our limited operating history, we may not be able to accurately predict our retention rates. Our customers' retention rates may decline or fluctuate as a result of a number of factors, including the level of their satisfaction with our platform, our customer support, customer budgets and the pricing of our platform compared with the products and services offered by our competitors. If our customers renew their subscriptions, they may renew for shorter contract lengths or on other terms that are less economically beneficial to us. We cannot assure you that our customers will renew their subscriptions, and if our customers do not renew their subscriptions or renew them on less favorable terms, our revenue may grow more slowly than expected, not grow at all, or even decline.

We also depend on our installed customer base for future support and maintenance of revenues. We offer our service and support agreements for terms that generally range between one and three years. If customers choose not to renew their support and maintenance agreements or seek to renegotiate the terms of their service and support agreements prior to renewing such agreements, our revenue may grow more slowly than expected, not grow at all, or even decline.

If we are unable to retain our customers, renew and expand our relationships with them, and add new customers, we may not be able to sustain revenue growth and we may not achieve or maintain profitability in the future.

We are a relatively new company with limited operating history. Although we anticipate rapid growth based on our industry experience, we may not experience growth due to a myriad of factors and any success that we may experience will depend, in large part, on our ability to, among other things:

? maintain, renew, and expand our customer base; ? win new customers to our solutions; ? increase revenues from existing customers through increased use of our products, subscriptions, and services within their organizations; ? improve the capabilities of our products and subscriptions through research and development; ? continue to develop our AI, IIOT and cloud-based, analytics solutions; ? maintain the rate at which customers purchase our subscriptions and support; ? continue to successfully expand our business domestically and internationally; and ? successfully compete with other companies.

If we are unable to maintain consistent or increasing revenue growth or if our revenues decline, it may be difficult to achieve and maintain profitability and our business and financial results could be adversely affected.

If we are unable to increase sales to large organizations while mitigating the risks associated with serving such customers, our business, financial position, and results of operations may suffer.

Our growth strategy is dependent, in part, upon increasing sales of our solutions to commercial enterprises. Sales to commercial customers involve risks that may not be present (or that are present to a lesser extent) with sales to retail customers. These risks include:

    UNITED STATES

Fluctuating economic conditions make it difficult to predict revenue for a particular period, and a shortfall in revenue may harm our business and operating results.

Our revenue depends significantly on general economic conditions and the demand for services in the industrial automation market. Economic weakness, customer financial difficulties, and constrained spending on equipment condition monitoring may result in decreased revenue and earnings. Such factors could make it difficult to accurately forecast our sales and operating results and could negatively affect our ability to provide accurate forecasts to our contract manufacturers and manage our inventory purchases, contract manufacturer relationships and other costs and expenses. General economic weakness may lead to longer collection cycles for payments due from our customers, an increase in customer bad debt, restructuring initiatives and associated expenses, and impairment of investments. Furthermore, the continued uncertainty in worldwide credit markets may adversely impact the ability of our customers to adequately fund their expected capital expenditures, which could lead to delays or cancellations of planned purchases of our platform.

17

Table of Contents

Uncertainty about future economic conditions also makes it difficult to forecast operating results and to make decisions about future investments. Future or continued economic weakness for us or our customers, failure of our customers and markets to recover from such weakness, customer financial difficulties, and reductions in spending on equipment condition monitoring services could have a material adverse effect on demand for our platform and consequently on our business, financial condition, and results of operations.

Claims by others that we infringe their proprietary technology or other rights could harm our business.

Technology companies frequently enter into litigation based on allegations of patent infringement or other violations of intellectual property rights. In addition, patent holding companies seek to monetize patents they have purchased or otherwise obtained. As we face increasing competition and gain an increasingly higher profile, the possibility of intellectual property rights claims against us grows. From time to time, third parties may assert, and we expect that third parties will assert, claims of infringement of intellectual property rights against us. Third parties may in the future also assert claims against our customers or channel partners, whom our standard license and other agreements obligate us to indemnify against claims that our products infringe the intellectual property rights of third parties. While we intend to increase the size of our patent portfolio, many of our competitors and others may now and in the future have significantly larger and more mature patent portfolios than we have. In addition, future litigation may involve patent holding companies or other patent owners who have no relevant product offerings or revenue and against whom our own patents may therefore provide little or no deterrence or protection. Any claim of intellectual property infringement by a third party, even a claim without merit, could cause us to incur substantial costs defending against such claim, could distract our management from our business and could require us to cease use of such intellectual property.

Although third parties may offer a license to their technology or other intellectual property, the terms of any offered license may not be acceptable, and the failure to obtain a license or the costs associated with any license could cause our business, financial condition, and results of operations to be materially and adversely affected. We may also be subject to additional fees or be required to obtain new licenses if any of our licensors allege that we have not properly paid for such licenses or that we have improperly used the technologies under such licenses. In addition, some licenses may be non-exclusive, and therefore our competitors may have access to the same technology licensed to us. If a third party does not offer us a license to its technology or other intellectual property on reasonable terms, or at all, we could be enjoined from continued use of such intellectual property. As a result, we may be required to develop alternative, non-infringing technology, which could require significant time (during which we could be unable to continue to offer our affected products, subscriptions, or services), effort, and expense and may ultimately not be successful. Furthermore, a successful claimant could secure a judgment, or we may agree to a settlement that prevents us from distributing certain products, providing certain subscriptions, or performing certain services or that requires us to pay substantial damages, royalties, or other fees. Any of these events could harm our business, financial condition, and results of operations.

The Company is not aware of any material violation or infringement of the intellectual property rights of others. Nevertheless, there can be no assurance that in its development of protocols, logos, and methods, Nexscient may inadvertently infringe the intellectual property rights of others, or others may assert infringement claims against the Company. Such claims against the Company, even if untrue or baseless, could result in significant egal and other costs and may be a distraction to its management. Adverse determinations in such litigation could result in loss of proprietary rights or subject Nexscient to significant liabilities. As a result, the Company's financial and operating results may be adversely affected.

If organizations do not adopt cloud-based SaaS-delivered monitoring solutions, our ability to grow our business and results of operations may be adversely affected.

We believe our future success will depend in large part on the growth, if any, in the market for cloud-based SaaS-delivered condition monitoring solutions. The use of SaaS solutions to manage and automate condition monitoring of equipment is at an early stage and rapidly evolving. As such, it is difficult to predict its potential growth, if any, customer adoption and retention rates, customer demand for our solutions, or the success of existing competitive products. Any expansion in our market depends on a number of factors, including the cost, performance, and perceived value associated with our solutions and those of our competitors. If our solutions do not achieve widespread adoption or there is a reduction in demand for our solutions due to a lack of customer acceptance, technological challenges, competing products, privacy concerns, decreases in corporate spending, weakening economic conditions or otherwise, it could result in early terminations, reduced customer retention rates, or decreased revenue, any of which would adversely affect our business, results of operations, and financial results. We do not know whether the trend in adoption of cloud-based SaaS-delivered condition monitoring solutions we have experienced in the past will continue in the future. Furthermore, if we or other SaaS condition monitoring providers experience security incidents, loss or disclosure of customer data, disruptions in delivery, or other problems, the market for SaaS solutions, including our condition monitoring solutions, may be negatively affected. You should consider our business and prospects in light of the risks and difficulties we encounter in this new and evolving market.

18

Table of Contents

The Company faces market risk from other players in the industry.

We expect our greatest competition to be from existing analytical test equipment, computerized maintenance management systems, and related companies in the market today. These industry segments are highly competitive and includes numerous manufactures, distributors, marketers that actively compete for the business of consumers both in the United States and abroad. Additionally, there are several other companies currently marketing similar monitoring services and related company products, many of which have established market presence both domestically and internationally. Some or all of these companies have greater financial resources than those available to the Company and have established market positions which the Company may be unable to effectively compete with. As a result, the Company's ability to remain competitive depends in part upon the successful introduction and consumer acceptance of its products and services. The principal competitive factors affecting the market for our products include product performance, reliability, timeliness, scalability, ease of use, price, and distribution capabilities. There can be no assurance that the Company will be able to compete successfully against current and future competitors based on these and other factors. Any failure to adapt to these changing technologies may have a material adverse effect on the Company's business, financial condition, and results of operations.

We will operate in a competitive industry.

The growth in the industrial automation industry may result in potential competitors to the Company entering the market. Many of our potential competitors may be large, well-financed and established companies that have greater financial and marketing resources than does the Company. Our ability to compete effectively is dependent upon, among other things, our ability to form strategic development and marketing relationships with major companies that participate in markets relevant to the Company's products. No assurance can be given that we will be successful in these efforts. We plan to offer our resulting products and services in several distinct markets, all of which contain potential competitors, which may be large, well-financed and established companies that have greater financial and marketing resources than does the Company. There are several purveyors of condition monitoring solutions offering many products on the market today. Our ability to compete effectively is dependent upon, among other things, our ability to develop and market our products and services to customers in markets relevant to our solutions. No assurance can be given that we will be successful in these efforts.

We face intense competition and could lose market share to our competitors, which could adversely affect our business, financial condition, and results of operations.

The market for industrial automation and condition-based monitoring products and services is intensely competitive and characterized by rapid changes in technology, customer requirements, industry standards, and frequent new product introductions and improvements. We anticipate continued challenges from current competitors, which in many cases are more established and enjoy greater resources than us, as well as by new entrants into the industry. If we are unable to anticipate or effectively react to these competitive challenges, our competitive position could weaken, and we could experience a decline in our growth rate or revenue that could adversely affect our business and results of operations.

Our competitors and potential competitors include condition monitoring equipment vendors of greater size such as Fluke, Emerson, and Augury that may emulate or integrate certain features similar to ours into their own products; test equipment vendors that offer products or features that claim to perform similar functions to our platform; small and large companies, including new market entrants, that offer niche monitoring solutions that compete with some of the features present in our solutions; and other providers of condition-based monitoring services. Other equipment providers offer, and may continue to introduce, remote monitoring features that compete with our platform, either in stand-alone products or as additional services in their network infrastructure offerings. Many of our existing competitors have, and some of our potential competitors could have, substantial competitive advantages such as:

    UNITED STATES

19

Table of Contents

In addition, some of our competitors have substantially broader product offerings and may be able to leverage their relationships with distribution partners and customers based on other products or incorporate functionality into existing products to gain business in a manner that discourages users from purchasing our products, subscriptions, and services, including by selling at zero or negative margins, product bundling or offering closed technology platforms. Potential customers may also prefer to purchase from their existing suppliers rather than a new supplier regardless of product performance or features. As a result, even if the features of our platform are superior, customers may not purchase our products. In addition, new innovative start-up companies, and larger companies that are making significant investments in research and development, may invent similar or superior products and technologies that compete with our platform. Our current and potential competitors may also establish cooperative relationships among themselves or with third parties that may further enhance their resources. Further, as our customers refresh the condition monitoring products bought in prior years, they may seek to consolidate vendors, which may result in current customers choosing to purchase products from our competitors on an ongoing basis.

Some of our competitors have made or could make acquisitions of businesses that allow them to offer more competitive and comprehensive solutions. As a result of such acquisitions, our current or potential competitors may accelerate the adoption of new technologies that better address end-customer needs, devote greater resources to bring these products and services to market, initiate or withstand substantial price competition, or develop and expand their product and service offerings more quickly than we do. These competitive pressures in our market or our failure to compete effectively may result in price reductions, fewer orders, reduced revenue and gross margins, and loss of market share. If we are unable to compete successfully, or if competing successfully requires us to take costly actions in response to the actions of our competitors, our business, financial condition, and results of operations could be adversely affected.

Real or perceived defects, errors or vulnerabilities in our products or services, the misconfiguration of our products, the failure of our products or services to identify incipient issues, or the failure of customers to take action on issues identified by our products or services could harm our reputation and adversely impact our business, financial position and results of operations.

Because our products and services are complex, they have contained and may contain design or manufacturing defects or errors that are not detected until after their deployment. Our products also provide our customers with the ability to customize a multitude of settings, and it is possible that a customer could misconfigure our products or otherwise fail to configure our products in an optimal manner. Such defects and misconfigurations of our products could cause our products or services to be vulnerable to missed identification of incipient issues, cause equipment to fail, or temporarily interrupt the operations of our customers. In addition, because the techniques used to detect, analyze and send notifications are still developing and generally are not recognized until sufficient data has been accrued, there is a risk that an undetected issue could emerge that our products and services are unable to detect or prevent. In addition, defects or errors in our subscription updates or our products could result in a failure of our subscriptions to effectively update customers' hardware and cloud-based products. Our data centers and networks may experience technical failures and downtime, may fail to distribute appropriate updates, or may fail to meet the increased requirements of a growing installed customer base, any of which could temporarily or permanently expose our customers' equipment, leaving their them unmonitored, which could lead to eventual failure. Similarly, if we inadvertently update our products with an erroneous configuration or untested detection content, invalid detections or product downtime could occur. Any of these situations could result in negative publicity to us, damage to our reputation, declining sales, increased expenses, and customer relations issues, and therefore adversely impact our business, financial position and results of operations.

In addition, we cannot assure you that any limitation of liability provisions in our customer agreements, contracts with third-party vendors and service providers or other contracts would be enforceable or adequate or would otherwise protect us from any liabilities or damages with respect to any particular claim relating to equipment failure or other condition-related matter. While our insurance policies expect to include liability coverage for certain of these matters, if we experienced a widespread incident that impacted a significant number of our customers to whom we owe indemnity obligations, we could be subject to indemnity claims or other damages that exceed our insurance coverage. We also cannot be certain that our insurance coverage will be adequate for such liabilities actually incurred, that insurance will continue to be available to us on economically reasonable terms, or at all, or that any future claim will not be excluded or otherwise be denied coverage by any insurer. The successful assertion of one or more large claims against us that exceed available insurance coverage, or the occurrence of changes in our insurance policies, including premium increases or the imposition of large deductible or co-insurance requirements, could have a material adverse effect on our business, including our financial condition, operating results, and reputation.

20

Table of Contents

Any real or perceived defects, errors or vulnerabilities in our products and services, or any other failure of our products and services to detect an incipient issue, could result in:

? a loss of existing or potential customers or channel partners; ? delayed or lost revenue and harm to our financial condition and results of operations; ? a delay in attaining, or the failure to attain, market acceptance; ? the expenditure of significant financial and product development resources in efforts to analyze, correct, eliminate, or work around errors or defects, or to identify and ramp up production with alternative third-party manufacturers; ? an increase in warranty and other claims, or an increase in the cost of servicing warranty and other claims, either of which would adversely affect our gross margins; ? harm to our reputation or brand; and ? claims and litigation, regulatory inquiries, or investigations, enforcement actions, and other claims and liabilities, all of which may be costly and burdensome and further harm our reputation.

If we do not accurately anticipate and respond promptly to changes in our customers' technologies, business plans or equipment-monitoring needs, our competitive position and prospects could be harmed.

The industrial automation market has grown quickly and is expected to continue to evolve rapidly. Moreover, many of our customers operate in markets characterized by rapidly changing technologies and business plans, which require them to adapt to increasingly complex manufacturing environments, incorporating a variety of hardware, software applications, operating systems and networking protocols. As their technologies and business plans grow more complex, we expect these customers to face an increasing number of equipment failures. We face significant challenges in ensuring that our platform effectively identifies and responds to these incipient issues without disrupting our customers' operations or performance.

We have identified a number of new products and enhancements to that we believe are important to our success in the industrial automation market, including our predictive maintenance platform and remote monitoring solutions. There can be no assurance that we will be successful in developing and marketing, on a timely basis, such new products or enhancements or that our new products or enhancements will adequately address the changing needs of the marketplace. We may experience unanticipated delays in the availability of new products and enhancements to our platform and fail to meet customer expectations with respect to the timing of such availability. If we do not quickly respond to the rapidly changing and rigorous needs of our customers by developing, releasing and making available on a timely basis new products and enhancements to our platform, such as our threat intelligence platform and enhancements to our monitoring solutions, that can adequately respond to incipient equipment issues and our customers' needs, our competitive position and business prospects will be harmed. Furthermore, from time to time, we or our competitors may announce new products with capabilities or technologies that could have the potential to replace or shorten the life cycles of our existing products. There can be no assurance that announcements of new products will not cause customers to defer purchasing our existing products.

Additionally, the process of developing new technology is expensive, complex, and uncertain. The success of new products and enhancements depends on several factors, including appropriate component costs, timely completion and introduction, differentiation of new products and enhancements from those of our competitors, and market acceptance. To maintain our competitive position, we must continue to commit significant resources to developing new products or enhancements to our platform before knowing whether these investments will be cost-effective or achieve the intended results. There can be no assurance that we will successfully identify new product opportunities, develop, and bring new products or enhancements to market in a timely manner, or achieve market acceptance of our platform, or that products and technologies developed by others will not render our platform obsolete or noncompetitive. If we expend significant resources on researching and developing products or enhancements to our platform and such products or enhancements are not successful, our business, financial position and results of operations may be adversely affected.

War, terrorism, other acts of violence or natural or manmade disasters such as a global pandemic may affect the markets in which the Company operates, the Company's customers, the Company's delivery of products and customer service, and could have a material adverse impact on our business, results of operations, or financial condition.

The Company's business may be adversely affected by instability, disruption, or destruction in a geographic region in which it operates, regardless of cause, including war, terrorism, riot, civil insurrection or social unrest, and natural or manmade disasters, including famine, food, fire, earthquake, storm or pandemic events and spread of disease (including the recent outbreak of the coronavirus commonly referred to as "COVID- 19"). Such events may cause customers to suspend their decisions on using the Company's products and services and give rise to sudden significant changes in regional and global economic conditions and cycles that could interfere with purchases of goods or services. These events also pose significant risks to the Company's personnel and operations, which could materially adversely affect the Company's financial results.

Any significant disruption to communications and travel, including travel restrictions and other potential protective quarantine measures against COVID-19 by governmental agencies, could make it difficult for the Company to deliver goods services to its customers. War, riots, or other disasters may increase the need for our products and demand may make it difficult for use to provide products to customers. Further, travel restrictions and protective measures against pandemics, like COVID-19, could cause the Company to incur additional unexpected labor costs and expenses or could restrain the Company's ability to retain the highly skilled personnel the Company needs for its operations. The extent to which health concerns, like COVID-19, impacts the Company's business, sales and results of operations will depend on future developments, which are highly uncertain and cannot be predicted.

21

Table of Contents

    UNITED STATES

There is presently no market for the Company's common stock.

A market does not presently exist for the Company's securities (the "Securities"), and no assurances can be given that a market will ever develop. Consequently, holders of the Securities offered hereby may not be able to liquidate their investment in the Company in a timely manner or at any time, and such Securities will not be readily acceptable as collateral for loans. Although we may endeavor to establish a trading market for the Company's securities at an unspecified future date, no assurances can be given that we will be successful in our efforts. Further, even if we establish a trading market, no assurances can be given as to the timing of such event or whether the market, if established, will be sufficiently liquid to enable the investor to liquidate his investment in the Company. Finally, if a market is developed for the Company's securities through a public offering, the holders of the Securities offered hereby, as a condition to such offering, may be required to enter into an agreement not to sell or otherwise transfer their stock for a significant period of time following the public offering (see "Description of Securities").

We do not expect to pay dividends in the foreseeable future.

We do not intend to declare dividends for the foreseeable future, as we anticipate that we will reinvest any future earnings in the development and growth of our business. Therefore, investors will not receive any funds unless they sell their common stock, and stockholders may be unable to sell their Shares on favorable terms or at all. We cannot assure you of a positive return on investment or that you will not lose the entire amount of your investment in our common stock.

The officers and directors of the Company have controlling interest in the Company.

Currently there are issued and outstanding 19,955,980 shares of Common Stock of which 12,273,000 shares of Common Stock are issued to the officers and directors of the Company. The holders of the Common Stock are entitled to one (1) vote per share so that presently, management control shares of Common Stock that are entitled to 12,273,000 votes or 61.50% of the issued and outstanding voting shares. At the completion of this Offering, assuming the sale of all 4,000,000 shares of Common Stock being offered hereby there will be issued and outstanding 23,955,980 shares of Common Stock, of which management will then have approximately 51.23% of such voting power. Additionally, should the Company issue additional shares of Common Stock the purchasers in this Offering would be further diluted in voting control (see "Management," "Principal Shareholders" and "Description of Securities").

We may in the future issue additional shares of our common stock which would reduce investors' ownership interests in the Company, and which may dilute our share value.

Our Certificate of Incorporation authorize the issuance of 75,000,000 shares of Common Stock, par value $0.001 per share and 10,000,000 shares of authorized but undesignated shares of Preferred Stock, par value $0.001 per share. The future issuance of all or part of our remaining authorized Common Stock or the designation and subsequent issuance of any Preferred Stock may result in substantial dilution to our then existing stockholders. We may value any stock issued in the future on an arbitrary basis. The issuance of our stock for future services or acquisitions or other corporate actions may have the effect of diluting the value of the shares held by our investors and might have an adverse effect on any trading market for our stock.

An active trading market for our common stock may never develop or be sustained.

We cannot assure you that an active trading market for our Common Stock will develop in the future or, if developed, that any market will be sustained. Accordingly, you may be required to hold your Shares indefinitely or to sell them at a price that does not meet your expectations, if at all.

22

Table of Contents

The Company's stock price may be volatile.

The market price of the Company's common stock is likely to be highly volatile and could fluctuate widely in price in response to various potential factors, many of which will be beyond the Company's control, including the following:

? Competition; ? Additions or departures of key personnel; ? The Company's ability to execute its business plan; ? Operating results that fall below expectations; ? Loss of any strategic relationship; ? Industry developments; ? Economic and other external factors; and ? Period-to-period fluctuations in the Company's financial results.

In addition, the securities markets have from time-to-time experienced significant price and volume fluctuations that are unrelated to the operating performance of particular companies. These market fluctuations may also materially and adversely affect the market price of the Company's common stock.

The Company's stock may be considered a penny stock and any investment in the Company's stock will be considered a high-risk investment and subject to restrictions on marketability.

If the Shares commence trading, the trading price of the Company's common stock may be below $5.00 per share. If the price of the common stock is below such level, trading in its common stock would be subject to the requirements of certain rules promulgated under the Securities Exchange Act of 1934, as amended. These rules require additional disclosure by broker-dealers in connection with any trades generally involving any non-NASDAQ equity security that has a market price of less than $5.00 per share, subject to certain exceptions. Such rules require the delivery, before any penny stock transaction, of a disclosure schedule explaining the penny stock market and the risks associated therewith, and impose various sales practice requirements on broker-dealers who sell penny stocks to persons other than established customers and accredited investors (generally institutions). For these types of transactions, the broker-dealer must determine the suitability of the penny stock for the purchaser and receive the purchaser's written consent to the transactions before sale. The additional burdens imposed upon broker-dealers by such requirements may discourage broker-dealers from effecting transactions in the Company's common stock which could impact the liquidity of the Company's common stock.

FINRA sales practice requirements may limit a stockholder's ability to buy and sell our stock.

The Financial Industry Regulatory Authority ("FINRA") has adopted rules that relate to the application of the SEC's penny stock rules in trading our securities and require that a broker/dealer have reasonable grounds for believing that the investment is suitable for that customer, prior to recommending the investment. Prior to recommending speculative, low-priced securities to their non-institutional customers, broker/dealers must make reasonable efforts to obtain information about the customer's financial status, tax status, investment objectives and other information.

Under interpretations of these rules, FINRA believes that there is a high probability that speculative, low-priced securities will not be suitable for at least some customers. FINRA's requirements make it more difficult for broker/dealers to recommend that their customers buy our common stock, which may have the effect of reducing the level of trading activity and liquidity of our common stock. Further, many brokers charge higher transactional fees for penny stock transactions. As a result, fewer broker/dealers may be willing to make a market in our common stock, reducing a shareholder's ability to resell shares of our common stock.

There has been no prior public market for the Company's securities and the lack of such a market may make resale of the stock difficult.

No prior public market has existed for the Company's Securities and the Company cannot assure any investor that a market will develop subsequent to this offering. An investor must be fully aware of the long-term nature of an investment in the Company. The Company intends to apply for quotation of its common stock on the OTC Bulletin Board as soon as possible, which may be while this offering is still in process. To qualify for quotation on the OTC Bulletin Board, an equity security must have one registered broker-dealer, known as the market maker, willing to list bid or sale quotations and to sponsor the company listing (currently, the Company does not have an arrangement with any such market maker to qualify the Company's securities for quotation on the OTC Bulletin Board). Moreover, the Company does not know if it will be successful in such application for quotation on the OTC bulletin board, how long such application will take, or, that if successful, that a market for the common stock will ever develop or continue on the OTC Bulletin Board. If for any reason the common stock is not listed on the OTC Bulletin Board or a public trading market does not otherwise develop, investors in the offering may have difficulty selling their common stock should they desire to do so. If the Company is not successful in its application for quotation on the OTC Bulletin Board, it will apply to have its securities quoted by the OTC Markets Group's Pink Open Market., real-time quotation service for over-the-counter equities.

Shares of common stock in the Company are subject to resale restrictions imposed by Rule 144 of the Securities and Exchange Commission.

The shares of common stock held by current shareholders are "restricted securities" subject to the limitations of Rule 144 under the Securities Act. In general, securities can be sold pursuant to Rule 144 after being fully-paid and held for more than 12 months (6 months if registered under the Exchange Act). Unregistered shares of the Company's common stock held by current shareholders are subject to Rule 144 resale restrictions; provided, however, investors participating in the Offering are not subject to such resale limitations.

23

Table of Contents

    UNITED STATES

This prospectus contains forwardlooking statements that are based on our management's beliefs and assumptions and on information currently available to us. All statements other than statements of historical facts are forwardlooking statements. The forwardlooking statements are contained principally in, but not limited to, the sections entitled "Prospectus Summary," "Risk Factors," "Management's Discussion and Analysis of Financial Condition and Results of Operations" and "Business." These statements relate to future events or to our future financial performance and involve known and unknown risks, uncertainties and other factors that may cause our actual results, levels of activity, performance or achievements to be materially different from any future results, levels of activity, performance or achievements expressed or implied by these forwardlooking statements. Forwardlooking statements include, but are not limited to, statements about:

? our goals and strategies; ? our future business development, financial condition and results of operations; ? expected changes in our revenue, costs or expenditures; ? growth of and competition trends in our industry; ? our expectations regarding demand for, and market acceptance of, our products; ? our expectations regarding our relationships with investors, institutional funding partners and other parties with whom we collaborate; ? our expectation regarding the use of proceeds from this offering; ? fluctuations in general economic and business conditions in the markets in which we operate; and ? relevant government policies and regulations relating to our industry.

In some cases, you can identify forwardlooking statements by terms such as "may," "could," "will," "should," "would," "expect," "plan," "intend," "anticipate," "believe," "estimate," "predict," "potential," "project" or "continue" or the negative of these terms or other comparable terminology. These statements are only predictions. You should not place undue reliance on forwardlooking statements because they involve known and unknown risks, uncertainties and other factors, which are, in some cases, beyond our control and which could materially affect results. Factors that may cause actual results to differ materially from current expectations include, among other things, those listed under the heading "Risk Factors". If one or more of these risks or uncertainties occur, or if our underlying assumptions prove to be incorrect, actual events or results may vary significantly from those implied or projected by the forwardlooking statements. No forwardlooking statement is a guarantee of future performance.

The forwardlooking statements made in this prospectus relate only to events or information as of the date on which the statements are made in this prospectus. Although we will become a public company after this offering and have ongoing disclosure obligations under United States federal securities laws, we do not intend to update or otherwise revise the forwardlooking statements in this prospectus, whether as a result of new information, future events or otherwise.

    UNITED STATES

As a result of there being no established public market for our shares, the offering price and other terms and conditions relative to our shares have been arbitrarily determined by the Company and do not bear any relationship to assets, earnings, book value, or any other objective criteria of value. In determining the number of shares to be offered and the Offering price, we took into consideration our capital structure and the amount of money we would need to implement our business plan. Accordingly, the Offering price should not be considered an indication of the actual value of our securities. In addition, no investment banker, appraiser, or other independent third party has been consulted concerning the offering price for the shares or the fairness of the offering price used for the shares.

    UNITED STATES

Our offering is being made in a direct public offering without the involvement of underwriters or broker-dealers. We intend to disburse the proceeds from this offering in the priority set forth below within the first 12 months after successful completion of this offering.

Not taking into account any possible additional funding or revenues, we intend to use the proceeds from this offering as follows. The following chart indicates the approximate amount of funds that we will allocate to each item, but does not indicate the total fee/cost of each item. The amount of proceeds we allocate to each item is dependent upon the amount of proceeds we receive from this offering:

24

Table of Contents

If we sell all of the Shares being offered, our net proceeds will be $3,000,000. If the Offering is fully subscribed, the proceeds will be applied in the manner described below. If less than the full numbers of shares are subscribed, the proceeds will be applied in the order of priority listed. If we are only to receive between $0 and $750,000, we would need to amend our business plan. The following table sets forth a breakdown of the estimated use of the net proceeds as we currently expect to use them, assuming the sale of 25%, 50%, 75% and 100% of the Shares offered for sale in this Offering:

    UNITED STATES

The above figures represent only estimated costs. As indicated in the table above, if we sell only 25%, or 50%, or 75% of the Shares offered for sale in this offering, we would expect to use the resulting net proceeds for the same purposes as we would use the net proceeds from a sale of 100% of the Shares, and in approximately the same proportions. However, the lower our net proceeds, the less we would expect to use the funds in the expenditure caries.

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

In the event we do not sell all of the Shares being offered, we may seek additional financing to support the intended use of proceeds discussed above. If we secure additional equity funding, investors in this offering would be diluted. In all events, there can be no assurance that additional financing would be available when needed and, if available, on terms acceptable to us.

25

Table of Contents

    UNITED STATES

We have not paid any dividends on our common stock since inception and we currently expect that, in the foreseeable future, all earnings (if any) will be retained for the development of our business and no dividends will be declared or paid. Any future dividends will be subject to the discretion of our board of directors and will depend upon, among other things, our earnings (if any), operating results, financial condition and capital requirements, general business conditions and other pertinent facts.

    UNITED STATES

As of October 15, 2023, Nexscient, Inc. has issued and outstanding 19,955,980 shares of Common Stock. The Company is registering an additional 4,000,000 shares of its Common Stock for sale at the price of $0.75 per share. There is no arrangement to address the possible effect of the offering on the price of the stock. In connection with the Company's selling efforts in the offering, our officers and directors will not register as broker-dealers pursuant to Section 15 of the Exchange Act, but rather will rely upon the "safe harbor" provisions of SEC Rule 3a4-1, promulgated under the Securities Exchange Act of 1934, as amended (the "Exchange Act"). Generally speaking, Rule 3a4-1 provides an exemption from the broker-dealer registration requirements of the Exchange Act for persons associated with an issuer that participate in the sale of the securities of such issuer.

Our officers and directors meet the conditions of the Rule 3a4-1 exemption, as: (1) they are not subject to any statutory disqualification, as that term is defined in Section 3(a)(39) of the Exchange Act; (2) they will not be compensated in connection with their participation in the direct public offering or resale offering by the payment of commissions or other remuneration based either directly or indirectly on transactions in our securities; and (3) they will not be associated persons of a broker or dealer at the time of their participation in the direct public offering and resale offering. Further, our officers and directors: (1) at the end of the offerings, will continue to primarily perform substantial duties for the Company or on its behalf otherwise than in connection with transactions in securities; (2) are not, nor have been within the preceding 12 months, a broker or dealer, and they are not, nor have they been within the preceding 12 months, an associated person of a broker or dealer; and (3) they have not participated in another offering of securities pursuant to the Exchange Act Rule 3a4-1 in the past 12 months and they have not and will not participate in selling an offering of securities for any issuer more than once every 12 months other than in reliance on the Exchange Act Rule 3a4-1(a)(4)(i) or (iii).

In order to comply with the applicable securities laws of certain states, the securities will be offered or sold in those states only if they have been registered or qualified for sale, an exemption from such registration is available, or if qualification requirement is available and with which the Company has complied. In addition, and without limiting the foregoing, the Company will be subject to applicable provisions, rules and regulations under the Exchange Act with regard to security transactions during the period of time when this Registration Statement is effective.

Offering Period and Expiration Date

This offering will start on the date of this Prospectus and continue for a period of up to 180 days, unless extended by our board of directors for an additional 90 days.

Concurrent Offering

The Company will be offering shares of the Company's Common Stock under the direct public offering at the same time that the Selling Shareholders may be offering shares of the Company's Common Stock under the resale offering. The Selling Shareholders do not include any of our officers and directors.

Procedures for Subscribing

If you decide to subscribe for any shares in this offering, you must:

(1) execute and deliver a Subscription Agreement; and

    UNITED STATES

26

Table of Contents

The Subscription Agreement requires you to disclose your name, address, social security number, telephone number, number of shares you are purchasing, and the price you are paying for your shares.

All subscriptions must be funded by wire transfer or by check made payable to "Nexscient, Inc."

Acceptance of Subscriptions

Upon the Company's acceptance of a Subscription Agreement and receipt of full payment, the Company shall countersign the Subscription Agreement and issue a stock certificate along with a copy of the Subscription Agreement.

Right to Reject Subscriptions

We have the right to accept or reject subscriptions in whole or in part, for any reason or for no reason. All monies from rejected subscriptions will be returned immediately by us to the subscriber, without interest or deductions. Subscriptions for securities will be accepted or rejected within 48 hours after we receive them.

No Minimum Subscription

There is no minimum number of shares that must be sold under the offering. As such, there is no guarantee that the Company will raise any funds from the offering.

Penny Stock Regulation

Our Common Shares are not quoted on any stock exchange or quotation system. The SEC has adopted rules that regulate broker-dealer practices in connection with transactions in penny stocks. Penny stocks are generally equity securities with a price of less than $5.00 (other than securities registered on certain national securities exchanges or quoted on the NASDAQ system, provided that current price and volume information with respect to transactions in such securities is provided by the exchange system).

The penny stock rules require a broker-dealer, prior to a transaction in a penny stock not otherwise exempt from those rules, to deliver a standardized risk disclosure document prepared by the SEC, that:

    UNITED STATES

The broker-dealer also must provide the customer with the following, prior to proceeding with any transaction in a penny stock:

? bid and offer quotations for the penny stock; ? details of the compensation of the broker-dealer and its salesperson in the transaction; ? the number of shares to which such bid and ask prices apply, or other comparable information relating to the depth and liquidity of the market for such stock; and, ? monthly account statements showing the market value of each penny stock held in the customer's account.

27

Table of Contents

In addition, the penny stock rules require that prior to a transaction in a penny stock not otherwise exempt from those rules, the broker-dealer must make a special written determination that the penny stock is a suitable investment for the purchaser and receive the purchaser's written acknowledgment of the receipt of a risk disclosure statement and a signed and dated copy of a written suitability statement. These disclosure requirements will have the effect of reducing the trading activity in the secondary market for our stock because it will be subject to these penny stock rules. Therefore, stockholders may have difficulty selling those securities.

Registration Rights

We have not granted registration rights to any persons.

    UNITED STATES

Net tangible book value per share represents the amount of the Company's tangible assets less total liabilities, divided by 19,955,980 shares of Common Stock outstanding as of June 30, 2023 pursuant to the financials enclosed herein. Net tangible book value dilution per share represents the difference between the amount per share paid by purchasers of the Shares in this offering assuming the offering price of $0.75 per share of Common Stock and the pro forma net tangible book value per share of Common Stock immediately after completion of the offering.

After giving effect to the sale of the 4,000,000 shares offered by the Company hereunder, at an Offering Price of $0.75 per share the pro forma net tangible book value of the Company at June 30, 2023, would have been $0.152 per share, representing an immediate increase in tangible book value of $0.143 per share to existing shareholders and an immediate dilution of $0.598 per share to purchasers of the Shares.

The following table illustrates the foregoing information with respect to new investors on a per share basis:

    UNITED STATES

    UNITED STATES

Our executive offices are located at 2029 Century Park East, Suite 400, Los Angeles, CA 90067. We signed an office service agreement with Regus Management Group, LLC for mailbox plus virtual office and workstation. However, once we expand our business to a significant degree, we will have to lease office space. We do not foresee any significant difficulties in obtaining any required office space. We do not currently own any real property.

    UNITED STATES

Common Stock and Preferred Stock

Our Amended and Restated Certificate of Incorporation authorize us to issue up to eighty-five million (85,000,000) shares, consisting of: (i) seventy-five million (75,000,000) shares of Common Stock, par value $0.001 per share (the "Common Stock"); and (ii) 10,000,000 shares of blank check Preferred Stock, par value $0.001 per share (the "Preferred Stock").

Our Certificate of incorporation authorize our board, without stockholder approval, to issue up to 10,000,000 shares of Preferred Stock in one or more series, to determine the designations and the powers, preferences and rights and the qualifications, limitations and restrictions thereof, including the dividend rights, conversion or exchange rights, voting rights (including the number of votes per share), redemption rights and terms, liquidation preferences, sinking fund provisions and the number of shares constituting the series. Our board of directors has the discretion to issue Preferred Stock with voting and other rights that could adversely affect the voting power and other rights of the holders of Common Stock and which could have the effect of making it more difficult for a third party to acquire, or of discouraging a third party from attempting to acquire, a majority of our outstanding voting stock.

28

Table of Contents

The following statements relating to the capital stock set forth the material terms of the securities of the Company. Reference is also made to the more detailed provisions of the certificate of incorporation and the by-laws, copies of which are filed as exhibits to this registration statement.

Voting Rights

Except as otherwise required by law or as may be provided by the resolutions of the board of directors authorizing the issuance of Common Stock, all rights to vote and all voting power shall be vested in the holders of Common Stock. Each share of Common Stock shall entitle the holder thereof to one vote.

No Cumulative Voting

Except as may be provided by the resolutions of the board of directors authorizing the issuance of Common Stock, cumulative voting by any shareholder is expressly denied.

No Preemptive Rights

Preemptive rights shall not exist with respect to shares of Common Stock or securities convertible into shares of Common Stock of the Company.

Dividends

We have not paid any cash dividends on our Common Stock since inception and presently anticipate that all earnings, if any, will be retained for development of our business and that no dividends on our Common Stock will be declared in the foreseeable future. Any future dividends will be subject to the discretion of our Board of Directors and will depend upon, among other things, future earnings, operating and financial condition, capital requirements, general business conditions and other pertinent facts. Therefore, there can be no assurance that any dividends on our Common Stock will be paid in the future.

Rights upon Liquidation, Dissolution or Winding-Up of the Company

Upon any liquidation, dissolution or winding-up of the Company, whether voluntary or involuntary, the remaining net assets of the Company shall be distributed pro rata to the holders of the Common Stock.

Warrants and Options

The Company has not issued any warrants or options.

Holders

As of October 15, 2023, we have 19,955,980 issued and outstanding shares of Common Stock, which are held by 73 shareholders of record.

Securities Authorized for Issuance Under Equity Compensation Plans

None.

Transfer Agent and Registrar

Nexscient, Inc. has appointed VStock Transfer, LLC as its transfer agent. VStock's address is 18 Lafayette Place, Woodmere, NY 11598. The transfer agent is responsible for all record-keeping and administrative functions in connection with the common shares.

29

Table of Contents

No Public Market for Common Stock

There is currently no public trading market for our Common Stock and no such market may ever develop. While we intend to seek and obtain quotation of our Common Stock for trading on the OTC Markets ("OTCQB"), there is no assurance that our application will be approved. An application for quotation on the OTCQB must be submitted by one or more market makers who: 1) are approved by the Financial Industry Regulatory Authority ("FINRA"); 2) who agree to sponsor the security; and 3) who demonstrate compliance with SEC Rule 15(c)2-11 before initiating a quote in a security on the OTCQB. In order for a security to be eligible for quotation by a market maker on the OTCQB, the security must be registered with the SEC and the company must be current in its required filings with the SEC. There are no listing requirements for the OTCQB and accordingly no financial or minimum bid price requirements. We intend to cause a market maker to submit an application for quotation to the OTCQB upon the effectiveness of this Registration Statement of which this Prospectus forms a part. However, we can provide no assurance that our shares will be traded on the bulletin board or, if traded, that a public market will materialize.

Admission to Quotation on the OTC Bulletin Board

If the Company meets the qualifications, it intends to apply for quotation of its securities on the OTC Bulletin Board. The OTC Bulletin Board differs from national and regional stock exchanges in that it (1) is not situated in a single location but operates through communication of bids, offers and confirmations between broker-dealers and (2) securities admitted to quotation are offered by one or more broker-dealers rather than the "specialist" common to stock exchanges. To qualify for quotation on the OTC Bulletin Board, an equity security must have one registered broker-dealer, known as the market maker, willing to list bid or sale quotations and to sponsor the company listing. In addition, the Company must make available adequate current public information as required by applicable rules and regulations.

In certain cases, the Company may elect to have its securities initially quoted in the Pink Sheets published by Pink OTC Markets Inc. In general, there is greater liquidity for traded securities on the OTC Bulletin Board, and less through quotation on the Pink Sheets. It is not possible to predict where, if at all, the securities of the Company will be traded following the effectiveness of this registration statement.

Penny Stock Regulation

Penny stocks generally are equity securities with a price of less than $5.00 per share other than securities registered on national securities exchanges or listed on the NASDAQ Stock Market, provided that current price and volume information with respect to transactions in such securities are provided by the exchange or system. The penny stock rules impose additional sales practice requirements on broker-dealers who sell such securities to persons other than established customers and accredited investors (generally those with assets in excess of $1,000,000 or annual income exceeding $200,000, or $300,000 together with their spouse). For transactions covered by these rules, the broker-dealer must make a special suitability determination for the purchase of such securities and have received the purchaser's written consent to the transaction prior to the purchase. Additionally, for any transaction involving a penny stock, unless exempt, the rules require the delivery, prior to the transaction, of a disclosure schedule prescribed by the SEC relating to the penny stock market. The broker-dealer also must disclose the commissions payable to both the broker-dealer and the registered representative and current quotations for the securities. Finally, monthly statements must be sent disclosing recent price information on the limited market in penny stocks. Because of these penny stock rules, broker-dealers may be restricted in their ability to sell the Company's common stock. The foregoing required penny stock restrictions will not apply to the Company's common stock if such stock reaches and maintains a market price of $5.00 per share or greater.

Additional Information

We refer you to our Certificate of Incorporation, Bylaws, and the applicable provisions of the Delaware Revised Statues for a more complete description of the rights and liabilities of holders of our securities.

30

Table of Contents

    UNITED STATES

THE FOLLOWING DISCUSSION AND ANALYSIS SHOULD BE READ TOGETHER WITH THE CONSOLIDATED FINANCIAL STATEMENTS OF THE COMPANY AND THE NOTES TO CONSOLIDATED FINANCIAL STATEMENTS INCLUDED ELSEWHERE IN THIS REGISTRATION STATEMENT ON FORM S-1. THIS DISCUSSION SUMMARIZES THE SIGNIFICANT FACTORS AFFECTING OUR OPERATING RESULTS, FINANCIAL CONDITIONS AND LIQUIDITY AND CASH-FLOW SINCE INCEPTION.

    UNITED STATES

The Company Overview

Nexscient, Inc. is early-stage company engaged in the business of developing a Software as a Service (Saas) platform for commercialization that intends to exploit Industrial Internet-of-Things (IIoT), Artificial Intelligence (AI), and Cloud-computing technologies to deliver an innovative solution for manufacturers and continuous production facilities in the industrial automation sector that helps reduce equipment failures, avoid unscheduled downtimes, decrease equipment maintenance costs, and improve overall equipment efficiencies. The platform is currently under development.

Corporate History and General Information about the Company

Nexscient, Inc. was incorporated in the State of Delaware on March 14, 2023. Our fiscal year end is June 30. We are a development stage enterprise. Our principal office is located at 2029 Century Park East, Suite 400, Los Angeles, CA 90067. Our telephone number is (310) 494-6620 and our e-mail contact is [email protected]. Our website can be viewed at nexscient.com.

Addressing the shortcomings of most existing condition-based monitoring products on the market today, Nexscient is taking a unique approach by developing a remote, continuous monitoring solution as a subscription-based service -- one that not only will offer all of the benefits of condition-based monitoring diagnostic system through vibration and acoustic analysis, but also will offer those benefits with (i) no upfront capital expense of equipment and software purchases; (ii) no need to update and maintain and update purchased diagnostic equipment and software, (iii) no requirement for specialized training of maintenance personnel; and (iv) no need for licensing, maintaining, and updating software. From a financial perspective, our solution is expected to be more affordable because it does not require upfront investment and shifts what would be a capital expenditure to an operating expense for the customer. For the Company, our business model provides a pathway to profitability through recurring stream of revenues that can be realized through a growing base of subscribers and subscriptions.

Business and Market Summary

Nexscient represents the next-generation, wireless condition monitoring solution that is robust, secure, and scalable, offering manufacturers and continuous-process facilities a powerful new tool for not only reducing maintenance costs and protecting against potentially adverse conditions due to unexpected machine failures, but also improving production schedules, product quality and yield, and overall equipment efficiencies. Having instant access to accurate and timely information provides plant managers with a notable advantage in making front-end decisions that can improve return on investment. Through its anticipated subscription-based service, Nexscient expects to offer increased visibility, analytics, and continuous connectivity that not only provides an immediate solution to avert sudden machine failures, but also enables actionable insights into machine health and recommends adjustments for optimal performance. We intend to generate revenues initially from subscription fees and may generate additional revenues from premium service offerings as well as consulting services that may be offered directly to customers.

Operational & Financial Benefits

By leveraging the power of low-power sensor, edge processing, secure wireless connectivity, and Cloud computing technologies, we intend to develop an easy-to-use and affordable solution that helps continuous process, industrial facilities improve uptime and reliability, and optimize total cost of operations and maintenance. Continuous condition monitoring can help manufacturers automate the entire orchestration of events-from sensing performance data, updating critical systems and predicting breakdowns to alerting appropriate personnel and triggering schedule repairs-with regard to equipment maintenance. This makes continuous condition monitoring a compelling proposition for modern industrial facilities seeking to improve equipment productivity and cost competitiveness.

31

Table of Contents

    UNITED STATES

    UNITED STATES

According to the Deloitte Analytics Institute1 and various industry benchmarks, on average, predictive maintenance increases productivity by 25%, reduces breakdowns by 70% and lowers maintenance costs by 25%. Operational and financial benefits that can be further realized from using the Nexscient System for continuous condition monitoring include:

    UNITED STATES

Additional benefits of condition monitoring for industrial equipment include:

? Decrease average equipment repair time; ? Reduce need for stocking spare parts inventory; ? Increase in Overall Equipment Effectiveness (OEE) (availability, performance, quality); ? Reduce maintenance costs through efficient scheduling of repairs; ? Reduce chances of collateral damage or catastrophic failure; ? Increase production through greater machine availability; ? Extend equipment and bearing service life; ? Improve product quality; and ? Improve employee safety.

Apart from these quantifiable benefits in relation to equipment performance, Nexscient is expected to deliver multiple intangible benefits. When implemented, the Nexscient system is expected to foster smooth running of factory operations and optimized production, by minimizing plant interruptions on account of machinery-related delays. Some of the other qualitative gains that may be derived include higher customer satisfaction, superior capacity management and better supply chain relationships.

The Industry/Marketplace

The maintenance of manufacturing equipment such as motors, pumps, compressors, and other industrial machinery is experiencing a major shift as new maintenance methods are increasingly being adopted across the industrial sector. The emergence of 'Industry 4.0' and Industrial Automation is pushing companies to adopt IIoT and AI into their maintenance practices to achieve better outcomes from their operations.

_____________________

1"Taking pro-active measures based on advanced data analytics to predict and avoid machine failure", Predictive Maintenance | Position Paper -Deloitte Analytics Institute, 2017

32

Table of Contents

Properly managing machine health plays an increasingly important role for continuous process, asset-intensive manufacturers in reducing operational expenditure, achieving superior cost efficiencies and resource utilization, and is becoming the top driver for many companies to remain competitive. Efficient machine maintenance practices go a long way in improving factory floor operations and reducing unforeseen expenditures.

Typically, manufacturers allocate 40% of their operating budgets toward running critical equipment, with an additional 5-8% earmarked for maintenance of the same equipment. Any unexpected equipment failure, not only increases the cost of operations, but also adversely affects asset utilization levels and ultimately impacts productivity.

Furthermore, the amount of money that is locked up in spare parts and inventory for repairs is in the tens of millions of dollars, because these parts often have such unexpected failures. For example, an auto assembly factory can experience the ill effects of downtime misfortunes adding up to $22,000 per minute or approximately $1.3 million every hour2. Likewise, an average manufacturing plant can have downtime costs extending in the vicinity of 5-20%.

The global predictive maintenance market is expected to grow from $5.66 billion in 2021 to $64.25 billion by 2030, witnessing a Compound Annual Growth Rate (CAGR) of 27.4% from 2022 to 2030, according to a market research report published by Next Move Strategy Consulting3. The major factors fueling the market growth include the increasing use of emerging technologies to gain valuable insights, and growing need to reduce maintenance cost and downtime.

The global predictive maintenance market is driven by rising demand for smart factories and is expected to register significant growth due to technological advancement such as wireless technology and remote monitoring. Remote monitoring is the most preferred monitoring process in continuous-process facilities that work continuously and are highly prone to flaws because it enables the operator to accurately collect data, which can be communicated immediately to all the concerned personnel.

Trends

The increasing advancements in efficiency and accuracy of machine condition monitoring equipment is resulting in growing demand for this equipment in several industries, as it maximizes machine productivity. Through effective condition monitoring, it is possible to virtually eliminate plant downtime resulting from unexpected machine failure. Condition monitoring facilitates planning of repairs during non-peak production hours. As an outcome of machine maintenance planning, the actual repair/maintenance work is more cost effective than the traditional way. Often, the overall effect of improved maintenance improves product quality.

Target Industries

Manufacturers and continuous process facilities using condition-based monitoring can be found in industries such as (i) automotive manufacturing, (ii) chemicals, (iii) metals and mining, (iv) oil & gas, (v) power & utilities and others, including (vi) food & beverage, (vii) cement, (viii) paper & pulp, (ix) pharmaceuticals, and (x) semiconductor & electronics. Many of these industries are under continuous pressure to improve performance in a competitive and cost-sensitive environment. Preventing machine downtime in production lines is a top priority. Ends users in these industries are increasingly adopting condition-based monitoring to help improve their competitive standing.

______________________________

2According to a research study conducted by Nielsen Research in 2006 following survey of 101 manufacturing executives in the automotive industry. https://news.thomasnet.com/companystory/downtime-costs-auto-industry-22k-minute-survey-481017

3Globe Newswire https://www.globenewswire.com/en/news-release/2022/08/24/2503654/0/en/Global-Predictive-Maintenance-Market-to-Generate-USD-64-25-Billion-by-2030-States-a-New-Report-by-Next-Move-Strategy-Consulting.html

33

Table of Contents

Geographic Locations

North America dominated the market in 2022, accounting for over 36% share of the global revenue4. The U.S. and Canada are slated to provide promising growth opportunities against bullish demand from power generation, aerospace, oil & gas, marine, and food & beverages industries.

The trend for vibration monitoring has become pronounced for oil condition monitoring in the oil and gas platform machinery lubricants. The rapid growth in the energy sector as well as technological advancements in manufacturing sector spurred the demand for condition-based monitoring in other countries. Also, the rising need for effective scheduling of machine maintenance as well as prediction of equipment failure across major industries, namely manufacturing, oil and gas and construction, are the major factors behind North America's largest market share. Manufacturers and continuous process facilities using condition-based monitoring can also be found in (i) Asia Pacific, (ii) Europe, (iii) Latin America, and (iv) Middle East/North Africa.

Drivers

Now-a-days smart factories hold huge potential for innovation. Some of the biggest challenges that the firms face today are resource and energy inefficiency, high labor cost, increasing capital, operational cost, and demographic change. Hence, more and more companies are implementing plant automation solutions to ensure regular monitoring of plant operations and processes, and thereby propelling the growth of the market.

Condition-based monitoring offers the flexibility required to accommodate a wide range of production processes and interfaces for smooth information exchange between the plant control system, process visualization unit and operator. The need for technology advancements and demand for effective and efficient operation in the smart factories increase the use of machine condition monitoring equipment.

Restraints

High capital expenditure and maintenance requirement is one of the key restraints impacting the condition-based monitoring market. The procurement, installation, operation, and maintenance cost of condition-based monitoring equipment, and other expensive monitoring systems, affects the overall spending. High capital requirement for such equipment would further hamper market growth. In spite of these restraints, condition monitoring still stands out as a superior way of driving efficient predictive maintenance, since it can boost the plant production capacity while driving down operating costs over the long term.

Opportunities

Large untapped markets in Asia-Pacific and Middle East could offer growth opportunities to market players. The condition-based monitoring market in Asia-Pacific is displaying strong growth due to continuous infrastructure development and business expansions, especially in emerging countries, mainly China and India. The deregulation policy and a substantial increase in foreign direct investments (FDIs) in Asian countries also triggered the establishment of new businesses across many industries in Asia-Pacific region. Moreover, the countries in the Middle East, primarily Saudi Arabia and Qatar, are also increasing the use of condition-based monitoring in the oil & gas sector.

Competition

We intend to compete with an array of established and emerging vendors of condition-based monitoring products and services and IIOT-equipped devices. As organizations increasingly embrace predictive maintenance, IIoT and other new industrial automation technologies, an increasing number of companies offering machine monitoring products and services could result to fill the growing demand. The introduction of new technologies and market entrants will continue to fuel an intense competitive environment as companies seek solutions to predicting equipment failures and maintaining equipment performance. Our competitors include condition-based monitoring equipment vendors, diversified diagnostic equipment and services vendors, and providers of machine monitoring products that compete with some of the features present in our solution such as Fluke, Emerson Electric Co. (NYSE: EMR), and Augury, Inc. We compete based on several factors, including product functionality; scope of offerings; performance; brand, reputation, and customer satisfaction; ease of implementation, use and service; price, scalability, reliability, and security. We believe that we will compete favorably with respect to these factors and will become well positioned as an emerging provider of predictive maintenance solution, data analysis, and professional services.

Purchase of Nodes

Management is in advanced discussions with a developer of nodes specifically designed for condition-based monitoring that substantially meet our technical requirements (the "Generic Nodes"). Management believes that by initially purchasing and integrating Generic Nodes, the cost and risk associated with the design and manufacture its own nodes will be significantly reduced allowing it to focus its resources on the development of the software required for its SaaS platform. While we're in the process of discussing a potential partnership with a Generic Nodes supplier, we have yet to finalize any purchase or enter into a binding agreement.

Contract Manufacturers, Joint Venture Partners & Suppliers

We ultimately expect to design and develop our own Nexscient Nodes and outsource the manufacturing of such Nodes to third-party contract manufacturers or joint venture partners. Over the long term, management believes that strategic partnerships with suppliers and contract manufacturers will be a major component of the Company's operating strategy and path to success. Currently, the Company has no existing agreements in place with such suppliers, joint venture partners, or contract manufacturers.

______________________

4"Machine Condition Monitoring Market Size, Share & Trends Analysis Report, 2023 - 2030", Grand View Research, 2022, https://www.grandviewresearch.com/industry-analysis/machine-condition-monitoring-market-report

34

Table of Contents

    UNITED STATES

We are developing a Software as a Service (SaaS) platform that intends to exploit Industrial Internet-of-Things (IIoT), Artificial Intelligence (AI)/Machine Learning (ML), and Cloud-computing technologies to deliver an innovative solution for manufacturers and continuous production facilities in the industrial automation sector that helps reduce equipment failures, avoid unscheduled downtimes, decrease equipment maintenance costs, and improve overall equipment efficiencies. As of the date of this Prospectus, we are in the pre-development phase.

Industrial Internet of Things (IIoT)

The Internet of Things (IoT) refers to the network of physical objects or "things" embedded with sensors, software, and other technologies, interconnected through various communication protocols, networks, and cloud-based platforms. These interconnected objects collect and exchange data, enabling them to interact with the external environment or other systems in an intelligent manner. The Industrial Internet of Things (IIoT) is a transformative manufacturing strategy that integrates advanced digital technologies into the industrial sector to enhance operational efficiencies, improve performance, and create new revenue models. IIoT is an extension of the Internet of Things (IoT) paradigm, specifically tailored to industrial contexts, encompassing sectors including manufacturing, energy, oil and gas, and transportation.

Artificial Intelligence (AI)& Machine Learning (ML)

Artificial Intelligence (AI) is a branch of computer science focused on creating systems capable of performing tasks that would typically require human intelligence. These tasks include, but are not limited to, problem-solving, understanding natural language, perception (such as vision or speech recognition), and decision-making. AI systems are designed to mimic or simulate human cognitive functions, and they can operate either based on predefined rules (via algorithms) or by learning from data. Machine Learning is a subset of AI that provides systems the ability to learn and improve from experience without being explicitly programmed. In essence, ML focuses on the development of algorithms that can process vast amounts of data, derive patterns from this data, and then make decisions or predictions based on it.

Cloud Computing

Cloud computing is a technology paradigm that provides scalable, on-demand computing resources, delivered as a service over the internet. Instead of owning and maintaining physical data centers and servers, businesses can rent access to anything from applications to storage from a cloud service provider. This offers flexibility, cost-effectiveness, and the ability to scale services according to the need of the user. In the case of Nexscient, we intend to leverage cloud computing to offer Software as a Service (SaaS) to deliver our software solution over the Internet on a subscription basis, which will be hosted and maintained "in the cloud," thus eliminating the need for users to install or maintain the software locally.

Nexscient System

Nexscient intends to leverage the latest IIoT technology with edge processing, machine-learning/AI algorithms, and Cloud computing infrastructure to collect, diagnose and transmit critical information about machine health and performance. Designed as a scalable, stand-alone service, Nexscient does not depend on integration with any control or IT system (i.e., SCADA, CMMS, MES, ERP, etc.)* for its data source.

We have engaged an outsourced, third-party software development firm that is currently in the process of developing the Nexscient SaaS platform. When complete, the Nexscient predictive maintenance platform intends to offer a simple, cost-effective solution for continuous monitoring of rotating machinery. Nexscient strives to become the next-generation, wireless condition monitoring solution that is robust, secure and scalable, offering manufacturers and continuous-process facilities a powerful new tool for, not only reducing maintenance costs and protecting against potentially adverse conditions due to unexpected machine failures, but also improving production schedules, product yield and overall quality. Having instant access to accurate real-time data provides plant managers with a notable advantage in making front-end decisions that can improve return on investment.

    UNITED STATES

Figure: Fundamental processes in the Nexscient Predictive Maintenance System

________________________________

*SCADA: Supervisory Control and Data Acquisition; CMMS: Computerized Maintenance Management System; MES: Manufacturing Execution Systems; and ERP: Enterprise Resource Planning.

35

Table of Contents

Collect: Nexscient Nodes externally attach to the outer casing of the equipment being monitored and data is collected via three on-board sensors: acoustic, vibration and temperature. Collected data is processed and wirelessly transmitted to a secure gateway, which makes the information available in the Cloud for analysis and viewing via a Web browser or mobile device.

Analyze: Our Cloud-based software uses rule-based logic, which incorporates domain-level expertise to effect immediate actionable insights and corrective recommendations without the reliance upon a large historical data set. Raw signal and temperature data collected from the Nexscient Nodes is stored in the Cloud and made available on demand for deeper analysis and engineering assessments, if desired.

Diagnose: In conjunction, our advanced machine learning/AI algorithms and analytics combine streaming data with historical information to learn, diagnose, and deliver long-term assessments, such as root cause analysis and estimate remaining useful life.

Execute: Resulting actionable outcomes are pushed to personnel and made available for viewing in an intuitive user interface accessible through any secure Web browser from anywhere in the world.

High-Performance Sensors

All rotating machinery exhibit physical and audible operating characteristics based on the type of equipment, i.e., pump, motor, compressor, fan, gearbox, etc. Nexscient Nodes collect data using the three on-board sensors, including acoustic, vibration and temperature, to diagnose potential problems before they occur.

Acoustic

Acoustic monitoring is highly accurate and provides an early indicator of potential issues. Not only can it identify potential failures extremely early, but it can also narrow down and specifically pinpoint which parts are in danger of failing. Because our sensors capture readings in the ultrasonic acoustic spectrum, they are able to detect ultrasonic frequencies generated by friction, a defect symptom, which is an indication of poor lubrication or bearing wear. Other symptoms may include rubbing and skidding of rolling elements against the bearing raceway, or impacting due to mechanical flaws or contaminated lubricant. Lubrication issues and bearing wear represent upwards of 80% of the issues encountered with rotating machinery. Because ultrasonic monitoring encompasses both sonic and electrical elements of machinery, it is capable of detecting not only mechanical failures but electric failures as well. Ultrasonic detectors can also be useful for identifying defect symptoms arising from misalignment, imbalance, or worn shaft couplings.

Vibration

Vibration sensors measure the radial, axial and horizontal displacement of the rotating machine. Our embedded 3-axis accelerometer, which detect vibration from all directions with one sensor, captures readings in the requisite frequency range. It checks for any unusual physical vibrations, which can serve as an early indicator of misalignment or motion that is too fast or too slow. A number of problems can cause anomalies in the vibration pattern, including but not limited to the slowing down or stopping of moving parts, bearings rubbing against each other in an unusual manner, and any internal imbalances or misalignments.

Temperature

Temperature sensors are typically used to detect heat caused by friction. They complement the acoustic and vibration sensors to collaborate vibration-detected degradation. The temperature trend will actually be a measure of the temperature inside the accelerometer. Although this is not the absolute temperature of the bearing, it is a relative temperature of the bearing casing the accelerometer is mounted on and can be trended over time or alarmed for changes in the bearing temperature. Wear and tear or problems with lubrication will often cause high vibration and high temperature in the bearing. There is a relatively good correlation between the overall vibration trend and the temperature trends providing supporting data on bearing condition and performance.

36

Table of Contents

Nexscient System Components

The Nexscient System is comprised of three primary components (Sensors, Cloud, Apps) that work together to produce an integrated subscription-based service (SaaS model) for customers seeking an affordable yet effective predictive maintenance solution.

    UNITED STATES

    UNITED STATES

Sensors

One key feature of the Nexscient System is its wireless sensors nodes, called Nexscient Nodes. These autonomous data collection beacons simply mount on existing machinery, seamlessly connect to our Cloud-based monitoring service, and wirelessly transmit collected data for analysis and diagnosis.

Data Collection

Each Nexscient Node incorporates three sensors, acoustic, 3-axial vibration, and temperature, to collect data. Since Nexscient Nodes are externally mounted on the equipment, there is no integration required, thereby bypassing the hassle and expense of integrating with any data network.

Cloud

Nexscient monitors assets continuously 24 hours a day, 7 days a week. Our Cloud-based services and Web apps are designed to meet the needs of managers who need a quick snapshot or engineers who want sophisticated tools and analysis features. Mobile apps (iPhone and iPad) are expected to match all of the functionality of the Web version.

Secure Wireless Connectivity

Deployment is virtually plug 'n play, as each Nexscient Node takes only a few minutes to self-configure with the gateway before beginning to collect data. Each Nexscient Node utilizes Wirepas wireless mesh networking protocol using to send data to the Nexscient gateway. Client certificates are used to identify the device on the server and AES-256 ciphers are supported for communications.

AI Analytics

Our platform design incorporates a combination of rule-based logic and machine learning/AI to achieve a short- and long-term view of the machine's health. We intend to use machine learning/AI analytics to carefully monitor, diagnose and relay changes to a machine's health status to designate personnel at the first sign of developing issues along with actionable insights. Our continuous machine monitoring service, once developed, will not only send notification alerts with detailed malfunction analysis, but will also recommend corrective actions.

37

Table of Contents

    UNITED STATES

Nexscient intends to exploit the latest state-of-the-art IIoT, Cloud computing, and edge processing technology to enable data collection and transmission, driving machine learning/AI analytics to deliver real-time insights for predictive maintenance solutions. Nexscient's scalable platform will be extended to address more complex implementations and realizing greater value offered automatically detecting failures in equipment and common sub-assemblies spanning the entire manufacturing process. Nexscient's SaaS platform is currently under development.

Nexscient System Architecture Stack

The Nexscient SaaS platform intends to use state-of-the-art IoT architecture designed for redundancy, flexibility and scalability. Our platform represents a secure end-to-end Industrial IoT solution that takes a holistic approach on multiple levels by fusing together important features across four layers: Infrastructure, Data Management, Analytics, and Security.

The infrastructure layer refers to the connectivity networks of the Nexscient IIoT solution over which the data is securely transmitted/received. The data management layer represents the data acquisition and aggregation processes where edge processing generates meaningful results, which are passed on to the Cloud for further processing and analysis. The analytics layer refers to the software backend where data is ingested, analyzed, and interpreted at scale to generate insights. The security layer is an overarching layer with continuous processes ensuring sufficient security levels are in place on all levels.

INFRASTRUCTURE LAYER

The infrastructure layer includes the Nexscient Nodes with sensors, which capture data and communicate with a gateway via Wirepas mesh networking protocol. Collected data is pre-processed and stored, before it is transported from the gateway to the Nexscient Cloud platform, where further processing and analysis happens.

Sensors

The primary components of the Nexscient system are the Nexscient Node sensors, which collect various raw data into a data logger. These sensors collect real-time data that contains information, which provides us with an understanding of the machine's health and performance conditions. By monitoring these conditions in real time, we can analyze and predict alert situations, which can be communicated to designate personnel for further action. Each Nexscient Node includes an acoustic, vibration and temperature sensor.

Acoustic Ultrasonic Sensor

The embedded MEMS ultrasonic acoustic detector measures sound pressure waves in the 0-40 kHz frequency range. The waves act upon a resonant sensor to create a small electrical charge. The charge is amplified, measured, and converted to a corresponding audible frequency that is recorded to the data collector's memory. The signals monitored by an ultrasonic device are expressed as data using the unit decibels per microvolt (dBuV). Ultrasonic detectors are capable of accurately interpreting the sounds created by under-lubrication, over-lubrication, and early signs of wear. Ultrasound is produced by friction, impact, turbulence, and electrical discharge. Friction and impact are the by-products of mechanical equipment. For example, a roller bearing will produce friction as the shaft and balls roll around the center. If there is too much friction, however, problems begin to occur on the equipment due to imbalance, or the bearing might seize, thereby shutting down equipment altogether. Ultrasonic sensors offer a fast and effective means of determining such conditions in moving, mechanical components such as bearings, gearboxes, motors, compressors, etc.

According to NASA research5, "Ultrasonic monitoring of bearings provides the earliest warning of bearing failure. They noted that an increase in amplitude of a monitored ultrasonic frequency of 12 decibels over baseline would indicate the initial (incipient) stages of bearing failure. This change is detected long before it is indicated by changes in vibration or temperature."

Vibration Sensors

Vibration sensors can detect vibration from all directions with one sensor, measures the vibrations, which occur while the equipment is in motion. Our vibration sensor consists of a tri-axial MEMS accelerometer with a frequency range up to 6.3kHz (+/-3dB) with a 2,6667 Hz sampling rate. They check for any unusual acoustics or physical vibrations, which can serve as an early indicator of misalignment or motion that is too fast or too slow. It usually involves measuring the Root Mean Square (RMS) vibration of the bearing housing or some other point on the machine with the transducer located as close to the bearing as possible.

In machines where there is little vibration other than from the bearings, the spikiness of the vibration signal indicated by the Crest Factor (Peak-to-RMS ratio) may imply incipient defects, whereas the high energy level given by the RMS level may indicate severe defects. In some situations, the Crest Factor of the vibration is capable of giving an earlier warning of bearing defects. A number of problems can cause anomalies in the vibration pattern, including but not limited to the slowing down or stopping of moving parts, bearings rubbing against each other in an unusual manner, and any internal imbalances or misalignments.

______________________________

5Engineering Acoustics and Structural Acoustics and Vibration: Vibration and Acoustic Monitoring of Machinery and Structures, Robert D. Finch, Cochair Department of Mechanical Engineering, University of Houston, Houston, Texas 77204-4792

38

Table of Contents

Temperature Sensor

Temperature sensors are typically used to detect heat caused by friction. We use a thermistor with a range of -40 to 85oC and accuracy +/- 1oC (0 to 70oC). It complements the acoustic and vibration sensors to collaborate vibration-detected degradation. The temperature trend will actually be a measure of the temperature inside the accelerometer. Although this is not the absolute temperature of the bearing, it is a relative temperature of the bearing casing the accelerometer is mounted on and can be trended over time or alarmed for changes in the bearing temperature. Wear and tear or problems with lubrication will often cause high vibration and high temperature in the bearing. There is a relatively good correlation between the overall vibration trend and the temperature trends providing supporting data on bearing condition and performance.

Secure Connectivity

Each Nexscient Node is a fully wireless device that has no cables or external antenna. It uses Wirepas mesh networking protocol to send acoustic, vibration and temperature data to the Nexscient Cloud. Nexscient Nodes connect to the Cloud using TLS 1.2 over a TCP or cellular connection. Client certificates are used to identify the device on the server and AES-256 ciphers are supported for communications.

Industrial Compliance

Nexscient Nodes were specifically designed for industrial environments made from materials chosen to handle exposure to a wide range of chemicals and temperatures while providing a significant level of ingress protection in dirty environments. Nexscient Nodes are suitable for indoor or outdoor use (IP67) and certified for use in Class 1 Div. 2 environments and certified for FCC, CE, UL60079, and CSA 60079.

DATA MANAGEMENT LAYER

Data management layer provides a centralized secure layer where we effect data acquisition, aggregation, and processing.

Data Acquisition

At the core of our data acquisition system, collected data from the sensors is converted to discrete levels that can be interpreted by the processor and stored for analysis. We take advantage of libraries that abstract hardware interfaces, which enable us to work with sensors in a more straightforward way by collecting information the sensors provide to our application instead of on the low-level details of working directly with hardware.

Edge Processing

Because sensor data can easily consume network bandwidth and potentially cause latency issues, we perform edge processing on the collected data as a way to lessen the burden on the core infrastructure. With this approach, we preprocess the data, generate meaningful results, and pass only those on to the Cloud for further processing and analysis. For example, rather than passing on raw vibration data for the pumps, we aggregate and convert the data, analyze it, and send only projections as to when each device will fail or need service.

ANALYTICS LAYER

The analytics layer reads the data digested by the Data Management layer. Our solution employs rule-based logic and AI analytics to accurately evaluate current technical condition of the machines and to predict their failures. The analytics layer also processes and displays the information collected via the sensors. It includes analytics tools, AI and machine learning, and visualization capabilities.

39

Table of Contents

Rule-Based Logic

Continuous diagnostics relies on sensors to continuously collect data about equipment and send alerts according to predefined rules, i.e., when a specified threshold has been reached. With rule-based logic, we use pre-defined rules, such as "if-this-then-that", which describe certain machine behaviors and inter-dependencies between the various system components, to trigger certain events. Rule-based logic delivers immediate measurable benefits without the need for a large historical data set or advanced machine learning/AI algorithms and data science at the outset. Our solution offers quick results and forms a steppingstone into advanced analytics as data is collected over time - advanced analytics with predictive alerts and automated root cause analysis can be applied at a later phase once sufficient historical data has been collected to accurately identify issues before they occur.

Machine Learning/AI

Machine learning and AI tools are applied to acoustic, vibration and temperature data to push the boundaries of production floor efficiency. Advanced machine learning/AI algorithms learn a machine's normal data behavior and use this as a baseline to identify and alert deviations in real-time. These algorithms look at collected historical data combined with tailored machine-learning algorithms, to run different scenarios and predict what will go wrong and when. We use two approaches to AI and machine learning for predictive analytics - supervised and unsupervised machine learning - each is relevant for a different scenario and depends on the availability of sufficient historical training data and the frequency of asset failure.

Anomaly Analysis

Anomaly Analytics uses machine learning to understand behavioral patterns within time series data, to identify anomalies and to continuously forecast future values. Our alerts operate in real time and offer context - correlating each incident to similar anomalies, relevant factors and the potential root cause.

Regression Analysis

We use regression models to predict metrics such as Remaining Useful Life - the amount of time an asset will remain operational before its next failure - while iteratively trialing and selecting the most appropriate algorithms to use.

Root Cause Analysis

By implementing Automated Root Cause Analysis, there is accurate visibility into early causes of process inefficiencies, with a low number of alerts and false positives. By fusing historical and real-time machine data, machine-learning algorithms trace correlations between the consolidated data and the process inefficiencies. Then, root causes are ranked by likelihood level, delivering production teams with prioritized suggestions to quickly mitigate machine failure that may impact production yield and quality. Automated Root Cause Analysis generates actionable insights, enabling plant managers to reduce unplanned downtime, increase production throughput and maintain schedules.

Data Visualization

Nexscient presents a user-friendly interface with real-time dashboards and interactive data visualizations designed to facilitate major takeaway points. We incorporate point and click data exploration and rich analysis tools to get quicker and accurate interpretations. Our automatic work order generator produces easy-to-understand instructions for inspections and follow-up recommendations.

Automatic Work Orders

User requirements for events and notifications vary based on an application's criticality, the user's role, and personal preference. Nexscient offers a flexible and versatile notifications service that generates work orders specifically describing developing issues along with recommended actions or maintenance procedures. These real-time alerts and reports are sent via push notifications, emails and/or text messages. Optionally, by leveraging its REST API interface, Nexscient can also be optionally integrated with existing CMMS or ERP systems to natively generate and send work orders through the respective system.

Real-Time Dashboard

Leveraging a powerful, yet simple and intuitive Web-based user interface, users can view the dashboard to visualize and analyze machine performance. Visual indicators and alerts are provided in the context of the production process and enable users to quickly pinpoint the root cause and determine the required maintenance action.

40

Table of Contents

Rich Analysis Tools

For deeper analysis, Nexscient plans to offer rich analysis tools for power-users:

? Explore trend, waveform, and spectrum graphs on any browser; ? Analyze spectra with harmonic cursors and sidebands; ? Trend broadband features, like RMS or peak-to-peak; ? Trend narrowband features, like forcing frequencies and bearing tones; ? Configure F-max, lines of resolution, windowing, and averaging metrics; ? Configure bearing tones from our database of bearings; and ? View demodulated and enveloped spectra to catch bearing and other high-frequency issues.

SECURITY LAYER

Security spans all layers, guaranteeing protection of data, plus management, monitoring, orchestration, and provisioning to allow rapid scaling on an ongoing basis. All of the data paths between sensors, the Cloud and apps are authenticated and fully encrypted; connection requests are always initiated by the sensors to prevent inbound threats. From pre-to post-development, our secure software development lifecycle (SDLC) provides best-in-class level of security.

Security Automation and Orchestration

We build in-house tools and capabilities that automatically combat threats - quickly and at scale. These tools respond for us when possible, allowing us to focus on improving our defenses.

Proactive Security

We safeguard data with continuous delivery and code-level security insights. We use static and dynamic code analysis, including process gates to prevent introducing vulnerabilities into the production environment.

Information Classification

To determine the right level of protection, we first classify information before any ingestion takes place. We classify all data, provide clear visibility of threats, maintain highly restricted access and isolate live data from other environments. Once data ingestion begins, we encrypt information while it's in transit and at rest.

Access and Authentication

Based on National Institute of Standards and Technology (NIST) requirements, users only receive the level of access necessary to perform their jobs. Data access control includes passwords, cryptographic keys and multi-factor authentication devices.

Access Zone Security

Our networks use a tiered classification framework to provide data separation. Each client-protected data enclave is a fully security-hardened stack that includes endpoint and network threat prevention, application firewalls and vulnerability scanning.

41

Table of Contents

    UNITED STATES

We believe our service will be viewed by businesses as a cost-effective way to reduce maintenance costs while increasing productivity, giving them advance warning of potential machine failure allowing them to properly schedule maintenance and better manage their resources. One of the key differentiators in our marketing strategy is to emphasize the "no up-front cost" subscription feature because we provide all of the monitoring sensors as part of the subscription service, thereby eliminating a capital expenditure to the business's balance sheet.

Management will emphasize speed in penetrating selected markets and implementing advertising and public relations campaigns. Financial results will be compiled and reported weekly so that gross and net margins can be reviewed and benchmarked. Marketing will be continually monitored and adjusted as needed to maximize market penetration and profitability. Cost control and brand management will be critical to the overall strategy.

Brand Development

We will focus our marketing efforts on increasing the strength of the 'NEXSCIENT' brand, communicating product advantages and business benefits, generating leads for our sales teams and channel partners while driving product adoption. We will deliver targeted content to demonstrate our predictive maintenance platform and use digital advertising methods to deliver opportunities to our sales teams. We will engage with existing customers to provide education and awareness to promote expanded use of our solution. We will work with our own researchers, as well as the broader data science community, to gather important information about potential opportunities and customer leads through an online community, social media, and traditional public relations.

Differentiate us from our competitors

The Nexscient system has powerful capabilities, quick to set up, easy to use, does not require up-front costs, special training, is compatible with most rotating machines in use today, and works right out-of-the-box without the need for any system integration. We plan to establish our service as a cost efficient, machine-monitoring solution for our target markets.

Build a relationship-oriented business

For future clients, such as channel partners and OEMs, relationships will be important. We will become a revenue-generating partner for them, not just a vendor, making these market segments increasingly receptive to our offerings. We must effectively convey the potential monetary value of the relationship, as well as the intrinsic value in being able to offer no upfront cost, ease of deployment, and powerful predictive capabilities to their end-users.

Focus on target markets

We plan to focus our sales and marketing efforts strategically in order to succeed in our target markets. As a start-up company, we believe direct and channel sales will give us the quickest launch and penetration while immediately generating revenues to sustain our company's growth and expansion into other markets.

Fulfill the promise

We can't just market and sell our products, service and support; we must actually deliver as well. We need to make sure we have the technological knowledge we claim to have, while keeping up with evolving technologies to advance the capabilities of our newest products and services.

    UNITED STATES

Our most important marketing goal as a start-up is to establish product and brand awareness with customers in each target market. The way we go about this task will vary from one target market segment to another.

Direct Sales

We will be marketing to businesses through traditional sales efforts, such as advertising in trade journals and publications and establishing a presence at select trade shows geared towards businesses in our market segment. For the larger companies we target, we will offer the free use of our service for a limited time, to prove their efficacy in controlling maintenance costs and averting potential equipment failures, in order to penetrate and gain market share in this segment. We believe once reliability engineers and senior management of these businesses experience the rapid installation of the system, which is virtually plug-n-play and requires no integration with existing IT systems; experience the easy-to-understand tools and user interface without specialized training; and feel more in control of the health and performance of their equipment while realizing notable savings in equipment maintenance costs; all with no upfront costs, they will understand the value of Nexscient.

42

Table of Contents

Channel Partners

We will focus our efforts to partner with condition-based monitoring test equipment and analysis software suppliers. We will emphasize our products' potential as an additional source of revenue for them with recurring monthly revenues; this should make our product very desirable as part of their product lines. By solidifying these partnership agreements, we will also enable cross-marketing back into the consumer market through their sales forces' efforts and their advertising, increasing our sales efforts nationwide without the expense of additional personnel to cover the entire U.S. We believe that once partnered with these companies, our channel market partners (resellers) will advertise the Nexscient system as new features in their traditional outlets, primarily print advertising and in-house POS material, in order to increase mutual sales and brand awareness, benefiting both organizations.

OEMs

Another marketing strategy is to position Nexscient as a strategic ally with original equipment manufacturers of industrial equipment, such as motors, pumps, and compressors. By building a business based on long-standing relationships, we build defenses against competition through the demonstrated efficacy of our products, and our partners' loyalties.

    UNITED STATES

The key to selling Nexscient products and services is the ability to identify a singular market and its unique needs, develop channels to these markets, to configure the Nexscient System, and market that particular feature set to that market. This strategy has the distinct advantage, critical with a potentially complex product, of a focused and simple sales message.

Direct Sales

We believe Nexscient services will benefit any manufacturer or continuous process plant that seeks actionable insights on maintenance and repair issues for their machines and equipment on a real-time basis. The keys to success in this segment are threefold:

    UNITED STATES

The company will market its products to customer segments that require remote, continuous machine monitoring solution (highlighting its machine learning/AI capabilities) in a monthly subscription service. Other features will be specific to each customer segment. The company will spend substantial marketing efforts in determining which set of features are the most attractive to each customer segment. Offering customized quality product to each customer segment at a competitive price level will be one of the marketing goals of Nexscient.

Channel Partners

The sales through channel partners segment are anticipated to be strong for several reasons. By positioning our product to sensor manufacturers, testing equipment suppliers, and software analysis companies as an ancillary item to help them market their own products, we will effectively increase our sales force substantially, without the expenses of payroll, benefits, etc., because their sales force(s) will sell our products to their respective companies. This would also positively impact branding, making our name more commonplace in all the markets discussed herein. By securing alliances in this market, we also position ourselves as the leader in this new technology and its associated applications. This will foster confidence in the Nexscient product, increase sales dramatically and help our Company break into the global market.

43

Table of Contents

OEMs

As the market of industrial equipment manufacturers grows more competitive each year, this segment is continuously looking to add new technologies and systems to draw consumers to their specific and sometimes proprietary products and services. This natural synergy between our product's capabilities and this market segment's needs should prove to have a large and positive impact on the awareness of the Nexscient name and products, as well as increasing revenues through positioning our products with the leaders of this market segment. It is our understanding that many manufacturers of motors, blowers, compressors, and pumps, among others, will be incorporating IoT technologies, such as that in our Nexscient Nodes, into their products over the next five years. This will prove invaluable for Nexscient, as we position ourselves as the preferred supplier of remote, continuous monitoring technologies to OEMs.

Service and Support

We believe, as a value-add, we must be able to sell a support option in order to accommodate certain customers. The Nexscient System, while very easy to install and facilitate, will be better received if we offer (fee-based) consulting services for our larger clients, such as our channel sales partners and large corporate accounts. Simplifying the understanding and implementation of our system will help encourage the daily use and sales efforts of our product, while generating additional revenues for Nexscient, our channel market resellers while increasing the ROI for our investor/partner(s).

    UNITED STATES

We intend to retain and public relations and marketing firm to coordinate the marketing, advertising, and promotion strategy, which will include print advertising in popular industry journals and attending trade shows for Condition-Based Monitoring, Vibration Analysis, and Predictive Maintenance, to name a few. Nexscient will utilize five primary promotion programs:

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

Website & Online Strategy

The Nexscient website will be the virtual business card and portfolio for the company, as well as its online "corporate home" for business-to-business marketing and investor relations. It will showcase our products and services, as well as hosting a portfolio of case studies and whitepapers. The website needs to be simple to navigate, yet well designed and flexible, to accommodate changes in our online needs. The key to the online strategy will be combining a very well-designed front end, with a back end capable of recording leads, processing online demos and information requests, offering online manuals, and running online marketing program for channel partners.

The Nexscient website is developed with few technical resources; a simple hosting provider will host the site and provide the technical back end. The design, updates and maintenance of the site will be done by contracted Web designers, for a more professional image of our company, freeing up senior management to focus on company growth and product development. As the website rolls out future developments such as new products, product add-ons and software updates, ancillary products, newsletters, and downloadable market research reports. We may need to contract further technical resources to build the trackable download information with the capabilities of transmitting and organizing extensive information.

44

Table of Contents

    UNITED STATES

Nexscient subscription requirements will vary depending on the size of the facility and number of machines. Each Nexscient deployment will include a gateway, Nexscient Nodes and unlimited number of accounts to our Nexscient Cloud service. Depending on the number of assets to be monitored, a Nexscient network could include tens to hundreds to several hundred Nexscient Nodes; the price will vary based on the subscription package selected, number of Nexscient Nodes installed, and the number of machines being monitored.

Nexscient expects to offer the lowest cost structure in the industry, but premium pricing based on its uniquely rich feature set and quality service. The company expects it will be the pricing leader, manage the Nexscient brand for this identification and strive to maintain this leadership once obtained. We plan to organize focus groups to determine the best feature set and pricing for the present Nexscient service. The pricing schedule for its subscription offerings has not yet been determined.

Purchase Decision Factors

The primary purchase decision factors in predictive maintenance market are price, accessibility, and ease of use. Based on the Company's review of the existing market of prospective customers, we have identified significant brand loyalty by businesses in this industry. Once an individual has acclimated to the Nexscient system and realized the immediate benefits of the system, we believe they will be reluctant to switch to another service.

Powerful branding and advertising, emphasizing our competitive pricing structure, will create a significant barrier to competitors taking our customers. Becoming a market leader will strengthen the company's branding position and also make it more difficult for the competition. Management feels the primary competition will be other well-branded companies, which have deep advertising pockets, competitive products, and an established brand. Many of the major test instrumentation companies are moving into the remote, condition-based monitoring space because they have the infrastructure to support it and the brand to promote it. They will have the initial advantage in branding and marketing muscle, but they lack the nimble and spry nature of a start-up, such as Nexscient. We believe the marketplace is big enough to support all this competition and then some.

    UNITED STATES

The increased visibility, analytics, and continuous connectivity afforded by Nexscient does not just offer a short-term solution for monitoring equipment for immediate problems, but rather, it enables continuous improvement by providing continuous process facilities with forward-looking capabilities necessary to solve future problems before they arise-compounding the value of the monitoring service over time. Many manufacturers with aged machines are challenged with the expense or feasibility of retrofitting their old equipment with modern sensors. Furthermore, outdated expensive hardware can lead to inefficient performance of the overall predictive maintenance program.

Even if industrial enterprises were to overcome such challenges, they would still have to incur an up-front capital expenditure to purchase the hardware, license the software, and train their personnel to ensure the data being captured is applied and interpreted correctly. With Nexscient, there will be no requirement to purchase any hardware or software, integration to existing IT systems is optional, and specialized training for personnel is not necessary. The key advantages of Nexscient System include:

No Upfront Cost; Low Cost of Entry

Unlike most other continuous monitoring systems on the market today, each subscription to the Nexscient monitoring system includes the sensors nodes used to remotely collect the data from the machines being monitored. Depending on the selected subscription plan and the number of machines to be monitored, Nexscient Nodes are provided as part of the subscription contract.

Quick Installation; Virtually Plug 'n Play

Due to the significantly quicker and less complicated installation process, the Nexscient system is anticipated to take less time to get up and running than alternative legacy monitoring systems. Setup is effectively plug 'n play, taking only a few minutes to install and commence monitoring.

45

Table of Contents

No Integration Required; Autonomous and Cloud-Based

Nexscient does not require integration with control systems or IT networks, thereby bypassing the hassle and expense of integration. If integration is desired, the Nexscient gateway will provide for integration via REST API.

Predictive Analytics; Rule-Based Expert System + AI Algorithms

Proprietary rule-based logic immediately diagnoses incipient problems while at the same time our machine learning/AI algorithms ingest data over time to construct a comprehensive profile for machine health and performance which allows for longer term analysis and planning of machine maintenance, helps reduce machine downtime, increases mean time between failures, and reduces costs of unnecessary preventative maintenance and spare parts inventory.

Remote Access; Continuous Connectivity

Visibility to the operational status of machine components allows plant managers to monitor and diagnose systems quickly as well as identify and resolve problems before the impact on machine availability and productivity. Continuous communication with the monitored equipment allows for a more streamlined process for data collection by replacing manual, route-based patrol thereby increasing efficiencies and leading to better machine health and performance.

Intellectual Property

To protect our unpatented proprietary technologies and processes, we rely on trade secret laws and confidentiality agreements with our employee(s), consultants, channel partners and vendors. At present our only intellectual property is our trademark for "Nexscient" Serial Number 97925547 registered with the USPTO and the Nexscient Predictive Maintenance Platform, which is still in development. The company will rely on provisional patents in the near term, filing for full patent protection, as necessary.

The duration of our trademark registration will vary from country to country, if we register such outside the United States. However, trademarks are generally valid and may be renewed indefinitely as long as they are in use and/or their registrations are properly maintained.

Subsidiaries

The Company has no subsidiaries.

Employees

We currently employ three full-time employees, which include the President & Chief Executive Officer, Chief Financial Officer, and Chief Operating Officer of the Company, all of which have responsibility for all segments of our business. Additionally, we have two contracted consultants.

Jumpstart Our Business Startups Act

In April, 2012, the Jumpstart Our Business Startups Act ("JOBS Act") was enacted into law. The JOBS Act provides, among other things:

    UNITED STATES

46

Table of Contents

In general, under the JOBS Act, a company is an emerging growth company if its initial public offering ("IPO") of common equity securities was effected after December 8, 2011 and the company had less than $1 billion of total annual gross revenues during its last completed fiscal year. A company will no longer qualify as an emerging growth company after the earliest of:

    UNITED STATES

The JOBS Act provides additional new guidelines and exemptions for non-reporting companies and for non-public offerings. Those exemptions that impact the Company are discussed below.

Financial Disclosure. The financial disclosure in a registration statement filed by an emerging growth company pursuant to the Securities Act of 1933 will differ from registration statements filed by other companies as follows:

(i) audited financial statements required for only two fiscal years; (ii) selected financial data required for only the fiscal years that were audited; (iii) executive compensation only needs to be presented in the limited format now required for smaller reporting companies.

(A smaller reporting company is one with a public float of less than $75 million as of the last day of its most recently completed second fiscal quarter).

However, the requirements for financial disclosure provided by Regulation S-K promulgated by the Rules and Regulations of the SEC already provide certain of these exemptions for smaller reporting companies. The Company is a smaller reporting company. Currently a smaller reporting company is not required to file as part of its registration statement selected financial data and only needs audited financial statements for its two most current fiscal years and no tabular disclosure of contractual obligations.

The JOBS Act also exempts the Company's independent registered public accounting firm from complying with any rules adopted by the Public Company Accounting Oversight Board ("PCAOB") after the date of the JOBS Act's enactment, except as otherwise required by SEC rule.

The JOBS Act also exempts an emerging growth company from any requirement adopted by the PCAOB for mandatory rotation of the Company's accounting firm or for a supplemental auditor report about the audit.

Internal Control Attestation. The JOBS Act also provides an exemption from the requirement of the Company's independent registered public accounting firm to file a report on the Company's internal control over financial reporting, although management of the Company is still required to file its report on the adequacy of the Company's internal control over financial reporting.

Section 102(a) of the JOBS Act exempts emerging growth companies from the requirements in 14A(e) of the Securities Exchange Act of 1934 for companies with a class of securities registered under the 1934 Act to hold shareholder votes for executive compensation and golden parachutes.

47

Table of Contents

Other Items of the JOBS Act. The JOBS Act also provides that an emerging growth company can communicate with potential investors that are qualified institutional buyers or institutions that are accredited to determine interest in a contemplated offering either prior to or after the date of filing the respective registration statement. The Act also permits research reports by a broker or dealer about an emerging growth company regardless if such report provides sufficient information for an investment decision. In addition, the JOBS Act precludes the SEC and FINRA from adopting certain restrictive rules or regulations regarding brokers, dealers and potential investors, communications with management and distribution of a research reports on the emerging growth company IPO.

Section 106 of the JOBS Act permits emerging growth companies to submit 1933 Act registration statements on a confidential basis provided that the registration statement and all amendments are publicly filed at least 21 days before the issuer conducts any road show. This is intended to allow the emerging growth company to explore the IPO option without disclosing to the market the fact that it is seeking to go public or disclosing the information contained in its registration statement until the company is ready to conduct a roadshow.

Election to Opt Out of Transition Period. Section 102(b)(1) of the JOBS Act exempts emerging growth companies from being required to comply with new or revised financial accounting standards until private companies (that is, those that have not had a 1933 Act registration statement declared effective or do not have a class of securities registered under the 1934 Act) are required to comply with the new or revised financial accounting standard.

The JOBS Act provides a company can elect to opt out of the extended transition period and comply with the requirements that apply to non-emerging growth companies but any such an election to opt out is irrevocable. The Company has elected not to opt out of the transition period.

    UNITED STATES

We know of no material, existing or pending legal proceedings against our Company, nor are we involved as a plaintiff in any material proceeding or pending litigation. There are no proceedings in which our directors, officers or any affiliates, or any registered or beneficial shareholder, is an adverse party or has a material interest adverse to our interest.

48

Table of Contents

    UNITED STATES

The following discussion of our financial condition and results of operations should be read in conjunction with the financial statements and related notes to the financial statements included elsewhere in this Registration Statement. Some of the statements under "Management's Discussion and Analysis," "Description of Business" and elsewhere herein may include forward-looking statements which reflect our current views with respect to future events and financial performance. These statements include forward-looking statements both with respect to us specifically and the renewable energy industry in general. Statements which include the words "expect," "intend," "plan," "believe," "project," "anticipate," "will," and similar statements of a future or forward-looking nature identify forward-looking statements for purposes of the federal securities laws or otherwise. The safe harbor provisions of the federal securities laws do not apply to any forward-looking statements contained in this Registration Statement. All forward-looking statements address such matters that involve risks and uncertainties. Accordingly, there are or will be important factors that could cause our actual results to differ materially from those indicated in these statements. We undertake no obligation to publicly update or review any forward-looking statements, whether as a result of new information, future developments or otherwise. If one or more of these or other risks or uncertainties materialize, or if our underlying assumptions prove to be incorrect, actual results may vary materially from what we projected. Any forward-looking statements you read herein reflect our current views with respect to future events and are subject to these and other risks, uncertainties and assumptions relating to our written and oral forward-looking statements attributable to us or individuals acting on our behalf and such statements are expressly qualified in their entirety by this paragraph.

The Company is an early-stage company and was incorporated in the State of Delaware on March 14, 2023. During the fiscal year ended June 30, 2023, the Company generated no revenues and incurred operating losses of $93,766 as part of its operating activities.

We believe that our current cash and cash equivalents, anticipated cash flow from operations and the proceeds from the sale of the maximum amount of shares being offered hereunder will only be sufficient to meet our anticipated cash needs for the next 12-48 months. Our management has determined that the maximum amount of funds received from this Offering would be sufficient to cover our intended plan of operations contemplated for the next 48 months.

Results of Operations

From March 14, 2023 (inception) to Year Ended June 30, 2023

Revenues

We are in our development stage and have not generated any revenue from March 14, 2023 (inception) to year ended June 30, 2023.

Operating Expenses

We incurred total operating expenses of $93,766 from March 14, 2023 (inception) to year ended June 30, 2023. All of these expenses are related to development costs and general and administrative expenses, which included professional fees of $67,752 relating to consulting, legal and accounting costs incurred, including fees as part of the formation process of the Company. There is no historical financial data for the Company.

Net Loss

We incurred a net loss of $93,766 from March 14, 2023 (date of inception) to year ended June 30, 2023.

Liquidity and Capital Resources

As at June 30, 2023, the Company has a working capital surplus of $173,099, a net loss of $93,766 and has no revenues to cover its operating costs. We have $202,459 cash on hand and our anticipated burn rate is approximately $61,500 per month. Presently, our operations are being funded by funds previously raised and we believe our currently available capital resources would be sufficient to sustain our operations for a minimum of three (3) months. The Company intends to fund future operations through equity or debt financing arrangements. The ability of the Company to realize its business plan is dependent upon, among other things, obtaining additional financing to continue operations, and development of its business plan. In response to these requirements, management intends to raise additional funds through public or private placement offerings. These factors, among others, raise substantial doubt about the Company's ability to continue as a going concern. The accompanying financial statements do not include any adjustments that might result from the outcome of this uncertainty.

49

Table of Contents

We are currently in development of our software platform. We believe we will require a minimum of $738,000 to proceed with our business plan and remain in operation for at least the next 12 months, see Cash Requirements. As the platform comes online and starts to generate revenue, we will be hiring additional staff which will increase our monthly capital requirements, however, we believe the revenue generated from our operations should cover any additional expenditures.

Beginning October 2023, and continuing for the next twelve months, our plan of operations as presented below includes estimates for our proposed milestones, any one of which may be subject to delays resulting in overall setback of our development timeline. If we are unable to raise the maximum amount in this Offering, we will have to scale back our development and operational efforts, which may curtail the achievement of the proposed milestones, commensurate with the amount raised.

Month 1-2: Pre-launch Preparation (Estimated Expense: $35,000 - $45,000)

Define Technical and Functional Requirements: Determine the core features and functionality required for the initial release; Prioritize features based on customer needs.

Retain Outsourced Software Development Firm: A dedicated team of developers, designers, testers, and customer support representatives to provide the initial development of the Nexscient platform.

Budget Allocation and Roadmap: Allocate budget resources for development, marketing, and ongoing operations. Establish key milestones for achievement in the design, development, and deployment.

Month 3-4: Development and Pilot Program (Estimated Expense: $95,000 - $110,000)

Commence Product Development: Begin building the Minimum Viable Product (MVP) based on the defined specifications and established roadmap. Implement agile development methodologies for flexibility and continuous improvement.

Sensor Node Integration: Design and integrate interface for establishing connections with sensor nodes. Sensor nodes will transmit collected data to the system in real-time and at specified intervals. The system must provide authentication mechanisms to ensure only authorized sensors can send data. Data collected from sensors should include time-stamped acoustic, vibration, temperature information.

Feature Prioritization: Prioritize features based on feature specifications and technical requirements, competitive advantage, and resource availability. Create a detailed product roadmap.

System Reports: Build functionality into user interface to generate custom reports based on selected time periods and sensor types. Reports will include visualizations such as graphs, charts, and tables to represent data trends. Users should have the option to export reports in formats such as PDF or CSV or HTML.

Notifications: Notifications will be triggered by certain threshold-triggered events, system updates, and user configurations. Users will have the option to set custom triggers for notifications; notifications will provide concise and relevant information, including sensor details, event description and timestamp.

Continuous Testing: Conduct rigorous testing, including unit testing, integration testing, and user acceptance testing (UAT). Address any issues promptly.

Pilot Program: Deploy a pilot program with a select group of industrial customers. Gather feedback and iterate on the product.

Month 5-6: User Onboarding and Beta Testing (Estimated Expense: $55,000 - $85,000)

Beta Release: Launch a closed beta version of the software to a limited group of customers. Invite a select group of industrial customers to participate in beta testing. Gather valuable feedback to identify and fix any issues and refine the product based on input.

Documentation and Training: Develop comprehensive user documentation and training materials for both customers and internal teams.

Pricing and Packaging: Finalize subscription pricing models and packaging options. Prepare for billing and payment processing.

50

Table of Contents

Quality Assurance: Conduct thorough testing to ensure the product is stable, secure, and user-friendly.

Month 7-8: Marketing and Sales (Estimated Expense: $35,000 - $65,000)

Content Creation: Develop marketing materials, including website content, blog posts, demo videos, and case studies.

Marketing Strategy: Launch a marketing campaign targeting industrial customers through digital channels, industry events, and partnerships. Consider webinars, social media promotions, and email marketing.

Sales Strategy: Identify and work with channel partners. Develop and train sales personnel on the product's features and benefits. Develop sales collateral and pricing strategies. Equip the sales team with product knowledge and sales materials to effectively communicate the value proposition.

Early Access Program: Offer early access to interested customers at a discounted subscription rates to generate initial revenue and gather more feedback.

Month 9-10: Deployment (Estimated Expense: $90,000 - $120,000)

Beta Launch: Open the software to a wider group of customers, including early beta testers and selected leads.

Customer Onboarding: Develop an onboarding program to ensure customers can easily adopt the software.

Full Product Release: Launch the SaaS application to the public, with a focus on the identified industrial customer segments.

Monitoring and Support: Implement tools for monitoring customer usage and feedback. Provide dedicated customer support.

Customer Support: Scale up customer support operations to handle inquiries and issues effectively. Implement a ticketing system for tracking and resolution.

Month 11-12: Growth and Optimization (Estimated Expense: $50,000 - $75,000)

Monitor Performance Metrics: Continuously monitor key performance indicators (KPIs) such as customer acquisition cost (CAC), customer lifetime value (CLV), and churn rate to refine the strategy. Continue collecting and analyzing customer feedback to drive product improvements. Based on user feedback and data analytics, release updates and improvements to the software.

Reporting and Analysis: Regularly assess the performance against objectives and adjust strategies as needed.

Customer Engagement: Nurture customer relationships through engagement initiatives, including webinars, newsletters, and forums.

Customer Retention: Implement strategies to retain and upsell existing customers, including regular feature updates and customer support.

Cash Flow from Operating Activities

From March 14, 2023 (inception) to year ended June 30, 2023, the cash flows used in the Company's operating activities was $16,381.

Cash Flow from Investing Activities

From March 14, 2023 (inception) to year ended June 30, 2023, the net cash used in investing activities by the Company was $0.

Subsequent Event

On October 2, 2023, we entered into a Software Development Agreement with CORSAC Technologies Corporation, a non-related party, for the software development of the Nexscient SaaS platform.

51

Table of Contents

Cash Flow from Financing Activities

From March 14, 2023 (inception) to year ended June 30, 2023, the net cash provided by financing activities by the Company was $218,840. The cash provided by financing activities is related to increases in proceeds received from sales of our common stock and advances from related party.

Going Concern

We have not attained profitable operations and are dependent upon obtaining financing to pursue any extensive activities. For these reasons, our auditors stated in their report on our audited financial statements that they have substantial doubt that we will be able to continue as a going concern.

Contractual Obligations

We are a smaller reporting company as defined by Rule 12b-2 of the Securities Exchange Act of 1934 and are not required to provide the information under this item.

Future Financings

We will continue to rely on equity sales of our common shares and debt proceeds in order to continue to fund our business operations. Issuances of additional shares will result in dilution to existing stockholders. There is no assurance that we will achieve any additional sales of the equity securities or arrange for debt or other financing to fund our operations and other activities.

Expected Purchase or Sale of Significant Equipment

We do not anticipate the purchase or sale of any significant equipment, as such items are not required by us at this time or in the next twelve months.

Off-Balance Sheet Arrangements

We have no significant off-balance sheet arrangements that have or are reasonably likely to have a current or future effect on our financial condition, changes in financial condition, revenues or expenses, results of operations, liquidity, capital expenditures or capital resources that are material to stockholders.

Disagreements with Accountants on Accounting and Financial Disclosure

Other than the disclosure of uncertainty regarding the ability for us to continue as a going concern which was included in our accountant's report on the financial statements for the period from March 14, 2023 (inception) to year ended June 30, 2023; dbbmckennon's report on the financial statements of the Company for the years ended June 30, 2023 did not contain an adverse opinion or a disclaimer of opinion, nor were they qualified or modified as to uncertainty, audit scope, or accounting principles.

In connection with the audit of the financial statements of the Company from March 14, 2023 (inception) to year ended June 30, 2023, there were no disagreements on any matter of accounting principles or practices, financial statement disclosures, or auditing scope or procedures, which disagreements if not resolved to their satisfaction would have caused them to make reference in connection with dbbmckennon's opinion to the subject matter of the disagreement.

In connection with the audited financial statements of the Company from March 14, 2023 (inception) to year ended June 30, 2023, there have been no reportable events with the Company as set forth in Item 304(a)(1)(v) of Regulation S-K.

Critical Accounting Policies

Critical Accounting Policies described in the Notes to the Financial Statements, page F-7.

52

Table of Contents

Cash Requirements

We anticipate that our current cash and cash equivalents, anticipated cash flow from operations and the proceeds from the sale of the maximum amount of shares being offered hereunder will be sufficient to meet our anticipated cash needs for the next 48 months. If we are able to sell only 75%, 50% or 25% of our offered shares, we anticipate that we will only be able to meet our anticipated cash needs for the next 36 months, 24 months or 12 months, respectively. There is no minimum number of shares that must be sold and there is no guarantee that the Company will raise any funds from the Offering.

We estimate that our maximum and minimum amount of expenses over the next 12 months will be approximately $960,000 and $738,000, respectively, as described in the table below. These estimates may change significantly depending on the nature of our future business activities and our ability to raise additional capital from shareholders or other sources. Some of these estimates will be paid for out of the proceeds of this offering, assuming we are successful in raising any such proceeds.

    UNITED STATES

The foregoing chart sets forth estimates of the Company's total maximum and minimum operational expenses for the initial 12-month period following effectiveness of this Offering. The minimum expenses represent development costs and basic G&A expenses associated with minimal rents and office expenses, working capital for professional fees associated with project development expenses and general legal, accounting and consultant expenses. The amounts are not limited to proceeds received under this offering, if any, and therefore in order to reach our targets, we will need additional funds in the form of financing or revenues.

    UNITED STATES

Identification of Directors and Executive Officers

The following table sets forth the names and ages of our current directors and executive officers:

    UNITED STATES

Term of Office

Should a vacancy exist, the Company's Board of Directors has the power to nominate and appoint a director or directors to fill such vacancy, and each shall hold office until the next annual meeting of stockholders and until his/her successor shall have been duly elected and qualified.

53

Table of Contents

Background and Business Experience

Fred E. Tannous, MSEE, MBA- Director, President & Chief Executive Officer, Treasurer and Secretary

Since founding Nexscient, Inc. in March, 2023, as President and Chief Executive Officer, Mr. Tannous is responsible for overseeing all aspects of its vision, strategy, and product development. Mr. Tannous has over thirty-five years of experience in finance, engineering and new business development and previously consulted to several Fortune 500 companies as well as launching several of his own start-ups. Some of the companies that he founded and operated include Cryptonic Ventures (January 2021-March 2023), a blockchain-based videogame developer; Promise Nutritionals, Inc., (June 2020 - August 2021), a retail purveyor of wellness products under the brand name Promise Guru®; and OverNear/Rowl, Inc. (June 2011- March 2015), a location-based mobile messaging platform and mobile application. Over the past fifteen years, he has worked extensively with development stage and emerging companies to improve performance, enhance enterprise value and maximize returns. As a principal of Rothswell Financial, Inc. (2015-Present), Mr. Tannous has also helped effect transactions valued at more than $1.2 billion in companies across several industries, including mobile and wireless communications and networking technology sectors. One of his previous start-up companies partnered with Los Alamos National Laboratories to commercialize a declassified military technology for continuous remote sensing and monitoring applications. Drawing on his previous public company experience, Mr. Tannous co-founded and was the Chief Executive Officer of Health Sciences Group (2000-2005), an innovative life sciences company, where he was instrumental in successfully taking it public by effecting a self-underwritten public offering (IPO) of its equity securities and growing its market value to more than $100 million. Prior, Mr. Tannous held the position of Senior Analyst at corporate treasury for Hughes Aircraft Company, a government contractor, before transitioning to the position of Manager of Investments & Acquisitions at DIRECTV, where he worked with the CFO in financial operations and was responsible for valuing, structuring and executing strategic investments and overseeing the company's portfolio having a market valuation of over $1 billion. As Chief Financial Officer of Colorado Casino Resorts, Inc. (1996-1999), a gaming and hospitality concern, Mr. Tannous was instrumental in obtaining its listing and trading on NASDAQ and raising over $65 million in combined private equity and debt financing to expand its operations. Mr. Tannous started his career as an electrical engineer at Hughes Aircraft, where he worked on advanced radar signal and data processing techniques for electronic counter-counter-measures used in radar systems onboard F-14, F-15 and F-18/A fighter aircraft. He has co-authored several papers on proprietary and unconventional methods for detecting and countering radar jamming. Mr. Tannous holds a Master of Business Administration (MBA) in Finance and Banking from the University of Chicago (Booth) Graduate School of Business (1994) as well as a Master of Science (1990) and a Bachelor of Science (1988) in Electrical Engineering from the University of Southern California. Mr. Tannous is a member of the Association for the Advancement of Artificial Intelligence and the Association for Computing Machinery.

Tarek N. Shoufani- Director, Chief Operating Officer

Mr. Shoufani has over twenty-five years of experience at the forefront of new and innovative technology sectors where he has focused on implementing corporate strategy into daily operations to meet key objectives. Since 2006, as Managing Director of SinoAmerican Global Fund, Mr. Shoufani is involved in various stages of the Fund's portfolio companies spanning across a broad spectrum of industries globally. Mr. Shoufani brings extensive management experience in the technology industry as well as valuable know-how and expertise in market development and finance structuring within various industry sectors throughout the Americas, Asia, Europe, and Middle East. While working with IZP (2012-2015), a leading global big data company in Shenzhen, China, Mr. Shoufani was instrumental in helping expand their financial and logistical transactions segment across Asia-Pacific, Latin America, Europe and Middle East. As a key liaison with MPR Tech (2010-2012), China's equivalent to eBay, Mr. Shoufani worked with management to streamline online auction management operations and improve top line revenues while helping realize savings in operating expenses. As a key member of 4PX (2007-2010), an e-commerce solutions provider based in Shanghai, China, Mr. Shoufani worked with designers and engineers to implement custom supply chain systems and software services that delivered efficiencies across multiple levels including installation, training, maintenance, and security. Mr. Shoufani holds a Bachelor of Arts (BA) from University of California in Business Economics and Marketing, and is fluent in English, Arabic and French.

Michael J. Portera - Director, Chief Financial Officer

Mr. Portera joined the Company as a Director and Chief Financial Officer on July 12, 2023. With over forty years of experience in finance, sales, and business development, he is responsible for overseeing the financial operations of the Company, liaising with investment banks and financial institutions on fundraising initiatives, advising on merger and acquisition transactions, and implementing industry best practices for the Company's finances and overall financial health. Over the past fifteen years, as a consultant, Mr. Portera has worked with seasoned executives, entrepreneurs, and start-up businesses to successfully consummate thousands of transactions on a global basis, including serving as Treasurer of OverNear/Rowl, Inc. (September 2019 - September 2023), a location-based mobile messaging platform and mobile application. As a former Managing Director with NYPPEX Private Markets (2000-2011), he assisted accredited investors achieve liquidity for over half a billion dollars in illiquid securities in secondary markets with venture capital and private equity funds and was instrumental in raising capital for founders and management teams of early-stage startups. Previously, as Senior Vice President of Investments at Gilford Securities (1995-1999), Mr. Portera worked with Fortune 500 CEOs, Forbes 400 members, and high-net-worth individuals and institutions in various financings and investment-related initiatives. Over the course of his early career as a registered representative, Mr. Portera held senior-level positions at several investment banking firms, including Smith Barney (1992-1995), UBS (1988-1992), and Drexel Burnham Lambert (1983-1987). Early in his career, as a Certified Public Accountant (CPA), Mr. Portera served as a senior auditor at Deloitte & Touche in New York City. Mr. Portera holds a Bachelor of Science (BS) in Economics with a concentration in Accounting from the Wharton School at the University of Pennsylvania (1980).

54

Table of Contents

Eric Manlunas - Director

Mr. Manlunas joined the Nexscient Board of Directors in March, 2023. He has over thirty years of experience in various aspects of financing and building new enterprise and is a valuable member of our Board due to his depth of operating, strategic, and transactional experience. As a recognized business leader, Mr. Manlunas excels in demanding and fluid environments, often across multiple markets, continents, and cultures. Over the past twenty years, as founder and Managing Partner of Wavemaker Partners (2003 - Present), a cross-border venture capital firm with offices in Los Angeles and Singapore, Mr. Manlunas has been part of over 450 investments in early-stage businesses. He is adept at assimilating high levels of complexity, balancing competing factors, and quickly forming sensible and workable strategies to achieve stability and deliver sustainable outcomes. Prior to becoming a venture capitalist, from 1999 to 2003, Mr. Manlunas founded, built and successfully sold two businesses, an e-commerce and Internet Service Provider, to strategic buyers. During the early part of his career, he started as a consultant with Arthur Andersen's Retail Management Group. Mr. Manlunas holds a Master of Business Administration (MBA) from Pepperdine University (1995) and earned a Bachelor of Arts (BA) in Communications from Florida International University (1990).

Term of Office

Each director serves for a term of one year and until his successor is elected at the Annual Shareholders' Meeting and is qualified, subject to removal by the shareholders. Each officer serves for a term of one year and until his successor is elected at a meeting of the Board of Directors and is qualified.

Employees

We have three executive officers. These individuals are not obligated to devote any specific number of hours to our matters and intend to devote only as much time as they deem necessary to our affairs. Our officers are devoted full time to the Company; the amount of time they will devote in any time period will vary based on the stage of the business and progress the company is making. Accordingly, once we are beyond the developmental phase our management will spend more time on our affairs.

Limitation of Liability and Indemnification Matters

Insofar as indemnification for liabilities arising under the Securities Act may be permitted to directors, officers and controlling persons of the registrant pursuant to the foregoing provisions, or otherwise, we have been advised that in the opinion of the Securities and Exchange Commission such indemnification is against public policy as expressed in the Securities Act, and is, therefore, unenforceable.

Identification of Significant Employees

We have no significant employees other than the aforementioned Officers and Directors.

Family Relationship

Tarek N. Shoufani is the brother-in-law of Fred E. Tannous. Other than the foregoing, we currently do not have any officers or directors of our Company who are related to each other.

Involvement in Certain Legal Proceedings

During the past ten years no director, executive officer, promoter or control person of the Company has been involved in the following:

    UNITED STATES

    UNITED STATES

    UNITED STATES

55

Table of Contents

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

i. Any Federal or State securities or commodities law or regulation; or ii. Any law or regulation respecting financial institutions or insurance companies including, but not limited to, a temporary or permanent injunction, order of disgorgement or restitution, civil money penalty or temporary or permanent cease-and-desist order, or removal or prohibition order; or iii. Any law or regulation prohibiting mail or wire fraud or fraud in connection with any business entity; or

    UNITED STATES

Independence of Directors

The Board of Directors is currently composed of four members. Mr. Fred E. Tannous, Mr. Tarek N. Shoufani, Mr. Michael J. Portera, and Mr. Eric Manlunas. Messrs. Tannous, Shoufani and Portera do not qualify as independent Directors in accordance with the published listing requirements of the NASDAQ Global Market as they each hold officer positions. Mr. Eric Manlunas does qualify as an independent director as he is not an officer of the Company. The NASDAQ independence definition includes a series of objective tests, such as that the Director is not, and has not been for at least three years, one of the Company's employees and that neither the Director, nor any of his family members has engaged in various types of business dealings with us. In addition, the Board of Directors has not made a subjective determination as to each Director that no relationships exist which, in the opinion of the Board of Directors, would interfere with the exercise of independent judgment in carrying out the responsibilities of a Director, though such subjective determination is required by the NASDAQ rules. Had the Board of Directors made these determinations, the Board of Directors would have reviewed and discussed information provided by the Directors and the Company with regard to each Director's business and personal activities and relationships as they may relate to the Company and its management.

56

Table of Contents

Committees

We do not currently have an audit, compensation or nominating committee. The Board of Directors as a whole currently acts as our audit, compensation and nominating committees. We intend to establish an audit, compensation and nominating committee of our Board of Directors once we expand the Board to include one or more independent directors and intend to adopt a charter for each committee.

Our audit committee shall be primarily responsible for reviewing the services performed by our independent auditors, evaluating our accounting policies and our system of internal controls. Our compensation committee shall assist the Board in reviewing and approving the compensation structure, including all forms of compensation, relating to our directors and executive officers and periodically reviewing and approving any long-term incentive compensation or equity plans, programs or similar arrangements. Our nominating committee shall assist the Board in selecting individuals qualified to become our directors and in determining the composition of the Board and its committees.

Compliance with Section 16(a) of the Exchange Act

Section 16(a) of the Securities Exchange Act of 1934 requires our directors and executive officers and persons who beneficially own more than ten percent of a registered class of our equity securities to file with the SEC initial reports of ownership and reports of change in ownership of our common stock and other equity securities. Officers, directors and greater than ten percent stockholders are required by SEC regulations to furnish us with copies of all Section 16(a) forms they file. Since inception, we have not had a class of equity securities registered under the Securities Exchange Act of 1934, as amended. Hence, compliance with Section 16(a) thereof by our officers and directors is not required.

Risk Oversight

Effective risk oversight is an important priority of the Board of Directors. Because risks are considered in virtually every business decision, the Board of Directors discusses risk throughout the year generally or in connection with specific proposed actions. The Board of Directors' approach to risk oversight includes understanding the critical risks in the Company's business and strategy, evaluating the Company's risk management processes, allocating responsibilities for risk oversight among the full Board of Directors, and fostering an appropriate culture of integrity and compliance with legal responsibilities.

Corporate Governance

The Company promotes accountability for adherence to honest and ethical conduct; endeavors to provide full, fair, accurate, timely and understandable disclosure in reports and documents that the Company files with the SEC and in other public communications made by the Company; and strives to be compliant with applicable governmental laws, rules and regulations. The Company has not formally adopted a written code of business conduct and ethics that governs the Company's employees, officers and Directors as the Company is not required to do so.

In lieu of an Audit Committee, the Company's Board of Directors is responsible for reviewing and making recommendations concerning the selection of outside auditors, reviewing the scope, results and effectiveness of the annual audit of the Company's financial statements and other services provided by the Company's independent public accountants. The Board of Directors reviews the Company's internal accounting controls, practices and policies.

Code of Ethics

Our Board of Directors has not adopted a code of ethics. We anticipate that we will adopt a code of ethics when we increase either the number of our directors or the number of our employees.

57

Table of Contents

    UNITED STATES

    UNITED STATES

    UNITED STATES

Narrative Disclosure to Summary Compensation Table

There are no formal contracts in place for employment of any officers. In addition to the foregoing, there are no employment contracts, compensatory plans or arrangements, including payments to be received from the Company with respect to any executive officer, that would result in payments to such person because of his resignation, retirement or other termination of employment with the Company, or its subsidiaries, any change in control, or a change in the person's responsibilities following a change in control of the Company.

Outstanding Equity Awards at Fiscal Year-End

There are no current outstanding equity awards to our executive officers.

Long-Term Incentive Plans

There are no arrangements or plans in which we provide pension, retirement or similar benefits for directors or executive officers.

Compensation of Directors

Our directors receive no annual salary or bonus for their service as members of the Company's board of directors.

Security Holders Recommendations to Board of Directors

Shareholders can direct communications to our Chief Executive Officer, Fred E. Tannous, at our executive offices. However, while we appreciate all comments from shareholders, we may not be able to individually respond to all communications. We attempt to address shareholder questions and concerns in our press releases and documents filed with the SEC so that all shareholders have access to information about us at the same time. Mr. Tannous collects and evaluates all shareholder communications. All communications addressed to our directors and executive officers will be reviewed by those parties unless the communication is clearly frivolous.

58

Table of Contents

SECURITY OWNERSHIP OF CERTAIN BENEFICIAL OWNERS AND MANAGEMENT

The following table sets forth certain information concerning the number of shares of our common stock owned beneficially as of October 15, 2023, by: (i) each of our directors; (ii) each of our named executive officers; and (iii) each person or group known by us to beneficially own more than 5% of our outstanding shares of common stock. Unless otherwise indicated, the shareholders listed below possess sole voting and investment power with respect to the shares they own. Unless otherwise specified, the address of each of the persons set forth below is care of the Company at the address 2029 Century Park East, Suite 400, Los Angeles, CA 90067.

Beneficial ownership has been determined in accordance with Rule 13d-3 under the Exchange Act. Under this rule, certain shares may be deemed to be beneficially owned by more than one person (if, for example, persons share the power to vote or the power to dispose of the shares). In addition, shares are deemed to be beneficially owned by a person if the person has the right to acquire shares (for example, upon exercise of an option or warrant) within 60 days of the date as of which the information is provided. In computing the percentage ownership of any person, the amount of shares is deemed to include the amount of shares beneficially owned by such person by reason of such acquisition rights. As a result, the percentage of outstanding shares of any person as shown in the following table does not necessarily reflect the person's actual voting power at any particular date.

    UNITED STATES

    UNITED STATES

Changes in Control

There are no present arrangements or pledges of the Company's securities, which may result in a change in control of the Company.

59

Table of Contents

    UNITED STATES

Related Party Transactions

Related party transactions are measured at the exchange amount, which is the amount of consideration established and agreed to by the related parties. Related parties are natural persons or other entities that have the ability, directly, or indirectly, to control another party or exercise significant influence over the party in making financial and operating decisions. Related parties include other parties that are subject to common control or that are subject to common significant influences.

After the date of incorporation, 10,000,000 shares were issued to directors and officers at par value in exchange for concept and services for the Company valued at $10,000: Fred E. Tannous, founder, Director, President & CEO, Secretary, Treasurer: 6,000,000 shares; Tarek N. Shoufani, Director, Chief Operating Officer: 3,000,000 shares; and Eric Manlunas, Director: 1,000,000 shares. In addition, founder stock in the amount of 525,000 shares was issued to advisors at par value in exchange for services valued at $525: Dr. Leroy B. Pascal: 150,000 shares; Koji Kawana: 130,000 shares; Edwin Medley Payne: 100,000 shares; Dominique Laurin: 100,000 shares; and Salvatore Russo: 45,000 shares.

During the period ended June 30, 2023, there were expenses incurred on behalf of the Company by Fred E. Tannous, Director, President & CEO, Secretary and Treasurer totaling an amount of $19,860 which is included in accounts payable. As of June 30, 2023, included in advances from a related party is $500 due to this officer.

During the period ended June 30, 2023, there were cash expenses of $3,500 incurred for bookkeeping transactions between the Company and David E. Tannous, brother of our CEO, Fred E. Tannous. In addition, the Company issued 250,000 shares of its common stock, with a fair market value of $2,500, for bookkeeping services.

On April 26, 2023, pursuant to a unanimous written consent of the Board of Directors and Common Stock Subscription Agreement, the Company issued 123,000 shares of its common stock to our Director, Eric Manlunas, in exchange for a cash investment of $9,840.

On May 17, 2023, pursuant to a unanimous written consent of the Board of Directors and a Board Member Consulting Agreement, the Company issued 225,000 shares, with a fair value of $18,000 to Eric Manlunas, a Director of the Company, in exchange for consulting services.

On June 1, 2023, the Company entered into a Consulting Agreement with MJP Consulting, LLC ("MJP), a company owned by Michael J. Portera, whereby MJP was retained to provide market research and business, consulting and advisory services as reasonably requested by the Company in the various aspects regarding financial and operational issues of the Company. Consultant fee totaled $18,000, paid in two equal installments. Subsequently, the Board appointed Mr. Portera as a Director and Chief Financial Officer of the Company.

Other than the foregoing, none of the directors or executive officers of the Company, nor any person who owned of record or was known to own beneficially more than 5% of the Company's outstanding shares of its Common Stock, nor any associate or affiliate of such persons or companies, has any material interest, direct or indirect, in any transaction that has occurred during the past fiscal year, or in any proposed transaction, which has materially affected or will affect the Company.

With regard to any future related party transaction, we plan to fully disclose any and all related party transactions in the following manner:

? Disclosing such transactions in reports where required; ? Disclosing in any and all filings with the SEC, where required; ? Obtaining disinterested directors' consent; and ? Obtaining shareholder consent where required.

60

Table of Contents

Review, Approval or Ratification of Transactions with Related Persons

Given our small size and limited financial resources, we have not adopted formal policies and procedures for the review, approval or ratification of transactions, such as those described above, with our executive officers, Directors and significant stockholders. However, all of the transactions described above were approved and ratified by our Board of Directors. In connection with the approval of the transactions described above, our Board of Directors, took into account several factors, including their fiduciary duties to the Company; the relationships of the related parties described above to the Company; the material facts underlying each transaction; the anticipated benefits to the Company and related costs associated with such benefits; whether comparable products or services were available; and the terms the Company could receive from an unrelated third party.

We intend to establish formal policies and procedures in the future, once we have sufficient resources and have appointed additional Directors, so that such transactions will be subject to the review, approval or ratification of our Board of Directors, or an appropriate committee thereof. With regard to any future related party transaction, we plan to fully disclose any and all related party transactions in the following manner:

? Disclosing such transactions in reports where required; ? Disclosing in any and all filings with the SEC, where required; ? Obtaining disinterested directors' consent; and ? Obtaining shareholder consent where required.

Director Independence

Quotations for the Company's common stock are entered on the Over-the-Counter Bulletin Board inter-dealer quotation system, which does not have director independence requirements. For purposes of determining director independence, the Company applied the definitions set out in NASDAQ Rule 4200(a)(15). Under NASDAQ Rule 4200(a)(15), a director is not considered to be independent if he or she is also an executive officer or employee of the corporation. As a result, the Company has one independent director, Eric Manlunas, as our other directors, Fred E. Tannous, Michael Portera, and Tarek Shoufani, are each also an executive officer of the Company.

    UNITED STATES

Lockett + Horwitz, a Professional Law Corporation of Foothill Ranch, California is acting as our counsel in connection with the registration of our securities under the Securities Act, and as such, will pass upon the validity of the securities offered in this offering.

    UNITED STATES

The financial statements of our Company appearing elsewhere in this prospectus have been included herein in reliance upon the report of dbbmckennon, an independent registered public accounting firm, appearing elsewhere herein (which contains an explanatory paragraph describing conditions that raise substantial doubt about our ability to continue as a going concern as described in Note to the financial statements), and upon the authority of said firm as experts in accounting and auditing.

61

Table of Contents

COMMISSION POSITION ON INDEMNIFICATION FOR SECURITIES ACT LIABILITIES

Our Certificate of Incorporation and Delaware law provide that none of our officers or directors will be personally liable to the Company or its stockholders for any damages as a result of any act or failure to act in his or her capacity as an officer or director unless it is proven that:

    UNITED STATES

These provisions eliminate our rights and those of our stockholders to recover damages from an officer or director for his or her breach of a fiduciary duty unless such breach involved intentional misconduct, fraud or a knowing violation of law. The limitations summarized above, however, do not affect our ability or that of our stockholders to seek non-monetary remedies, such as an injunction or rescission, against an officer or director for his or her acts or failure to act.

Insofar as indemnification for liabilities arising under the Securities Act may be permitted to our directors, officers and other persons pursuant to the foregoing provisions, we have been advised that in the opinion of the Securities and Exchange Commission, such indemnification is against public policy as expressed in the Securities Act and is therefore unenforceable.

    UNITED STATES

This prospectus, which constitutes a part of the registration statement, does not contain all of the information set forth in the registration statement and the exhibits thereto. Statements contained in this prospectus as to the contents of any contract or other document that is filed as an exhibit to the registration statement are not necessarily complete and each such statement is qualified in all respects by reference to the full text of such contract or document. For further information with respect to us and the common stock, reference is hereby made to the registration statement and the exhibits thereto, which may be inspected and copied at the principal office of the SEC, 100 F Street NE, Washington, D.C. 20549, and copies of all or any part thereof may be obtained at prescribed rates from the Commission's Public Reference Section at such addresses. Also, the SEC maintains a World Wide Web site on the Internet at http://www.sec.govthat contains reports and other information regarding registrants that file electronically with the SEC. We also make available free of charge our annual, quarterly and current reports, and other information upon request. To request such materials, please contact Mr. Fred E. Tannous, President & Chief Executive Officer.

62

Table of Contents

    UNITED STATES

    UNITED STATES

Report of Independent Registered Public Accounting Firm (PCAOB ID F-2 3501) Balance Sheet as of June 30, 2023 F-3 Statement of Operations for the period March 14, 2023 to June 30, 2023 F-4 Statement of Stockholders' Equity for the period March 14, 2023 to June F-5 30, 2023 Statement of Cash Flows for the period March 14, 2023 to June 30, 2023 F-6 Notes to Financial Statements F-7

F-1

Table of Contents

    UNITED STATES

To the Board of Directors of Nexscient Inc.

Opinion on the Financial Statements

We have audited the accompanying balance sheet of Nexscient Inc. (the "Company") as of June 30, 2023, and the related statements of operations, stockholders' equity, and cash flows for the period from March 14, 2023 (Inception) to June 30, 2023 and the related notes (collectively referred to as the financial statements). In our opinion, the financial statements present fairly, in all material respects, the financial position of the Company as of June 30, 2023, and the results of their operations and their cash flows for the period then ended, in conformity with accounting principles generally accepted in the United States of America.

Going Concern

The accompanying financial statements have been prepared assuming the Company will continue as a going concern. As discussed in Note 3 to the financial statements, the Company has not generated revenues and incurred losses from Inception, which raises substantial doubt about its ability to continue as a going concern. Management's plans in regard to these matters are also described in Note 3. The financial statements do not include any adjustments that might result from the outcome of this uncertainty.

Basis for Opinion

These financial statements are the responsibility of the Company's management. Our responsibility is to express an opinion on the Company's financial statements based on our audit. We are a public accounting firm registered with the Public Company Accounting Oversight Board (United States) (PCAOB) and are required to be independent with respect to the Company in accordance with the U.S. federal securities laws and the applicable rules and regulations of the Securities and Exchange Commission and the PCAOB.

We conducted our audit in accordance with the standards of the PCAOB. Those standards require that we plan and perform the audit to obtain reasonable assurance about whether the financial statements are free of material misstatement, whether due to error or fraud. The Company is not required to have, nor were we engaged to perform, an audit of its internal control over financial reporting. As part of our audit, we are required to obtain an understanding of internal control over financial reporting, but not for the purpose of expressing an opinion on the effectiveness of the Company's internal control over financial reporting. Accordingly, we express no such opinion.

Our audit included performing procedures to assess the risks of material misstatement of the financial statements, whether due to error or fraud, and performing procedures that respond to those risks. Such procedures included examining, on a test basis, evidence regarding the amounts and disclosures in the financial statements. Our audit also included evaluating the accounting principles used and significant estimates made by management, as well as evaluating the overall presentation of the financial statements. We believe that our audit provides a reasonable basis for our opinion.

/s/ dbbmckennon

We have served as the Company's auditor since 2023.

Newport Beach, California

September 15, 2023

F-2

Table of Contents

    UNITED STATES

    UNITED STATES

    UNITED STATES

LIABILITIES AND STOCKOLDERS' EQUITY Current liabilities Accounts payable - related party $ 28,860 Advances from related party 500 TOTAL LIABILITIES $ 29,360

STOCKHOLDERS' EQUITY

Preferred Stock 10,000,000 shares authorized, $0.001 par value, 0 shares issued and outstanding at June 30, 2023 $ - Common Stock 75,000,000 shares authorized, $0.001 par value, 16,528,000 shares issued and outstanding at June 30, 2023 16,528 Additional paid-in capital 404,837 Subscriptions receivable (154,500) Accumulated deficit (93,766) TOTAL STOCKHOLDERS' EQUITY 173,099

TOTAL LIABILITIES AND STOCKHOLDERS' EQUITY $ 202,459

The accompanying notes are an integral part of these financial statements

F-3

Table of Contents

    UNITED STATES

    UNITED STATES

    UNITED STATES

OPERATING EXPENSES Research and development 3,141 General and administrative 90,625 TOTAL OPERATING EXPENSES 93,766

NET LOSS $ (93,766) BASIC AND DILUTED LOSS PER COMMON SHARE $ (0.01) WEIGHTED AVERAGE NUMBEROF COMMON SHARES OUTSTANDING - BASIC AND DILUTED 12,220,670

The accompanying notes are an integral part of these financial statements

F-4

Table of Contents

    UNITED STATES

    UNITED STATES

    UNITED STATES

The accompanying notes are an integral part of these financial statements

F-5

Table of Contents

    UNITED STATES

    UNITED STATES

    UNITED STATES

CASH FLOWS FROM FINANCING ACTIVITIES Advances from related party 500 Proceeds from shares issued for cash 218,340 NET CASH PROVIDED BY FINANCING ACTIVITIES 218,840

NET INCREASE IN CASH 202,459 CASH AT BEGINNING OF THE PERIOD - CASH AT END OF THE PERIOD $ 202,459

Non-cash investing and financing activities: Shares issued for subscriptions receivable $ 154,500

    UNITED STATES

F-6

Table of Contents

NEXSCIENT INC.

NOTES TO FINANCIAL STATEMENTS

NOTE 1 - ORGANIZATION AND DESCRIPTION OF BUSINESS

Nexscient, Inc. (the "Company") was incorporated in the State of Delaware on March 14, 2023. The Company is developing a subscription-based, condition monitoring solution for maintaining and protecting industrial equipment. The Company's objective is to exploit Industrial Internet-of-Things (IIoT), artificial intelligence (AI), and Cloud-computing technologies to offer a continuous, remote machine health monitoring service that provides actionable insights to manufacturers and continuous process facilities seeking an effective yet affordable predictive maintenance solution to help reduce equipment failures, avoid unscheduled downtimes, decrease equipment maintenance costs, and improve overall equipment efficiencies. The Company's head office in Los Angeles, CA.

NOTE 2 - SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES

This summary of significant accounting policies is presented to assist in understanding the financial statements. The financial statements and notes are representations of the Company's management, who are responsible for their integrity and objectivity. These accounting policies conform to the United States of America ("US GAAP") and have been consistently applied in the preparation of the financial statements.

Use of Estimates

In preparing financial statements in conformity with US GAAP, management makes estimates and assumptions that affect the reported amounts of assets and liabilities and disclosures of contingent assets and liabilities at the dates of the financial statements, as well as the reported amounts of revenues and expenses during the reporting periods. Management makes these estimates using the best information available at the time the estimates are made. However, actual results could differ materially from those estimates. Current estimates relate to the fair value of the Company's common stock issued for services.

Concentrations of Credit Risk

The Company maintains its cash with a major financial institution located in the United States of America which it believes to be credit worthy. Balances are insured by the Federal Deposit Insurance Corporation up to $250,000. At times, the Company may maintain balances in excess of the federally insured limits.

Cash

The Company considers all highly liquid investments with original maturities of three months or less to be cash equivalents.

Fair Value of Financial Instruments

Accounting Standards Codification ("ASC") 820 "Fair Value Measurements and Disclosures", defines fair value, establishes a three-level valuation hierarchy for disclosures of fair value measurement and provides disclosure requirements for fair value measures. The three levels are defined as follows:

    UNITED STATES

For cash, accounts payable, and advances from related party, it is management's opinion that the carrying values are a reasonable estimate of fair value because of the short period of time between the origination of such instruments and their expected realization.

F-7

Table of Contents

Revenue Recognition

The Company will account for revenue under ASC 606, "Revenue from Contracts with Customers". The Company will determine revenue recognition through the following steps:

? Identification of a contract with a customer; ? Identification of the performance obligations in the contract; ? Determination of the transaction price; ? Allocation of the transaction price to the performance obligations in the contract; and ? Recognition of revenue when or as the performance obligations are satisfied

Revenue is recognized when control of the promised goods or services is transferred to customers, in an amount that reflects the consideration the Company expects to be entitled to in exchange for those goods or services.

To date, no revenues have been generated.

Research and Development

Research and development costs include costs to develop and refine technological processes used to carry out business operations. Research and development costs charged to expense for the period ended June 30, 2023 were $3,141.

Stock-Based Compensation

Stock-based compensation is accounted for in accordance with ASC Topic 718-10 "Compensation-Stock Compensation" ("ASC 718-10"). The Company measures all equity-based awards granted to employees, independent contractors and advisors based on the fair value on the date of the grant and recognizes compensation expense for those awards over the requisite service period, which is generally the vesting period of the respective award.

The Company classifies equity-based compensation expense in its statement of operations in the same manner in which the award recipient's payroll or contractor costs are classified or in which the award recipient's service payments are classified.

Income Taxes

The Company uses the asset and liability method of accounting for income taxes pursuant to ASC 740 "Income Taxes". ASC 740 requires an asset and liability approach for financial accounting and reporting for income taxes and allows recognition and measurement of deferred tax assets based upon the likelihood of realization of tax benefits in future years. Under the asset and liability approach, deferred taxes are provided for the net tax effects of temporary differences between the carrying amounts of assets and liabilities for financial reporting purposes and the amounts used for income tax purposes. Valuation allowances are provided for deferred tax assets if it is more likely than not these items will either expire before the Company is able to realize their benefits, or that future deductibility is uncertain. The provision for income taxes represents current taxes payable net of the change during the period in deferred tax assets and liabilities.

Earnings (Loss) per Share

Basic earnings (loss) per share is computed by dividing income (loss) available to common shareholders by the weighted-average number of common shares outstanding during the period. Diluted earnings (loss) per share reflects the actual weighted average of common shares issued and outstanding during the period, adjusted for potentially dilutive securities outstanding. Potentially dilutive securities are excluded from the computation of the diluted net earnings (loss) per share if their inclusion would be anti-dilutive. The Company had no dilutive securities for the period ended June 30, 2023.

F-8

Table of Contents

Recently Issued Accounting Pronouncements

Management does not believe that any other recently issued, but not yet effective, accounting standards could have a material effect on the accompanying financial statements. As new accounting pronouncements are issued, the Company will adopt those that are applicable under the circumstances.

NOTE 3 - GOING CONCERN

The financial statements have been prepared on a going concern basis which assumes the Company will be able to realize its assets and discharge its liabilities in the normal course of business for the foreseeable future.

The Company has generated no revenues and incurred losses since inception, resulting in an accumulated deficit of $93,766 as of June 30, 2023 and further losses are anticipated in the development of the Company's business. Accordingly, there is substantial doubt about the Company's ability to continue as a going concern.

The ability to continue as a going concern is dependent upon the Company generating profitable operations in the future and/or to obtain the necessary financing to meet its obligations and repay its liabilities arising from normal business operations when they come due. Management intends to finance operating costs over the next twelve months with existing cash on hand, loans from directors, private placement of common stock, and/or a registered offering of its common stock.

NOTE 4 - RELATED PARTY TRANSACTIONS

Related party transactions are measured at the exchange amount, which is the amount of consideration established and agreed to by the related parties. Related parties are natural persons or other entities that have the ability, directly, or indirectly, to control another party or exercise significant influence over the party in making financial and operating decisions. Related parties include other parties that are subject to common control or that are subject to common significant influences.

See Note 5 for stock issued for services and sold for cash to founders, officers and directors, and advisors.

On June 1, 2023, the Company entered into a Consulting Agreement with MJP Consulting, LLC ("MJP), owned by Michael J. Portera, whereby MJP was retained to provide market research and business, consulting and advisory services as reasonably requested by the Company in the various aspects regarding financial and operational issues of the Company. Consultant fee totaled $18,000, paid in two equal installments. Subsequently, the Board appointed Mr. Portera as a Director and Chief Financial Officer of the Company.

NOTE 5 - STOCKHOLDERS' EQUITY

At June 30, 2023, the Company's authorized capital consists of eighty-five million (85,000,000) shares, comprised of: (i) seventy-five million (75,000,000) shares of Common Stock, par value $0.001 per share (the "Common Stock"); and (ii) 10,000,000 shares of blank check Preferred Stock, par value $0.001 per share (the "Preferred Stock").

On March 17, 2023, the Company issued a total of 10,525,000 founder shares of its common stock to related parties, including officers and directors, and advisors in consideration for various pre-incorporation services rendered to the Company relating to the development of the its strategy, market research, marketing strategy and branding, and other. Management determined the fair value of stock issued to be $10,525, or $0.001 per share, using a market approach that considered infancy of the Company and an early cash investment at $0.01 per share discussed below.

During the period from Inception to June 30, 2023, the Company issued 1,350,000 shares of common stock for various services including product development, board of director services, and accounting services. Of these amounts, 475,000 were to related parties that included a director and a relative of the Company's Chief Executive Officer. The shares issued were valued from $0.01 to $0.08 based on the value of shares being sold for cash at the time of issuance to investors, which was deemed to be the market value. Total stock-based compensation for shares issued for services was $38,000.

A total of $48,525 stock-based compensation was recognized during the period ended June 30, 2023 and is included in general and administrative in the accompanying statement of operations.

On April 19, 2023, the Company issued 1,000,000 shares of its common stock to an early investor in exchange for a cash investment of $10,000, or $0.01 per share.

F-9

Table of Contents

On April 26, 2023, the Company issued 123,000 shares of its common stock to a Director, in exchange for a cash investment of $9,840, or $0.08 per share.

During the period from May 10, 2023 to June 30, 2023, the Company conducted a private placement offering whereby a total of 3,530,000 shares of common stock were issued at a price of $0.10 per share for a total value of $353,000. As at June 30, 2023, $154,500 of the subscriptions remained receivable. Such subscription receivable was received in full subsequent to June 30, 2023.

NOTE 6 - INCOME TAXES

For the periods ended December 31, 2022 and 2021, the Company did not record a current or deferred income tax expense or benefit due to current losses incurred by the Company.

Deferred taxes are recognized for temporary differences between the basis of assets and liabilities for financial statement and income tax purposes. Deferred tax assets of the Company, amounted to approximately $15,000 as of June 30, 2023, and consists primarily of net operating loss carryforwards totaling approximately $53,000. The net operating loss carryforwards are available to be utilized against future taxable income indefinitely. In assessing deferred tax assets, management considers whether it is more likely than not that some portion or all of the deferred income tax assets will not be realized. The ultimate realization of deferred tax assets is dependent upon the generation of future taxable income. Management considers the scheduled projected future taxable income, and tax planning strategies in making this assessment. Accordingly, the Company recognized a full valuation allowance on deferred tax assets. Deferred tax assets were calculated using the Company's combined effective tax rate, which is estimated to be approximately 28%, which is reduced to 0% for the period ended June 30, 2023 due to the full valuation allowance.

The Company has evaluated its income tax positions and has determined that it does not have any uncertain tax positions. The Company will recognize interest and penalties related to any uncertain tax positions through its income tax expense.

The Company is subject to taxation in the U.S. and state jurisdictions. The Company is not presently subject to any income tax audit in any taxing jurisdiction. The Company has not yet filed any tax returns and accordingly, all tax periods remain open to examination.

NOTE 7 - SUBSEQUENT EVENTS

Subsequent to June 30, 2023, the Company issued an additional 1,927,980 shares as part of its private placement offering for total cash proceeds of $192,798.

On July 12, 2023, at a special meeting of the Board of Directors, the Board appointed Michael J. Portera as a Director and Chief Financial Officer, and Company issued 1,500,000 shares of its restricted common stock, having a fair value of $150,000, based on its latest private placement offering price at $0.10 per share.

Management has evaluated subsequent events through September 15, 2023, the date the financial statements were available to be issued. Based on this evaluation, no material events were identified which require adjustment or disclosure in these financial statements, other than described above.

F-10

Table of Contents

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

Until _____________, all dealers that effect transactions in these securities, whether or not participating in this offering, may be required to deliver a Prospectus. This is in addition to the dealers' obligation to deliver a Prospectus when acting as underwriters and with respect to their unsold allotments or subscriptions.

    UNITED STATES

The information in this Prospectus is not complete and may be changed. We may not sell these securities until the Registration Statement filed with the Securities and Exchange Commission is effective. This Prospectus is not an offer to sell these securities and is not soliciting an offer to buy these securities in any jurisdiction where an offer or sale is not permitted.

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

THE INFORMATION IN THIS PROSPECTUS IS NOT COMPLETE AND MAY BE CHANGED. THESE SECURITIES MAY NOT BE SOLD UNTIL THE REGISTRATION STATEMENT FILED WITH THE SECURITIES AND EXCHANGE COMMISSION IS EFFECTIVE. THIS PROSPECTUS IS NOT AN OFFER TO SELL THESE SECURITIES AND IT IS NOT SOLICITING AN OFFER TO BUY THESE SECURITIES IN ANY STATE WHERE THE OFFER OR SALE IS NOT PERMITTED.

    UNITED STATES

Our existing shareholders (the "Selling Shareholders") are offering for resale, 7,682,980 shares of Common Stock. Our Common Stock is presently not traded on any market or securities exchange. The 7,682,980 shares of our Common Stock can be sold by the Selling Shareholders at a fixed price of $0.75 per share until our shares are quoted on the OTC Bulletin Board and thereafter at prevailing market prices or privately negotiated prices. There can be no assurance that a market maker will agree to file the necessary documents with the Financial Industry Regulatory Authority ("FINRA"), which operates the OTC Electronic Bulletin Board, nor can there be any assurance that such an application for quotation will be approved. We have agreed to bear the expenses relating to the registration of the shares for the Selling Shareholders.

63

Table of Contents

Each of the selling shareholders have been advised that they will be affected by the applicable provisions of the Securities Exchange Act of 1934, including, without limitation, Regulation M, which may limit the timing of purchases and sales of any of the securities by the selling shareholders or any such other person. We have instructed our selling shareholders that they may not purchase any of our securities while they are selling shares under this registration statement. Additionally, we have included the foregoing language in the Selling Shareholder Prospectus.

The Selling Shareholders and any broker or dealer participating in the sale of shares on behalf of the Selling Shareholders may be deemed to be "underwriters" within the meaning of the Securities Act of 1933, in which case any profit on the sale of shares by them or commissions received by such broker or dealer may be deemed to be underwriting compensation under the Securities Act of 1933.

This Prospectus covers the resale offering by the Selling Shareholders of 7,682,980 shares of Common Stock. The Company is concurrently conducting a primary offering for 4,000,000 shares, which is covered in a separate public offering prospectus.

THE PURCHASE OF THE SECURITIES OFFERED THROUGH THIS PROSPECTUS INVOLVES A HIGH DEGREE OF RISK. YOU SHOULD CAREFULLY READ AND CONSIDER THE SECTION OF THIS PROSPECTUS ENTITLED "RISK FACTORS" BEFORE BUYING ANY SHARES OF NEXSCIENT, INC. COMMON STOCK.

NEITHER THE SECURITIES AND EXCHANGE COMMISSION NOR ANY STATE SECURITIES COMMISSION HAS APPROVED OR DISAPPROVED OF THESE SECURITIES OR PASSED UPON THE ADEQUACY OR ACCURACY OF THIS PROSPECTUS. ANY REPRESENTATION TO THE CONTRARY IS A CRIMINAL OFFENSE.

You should rely only on the information contained in this Prospectus and in any Prospectus supplement we may file after the date of this Prospectus. We have not authorized anyone to provide you with different information. If anyone provides you with different or inconsistent information, you should not rely on it. We will not make an offer to sell these securities in any jurisdiction where an offer or sale is not permitted. The information contained in this Prospectus is accurate only as of the date of this Prospectus, regardless of the time of delivery of this Prospectus or of any sale of our securities.

    UNITED STATES

    UNITED STATES

64

Table of Contents

    UNITED STATES

    UNITED STATES

65

Table of Contents

You should rely only on the information contained or incorporated by reference to this Prospectus in deciding whether to purchase our Common Stock. We have not authorized anyone to provide you with information different from that contained or incorporated by reference to this Prospectus. Under no circumstances should the delivery to you of this Prospectus or any sale made pursuant to this Prospectus create any implication that the information contained in this Prospectus is correct as of any time after the date of this Prospectus. To the extent that any facts or events arising after the date of this Prospectus, individually or in the aggregate, represent a fundamental change in the information presented in this Prospectus, this Prospectus will be updated to the extent required by law.

    UNITED STATES

    UNITED STATES

Securities being Up to 7,682,980 shares of Common Stock. Our Common Stock is offered described in further detail in the section of this Prospectus titled "DESCRIPTION OF SECURITIES - Common Stock."

Number of shares 19,955,980 shares of Common Stock issued and outstanding as outstanding before of September 15, 2023. the offering

Net Proceeds to the We will not receive proceeds from the resale of shares by Company the Selling Shareholders.

    UNITED STATES

    UNITED STATES

    UNITED STATES

We will not receive any of the proceeds from the sale of our common shares by the Selling Shareholders. The Selling Shareholders will receive all of the net proceeds from the sales of common shares offered by them under this Prospectus.

    UNITED STATES

    UNITED STATES

The persons listed in the following table plan to offer the shares shown opposite their respective names by means of this Prospectus. The owners of the shares to be sold by means of this Prospectus are referred to as the "Selling Shareholders". These shares will be sold at a fixed price of $0.75 per share until our shares are quoted on the OTCQB and thereafter at prevailing market prices or privately negotiated prices.

The following table sets forth the name of the Selling Shareholders, the number of shares of Common Stock beneficially owned by each of the Selling Shareholders as of September 15, 2023 and the number of shares of Common Stock being offered by the Selling Shareholders. The Selling Shareholders may offer all or part of the shares for resale from time to time, however, the Selling Shareholders are under no obligation to sell all or any portion of such shares nor are the Selling Shareholders obligated to sell any shares immediately upon effectiveness of this Prospectus.

66

Table of Contents

    UNITED STATES

67

Table of Contents

James McMiller 25,000 25,000 25,000 0.10 % Leonard Panzer 25,000 25,000 25,000 0.10 % Marcos Hume 25,000 25,000 25,000 0.10 % Maria Danko 25,000 25,000 25,000 0.10 % Michael and Amy Gusick 25,000 25,000 25,000 0.10 % Paolo Sandejas 25,000 25,000 25,000 0.10 % Remeliza Ticsay 25,000 25,000 25,000 0.10 % Reynaldo Cuerdo Jr 25,000 25,000 25,000 0.10 % Robert Ticsay 25,000 25,000 25,000 0.10 % Santiago Enrique Sandejas 25,000 25,000 25,000 0.10 % Stephen Salzstein 25,000 25,000 25,000 0.10 % The Tomorrow Group, LLC 25,000 25,000 25,000 0.10 % Emile F. Tannous 25,000 25,000 25,000 0.10 % Alexander F. Tannous 25,000 25,000 25,000 0.10 % Thomas Keneipp 25,000 25,000 25,000 0.10 %

TOTALS 7,682,980 7,682,980 7,682,980 32.07 %

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

68

Table of Contents

    UNITED STATES

The Selling Shareholders and any of their pledgees, donees, transferees, assignees and successors-in-interest may, from time to time, sell any or all of their shares of common stock on any stock exchange, market or trading facility on which the shares are traded or quoted or in private transactions. These sales may be at fixed or negotiated prices. The Selling Shareholders may use any one or more of the following methods when selling shares:

    UNITED STATES

The Selling Shareholders may also sell shares under Rule 144 under the Securities Act, if available, rather than under this prospectus.

Broker-dealers engaged by the Selling Shareholders may arrange for other brokers-dealers to participate in sales. Broker-dealers may receive commissions or discounts from the Selling Shareholders (or, if any broker-dealer acts as agent for the purchaser of shares, from the purchaser) in amounts to be negotiated. The Selling Shareholders do not expect these commissions and discounts to exceed what is customary in the types of transactions involved.

The Selling Shareholders may from time to time pledge or grant a security interest in some or all of the Shares owned by them and, if they default in the performance of their secured obligations, the pledgees or secured parties may offer and sell shares of common stock from time to time under this prospectus, or under an amendment to this prospectus under Rule 424(b)(3) or other applicable provision of the Securities Act of 1933 amending the list of selling shareholders to include the pledgee, transferee or other successors in interest as selling shareholders under this prospectus.

Upon the Company being notified in writing by a Selling Shareholder that any material arrangement has been entered into with a broker-dealer for the sale of common stock through a block trade, special offering, exchange distribution or secondary distribution or a purchase by a broker or dealer, a supplement to this prospectus will be filed, if required, pursuant to Rule 424(b) under the Securities Act, disclosing (i) the name of each such Selling Shareholders and of the participating broker-dealer(s), (ii) the number of shares involved, (iii) the price at which such the shares of common stock were sold, (iv) the commissions paid or discounts or concessions allowed to such broker-dealer(s), where applicable, (v) that such broker-dealer(s) did not conduct any investigation to verify the information set out or incorporated by reference in this prospectus, and (vi) other facts material to the transaction. In addition, upon the Company being notified in writing by a Selling Shareholder that a donee or pledgee intends to sell more than 5,000 shares of common stock, a supplement to this prospectus will be filed if then required in accordance with applicable securities law.

69

Table of Contents

The Selling Shareholders also may transfer the shares of common stock in other circumstances, in which case the transferees, pledgees or other successors in interest will be the selling beneficial owners for purposes of this prospectus.

The Selling Shareholders and any broker-dealer participating in the distribution of the Selling Shareholder Shares may be deemed to be "underwriters" within the meaning of the Securities Act, and any commission paid, or any discounts or concessions allowed to, any such broker-dealer may be deemed to be underwriting commissions or discounts under the Securities Act. At the time a particular offering of the Selling Shareholder Shares is made, a prospectus supplement, if required, will be distributed which will set forth the aggregate amount of Selling Shareholder Shares being offered and the terms of the offering, including the name or names of any broker-dealers or agents, any discounts, commissions, and other terms constituting compensation from the Selling Shareholders and any discounts, commissions, or concessions allowed or reallowed or paid to broker-dealers.

Under the securities laws of some states, the Selling Shareholder Shares may be sold in such states only through registered or licensed brokers or dealers. In addition, in some states the Selling Shareholder Shares may not be sold unless such shares have been registered or qualified for sale in such state or an exemption from registration or qualification is available and is complied with.

There can be no assurance that any Selling Shareholder will sell any or all of the Selling Shareholder shares registered pursuant to the registration statement, of which this prospectus forms a part.

The Selling Shareholders and any other person participating in such distribution will be subject to applicable provisions of the Exchange Act and the rules and regulations thereunder, including, without limitation, Regulation M of the Exchange Act, which may limit the timing of purchases and sales of any of the Selling Shareholder Shares by the Selling Shareholders and any other participating person. Regulation M may also restrict the ability of any person engaged in the distribution of the Selling Shareholder Shares to engage in market-making activities with respect to the Selling Shareholder Shares. All of the foregoing may affect the marketability of the Selling Shareholder Shares and the ability of any person or entity to engage in market-making activities with respect to the Selling Shareholder Shares.

Once sold under the registration statement of which this prospectus forms a part, the Selling Shareholder Shares will be freely tradeable in the hands of persons other than our affiliates.

    UNITED STATES

70

Table of Contents

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

Until ______, all dealers that effect transactions in these securities, whether or not participating in this offering, may be required to deliver a Prospectus. This is in addition to the dealers' obligation to deliver a Prospectus when acting as underwriters and with respect to their unsold allotments or subscriptions.

PART II - INFORMATION NOT REQUIRED IN PROSPECTUS

    UNITED STATES

The following table sets forth estimated expenses expected to be incurred in connection with the issuance and distribution of the securities being registered. We will pay all such expenses.

Securities and Exchange Commission Registration Fee $ 966 Audit Fees and Expenses $ 15,000 Legal Fees and Expenses $ 25,000 Transfer Agent and Registration Fees and Expenses $ 6,500 Miscellaneous Expenses $ 4,500 Total $ 51,966 * * Estimate only.

    UNITED STATES

We are incorporated under the laws of the State of Delaware. As permitted by Section 102 of the Delaware General Corporation Law, we have adopted provisions in our amended and restated certificate of incorporation and bylaws that limit or eliminate the personal liability of our directors for a breach of their fiduciary duties as a director, which includes a director's duty of care, to the fullest extent permitted under Delaware law. The duty of care generally requires that, when acting on behalf of the corporation, directors exercise an informed business judgment based on all material information reasonably available to them. Consequently, a director will not be personally liable to us or our stockholders for monetary damages for breach of fiduciary duty as a director, except for liability for:

? any breach of the director's duty of loyalty to us or our stockholders; ? any act or omission not in good faith or that involves intentional misconduct or a knowing violation of law; ? any act related to unlawful stock repurchases, redemptions or other distributions or payment of dividends; or ? any transaction from which the director derived an improper personal benefit.

These limitations of liability do not affect the availability of equitable remedies such as injunctive relief or rescission. Our amended and restated certificate of incorporation also authorizes us to indemnify our officers, employees directors and other agents to the fullest extent permitted under Delaware law.

Section 145 of the Delaware General Corporation Law authorizes a court to award, or a corporation's board of directors to grant, indemnity to directors and officers in terms sufficiently broad to permit such. indemnification under certain circumstances for liabilities, including reimbursement for expenses incurred, arising under the Securities Act of 1933, as amended, or the Securities Act. Our amended and restated certificate of incorporation to be in effect immediately after the completion of this offering provides for indemnification of our directors, officers, employees and other agents to the maximum extent permitted by the Delaware General Corporation Law, and our amended and restated bylaws to be in effect immediately prior to the completion of this offering provide that we will indemnify our directors, officers, employees and other agents, in each case to the maximum extent permitted by the Delaware General Corporation Law.

71

Table of Contents

In addition, we will enter into indemnification agreements with our directors and officers that may in some respects be broader than the specific indemnification provisions contained in the Delaware General Corporation Law. These indemnification agreements generally require us, among other things, to indemnify our directors and officers against certain liabilities that may arise by reason of their status or service as directors and officers, other than liabilities arising from willful misconduct. These indemnification agreements also generally require us to advance expenses incurred by the directors and officers as a result of any proceeding against them as to which they could be indemnified. These indemnification provisions and the indemnification agreements may be sufficiently broad to permit indemnification of our directors and officers for liabilities, including reimbursement of expenses incurred, arising under the Securities Act. Further, a stockholder's investment may be adversely affected to the extent that we pay the costs of settlement and damage awards against directors and executive officers as required by these indemnification provisions.

    UNITED STATES

During the period from inception to the filing of this registration statement, the registrant has issued and/or sold the following securities in various transactions exempt from registration:

On March 17, 2023, the Company issued 10,525,000 shares to the founders and advisors with a fair value of $10,525 in exchange for concept development and services valued at $10,525.

On March 23, 2023, the Company issued 750,000 shares to a non-related party with a fair value of $7,500 in exchange for services and 250,000 shares to a related party with a fair value of $2,500 in exchange for services.

During the period April 19, 2023 to April 26, 2023, the Company sold 1,123,000 shares to a director and non-related party in a private investment for a total value of $19,840.

During the period from May 10, 2023 to the date of this prospectus, the Company sold a total of 5,457,980 common shares in a private placement at a price of $0.10 per share for a total value of $545,798.

During the period May 17, 2023 to May 22, 2023, the Company issued 350,000 shares to a director and non-related party with a fair value of $28,000 in exchange for services.

On July 12, 2023, the Company appointed a new officer and director to its Board and issued 1,500,000 shares with a fair value of $150,000 as compensation.

Exemption From Registration. The shares of Common Stock referenced herein were issued in reliance upon one of the following exemptions:

(a) The shares of Common Stock referenced herein were issued in reliance upon the exemption from securities registration afforded by the provisions of Section 4(a)(2) of the Securities Act of 1933, as amended, ("Securities Act"), based upon the following: (a) each of the persons to whom the shares of Common Stock were issued (each such person, an "Investor") confirmed to the Company that it or he is a sophisticated investor and has such background, education and experience in financial and business matters as to be able to evaluate the merits and risks of an investment in the securities, (b) there was no public offering or general solicitation with respect to the offering of such shares, (c) each Investor was provided with certain disclosure materials and all other information requested with respect to the Company, (d) each Investor acknowledged that all securities being purchased were being purchased for investment intent and were "restricted securities" for purposes of the Securities Act, and agreed to transfer such securities only in a transaction registered under the Securities Act or exempt from registration under the Securities Act and (e) a legend has been, or will be, placed on the certificates representing each such security stating that it was restricted and could only be transferred if subsequently registered under the Securities Act or transferred in a transaction exempt from registration under the Securities Act.

72

Table of Contents

(b) The shares of Common Stock referenced herein were issued pursuant to and in accordance with Rule 903 of Regulation S of the Act. No commissions were paid in connection with the completion of this offering, except as noted above. We completed the offering of the shares pursuant to Rule 903 of Regulation S of the Act on the basis that the sale of the shares was completed in an "offshore transaction", as defined in Rule 902(h) of Regulation S. We did not engage in any directed selling efforts, as defined in Regulation S, in the United States in connection with the sale of the shares. Each investor represented to us that the investor was not a "U.S. person", as defined in Regulation S, and was not acquiring the shares for the account or benefit of a U.S. person. The agreement executed between us and each investor included statements that the securities had not been registered pursuant to the Act and that the securities may not be offered or sold in the United States unless the securities are registered under the Act or pursuant to an exemption from the Act. Each investor agreed by execution of the agreement for the shares: (i) to resell the securities purchased only in accordance with the provisions of Regulation S, pursuant to registration under the Act or pursuant to an exemption from registration under the Act; (ii) that we are required to refuse to register any sale of the securities purchased unless the transfer is in accordance with the provisions of Regulation S, pursuant to registration under the Act or pursuant to an exemption from registration under the Act; and (iii) not to engage in hedging transactions with regards to the securities purchased unless in compliance with the Act. All certificates representing the shares were or upon issuance will be endorsed with a restrictive legend confirming that the securities had been issued pursuant to Regulation S of the Act and could not be resold without registration under the Act or an applicable exemption from the registration requirements of the Act.

(c) The shares of common stock referenced herein were issued pursuant to and in accordance with Regulation D Rule 506 and Section 4(a)(2) of the Securities Act. We made this determination in part based on the representations of Investors, which included, in pertinent part, that such Investors were an "accredited investor" as defined in Rule 501(a) under the Securities Act, and upon such further representations from the Investors that (a) the Investor is acquiring the securities for his, her or its own account for investment and not for the account of any other person and not with a view to or for distribution, assignment or resale in connection with any distribution within the meaning of the Securities Act, (b) the Investor agrees not to sell or otherwise transfer the purchased securities unless they are registered under the Securities Act and any applicable state securities laws, or an exemption or exemptions from such registration are available, (c) the Investor either alone or together with its representatives has knowledge and experience in financial and business matters such that he, she or it is capable of evaluating the merits and risks of an investment in us, and (d) the Investor has no need for the liquidity in its investment in us and could afford the complete loss of such investment. Our determination is made based further upon our action of (a) making written disclosure to each Investor prior to the closing of sale that the securities have not been registered under the Securities Act and therefore cannot be resold unless they are registered or unless an exemption from registration is available, (b) making written descriptions of the securities being offered, the use of the proceeds from the offering and any material changes in the Company's affairs that are not disclosed in the documents furnished, and (c) placement of a legend on the certificate that evidences the securities stating that the securities have not been registered under the Securities Act and setting forth the restrictions on transferability and sale of the securities, and upon such inaction of the Company of any general solicitation or advertising for securities herein issued in reliance upon Regulation D Rule 506 and Section 4(a)(2) of the Securities Act.

(d) The shares of common stock referenced herein were issued pursuant to and in accordance with Regulation D Rule 504 and Section 4(a)(2) of the Securities Act. We made this determination in part based on the fact that, at the time of each sale of stock, the Company was not a blank check company, did not have to file reports under the Securities Exchange Act of 1934 and sales of our stock under this exemption did not exceed $1,000,000 of our securities in any 12-month period. Our determination is made based further upon our action of (a) making written disclosure to each Investor prior to the closing of sale that the securities have not been registered under the Securities Act and therefore cannot be resold unless they are registered or unless an exemption from registration is available, (b) making written descriptions of the securities being offered, the use of the proceeds from the offering and any material changes in the Company's affairs that are not disclosed in the documents furnished, and (c) placement of a legend on the certificate that evidences the securities stating that the securities have not been registered under the Securities Act and setting forth the restrictions on transferability and sale of the securities, and upon such inaction of the Company of any general solicitation or advertising for securities herein issued in reliance upon Regulation D Rule 504 and Section 4(a)(2) of the Securities Act.

73

Table of Contents

    UNITED STATES

The following is a list of exhibits filed as part of this registration statement. Any statement contained in an incorporated document shall be deemed to be modified or superseded for purposes of this Registration Statement to the extent that a statement contained herein or in any other subsequently filed incorporated document modifies or supersedes such statement. Any such statement so modified or superseded shall not be deemed, except as so modified or superseded, to constitute a part of this Registration Statement.

    UNITED STATES

(1) Filed herewith. (2) Previously filed as exhibits to Form S-1 filed with the Commission September 15, 2023, incorporated herein by reference.

74

Table of Contents

    UNITED STATES

(a) The undersigned Registrant hereby undertakes to:

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

Provided however, that:

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

75

Table of Contents

    UNITED STATES

i. If the registrant is relying on Rule 430B:

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

76

Table of Contents

    UNITED STATES

Pursuant to the requirements of the Securities Act of 1933, as amended, the registrant certifies that it has reasonable grounds to believe that it meets all of the requirements for filing on Form S-1/A and has duly caused this registration statement to be signed on its behalf by the undersigned, thereunto duly authorized, on the 19th day of October, 2023.

NEXSCIENT, INC.

/s/ Fred E. Tannous

By: Fred E. Tannous

Title: President, & Chief (Principal) Executive Officer

/s/ Michael J. Portera

By: Michael J. Portera

Title: CFO and Chief (Principal) Accounting Officer

/s/ Tarek N. Shoufani

By: Tarek N. Shoufani

Title: Chief Operating Officer

In accordance with the requirements of the Securities Act of 1933, this Registration Statement has been signed below by or on behalf of the following persons in the capacities and on the dates stated.

Signature Title Date

/s/ Fred E. Tannous Director October 19, 2023 By: Fred E. Tannous

/s/ Michael J. Portera Director October 19, 2023 By: Michael J. Portera

/s/ Tarek N. Shoufani Director October 19, 2023 By: Tarek N. Shoufani

/s/ Eric Manlunas Director October 19, 2023 By: Eric Manlunas

77

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

October 19, 2023

Nexscient, Inc.

2029 Century Park East, Suite 400

Los Angeles, CA 90067

Ladies and Gentlemen:

You have requested our opinion as counsel to Nexscient, Inc., a Delaware corporation, (the "Company") in connection with the Company's registration statement on Form S-1, as amended, filed with the U.S. Securities and Exchange Commission (the "Commission") under the Securities Act of 1933, as amended (the "Securities Act") (File No. 333-274532) (the "Registration Statement"). The Registration Statement relates to the offering of 4,000,000 of the Company's common shares, par value $0.001 (the "Offering Shares") and the resale of an aggregate of 7,682,980 of the Company's common shares, par value $0.001, by selling shareholders (the "Resale Shares"). This opinion is being furnished in accordance with the requirements of Item 601(b)(5) of Regulation S-K under the Securities Act, and no opinion is expressed herein as to any matter pertaining to the contents of the Registration Statement or related Prospectus, other than as expressly stated herein with respect to the issue of the Offering Shares. It is understood that the opinions set forth below are to be used only in connection with the offer while the Registration Statement is in effect.

In rendering these opinions, we have examined the Company's Certificate of Incorporation and Bylaws, both as amended and currently in effect, the Registration Statement, and the exhibits thereto, and such other records, instruments and documents as we have deemed advisable in order to render these opinions. In such examination, we have assumed the genuineness of all signatures, the legal capacity of all natural persons, the authenticity of all documents submitted to us as originals, the conformity to original documents of all documents submitted to us as certified, conformed or photo static copies and the authenticity of the originals of such latter documents, and the accuracy and completeness of the corporate records made available to us by the Company. In providing these opinions, we have further relied as to certain matters on information obtained from officers of the Company. As to any facts material to the opinions expressed below, with your permission we have relied solely upon, without independent verification or investigation of the accuracy or completeness thereof, any certificates and oral or written statements and other information of or from public officials, officers or other representatives of the Company and others.

Based upon the foregoing and in reliance thereon, it is our opinion that the Offering Shares of the Company are duly authorized and will, upon the receipt of full payment, issuance and delivery in accordance with the terms of the offering described in the Registration Statement, be legally issued, fully paid and non-assessable. In addition, it is our opinion that the Resale Shares have been duly authorized and are duly and validly issued, fully paid and non-assessable.

We assume no obligation to update or supplement this opinion letter if any applicable laws change after the date of this opinion letter or if we become aware after the date of this opinion letter of any facts, whether existing before or arising after the date hereof, that might change the opinions expressed above.

1

This opinion letter is furnished in connection with the filing of the Registration Statement and may not be relied upon for any other purpose without our prior written consent in each instance. Further, no portion of this letter may be quoted, circulated or referred to in any other document for any other purpose without our prior written consent.

The opinions expressed herein are limited to the laws of the State of Delaware, all applicable provisions of the statutory provisions, and reported judicial decisions interpreting those laws. We are attorneys licensed to practice in the State of California and our opinions herein assume the laws of the State of Delaware as applied here are the same as in those jurisdictions. This opinion is limited to the laws in effect as of the date hereof and is provided exclusively in connection with the public offering contemplated by the Registration Statement.

This opinion is for your benefit in connection with the Registration Statement and may be relied upon by you and by persons entitled to rely upon it pursuant to the applicable provisions of the Act. We consent to your filing this opinion as an exhibit to the Registration Statement and to the reference to our firm in the Prospectus under the heading "Legal Matters." In giving this consent, we do not thereby admit that we are within the category of persons whose consent is required under Section 7 of the Securities Act, the rules and regulations of the Securities and Exchange Commission promulgated thereunder, or Item 509 of Regulation S-K promulgated under the Securities Act, nor do we admit that we are experts with respect to any part of the Registration Statement within the meaning of the term "expert" as used in the Securities Act, or the related rules and regulations of the SEC promulgated thereunder.. This opinion is expressed as of the date hereof unless otherwise expressly stated, and we disclaim any undertaking to advise you of any subsequent changes in the facts stated or assumed herein or of any subsequent changes in applicable laws.

Regards,

/s/ Lockett + Horwitz LOCKETT + HORWITZ A Professional Law Corporation

2

    UNITED STATES

    UNITED STATES

This Bookkeeping Services Agreement ("Agreement") is made and entered into on March 23, 2023 by and between David E. Tannous, with a mailing address of _______________ ("Bookkeeper") and Nexscient, Inc., a Delaware corporation, with address located at 2029 Century Park East, Suite 400, Los Angeles, CA 90067 ("Client").

Whereas, the Client and Bookkeeper ("Parties") agree to the following terms and conditions for the Bookkeeper's services, as an independent contractor, in exchange for fees.

Services. The Bookkeeper agrees to provide the following services:

- Accounts Payable - Accounts Receivable - Bank Reconciliation - Customized Reports - Detailed General Ledgers - Financial Statements - General Bookkeeping

The aforementioned selections shall be referred to as the "Services". The Bookkeeper shall conduct the Services within the specifications and guidelines set by the Client. The Bookkeeper shall, at all times, observe and comply with generally accepted bookkeeping and accounting practices and standards while complying with all Federal and State laws, regulations, and procedures when completing their Services in accordance with this Agreement.

Fees. The Client agrees to pay the Bookkeeper $3,500 in cash for establishing the Client's general ledger, chart of accounts, and initial financial statements to include balance sheet, income statement, and statement of cash flows. In addition, for the provision of on-going Services described above, the Client agrees to issue 250,000 shares of Nexscient common stock, $0.001 per share, par value.

Expenses. In addition to the Fees provided, the Client agrees to reimburse the Bookkeeper for any out-of-pocket expenses incurred that include, but are not limited to, travel expenses, audit fees, tax fees, and postage.

Term. The Term of this Agreement shall be for a period of one (1) year, starting from the date of the Agreement.

Termination. This Agreement can be terminated by Client by providing Bookkeeper 10 days prior written notice. Unless the Bookkeeper has not performed the Services in accordance with this Agreement, the Client shall pay the Bookkeeper, in-full, for any remaining balance owed following the termination of Services.

Client's Obligations. The Client shall be solely responsible for providing the Bookkeeper all financial information related to their personal and/or business affairs including, but not limited to, all materials, data, and documents necessary to perform the Services under this Agreement. The Client acknowledges and agrees that the accuracy of financial information supplied to the Bookkeeper is the sole responsibility of the Client and the Bookkeeper shall be held harmless from any liability resulting from the accuracy of the financial information provided.

Employment Status. The Parties agree that the Bookkeeper shall provide the Services to the Client as an independent contractor and shall not be acting or determined to be an employee, agent, or broker. As an independent contractor, the Bookkeeper shall be required to follow all requirements in accordance with the Internal Revenue Code which includes, and is not limited to, payment of all taxes levied for fees collected by the Client for payment of their employees, agents, brokers, and subcontractors. The Bookkeeper understands that the Client shall in no way withhold any amounts for payment of any taxes from the Bookkeeper's accumulated fees for Services.

Confidentiality. The Bookkeeper, shall in the course of performing the Services hereunder, may gain access to certain confidential or proprietary information of the Client. Such "Confidential Information" shall include all information concerning the business, affairs, products, marketing, systems, technology, customers, end-users, financial affairs, accounting, statistical data, documents, discussion, or other information developed by the Bookkeeper hereunder and any other proprietary and trade secret information of the Client whether in oral, graphic, electronic or machine-readable form. The Bookkeeper agrees to hold all such Confidential Information of the Client in strict confidence and shall not, without the express prior written permission of the client, disclose such Confidential Information to third parties or use such Confidential Information for any purposes whatsoever, other than the performance of its obligations hereunder. The obligations under this section shall survive the termination or expiration of this Agreement.

Assignment. The Bookkeeper shall have no rights to assign any of their rights under this Agreement, or delegate the performance of any of the obligations or duties hereunder, without the prior written consent of the Client. Any attempt by the Bookkeeper to assign, transfer, or subcontract any rights, duties, or obligations arising hereunder shall be void and of no effect.

Notices. Any notices, bills, invoices, or reports required by this Agreement shall be deemed received on the day of delivery if delivered by hand, standard mail, e-mail, or facsimile during the receiving party's regular business hours.

Governing Law. This Agreement shall be construed in accordance with and governed by Federal laws and those located in the State of Delaware.

Dispute Resolution. All disputes under this Agreement shall be settled by arbitration in the State of governing law before a single arbitrator pursuant to the commercial law rules of the American Arbitrator Association. Arbitration may be commenced at any time by any party hereto giving written notice to the other party to a dispute that such dispute has been referred to arbitration. Any award rendered by the arbitrator shall be conclusive and binding upon the parties hereto. This provision for arbitration shall be specifically enforceable by the parties and the decision of the arbitrator in accordance herewith shall be final and binding without right of appeal.

Severability. If any provision of this Agreement shall be held to be illegal, invalid or unenforceable under present or future laws, such provisions shall be severable, this Agreement shall be construed and enforced as if such illegal, invalid or unenforceable provision had never comprised a part of this Agreement; and, the remaining provisions of this Agreement shall remain in full force and effect.

2

Limitation of Liability. In no event shall either party be liable to the other party for any indirect, incidental, consequential, special or exemplary damages, including without limitation, business interruption, loss of or unauthorized access to information, damages for loss of profits, incurred by the other party arising out of the services provided under this Agreement, even if such party has been advised of the possibility of such damages. In no event will neither party's liability on any claim, loss or liability arising out of or connected with this Agreement shall exceed the amounts paid to the Bookkeeper during the period immediately preceding the event giving rise to such claim or action by the Client or the limits of the Bookkeeper's professional liability policy, whichever is greater of the errors and omissions policy that is in place.

Indemnification. Each party shall at its own expense indemnify and hold harmless, and at the other party's request defend such party affiliates, subsidiaries, and assigns its respective officers, directors, employees, sublicensees, and agents from and against any and all claims, losses, liabilities, damages, demand, settlements, loss, expenses, and costs, including attorneys' fees and court costs, which arise directly or indirectly out of or related to any breach of this Agreement or the gross negligence or willful misconduct of a party's employees or agents.

Entire Agreement. This Agreement is the final, complete and exclusive agreement of the parties with respect to the subject matter hereof and supersedes and merges all prior or contemporaneous representations, discussions, proposals, negotiations, conditions, communications, and agreements, whether written or oral, between the parties relating to the subject matter hereof and all past courses of dealing or industry custom. No modification of or amendment to this Agreement shall be effective unless in writing and signed by each of the Parties.

Waiver. The waiver by either party of a breach of or a default under any provision of this Agreement shall not be effective unless in writing and shall not be construed as a waiver of any subsequent breach of or default under the same or any other provision of this Agreement, nor shall any delay or omission on the part of either party to exercise or avail itself to any right or remedy that it has or may have hereunder operate as a waiver of any right or remedy.

3

IN WITNESS WHEREOF the parties have duly executed this Agreement as of the date first written above.

"Client" "Bookkeeper"

NEXCIENT, INC. DAVID E. TANNOUS

Name: Fred E. Tannous, CEO Name: David E. Tannous Name: David E. Tannous

Date: March 23, 2023 Date: March 23, 2023

4

    UNITED STATES

    UNITED STATES

This Consulting Agreement (this "Agreement") is entered and effective as of May 17, 2023 (the "Effective Date"), by and between Nexscient, Inc. with principal offices located at 2029 Century Park East, Suite 400, Los Angeles, CA 90067 (the "Company") and Eric Manlunas ("Board Member"), and together with the Company, the "Parties.").

    UNITED STATES

A. The Company has requested that Board Member provide certain consulting services to the Company and Board Member has agreed to provide such services.

B. The Parties would like to enter into this Agreement to define the parties' rights and obligations under which Board Member shall provide consulting services to the Company.

NOW, THEREFORE, in consideration of the mutual promises of the parties hereto and of other good and valuable consideration, the receipt and sufficiency of ich are hereby acknowledged, and intending to be legally bound hereby, the Parties hereto agree as follows:

    UNITED STATES

    UNITED STATES

1.1 Consulting Position. Board Member agrees to serve provide consulting services for the Company, on the terms and conditions set forth below.

2.2 Term. This Agreement shall begin on the Effective Date continue period or until terminated by either Party pursuant to Article 3 (the "Term").

3.3 Duties. Board Member agrees to undertake and perform all duties and services set forth on Exhibit A to this Agreement (the "Services"). Board Member shall perform the Services herein faithfully, diligently, to the best of Board Member's ability, and in the best interests of the Company.

3.4 Policies. The Board Member shall adhere to and comply with e policies and procedures adopted by the Company, as amended from time to time, and the laws, regulations, policies and industry standards of all applicable regulatory agencies, stock exchanges and security commissions.

3.5 Independent Contractor. Board Member's relationship with Company shall be that of an independent contractor and not that of an employee. Board Member shall not be entitled to any compensation for the performance of the services other than as set forth in his Agreement. Board Member acknowledges and agrees that except as specifically set forth in this Agreement, Board Member shall not be eligible for any Company employee benefits and, to the extent Board Member otherwise would be eligible for any Company employee benefits but for the express terms of this Agreement, Board Member (on behalf of himself and any of his employees) hereby expressly declines to participate in such Company employee benefits.

Board Member shall have full responsibility for applicable withholding taxes for all compensation paid to Board Member under this Agreement, and for compliance with all applicable labor and employment requirements with respect to Board Member's self-employment. Board Member agrees to indemnify, defend, and hold Company harmless from any liability for, or assessment of, any claims or penalties with respect to such withholding taxes, labor or employment requirements, including any liability for, or assessment of, withholding taxes imposed on Company by the relevant taxing authorities with respect to any compensation paid to Board Member.

    UNITED STATES

    UNITED STATES

2.1 Consulting Payments. The Company shall pay to the Board Member, as remuneration of his services, payment as set forth on Exhibit A.

2.2 Reimbursement for Business Expenses. During the term of this Agreement, the Company shall reimburse the Board Member for all reasonable traveling and other expenses actually, properly and necessarily incurred by the Board Member in connection with the performance of the Board Member's duties hereunder in accordance with the policies set from time to time by the Company, in its sole discretion. Expenses over $500 in any calendar month must be preapproved by the Company in writing prior to their incurrence. The Board Member shall furnish such receipts, vouchers or other evidence as are required by the Company to substantiate such expenses.

    UNITED STATES

    UNITED STATES

3.1 Termination. Either party shall have the right to terminate this Agreement upon written notice, with or without "Cause" (as defined below), before the expiration of the Term. Whatever the circumstances of the termination may be, Board Member shall continue to be bound after termination by Articles 5, 6, 7, and 8 of this Agreement. Except as set forth in Section 3.2, any compensation accrued and or due to be paid under this one-year agreement shall survive termination of this agreement. Board Member acknowledges that the Company has made no promise to Board Member that he will be retained for any particular amount of time and that the Company may terminate Board Member' s services for any reason whatsoever. The date of any termination pursuant to this Section 3.1 shall be referred to as the "Termination Date".

3.2 Termination for Cause. If this Agreement is terminated for Cause, Board Member shall forfeit any cash, equity compensation or bonus compensation not already received by Board Member or not already vested as of the Termination Date.

3.3 Cause. For purposes of this Agreement, "Cause" shall mean the following (i) the Board Member's commission of an act of fraud, theft or dishonesty against the Company; (ii) the arrest of the Board Member for any act involving dishonest conduct or other act of moral turpitude; (iii) willful or wanton misconduct, recklessness, or gross negligence by the Board Member in the performance of the Services; (iv) if Board Member is determined to have a "bad actor" disqualification as set forth in Rule 506(d) of Regulation D under the Securities Act of 1933, (v) a breach by Board Member of any obligation of Board Member under this Agreement, and (vi) unwillingness of the Board Member to perform the Services continuing for a period of five (5) business days after notice to the Board Member.

    UNITED STATES

    UNITED STATES

4.1 Non-Solicitation of Employees. So long as Board Member is a member of the Company's Board of Directors, and one year following such time, Board Member shall not directly or indirectly solicit for employment or for independent contractor work any employee of the Company or its affiliates, and shall not encourage any such employee to leave the employment of the Company or its affiliates.

4.2 Non-Compete. Board Member agrees that so long that Board Member is a member of the Company's Board of Directors, Board Member will not be an employee, agent, director, owner, partner, Board Member, financial backer, creditor or otherwise directly or indirectly be connected with or provide services to or participate in the management, operation or control of any Company which is in direct competition to the Company.

2

    UNITED STATES

    UNITED STATES

5.1 Nondisclosure. Board Member acknowledges that in the course of providing services to the Company, Board Member will have access to confidential information. Confidential information includes, but is not limited to, information about either the Company's clients, the terms and conditions under which the Company or its affiliates deals with clients, pricing information for the purchase or sale of assets, customer lists, research materials, manuals, computer programs, formulas for analyzing asset portfolios, techniques, data, marketing plans and tactics, technical information, lists of asset sources, the processes and practices of the Company, all information contained in electronic or computer files, all financial information, salary and wage information, and any other information that is designated by the Company or its affiliates as confidential or that Board Member knows is confidential, information provided by third parties that the Company or its affiliates are obligated to keep confidential, and all other proprietary information of the Company or its affiliates. Board Member acknowledges that all confidential information is and shall continue to be the exclusive property of the Company or its affiliates, whether or not prepared in whole or in part by Board Member and whether or not disclosed to or entrusted to Board Member in connection with service for the Company. Board Member agrees not to disclose confidential information, directly or indirectly, under any circumstances or by any means, to any third persons without the prior written consent of the Company. Board Member agrees that he will not copy, transmit, reproduce, summarize, quote, or make any commercial or other use whatsoever of confidential information, except as may be necessary to perform work done by Board Member for the Company. Board Member agrees to exercise the highest degree of care in safeguarding confidential information against loss, theft or other inadvertent disclosure and agrees generally to take all steps necessary or requested by the Company to ensure maintenance of the confidentiality of the confidential information.

5.2 Exclusions. Section 5.1 shall not apply to the following information: (a) information now and hereafter voluntarily disseminated by the Company to the public or which otherwise becomes part of the public domain through lawful means; (b) information already known to Board Member as documented by written records which predate the Effective Date; (c) information subsequently and rightfully received from third parties and not subject to any obligation of confidentiality; and (d) information independently developed by Board Member after termination of his services.

5.3 Subpoenas; Cooperation in Defense of the Company. If Board Member, during the Term or thereafter, is served with any subpoena or other compulsory judicial or administrative process calling for production of confidential information or if Board Member is otherwise required by law or regulation to disclose confidential information, Board Member will immediately, before making any such production or disclosure, notify the Company and provide it with such information as may be necessary for the Company to take such action as the Company deems necessary to protect its interests. Board Member agrees to cooperate reasonably with the Company, whether during the Term or thereafter, in the prosecution or defense of all threatened claims or actual litigation in which the Company is or may become a party, whether now pending or hereafter brought, in which Board Member has knowledge of relevant facts or issues. Board Member shall be reimbursed for his reasonable expenses for travel time due to cooperating with the prosecution or defense of any litigation for the Company.

5.4 Disclosure of and/or Trading on Material Nonpublic Information. Board Member acknowledges that Company is a public company and that in performing the Services he may have access to material nonpublic information. Information is material if there is a substantial likelihood that a reasonable investor would consider it important in deciding whether to buy, hold or sell a security. Nonpublic information is information that is not generally known or available to the public. Board Member agrees not to discuss any material nonpublic information with any third parties and to refrain from buying or selling any securities based on any material nonpublic information learned in performing the Services unless such disclosure or trading is permitted under applicable state and federal securities laws.

3

5.5 Confidential Proprietary and Trade Secret Information of Others. Board Member represents that he has disclosed to the Company any agreement to which Board Member is or has been a party regarding the confidential information of others and Board Member understands that Board Member's execution of this Agreement with the Company will not require Board Member to breach any-such agreement. Board Member will not disclose such confidential information to the Company nor induce the Company to use any trade secret or proprietary information received from another under an agreement or understanding prohibiting such use or disclosure.

5.6 No Unfair Competition. Board Member hereby acknowledges that the sale or unauthorized use or disclosure of any of the Company's confidential material obtained by Board Member by any means whatsoever, at any time before, during, or after the Term shall constitute unfair competition. Board Member shall not engage in any unfair competition with the Company or its affiliates either during the Term, or at any time thereafter.

5.7 Remedies. The Company shall have all remedies in law and equity against Board Member (including special and consequential damages) for damages to the Company caused by the violations of Articles 4 or 5.

    UNITED STATES

    UNITED STATES

6.1 Company's Ownership. Board Member agrees that all inventions, discoveries, improvements, trade secrets, formulae, techniques, processes, and know-how, whether or not patentable, and whether or not reduced to practice, that are conceived or developed during the Term, either alone or jointly with others, if on the Company's time, using the Company's equipment, supplies, facilities, or trade secret information or relating to the Company shall be owned exclusively by the Company, and Board Member hereby assigns to the Company all Board Member's right, title, and interest in all such intellectual property. The Board Member agrees that the Company shall be the sole owner of all domestic and foreign patents or other rights pertaining thereto, and further agrees to execute all documents that the Company reasonably determines to be necessary or convenient for use in applying for, prosecuting, perfecting, or enforcing patents or other intellectual property rights, including the execution of any assignments, patent applications, or other documents that the Company may reasonably request. This provision is intended to apply only to the extent permitted by applicable law.

6.2 Ownership of Copyrights. Board Member agrees that all original works of authorship not otherwise within the scope of Section 6.1 that are conceived or developed during Board Member's engagement with the Company, either alone or jointly with others, if on the Company's time, using Company' s facilities, or relating to the Company shall be owned exclusively by the Company, and Board Member hereby assigns to the Company all of Board Member's right, title, and interest in all such original works of authorship. Board Member agrees that the Company shall be the sole owner of all rights pertaining thereto, and further agrees to execute all documents that the Company reasonably determines to be necessary or convenient for establishing in Company's name the copyright to any such original works of authorship. Board Member shall claim no interest in any inventions, copyrighted material, patents, or patent applications unless Board Member demonstrates that any such invention, copyrighted material, patent, or patent application was developed before he began providing any services for Company. This provision is intended to apply only to the extent permitted by applicable law.

6.3 Ownership of Records. Any written record that Board Member may maintain of inventions, discoveries, improvements, trade secrets, formulae, processes, or know-how, whether or not patentable and whether or not reduced to practice, and any such records relating to original works of authorship made by Board Member, alone or jointly with others, in the course of Board Member's engagement with the Company shall remain the property of the Company. Board Member shall furnish the Company any and all such records immediately upon request.

4

6.4 Ventures. If Board Member, during engagement with the Company, is engaged in or associated with the planning or implementation of any project, program, or venture involving the Company and any third parties, all rights in the project, program, or venture shall belong to the Company, and Board Member shall not be entitled to any interest therein or to any commission, finder's fee, or other compensation in connection therewith other than the compensation to be paid to Board Member as provided in this Agreement.

6.5 Return of Company's Property and Materials. Upon termination of Board Member's services with the Company, Board Member shall deliver to the Company all Company property and materials that are in Board Member's possession or control, including all of the information described as confidential information in Section 5.1 of this Agreement and including all other information relating to any inventions, discoveries, improvements, trade secrets, formulae, processes, know-how, or original works of authorship of the Company.

    UNITED STATES

    UNITED STATES

7.1 By the Company. The Company agrees to indemnify and hold harmless the Board Member with respect to any liability (and actions in respect thereof) incurred by the Board Member by virtue of the performance of the Services hereunder and shall reimburse the Board Member for any legal or other expenses reasonably incurred in connection with investigating or defending any such liability or action, provided that the Company shall have the right to control the defense of any claim giving rise to such liability and no such claim shall be settled without the consent of the Company. The foregoing provisions shall survive termination of this Agreement and any investigation with respect thereto by any party hereto and shall not apply to any such losses, claims, related expenses, damages or liabilities arising out of or in connection with the Board Member' s willful misconduct, fraud, negligence or material breach of this Agreement.

7.2 By the Board Member. The Board Member agrees to indemnify and hold harmless the Company (including each of its directors, officers, employees, partners and agents) with respect to any liability (and actions in respect thereof) incurred by Company by virtue of reckless, negligent or intentional misconduct of the Board Member and shall reimburse the Company for any legal or other expenses reasonably incurred in connection with investigating or defending any such liability or action. The foregoing provisions shall survive termination of this Agreement and any investigation with respect thereto by any party hereto.

    UNITED STATES

    UNITED STATES

Except for disputes, controversies, or claims or other actions seeking injunctive or equitable relief, which may be brought before any court having jurisdiction, any controversy, dispute, or claim ("Claim") whatsoever between Board Member on the one hand, and the Company, or any of its affiliated entities or any of its employees, officers, directors, agents, and representatives of the Company or its affiliated entities on the other hand, shall be settled by binding arbitration, at the request of either party, under the rules of the American Arbitration Association. The arbitrator shall be a retired federal or state judge with at least ten-year experience as a judge. The arbitrator shall apply California law. The demand for arbitration must be in writing and made within the applicable statute of limitations period. The arbitration shall take place in Los Angeles, California. The parties shall be entitled to conduct reasonable discovery, including conducting depositions and requesting documents. The arbitrator shall have the authority to resolve discovery disputes, including but not limited to determining what constitutes reasonable discovery. The arbitrator shall prepare in writing and timely provide to the parties a decision and award which includes factual findings and the reasons upon which the decision is based.

5

The decision of the arbitrator shall be binding and conclusive on the parties, except as may otherwise be required by law. Judgment upon the award rendered by the arbitrator may be entered in any court having proper jurisdiction. Each party shall bear its or his own fees and costs incurred in connection with the arbitration, except that the arbitrator may award attorneys' fees and costs in accordance with applicable law.

Both the Company and Board Member understand and agree that by using arbitration to resolve any Claims between Board Member and the Company (or its affiliates) they are giving up any right that they may have to a judge or jury trial with regard to those Claims.

    UNITED STATES

    UNITED STATES

9.1 Entire Agreement. This agreement between Board Member and the Company constitutes the entire agreement between the parties with respect to the matters referenced herein.

9.2 Amendments. The agreement can be modified only by a written instrument executed by Board Member and Company or its successor on behalf of the Company.

9.3 Disqualification. Board Member represents and warrants to the company that Board Member does not have any "bad actor" disqualification set forth in Rule 506 (d) of Regulation D under the Securities Act of 1933. Board Member acknowledges that Board Member's representation set forth in this Section 9.3 was a condition precedent to the Company entering into this Agreement.

9.4 Severable Provisions. The provisions of this Agreement are separate and distinct, and if any provisions are determined to be unenforceable in whole or in part, the remaining provisions, and the enforceable parts of any partially unenforceable provisions, shall nevertheless be enforceable.

9.5 Surviving Terms. The provisions of Articles 5, 6, 7, 8, and Section 9.8 shall survive the Term of this Agreement and the termination of Board Member's services.

9.6 Successors and Assigns. The Company may assign its rights and delegate its duties under this Agreement. Board Member may assign his rights under this Agreement only with the Company's prior written consent. Board Member may not delegate his duties.

9.7 Resignation from Positions with the Company. The termination of the Board Member's services for the Company for any reason shall, without any further action on the part of the Board Member, constitute the Board Member's resignation from any board, or officer position the Board Member has with the Company and any of its affiliates, which resignation shall be effective as of the Board Member's last day of providing services.

6

9.8 Cooperation. From and after the termination of Board Member's services for the Company, the Board Member agrees, upon the Company's request, to reasonably cooperate in any investigation, litigation, arbitration or regulatory proceeding regarding events that occurred during the time that Board Member is retained by the Company or its affiliates. The Board Member will make himself reasonably available to consult with Company's counsel, to provide information and to appear to give testimony. The Company will, to the extent permitted by law, reimburse the Board Member for any reasonable out-of-pocket expenses that the Board Member incurs in extending such cooperation, so long as the Board Member provides the Company with advance written notice of the Board Member's request for reimbursement and provides satisfactory documentation of the expenses.

9.9 Governing Law. Regardless of the choice of law provisions of Delaware or of any other jurisdiction, Delaware law shall in all respects govern the validity, construction, and interpretation of this Agreement.

9.10 Headings. Section and subsection headings do not constitute part of this Agreement. They are included solely for convenience and reference, and they in no way define, limit, or describe the scope of this Agreement or the intent of any of its provisions.

9.11 Integration. This Agreement together with any exhibits or schedules attached hereto, including any documents expressly incorporated into it by the terms of this Agreement, constitutes the entire agreement between the parties and supersedes all prior oral and written agreements, understandings, negotiations, and discussions relating to the subject matter of this Agreement. With this Agreement the parties rescind any previous agreements or arrangements between themselves. Any supplement, modification, waiver, or termination of this Agreement is valid only if it is set forth in writing and signed by both parties. The waiver of any provision of this Agreement shall not constitute a waiver of any other provisions and, unless otherwise stated, shall not constitute a continuing waiver.

9.12 Notice. Any notice or other communication required or permitted under this Agreement shall be in writing to the address set forth on Exhibit A and shall be deemed to have been given (i) if personally delivered, when so delivered, (ii) if mailed, one week after having been placed in the United States mail, registered or certified, postage prepaid, addressed to the party to whom it is directed at the address listed below or (iii) by national overnight delivery service upon receipt In order for a party to change its address or other information for the purpose of this section, the party must first provide notice of that change in the manner required by this section.

9.13 Advice of Counsel. The Parties each agree and represent that they (i) have had advice of counsel of their choosing or had the opportunity of obtaining advice of counsel, in the negotiation and the preparation of this Agreement, (ii) have read this Agreement, and (iii) are fully aware of the contents and legal effect of this Agreement.

9.14 Counterparts. This Agreement may be executed in two or more counterparts, each of which shall be deemed an original, but all of which together shall constitute one and the same instrument.

    UNITED STATES

7

IN WITNESS WHEREOF, the parties have caused this Board Member Agreement to be duly executed by their respective authorized representatives as of the Effective Date.

"COMPANY" "BOARD MEMBER" Nexscient, Inc. Eric Manlunas a Delaware corporation

    UNITED STATES

8

    UNITED STATES

    UNITED STATES

A. Services. Board Member shall perform such duties and exercise such powers as are usually performed by a Board Member of the Company in addition to the following:

    UNITED STATES

B. Consulting Payment. The Board of the Company has determined that in the best interest of its shareholders it will issue 225,000 restricted shares of its restricted common stock to the Board Member for his continued aforementioned Services to the Company. The restricted common stock issuances are considered appropriate additional annual compensation for active board duties. All share grants will be subject to Rule 144 and will have a six-month holding period. If the director voluntarily leaves the Board during this 6-month holding period then the share grants will be rescinded. Relevant value of these unregistered shares shall be deemed for tax and accounting purposes to be $0.08 per share, due to the illiquid nature of the common shares and the financial condition of the Company. It is understood that the Company will issue a Form 1099 for the tax year ending 2023 for the relevant value of each share allocation of $0.08 per share of common stock once the 6-month holding period has lapsed.

C. Addresses. For purposes of notice under this Agreement the addresses of the Company and Board Member are as follows:

    UNITED STATES

    UNITED STATES

9

    UNITED STATES

    UNITED STATES

This CONSULTING AGREEMENT ("Agreement") is made and entered into as of June 1, 2023 by and between Nexscient, Inc., a Delaware corporation (the "Company") and MJP Consulting, LLC, a Connecticut limited liability company (the "Consultant").

WHEREAS, the Company is seeking to build a business and wishes to engage Consultant as a consultant for the Company to assist it in the financial matters of the business;

WHEREAS, Consultant desires to act a consultant to the Company;

WHEREAS, it is a condition precedent to the Company's engagement of Consultant, that he first enter into this Agreement with the Company;

WHEREAS, Consultant desires to enter into this Agreement and satisfy such condition;

NOW, THEREFORE, for other good and valuable consideration the sufficiency of which is hereby acknowledged, the parties hereto hereby agree as follows:

1.Consulting Terms. Consultant is hereby retained to provide business, consulting and advisory services and market research as reasonably requested by the Company in the various financial and operational issues regarding the Company (the "Services"). The Company and Consultant expect to have regular telephonic conversations and personal meetings on an as-needed basis in connection with Consultant's providing of the Services, and Company will provide Consultant with updates on latest corporate events and developments. Consultant may engage in other business activities during and after the Term. Consultant will not be an employee of the Company, but instead an independent contractor of the Company. The term of this Agreement, and the consulting arrangement described herein, shall be two (2) months commencing as of the date hereof (the "Term").

Consultant fee will be a total of $18,000, paid in two installments (the "Compensation"). The first installment in the amount of $9,000 shall be paid at the time of signing this Agreement; and the second installment of $9,000 shall be paid on or about July 1, 2023 but in no event later than July 15, 2023.

The Company shall reimburse Consultant, for his reasonable out-of-pocket expenses incurred in connection with providing the Services contemplated herein (but for any air-travel requested by the Company, the Company will book and pay for coach or business-class airfare tickets for Consultant); provided, however, that as a condition to any such reimbursement Consultant will obtain the Company's prior written approval for (1) any expense individually in excess of $100 or (2) all expenses in excess of an aggregate of $500 incurred since the date of this Agreement.

The Company may terminate this Agreement at any time upon written notice for "Cause" or due to a "Disability." "Cause" shall mean: (i) a material act of dishonesty by Consultant which has an adverse effect on the Company; (ii) the Consultant's conviction of, or plea of nolo contender to, a felony or a crime involving moral turpitude; (iii) the Consultant's gross misconduct (which could have a material adverse effect on the Company); or (iv) Consultant's failure to provide the consulting services required hereunder, which failure is not cured within the 30 days following notice thereof by the Company. Consultant will be deemed to be suffering from a "disability" upon the earlier of (i) the end of a three (3) consecutive month period during which, by reason of physical or mental injury or disease, Consultant has been unable to perform substantially all of Consultant's usual and customary duties under this Agreement or (ii) the date that a reputable physician selected jointly by the Company and Consultant (or if Consultant is clearly unqualified to make such selection, the person then authorized to make health care decisions for Consultant) determines in writing that Consultant will, by reason of physical or mental injury or disease, be unable to perform substantially all of Consultant's usual and customary duties under this Agreement for a period of at least three (3) consecutive months. (If any question arises as to whether Consultant is disabled, upon reasonable request therefor by the Company, Consultant shall submit to a medical examination for the purpose of determining the existence, nature and extent of any such "disability.")

2. Confidential Information. Consultant acknowledges that because of the consulting engagement by the Company, will be in a confidential relationship with the Company and will have access to confidential information and secrets of the Company and those interacting or doing business with the Company.

3. Indemnification. The Company shall indemnify, defend and hold harmless Consultant from and against all claims, damages, losses and expenses (including reasonable attorneys' fees, costs, expenses and disbursements), arising out of the performance by the Consultant of its duties pursuant to this Agreement.

4. Counterparts. This Agreement may be executed in two or more counterparts, each of which shall be deemed an original, but all of which together shall constitute one and the same instrument.

5. Headings. The headings herein are for convenience only, do not constitute a part of this Agreement, and shall not be deemed to limit or affect any of the provisions hereof.

6. Entire Understanding. This Agreement and the Exhibits hereto constitutes the entire agreement and understanding between the parties with respect to the engagement of Consultant by the Company, and supersedes all prior or other agreements, representations and understandings, both written and oral, between the parties hereto with respect to the subject matter hereof.

7. Amendments. This Agreement may not be modified or changed except by written instrument signed by all of the parties hereto. No provision of this Agreement shall be modified or construed by any practice that is inconsistent with such provision, and failure by either party to require the other party to comply with any provision shall not affect a party's rights to thereafter require the other party to comply.

2

8. Attorneys' Fees. If any action is brought to enforce or interpret any part of this Agreement or any other agreement or instrument provided for herein or the rights or obligations of any party to this Agreement or such other agreement or instrument, the prevailing party in such action shall be entitled to recover as an element of such party's costs of suit, and not as damages, its attorney's fee in such action. The prevailing party shall be the party who is entitled to recover its costs of suit as ordered by the court or by applicable law or court rules. A party not entitled to recover its costs shall not recover attorney's fees.

9. Governing Law. This Agreement shall be construed (both as to validity and performance) and enforced in accordance with and governed by the laws of the State of Delaware applicable to agreements made and to be performed wholly within such jurisdiction, notwithstanding any choice of law principles, statutes or rules to the contrary. Any rule of law or any legal decision that would require interpretation of any ambiguities in this Agreement against the party that drafted it, is of no application and is hereby expressly waived. The provisions of this Agreement shall be interpreted in a reasonable manner to effect the intentions of the parties and this Agreement. The parties agree that all actions or proceedings arising in connection with this Agreement shall be litigated only in the state and federal courts located in Los Angeles County, State of California.

10. Construction. Whenever in this Agreement the context so requires, references to the masculine shall be deemed to include feminine and the neuter, references to the neuter shall be deemed to include the masculine and feminine, and references to the plural shall be deemed to include the singular and the singular to include the plural.

11. Cooperation. Each party hereto shall reasonably cooperate with the other party and shall take such further reasonably action and shall execute and deliver such further documents as may be reasonably necessary or desirable in order to carry out the provisions and purposes of this Agreement.

12. Waiver. No amendment or waiver of any provision of this Agreement shall in any event be effective, unless the same shall be in writing and signed by the parties hereto, and then such waiver or consent shall be effective only in the specific instance and for the specific purpose for which given. The failure to insist in any one or more instances, upon performance of any of the terms, covenants or conditions of this Agreement shall not be construed as a waiver or relinquishment of any rights granted hereunder or any such term, covenant or condition.

13. Parties in Interest; Assignment. This Agreement shall inure to the benefit of the Company and its successors and assigns, and shall be binding upon Consultant. This Agreement may not be assigned by Consultant; and, this Agreement may be assigned by the Company with Consultant's consent (which will not be unreasonably withheld).

14. Severability. If any provision of this Agreement shall be deemed invalid, unenforceable or illegal, then notwithstanding such invalidity, unenforceability or illegality the remainder of this Agreement shall continue in full force and effect.

15. Full Understanding. Consultant represents and agrees that he fully understands his right to discuss all aspects of this Agreement with his private attorney, and that to the extent, if any, that he desired, he availed himself of this right. Consultant further represents that he has carefully read and fully understands all of the provisions and effects of the Agreement, that he is competent to execute this Agreement, that his agreement to execute this Agreement has not been obtained by any duress and that he freely and voluntarily enters into it, and that he has read this document in its entirety and fully understands the meaning, intent and consequences of this document.

3

IN WITNESS WHEREOF, the parties hereto have executed this Agreement as of the date first written above.

NEXSCIENT, INC.

    UNITED STATES

MJP CONSULTING, LLC

    UNITED STATES

4

    UNITED STATES

    UNITED STATES

AGREEMENT is made as of October 2nd, 2023 between Corsac Technologies Corporation with an address at 16 Yellow Birchway, North York, ON, Canada, M2H 2T3 ("Developer"), and Nexscient, Inc. with an address at 2029 Century Park East, Suite 400, Los Angeles, CA 90067 ("Customer").

WHEREAS, the Developer provides software development, programming, graphic design and other services (together, the "Services"); and

WHEREAS, Customer wishes to get software development and related services, and wants to hire Developer to develop these custom software packages; and

WHEREAS, Developer wishes to provide the Services to Customer, all pursuant to the terms and conditions set forth herein

NOW THEREFORE, in consideration of the mutual covenants herein contained and other good and valuable consideration, receipt and sufficiency of which is hereby acknowledged, the parties agree as follows:

1. Recitals. Appendices and Definition. The recitals set forth above together with appendices to this Agreement, form an integral part of this Agreement. The following capitalized terms when used in this Agreement shall have the respective meanings indicated below:

"Complete" or "Completion," with respect to development of the Software, shall mean that Developer has certified and Customer has confirmed that development and testing of the Software have been completed and that the Software and Documentation are ready for commercial use in material conformity with the Specifications.

"Deliverables" means the items to be delivered to a Customer in connection with the Project.

"Documentation" means all user manuals, installation manuals, and other written materials that relate to the Software.

"Development Schedule" shall mean the schedule for completion of the Services and delivery to Customer of the Deliverables.

"Error" means any failure of the Software to conform in any material respect to its Specifications.

"Object Code" means computer code in machine-readable form generated by compilation of Source Code and contained in a medium that permits it to be loaded into and operated on computers or other devices.

"Project" or "Projects" means the programming and creation of the Software in accordance with the Specifications and Development Schedule, as in effect from time to time.

"Software" means the object code of the software to be developed pursuant to this.

"Source Code" means the source code for the Software, in printed, machine readable, and any other form and including all existing comments, and all test suites and technical and other documentation reasonably necessary for a reasonably skilled programmer to understand and use the source code.

"Specifications" shall mean the business, technical and other specifications for the Software and Deliverables for a given Project.

2. Engagement of Developer. Developer hereby agrees to perform all of the programming and other work necessary for provision of the Services to Customer promptly and a high level of quality following and in accordance with the Specifications and Development Schedule for each Project for the Customer.

(a) The Parties acknowledge that Developer commences performance of the Services after the date hereof and that this Agreement shall govern all Services performed by Developer in respect of a Project for the Customer.

(b) Developer shall dedicate a separate software engineer to do the development for the Project on the full-time (40h/week) basis and the Customer is responsible to provide the respective amount of work to fully load 40 hours/week with Project tasks for the software engineer. If the Project specification requires so, Developer will provide more than one software engineer or other professional or role necessary to continue the development of the project.

(c) Project Coordination. Developer shall communicate directly with Customer with respect to (i) the schedules and progress of work pursuant to this Agreement; (ii) receiving and submitting requests for information and/or assistance; (iii) receiving and submitting materials; (iv) cooperating to implement and review the development, design and production efforts; and (v) supervising the exchange of confidential information pursuant to this Agreement.

(d) The services required by this Agreement shall be performed by Developer, or Developer's Staff, or Developer's contractors.

Developer has the sole right to control and direct the means, manner and method by which the services required by this Agreement will be performed.

(e) Development of Specifications. Customer shall have primary responsibility for the definition of the Software and the development of the functional objectives to be included in the Specifications for each of their Projects. Developer shall have primary responsibility for the development of the technical means for accomplishing such functional objectives, also to be included in the Specifications. The parties shall use their best commercial efforts to prepare their respective portions of the Specifications as promptly as possible. Once the Developer has completed the Specifications it shall submit them to the Customer for final review and acceptance. Specifications will be final when approved by Customer. In the event Developer believes that any change in Specification will have more than a de minimis affect the work being performed by Developer hereunder, Developer shall promptly notify Customer of such affect, including any impact on the Development Schedule and the costs to be incurred by the parties hereunder.

2

(d) Milestones. Major Projects may be subject to Milestones to be agreed upon upfront between the parties. Apart from Milestone, the Services may be provided on a monthly basis and each month shall constitute a separate Milestone for payment and reporting purposes.

(e) Delays. Developer shall regularly inform Customer of factors that are likely to lead to delays such as labor shortages, technical difficulties, and other factors but Developer shall seek to minimize such delays. Any delay or nonperformance of any provision of this Agreement caused by conditions beyond the reasonable control of the performing party shall not constitute a breach of this Agreement, provided that the delayed party has taken reasonable measures to notify the other of the delay in writing. The delayed party's time for performance shall be deemed to be extended for a period equal to the duration of the conditions beyond its control.

If the Developer needs to take a definite period of time off (sick days, holidays, force majeure etc.), the Developer will take its best efforts to warn the customer in advance and this time period will not be a part of the reporting period for the purposes of payment.

(f) Delivery. The Project Coordinators for each party shall agree upon the reasonable logistics and procedures for making delivery of the Deliverables and for performing acceptance testing. Upon completion of the Software, Developer shall notify the Development Coordinator for the Customer and shall deliver the agreed upon Deliverables to the Customer for acceptance testing in accordance with such agreed upon procedures.

(g) Acceptance Testing Procedures. If specifically requested by Customer, Developer shall establish mutually agreeable reasonable acceptance testing procedures to be generally in conformity with general industry practices to be performed after delivery of the Deliverables to determine if they meet the Specifications. In the event the Deliverables are rejected, Developer shall use reasonable diligence to correct any deficiencies cited in good faith by the Customer and to resolve any Customer concerns over the Deliverables.

(h) Basic Training. Developer will provide a reasonable amount of training to Customer in the use and support of the Software for each applicable Project. Customer may from time to time request Developer to provide additional training regarding the use and support of the Software. Developer shall use its reasonable commercial efforts to accommodate such requests.

U) Non-solicitation of Developer's Employees. Customer agrees not to knowingly hire or solicit Developer's employees during performance of this Agreement and for a period of 1 year after termination of this Agreement without Developer's written consent.

3

3. Development Fees. Developer shall provide to Customer an itemized, detailed accounting of time actually spent on Projects on a monthly basis (Time Report), or on other time period if specifically requested by Customer. Customer shall pay to Developer fees for Services rendered (the "Development Fees") in amount based on the amount of hours logged by developer in the respective Time Report sent on the Customer's email account.

The hourly rate for the development services is 40 USO/hour. The hourly rate for the graphic design services is 25 USO/hour.

The hourly rate for the quality assurance services is 25 USO/hour The hourly rate for project management services is 35 USO/hour.

The hourly rates can be reviewed every 6 months and changed upon the Customer's and Developer's mutual agreement on this matter.

The payment for Developer's services must be performed by the Customer on the monthly basis with regards to the Time Report.

Customer takes responsibility to review the monthly Time report provided Developer and pay the invoice for the respective time period during 5 business days period after the invoice was submitted.

The payment for every invoice must be submitted via a direct wire transfer on the Developer's bank account provided in the invoice.

4. Intellectual Property Ownership. The Parties agree that the Customer shall be the sole owner of all right title and interest in and to the Software including all Source Code and Object Code associated with the Software and Documentation and all results of the Development Services to be rendered pursuant to this Agreement, all whether in writing or not in writing (collectively the "Technology") provided that ownership in that Technology shall vest in the Customer. This ownership is conditioned upon full payment of the compensation due to the Developer under this Agreement for a respective time period.

The source code will be delivered to the Customer after the Developer receives payment for this Milestone or reporting period invoice (e.g. monthly payment).

5. Term and Termination. The term of this Agreement shall commence as of the date first set forth above and continue in effect until terminated in accordance with the terms hereof. Either party may terminate this Agreement without cause upon not less than 30 days prior written notice.

6. Headings. The section headings used in this Agreement are intended for reference purposes only and shall not affect the interpretation of this Agreement.

7. Counterparts. This Agreement may be executed in two (2) or more counterparts, each of which shall be considered an original but all of which together will constitute one and the same agreement. The execution and telecopy transmission of a facsimile shall be effective as execution and delivery of a counterpart.

4

8. No Assignment. The parties may not assign all or a portion of their rights and obligations hereunder without the prior written consent of the other party which shall not be unreasonably withheld or delayed.

9. Independent Contractor Status. Developer's relationship with Customer is that of an independent contractor and nothing in this Agreement shall be construed as creating any relationship of partnership, agency, joint venture, principal and agent or employer-employee. Neither party may make any representation, contract or commitment on behalf of the other party without the prior written consent of the other Party.

10. Limitation of Developer's Liability to Customer

a. In no event shall Developer be liable to Customer for lost profits of Customer, or special or consequential damages, even if Developer has been advised of the possibility of such damages.

b. Developer shall not be liable for any claim or demand made against Customer by any third party.

c. Customer shall indemnify Developer against all claims, liabilities and costs, including reasonable attorney fees, of defending any third party claim or suit arising out of the use of the Software provided under this Agreement.

IN WITNESS WHEREOF, the parties hereto have duly entered and executed this Agreement as of the day and year first above written and represent and warrant that the party executing this Agreement on their behalf is duly authorized.

Nexscient, Inc Corsac Technologies Corporation Fred E. Tannous Igor Omelianchuk CEO of Nexscient, Inc. CEO at Corsac Technologies Corporation

5

    UNITED STATES

    UNITED STATES

Goal:

- Deliver a comprehensive sensor-based monitoring system that utilizes a variety of sensors mounted on machinery. This system aims to proactively detect irregularities, anomalies, or potential issues with the machinery's performance. It will provide real-time notifications to engineers, enabling them to take prompt and informed action to prevent downtime, minimize disruptions, and ensure optimal operational efficiency of the machinery.

Team composition:

1 UI/UX designer - provides team with user flows and page designs

1 senior backend.Net developer/ Architect - supervises system architecture and backend development, develops features, participates in requirements elaborations to ensure compatibility of features.

1 middle backend.Net developer - develops features, participates in requirements elaborations

1 middle frontend Angular developer - develops UI and logic for the WEB page of the application

1 middle DevOps engineer - engages in infrastructure set up, security protocols, storing sensitive development data such as accounts, accesses etc

- 2 Quality Assurance engineers - perform manual UI testing, automated testing of backend, develop test cases and test plan

1 Project Manager - conducts meetings and ceremonies, elaborates requirements, supervises development processes, communicates with customer

Requirements (High level):

- User Registration and Authentication:

- Users must be able to create accounts using a valid email address and password.

- Users should receive a confirmation email upon registration.

- Registered users must be able to log in using their credentials.

- Connect to Sensors and Collect Data:

- The system should be able to establish connections with Nexscient sensors.

- Sensors should transmit data to the system in real-time or at specified intervals.

- The system must provide authentication mechanisms to ensure only authorized sensors can send data.

- Data collected from sensors should include Acoustic, vibrations, temperature (based on sensor specification and project requirements), and it should be time stamped upon receipt.

6

- Process Collected Data:

- Incoming sensor data should be normalized and validated for accuracy and consistency. In future updates data will be used for machine learning so accuracy and consistency is of a high priority.

- The system should apply predefined algorithms or rules to process raw sensor data into meaningful metrics.

- Processed data should be stored in a database for further analysis and reporting.

- Create Reports Based on Collected and Processed Data:

- Users should be able to generate custom reports based on selected time periods and sensor types.

- Reports should include visualizations such as graphs, charts, and tables to represent data trends.

- Users should have the option to export reports in formats such as PDF or CSV or HTML.

- Display Live Data:

- The system should provide a real-time dashboard that displays live sensor data and updates at regular intervals.

- Users should be able to customize the dashboard layout and select the sensors to be displayed.

- The dashboard should support interactive elements like real-time charts and gauges.

- Manage Users:

- Administrators should have the ability to create, modify, and delete user accounts.

- Users should be categorized into roles (e.g., super admin, company admin, engineer, etc.) with varying levels of access.

- User authentication and authorization should be implemented to ensure data security and privacy.

- Manage Subscriptions:

- Users should be able to buy subscription for different tiers and complete payment for chosen subscription

- Users should be able to subscribe to receive notifications based on specific sensor events or data thresholds.

- Subscriptions can include email alerts, SMS notifications, or in-app messages.

- Users should have the ability to modify or cancel their subscriptions.

7

- Notifications (this will be a big part of the system to achieve the best results with machinery maintenance that is why we paid a bit more attention to them):

- Notifications can be triggered by events such as sensor thresholds being crossed, system updates, or subscription-based triggers.

- Users should be able to define their notification preferences, such as choosing the communication channels (email, SMS, etc) and frequency.

- Users should have the option to set custom triggers for notifications, like receiving an alert when a temperature sensor records a value above a certain threshold.

- Notifications should provide concise and relevant information, including the sensor name, event description, and timestamp.

- For critical events, real-time notifications should be sent immediately.

- Non-critical notifications can be batched and sent at regular intervals to prevent overwhelming users.

- Users should have access to a notification history log, detailing past notifications with their statuses and timestamps.

- The system should support pre-defined notification templates for common events to ensure consistent messaging.

- A testing mode should be available to simulate notifications and ensure the notification system is functioning properly.

Infrastructure and set up:

Configure angular project

Configure.NET project

initial set up Cl/CD pipelines

set up test, stage, prod instances

design and implement Virtual Network For architecture solution

configuring the database instance

creating and initially configuring Virtual Machine for running application

Testing connectivity and tuning firewall settings

preparing repositories for source code

develop building script for frontend

develop delivery to server script for frontend

develop building script for backend

develop delivery to server script for backend

Cl/CD workflow and optimisation

Create and configure domain models with relations design system

8

Budget and time estimate:

[REDACTED FOR CONFIDENTIAL REASONS]

Payment for all Azure and other related hardware and third party services for project setup, servers and server functions will be provided by the Customer and is not part of the payment for the development services (not part of the Quote to deliver the Project according to this Specification). Developer will take reasonable actions to propose the appropriate services to the Customer and help to do all the setup of the services.

Note:

Here we suggest making the custom reports only a downloadable option for the first version of the system, as custom reports directly on interface can be challenging and take time to configure them. To reduce time to market we suggest moving custom reports, embedded in the system's interface, to next versions. This estimation is not final and may be adjusted during the development as requirements may change to fit the user demand

Development process

- We follow Agile principles and methodologies of development. Scrum is our framework of choice as it provides a good level of flexibility and control to achieve the best results. Scrum gives us a clear understanding of requirements and tasks, structures the workflow, and focuses on delivery of the best possible product in the least amount of time needed.

- Development overview:

- receive the requirements

- discuss and clarify the requirements to make sure all team members understand them on the same level

- divide requirements into deliverable increments based on priorities and architecture design

- compose backlog

- plan increment's development

- develop features to complete increment

- increment undergoes quality control

- increment is presented to customer

- increment is deployed to instance

- next increment is planned

- Based on the Milestone results and feedback the project scope and budget may change corresponding to further project needs.

9

Project transition

- Once all increments are delivered and tested, development and customer are satisfied with the result we initiate the transition of the project to customer if needed. This means that all the source code, all accounts and accesses are transferred to the customer and eliminated on the development side so that customer is the only owner of the source code and all the accesses.

- Transition

- make archive of the source code and transfer in secure manner to customer or upload it to Customer's coed repository

- transfer all the accounts and accesses to customer

- customer changes all passwords for all provided accounts and accesses

- Development provides customer with guidelines and instructions on how to build the project from received project components

- Development eliminates all the development and testing accounts and data, if possible and necessary, from live database in order to keep the system clean after transition

Nexscient, Inc Corsac Technologies Corporation Fred Tannous Igor Omelianchuk CEO of Nexscient, Inc. CEO at Corsac Technologies Corporation

10

    UNITED STATES

    UNITED STATES

We consent to the use, in this Registration Statement on Form S-1, as amended, of our report dated September 15, 2023, related to the financial statements of Nexscient, Inc. as of June 30, 2023, and for the period then ended, which includes an explanatory paragraph regarding the substantial doubt about the Company's ability to continue as a going concern. We also consent to the reference to us under the heading "Experts" in such Registration Statement.

/s/ dbbmckennon

Newport Beach, California

October 19, 2023

COMTEX_442155184/2255/2023-10-19T23:19:11

(c) 1995-2023 Cybernet Data Systems, Inc. All Rights Reserved

Blogs - Sports and leisure / Sports et loisirs (blog ref.) - Media Man News
November 27, 2023 86388 mots
Media Man News Blog: News Articles, Sports, Business and Pop Culture

Media Man News Media Man Int Blog updated Combat Sports Boxing, MMA and Wrestling ... Voir l'article

Ce document référence un lien URL de site non hébergé par Cision.

Blogs - Sports and leisure / Sports et loisirs (blog ref.) - Media Man Int
November 27, 2023 86396 mots
Media Man Int Blog: News Articles, Sports, Pop Culture and Business

Media Man Int Blog News Articles, Sports, Pop Culture and Business Media Man Int Blog updated Combat Sports ... Voir l'article

Ce document référence un lien URL de site non hébergé par Cision.

Blogs - Sports and leisure / Sports et loisirs (blog ref.) - Australian Sports Entertainment
November 28, 2023 86380 mots
Australian Sports Entertainment: News Articles

Australian Sports Entertainment Blog Blog updated Combat Sports Boxing, MMA and Wrestling ... Voir l'article

Ce document référence un lien URL de site non hébergé par Cision.

Muscat Daily
Monday, October 9, 2023 1472 mots

Readers' reflections - Muscat's morning muse

I love Muscat Daily newspapers for the role it plays in keeping me informed about the world, from local events to global news. The paper serves as a valuable source of information, offering diverse perspectives and in-depth reporting. Muscat Daily newspaper also contributes to a sense of community, connecting us over shared stories and concerns. In the age of digital media, the tactile experience of turning pages remains a nostalgic pleasure. Muscat Daily newspaper holds a special place in our hearts, reminding us of the power of print journalism.

Anupma Nagvanshi

Every morning before the sun rises, a bundle is eagerly waiting to be picked up at our doorsteps. The morning ritual begins with a cup of coffee in one hand and the crisp Muscat Daily in the other, where we scan through all the events that unfolded locally and internationally. The morning paper, with its succinct briefings, enriches and expands our knowledge about current affairs before we embark on the rest of the journey for the day. This lovely bond between a newspaper and its readers has not yet been replaced by the digital world, and hopefully it never will.

Janaki Venkatesh

My morning begins with a piping hot cup of masala tea and the Muscat Daily newspaper. In a world where many rely on social media for daily news updates, Muscat Daily has managed to stay relevant by providing much needed clarity and understanding of global and national news in a manner that is easy to read. An added bonus would be to add a section on the diverse and beautiful fauna and flora of Oman. A section that highlights an animal, plant, place or thing distinct to the sultanate would educate readers while also providing them an incentive to explore Oman.

Julie G

Winner of Muscat Daily 14th anniversary photo competition - sent by Venkatesh

SOME OTHER COMPETITION ENTRIES

I'm an avid reader of Muscat Daily and wanted to suggest ways as below to enhance reader engagement.

Encourage readers to submit articles or personal stories.

Include more puzzles and quizzes to challenge readers' minds.

Conduct reader surveys to gather feedback and insights on various topics.

For social media platforms:

Implement algorithms to recommend articles based on readers' interests.

Start a newspaper podcast series.

Add QR codes for multimedia content.

Host live QandA sessions with experts.

Use AR to make stories come alive with interactive visuals.

I believe these ideas can make Muscat Daily even more interactive and appealing to a broader audience.

Nida Adil Abbas

Happy 14th Anniversary! I adore Muscat Daily for its insightful reporting that keeps me informed about local and global events. The 'Culture and Arts' section is my absolute favourite, enriching my understanding of Oman's cultural landscape.

To make it more engaging, consider a weekly reader spotlight, where readers share their unique experiences. This could foster a sense of community and inclusivity.

Once again, congratulations on this milestone, and here's to many more years of exceptional journalism!

Regina Stalin

Life in the morning starts with prayers and the first thing before breakfast is reading Muscat Daily, which brings real pleasure in life. This paper covers all news regarding politics, business, culture, sports, features, travel, etc in Oman as well as the entire world. We congratulate the entire management and staff of Muscat Daily for maintaining high standards. I haven't written this to win a prize but to state the facts.

Amanullah Khan

I have been an avid reader of Muscat Daily since 2009 and I am happy to note that it is now the largest selling broadsheet newspaper in Oman.

Muscat Daily has always maintained its standards in delivering the correct and updated news from time to time. The national and international news coverage of Muscat Daily is a sumptuous breakfast for me before I step out of the house to my workplace. What I like the most are the sports pages, which cover all sports activities in detail. I congratulate the editorial team and management for their exemplary service. Keep going!

Radhakrishnan Nambiar

Being in my 40s and a management degree holder, I feel like a school child when I read the 'Test Your Knowledge' section. I am very fascinated by this section and try to answer it before seeing the answers given down, which my sons make fun of.

Interesting sections include the sudoku and word builder, which engage older people in our homes.

I would like to suggest Muscat Daily to include gold rates and a 'Market Watch' section with currency rates which is useful for expats like me. Thank you.

Salammashaha

At the outset, my congratulations to Muscat Daily on completing a well deserved 14 years in Oman. A late entrant, creating a storm in everyone's cup of tea is how I would describe MD. I love its easy to read style, well interspersed with beautiful colour pictures. It provides the right mix of information on Oman news - government and private - and world news. I love the business/economy/trade section with its coverage of corporate, technology and IPO news. We also appreciate its coverage of regional/India news including movie reviews.

Muscat Daily - Yehi hai right choice of everyone!

Sunil

Muscat Daily provides a plethora of news from Oman as well as from around the world. No one is left behind as the paper contains leisure pages like kids colouring, sudoku and daily horoscope as well as regular news. I love reading the paper and especially enjoy the world news and news regarding sports. The paper is filled with images that make it engaging and fun. I also look forward to the weekly supplement which has recipes and reviews on new movies at the end of the week. Thank you Muscat Daily!

Neel Anoop

As an expat living in Muscat, I truly appreciate the Your Say section of Muscat Daily. It is enriching to hear thoughts and perspectives from locals and other people from different sections of society on matters of current relevance. In a lively and happening city like Muscat, I feel capable of connecting with my fellow residents through this section and it does a great service to its readers.

Dr Latha Prasanna

I am an avid reader of your content. Your esteemed newspaper is my main source for information regarding the country.

The content is always on track and up to date with the latest happenings. The sports section is the one I love the most!

The ads in the newspapers are also very helpful for small businesses to gain recognition.

To appeal more to the younger generation, I kindly suggest that you include articles regarding topics such as pop culture that will capture the eye of your younger audience to encourage them to read the news. Your hard work is appreciated.

Zahraa Khalil

Thank you for providing an opportunity to suggest improvements in Muscat Daily.

Your career section needs to provide more national and international job opportunities for different skills. At the macro level, it will help to add interest and capture more jobseekers' attention, both Omanis and expats. A column featuring career possibilities for 10th and 12th graders could show them what lies ahead. It will help them recognise their skills at an early age to shape their future.

Manish Maheshwari

Winner of Muscat Daily 14th anniversary photo competition - sent by Nisanth Kallinkeel

I see a newspaper as a window of information and believe in the importance of daily reading for brain exercise. Starting my day with the Muscat Daily newspaper is a great way to stay informed about local, national and international news. It's also impressive that the newspaper has been around for 14 years and played a role in promoting reading habit through competitions. Indeed, newspapers provide valuable insights into a country's social, political, economic and cultural status.

Malina Ghosh

Congratulations on turning 14! Muscat Daily has been my source of national and international news. It's the really good quality content that keeps me going from page to page. In particular, I like the Nation Plus section as it keeps me updated on local happenings. On a whole, Muscat Daily is my perfect news snack along with hot tea, every time I start my day. A welcome relief and calming workout for my eyes, away from smartphones. Keep up the good work and cheers to more decades of success and keeping readers updated with all that matters.

Vrinda

Muscat Daily is the leading English language newspaper in Oman. It covers a wide range of topics, including local news, business, sports and more. It helps stay updated on what's happening in Muscat. The best part I adore and love about @muscatdaily is that it promotes new talent, including photographers by using their photos on its social media platforms and giving them credit for it.

Blogs - Sports and leisure / Sports et loisirs (blog ref.) - Australian Sports Entertainment
November 27, 2023 86386 mots
Australian Sports Entertainment Blog: News Articles, Combat Sports, Pop Culture and Entertainment

Australian Sports Entertainment Blog Updated Combat Sports Boxing, MMA and Wrestling ... Voir l'article

Ce document référence un lien URL de site non hébergé par Cision.

Blogs - Sports and leisure / Sports et loisirs (blog ref.) - Media Man International
November 6, 2023 39338 mots
Media Man International Blog: News Media

Media Man International Blog News, Sports, Combat Sports, Pop Culture, Entertainment, Digtal News, SEO, Marketing and more November 2023 SEJ ... Voir l'article

Ce document référence un lien URL de site non hébergé par Cision.

Blogs - Sports and leisure / Sports et loisirs (blog ref.) - Media Man Int
November 6, 2023 39285 mots
Media Man Int Blog: FOX CEO Lachlan Murdoch offers details why WWE SmackDown broadcast rights were not renewed

Media Man Int Blog Lachlan Murdoch WWE SmackDown broadcast rights News, Sports, Combat Sports, Pop Culture, Entertainment, Digtal News, SEO, Marketing and more ... Voir l'article

Ce document référence un lien URL de site non hébergé par Cision.

Blogs - Sports and leisure / Sports et loisirs (blog ref.) - Media Man News
November 6, 2023 39349 mots
Media Man News Blog: News, Sports, Combat Sports, Pop Culture, Entertainment, Digital News, SEO, Marketing and more

Media Man News Blog News, Sports, Combat Sports, Pop Culture, Entertainment, Digtal News, SEO, Marketing and more November 2023 SEJ ... Voir l'article

Ce document référence un lien URL de site non hébergé par Cision.

Blogs - Sports and leisure / Sports et loisirs (blog ref.) - Greg Tingle official blog
November 6, 2023 39353 mots
Greg Tingle Official Blog: News, Sports, Combat Sports, Pop Culture, Entertainment, Digtal News, SEO, Marketing and more

Greg Tingle Official Blog Greg Tingle Official Blog: News, Sports, Combat Sports, Pop Culture, Entertainment, Digtal News, SEO, Marketing and more November 2023 SEJ ... Voir l'article

Ce document référence un lien URL de site non hébergé par Cision.

Blogs - Sports and leisure / Sports et loisirs (blog ref.) - Greg Tingle official blog
November 7, 2023 39347 mots
Greg Tingle Official Blog: News, Pop Culture and Sports

Greg Tingle Official Blog Image credit: Google Art and Culture News, Sports, Combat Sports, Pop Culture, Entertainment, Digtal News, SEO, Marketing and more November 2023 ... Voir l'article

Ce document référence un lien URL de site non hébergé par Cision.

Blogs - Finance (blog ref.) - Canadian Insider
November 10, 2023 17790 mots
METALLA REPORTS FINANCIAL RESULTS FOR THE THIRD QUARTER OF 2023 AND PROVIDES ASSET UPDATES

METALLA REPORTS FINANCIAL RESULTS FOR THE THIRD QUARTER OF 2023 AND PROVIDES ASSET UPDATES Canada NewsWire VANCOUVER, BC, Nov. 10, 2023 (All dollar amounts are in thousands of United States dollars... Voir l'article

Ce document référence un lien URL de site non hébergé par Cision.

FOX News (web site ref.) - Fox News
October 13, 2023 64463 mots
Israel tells Gaza citizens to evacuate to 'minimize civilian casualties' in war against Hamas

incoming update… Tens of Thousands of anti-Israel protesters took to the streets in the Middle East on Friday in answer to Hamas' call for a "Day of Rage." Large numbers... Voir l'article

Ce document référence un lien URL de site non hébergé par Cision.

Reports - Transport - Eurail

Publication date: November 27, 2023 45317 mots

Single Programming Document 2024 - SPD 2024-2026.pdf

136 pages

Please note : This extract may not display a well formed paragraph

... | I Single Programming Document 2024-2026 Manuscript completed in November 2023 Neither the Agency nor any person acting on behalf of the Agency is responsible for the use which might be...

Full report:
https://www.era.europa.eu/system/files/2023-11/SPD%202024-2026.pdf
Blogs - Computer and Electronics / Ordinateurs et électroniques (blog ref.) - Human first-Medium
October 3, 2023 6878 mots
Top 10 Social Media Platforms: Maximize Your Digital Success!

Top 10 Social Media Platforms: Maximize Your Digital Success! In today’s digital age, social media platforms have become an integral part of our lives, transforming the way we connect, communicate... Voir l'article

Ce document référence un lien URL de site non hébergé par Cision.

Blogs - Sports and leisure / Sports et loisirs (blog ref.) - Australian Sports Entertainment
November 6, 2023 39340 mots
Australian Sports Entertainment Blog: News, Sports, Combat Sports

Australian Sports Entertainment Blog News, Sports, Combat Sports, Pop Culture, Entertainment, Digtal News, SEO, Marketing and more November 2023 SEJ ... Voir l'article

Ce document référence un lien URL de site non hébergé par Cision.

Blogs - Sports and leisure / Sports et loisirs (blog ref.) - Media Man Int
November 6, 2023 39349 mots
Media Man Int Blog: News, Sports, Combat Sports, Pop Culture, Entertainment, Digital News, SEO, Marketing and more

Media Man Int Blog News, Sports, Combat Sports, Pop Culture, Entertainment, Digtal News, SEO, Marketing and more November 2023 SEJ ... Voir l'article

Ce document référence un lien URL de site non hébergé par Cision.

Reports - Labor and Unions - ILO

Publication date: December 26, 2022 79203 mots

The ILO, a key partner in Post Disaster Needs Assessments (PDNAs) - [pdf 10488KB] - wcms_863195.pdf

196 pages

Please note : This extract may not display a well formed paragraph

... PAKISTAN FLOODS 2022 Post-Disaster Needs Assessment S U P P L E M E N TA L R E P O R T Ministry of Planning Development & Special Initiatives PAKISTAN...

Full report:
http://www.ilo.org/wcmsp5/groups/public/---ed_emp/documents/publication/wcms_863195.pdf
Indian eGov Newswire
Saturday, December 31, 2022 6422 mots, p. NA

STORM UPDATE.

PALO ALTO, Calif., Dec. 31 -- The Palo Alto Police Department issued the following news release:

Published on December 31, 2022

CURRENT CONDITIONS

Overnight water flow in all creeks remained far below flood warning levels. The flood risk remains low at this time, though rain and wind are expected to continue into the afternoon per the National Weather Service. The City is monitoring the next storm, with more rain forecasted for Saturday and continuing intermittently through next week. Crews are working to address fiveremaining power outages, with restoration expected by this afternoon for most customers.

City crews worked through the night. City crews from multiple departments were on duty throughout the night to assist the community. Public Works personnel responded to 33 calls concerning downed trees and 22 concerning flooding and storm drains. Utilities personnel responded to 10 reported outages, all due to downed trees or branches. Police officers and fire personnel responded to dozens of calls involving storm-related vehicle collisions, alarms, road closures, and other unsafe conditions. The City's emergency dispatch center answered more than 300 total calls overnight. The Community Resource Center welcomed 15 individuals yesterday and overnight.

Community Resource Center is open. The Community Resource Center at Rinconada Library is open and will close tonight at 8 p.m., if residents need a warm and dry location away from their home to relocate and gather. Visitors can also charge devices, use a laptop, find a hotel, and determine next steps.

Prepare for power outages and be safe out on the roadways. Crews worked around the clock to minimize utility customer impacts and will continue to respond as needed. Please remain patient through today's storm and future storms forecasted. Prepare for power outages by creating an emergency supply kit, filling your vehicle's gas tank, and consulting your medical provider concerning any special medical considerations that may arise during an outage. Go here for a complete list of tips and resources for preparing for an outage, and ways to gain real-time information. The City is also reminding the community to be safe while navigating roadways which may still contain standing water or fallen debris, and not to touch downed wires or move fallen branches, which may be entangled with live wires.

STREET CLOSURES IN EFFECT

As power outages continue, remember that street signals may be out as well. Treat dark signalized intersections as four-way stops. One current road closure remains in effect:

Update as of 3:15 p.m.: Closure lifted for both directions of El Camino Real at the University Avenue underpass. Please continue to use caution through this area.

REPORTING DAMAGE

For residents whose homes sustained storm-related damage from the January 4 storm, or flood damage from the December 31 storm,please fill out the online form at www.cityofpaloalto.org/reportflooddamage, and City building officials will follow-up. The City has established a process to offer three nights of hotel accommodations at select hotels for those who we confirm have been displaced from their homes as a result of storm-related damage from the January 4 storm or flooding from the December 31 storm. Please use [email protected] to request accommodations.

Prepare for this storm and future storm events. The National Weather Service is predicting a series of storms are on the way.

Sandbags.Staff are regularly monitoring supply levels of sandbag supplies at our four sandbag stations and replenishing as needed. Please do not overfill the sandbags - they only need to be filled about 1/3 of the way with sand. Watch this one-minute video from our partners at Valley Water on how to properly fill and pack a sandbag. To learn how to protect your home from water using filled sandbags, watch this five-minute video from Valley Water. The four sandbag stations are located at:

Storm drains.If you have a storm drain inlet near your home in the street, consider using a rake and clearing any debris (leaves, tree branches, etc.) that may have accumulated over the grate. If possible, please place organic matter into your compost bins. This will help reduce ponding on our roadways for the next storm.

Stay informed of current and forecast conditions.As noted above, we encourage the community to monitor changes in the weather forecast. Get real-time notifications from the City via Twitter, Facebook, Nextdoor, and the Police Department's Nixle feed. Receive emergency alerts via SCC Alert. Click here to connect. Track creek water levels at www.cityofpaloalto.org/creekmonitor

Report damage. For residents who have flood damage to their homes, please fill out this online form at www.cityofpaloalto.org/reportflooddamage, and City building officials will follow-up. The City has established a process to offer three nights of hotel accommodations at select hotels for those who we confirm have been displaced from their homes as a result of flooding. Please use [email protected] to request accommodations.

Prepare now for how to turn off your home's electrical power and gas, just in case.Take the time now to locate your home's electrical breaker box and gas turn-off valve. If water floods your home high enough that it might reach electrical outlets or any gas-powered appliance (furnace, hot water heater, gas-powered stove, etc.), immediately turn off the electrical power to your home by flipping all circuit breakers, and immediately turn off the gas to your home.

Residents in flood prone areas are welcome to move cars to a safer location. Options to park include surface lots in Downtown. Residential preferential parking (RPP) programs and timed parking regulations are temporarily suspended during the upcoming storm.

If an Evacuation Becomes Necessary

City Emergency Operations Center (EOC) staff track evacuation conditions during storms and actively monitoring creek flow. Here is the progression of notifications you can expect in the event evacuations become necessary:

If EOC staff observe a measured creek flow indicating that overtopping (flooding) is likely, the City will send a message indicating that and list specific blocks of specific streets to consider evacuating in advance of potential flooding.

If EOC staff observe a measured creek flow indicating that overtopping (flooding) is imminent or already occurring, the City will send another messaging indicating that and advising specific blocks of specific streets that flooding is now expected and that you should evacuate immediately. From the time this message would be sent, we hope to provide at least 30 to 45 minutes before the flooding is expected to begin.

Please understand that our estimates of impacted streets and potential evacuations will be based on best available information. While other streets may be affected to varying extents, this information is intended to provide residents with awareness of current conditions.

Any such messages will be sent City-wide so as to make everyone aware of what is occurring so they can remain safe and take informed action.These messages will be sent in the following ways, with messages on all platforms containing the same information:

Via AlertSCC, with a link to the City webpage for the specific blocks of specific streets impacted. The AlertSCC system will attempt to contact users first by SMS (text message), then by e-mail, and finally by phone. To sign up for AlertSCC, visitwww.cityofpaloalto.org/connect.

Via SMS (text message) and e-mail to subscribers of the Palo Alto Police Department's Nixle account. To sign up for this, text your ZIP code to 888777.

Via City of Palo Alto Twitter, Nextdoor, Instagram, and Facebook messages. To sign up for these notifications, visitwww.cityofpaloalto.org/connect.

Via the City website atwww.cityofpaloalto.org/FloodAlert.

Via a recording played on the City's Public Emergency Hotline at (650) 329-2420.

Flood risk is low, but the storm is continuing overnight with a wind warning in effect.The storm is upon us. While rain will continue overnight, the flood risk is low. Staff will continue to monitor creek levels overnight as a precaution. The largest challenge now appears to be power outages that are being caused intermittently by the high winds. The National Weather Service's high wind warning extends through the night, with gusts of wind exceeding 50 mph. Crews are on duty throughout the night to address these outages as quickly as they can. Please be patient as they will be working on power restorations while balancing emergency responses to other storm needs. To track National Weather Service storm updates, go tohttps://www.weather.gov/mtr/.

Gain real-time updates on storm impacts and stay informed on potential emergency alerts and warnings.Get real-time notifications from the City via Twitter, Facebook, Nextdoor, and the Police Department's Nixle feed. Receive emergency alerts via SCC Alert.Click here to connect. Track creek water levels atwww.cityofpaloalto.org/creekmonitor.

Community Resource Center is open.The Community Resource Center at Rinconada Library will remain open overnight until at least 8 p.m. on Thursday, if residents need a warm and dry location away from their home to relocate and gather. Visitors can also charge devices, use a laptop, find a hotel, and determine next steps.

As power outages continue, remember that street signals may be out as well. Treat dark signalized intersections as four-way stops. Here are current road closures in effect:

Northbound El Camino Real is closed at the University Avenue underpass for flooding. Southbound El Camino Real at that location remains open.

East Bayshore Road between Elwell Court and San Antonio Road is closed in both directions due to flooding.

West Bayshore Road between Loma Verde Avenue and Fabian Way is closed in both directions due to flooding.

Embarcadero Road is closed between Middlefield Road and Waverley Street in both directions due to a tree down.

Southbound Foothill Expressway is closed at Hillview Avenue due to a tree down and also a vehicle collision.

One lane of eastbound Page Mill Road between Hanover Street and Peter Coutts Road remains closed due to earlier fallen tree.

CURRENT CONDITIONS

Significant storm is arriving.A significantstorm has arrived, and the National Weather Service is still forecasting that the period of highest rainfall will occur overnightand into early Thursday morning. Any flooding risk that may occur will likely happen during the nighttime hours. There is also a high wind warning in effect right now, with gusts of wind exceeding 50 mph. Power outages are possible as a result; if they occur, please be patient as crews will be working on power restorations while balancing emergency responses to other storm needs. The National Weather Service has recently updated their forecast, and there may bea lower flood risk of the San Francisquito Creek than previously predicted. However, due to the likely nature of the creek to flash flood at times, and the high wind warning issued, the City continues to prepare for a significant storm response. To track National Weather Service storm updates, go tohttps://www.weather.gov/mtr/.

Gain real-time updates on storm impacts and stay informed on potential emergency alerts and warnings.Get real-time notifications from the City via Twitter, Facebook, Nextdoor, and the Police Department's Nixle feed.Receive emergency alerts via SCC Alert.Click here to connect. Track creek water levels atwww.cityofpaloalto.org/creekmonitor

What to expect if evacuations become necessary.While staff is hopeful that no evacuations become necessary due to flooding tonight or overnight, we wanted to share in advance the procedure we will use in the event that they do. Please see the section "What to Expect If Evacuations Become Necessary" below.

Community Resource Center is open.Staff has opened a Community Resource Center at Rinconada Library as of this afternoon, if residents need a warm and dry location away from their home to relocate and gather. Visitors can also charge devices, use a laptop, find a hotel, and determine next steps. The Community Resource Center will be open overnight until at least 8 p.m. on Thursday.

Emergency Operations Center is open.Staff from multiple City departments have opened our Emergency Operations Center at City Hall as of this afternoon, and it will remain open continuously overnight. This allows staff to best monitor current conditions, coordinate emergency responses, communicate emergency information to the public, and liaison with our regional partners.

Sandbag station status update.Staff are regularly monitoring supply levels of sandbag supplies at our four sandbag stations and replenishing as needed. See below for locations and instructions on how to properly fill and place sandbags to protect your home.

Residents in flood prone areas are welcome to move cars to a safer location.Options to park includesurface lotsin Downtown. Residential preferential parking (RPP) programs and timed parking regulations are temporarily suspended during the storm.

STREET CLOSURES IN EFFECT

All northbound lanes are closed on El Camino Real at the University Avenue underpass due to flooding.

POWER OUTAGE

There was a power outage in Midtown, near Greer Park, and crews restored power at 8:30 p.m.

WHAT TO EXPECT IF EVACUATIONS BECOME NECESSARY

While we hope no evacuations will be necessary due to flooding later today or overnight, we wanted to share in advance the procedure we will use in the event that the City issues advisory evacuation notices.City Emergency Operations Center (EOC) staff are tracking the storm and are actively monitoring the creek flow. Here is the progression of notifications you can expect:

If EOC staff observe a measured creek flow indicating that overtopping (flooding) is likely, the City will send a message indicating that and list specific blocks of specific streets to consider evacuating in advance of potential flooding.

If EOC staff observe a measured creek flow indicating that overtopping (flooding) is imminent or already occurring, the City will send another messaging indicating that and advising specific blocks of specific streets that flooding is now expected and that you should evacuate immediately. From the time this message would be sent, we hope to provide at least 30 to 45 minutes before the flooding is expected to begin.

Please understand that our estimates of impacted streets and potential evacuations will be based on best available information. While other streets may be affected to varying extents, this information is intended to provide residents with awareness of current conditions.

Any such messages will be sent City-wide so as to make everyone aware of what is occurring so they can remain safe and take informed action. These messages will be sent in the following ways, with messages on all platforms containing the same information:

Via AlertSCC, with a link to the City webpage for the specific blocks of specific streets impacted. The AlertSCC system will attempt to contact users first by SMS (text message), then by e-mail, and finally by phone. To sign up for AlertSCC, visitwww.cityofpaloalto.org/connect.

Via SMS (text message) and e-mail to subscribers of the Palo Alto Police Department's Nixle account. To sign up for this, text your ZIP code to 888777.

Via City of Palo Alto Twitter, Nextdoor, Instagram, and Facebook messages. To sign up for these notifications, visitwww.cityofpaloalto.org/connect.

Via the City website atwww.cityofpaloalto.org/FloodAlert.

Via a recording played on the City's Public Emergency Hotline at (650) 329-2420.

BE STORM READY

Find other ways to be storm-ready, and gain access to several flood maps.The various flood maps offer different levels flood risk. Based on flood management work by various agencies, these maps may show larger flood zones than exist today, though they could be helpful for community planning purposes. Visit our website atwww.cityofpaloalto.org/storms.

CURRENT CONDITIONS

Significant storm arriving today.Per the National Weather Service, a significantstorm is arriving today, with the period of highest rainfall occurring beginning this afternoon and lasting overnight into early Thursday morning. This means that the majority of the rain will fall after dark, and any flooding risk that may occur will likely happen during the nighttime hours. There is also a high wind warning in effect for the same period, with gusts of wind exceeding 50 mph. Power outages are possible as a result; if they occur, please be patient as crews will be working on power restorations while balancing emergency responses to other storm needs. National Weather Service recently updated their predictions, and there may bea lower flood risk of the San Francisquito Creek. Due to the likely nature of the creek to flash flood at times, and the high wind warning issued, the City continues to prepare for a significant storm response. To track National Weather Service storm updates, go tohttps://www.weather.gov/mtr/.

Gain real-time updates on storm impacts and stay informed on potential emergency alerts and warnings.Get real-time notifications from the City via Twitter, Facebook, Nextdoor, and the Police Department's Nixle feed.Receive emergency alerts via SCC Alert.Click here to connect. Track creek water levels atwww.cityofpaloalto.org/creekmonitor

Community Resource Center opening.Staff will be opening a Community Resource Center at Rinconada Library at 2 p.m. today, if residents need a warm and dry location away from their home to relocate and gather. Visitors can also charge devices, use a laptop, find a hotel, and determine next steps. The Community Resource Center will be open overnight until at least 8 p.m. on Thursday.

Emergency Operations Center opening.Staff from multiple City departments will be opening our Emergency Operations Center at City Hall later today. This will allow staff to best monitor current conditions, coordinate emergency responses, communicate emergency information to the public, and liaison with our regional partners.

Sandbag station status update.Staff are regularly monitoring supply levels of sandbag supplies at our four sandbag stations and replenishing as needed. See below for locations and instructions on how to properly fill and place sandbags to protect your home.

Residents in flood prone areas are welcome to move cars to a safer location.Options to park includesurface lotsin Downtown. Residential preferential parking (RPP) programs and timed parking regulations are temporarily suspended during the storm.

STREET CLOSURES IN EFFECT

All roadways are currently open.

PREPARE NOW FOR THE STORM

Prepare now, assist neighbors.Residents in flood risk areas should take precautions and prepare now to safeguard your home as much as possible. Please be a good neighbor and offer your assistance to your neighbors if you're able.

Sandbags.Staff are regularly monitoring supply levels of sandbag supplies at our four sandbag stations and replenishing as needed. Please do not overfill the sandbags - they only need to be filled about 1/3 of the way with sand.Watch this one-minute video from our partners at Valley Water on how to properly fill and pack a sandbag.To learn how to protect your home from water using filled sandbags, watch this five-minute video from Valley Water. The four sandbag stations are located at:Palo Alto Avenue at Chaucer Street, Rinconada Tennis Courts (at the corner of Newell Road and Hopkins Avenue), Mitchell Park (600 East Meadow Drive), Palo Alto Airport Terminal (1925 Embarcadero Road)

Storm drains.If you have a storm drain inlet near your home in the street, consider using a rake and clearing any debris (leaves, tree branches, etc.) that may have accumulated over the grate. If possible, please place organic matter into your compost bins. This will help reduce ponding on our roadways for the next storm.

Stay informed of current and forecast conditions.As noted above, we encourage the community to monitor changes in the weather forecast. Get real-time notifications from the City via Twitter, Facebook, Nextdoor, and the Police Department's Nixle feed.Receive emergency alerts via SCC Alert.Click here to connect. Track creek water levels atwww.cityofpaloalto.org/creekmonitor

Report damage.For residents who have flood damage to their homes from the December 31 storm event, please fill out this online form atwww.cityofpaloalto.org/reportflooddamage,and City building officials will follow-up. The City has established a process to offer three nights of hotel accommodations at select hotels for those who we confirm have been displaced from their homes as a result of flooding from the December 31 storm event. Please [email protected]o request accommodations.

Prepare now for how to turn off your home's electrical power and gas, just in case. Take the time now to locate your home's electrical breaker box and gas turn-off valve. If water floods your home high enough that it might reach electrical outlets or any gas-powered appliance (furnace, hot water heater, gas-powered stove, etc.), immediately turn off the electrical power to your home by flipping all circuit breakers, and immediately turn off the gas to your home.

Residents in flood prone areas are welcome to move cars to a safer location.Options to park includesurface lots in Downtown. Residential preferential parking (RPP) programs and timed parking regulations are temporarily suspended during the upcoming storm.

For other ways to be storm-ready, visit our website atwww.cityofpaloalto.org/storms. This website also shares various level of flood maps with different levels flood risk.Based on flood management work by various agencies, these maps may show larger flood zones than exist today, though they could be helpful for community planning purposes.

A new storm is headed our way. We are asking the public to prepare now and stay informed. Our community is stronger together, please help neighbors and others who need help getting prepared.Read a new community update with additional resources.

Significant storm with heavy rain and wind expected Wednesday to Thursday.Per the National Weather Service a strong storm will be arriving on Wednesday, with the period of highest rainfall occurring beginning Wednesday afternoon and lasting overnight into early Thursday morning. This means that the majority of the rain will fall after dark, and any flooding risk that may occur will likely happen during the nighttime hours. There is also a high wind watch in effect for the same period, with gusts of wind exceeding 50 mph. Compared to the impacts of the December 31 storm, the National Weather Service says to expect similar or worse impacts because of the storm arriving tomorrow.

Storm preparations continue.A multi-departmental City response is continuing to prepare for the upcoming storm and are in regular communication with our regional partners regarding preparations. Crews are continuing efforts to prepare the storm drain system for the coming storm, focusing on cleaning up from the December 31 storm. Crews are also staging equipment near where it will be needed most to facilitate a quick response once the storm hits.

New sandbag station set up.Staff opened a fourth sandbag station. This one is located on Palo Alto Avenue at Chaucer Street. This is in addition to the three existing sandbag stations (located at the Rinconada Tennis Courts at the corner of Newell Road and Hopkins Avenue, Mitchell Park at 600 East Meadow Drive, and the Palo Alto Airport Terminal at 1925 Embarcadero Road).

Community Resource Center to open on Wednesday.Staff will be opening a Community Resource Center at Rinconada Library's Embarcadero Room in the afternoon on Wednesday, if residents need a warm and dry location away from their home to relocate and gather. Visitors can also charge devices, use a laptop, find a hotel, and determine next steps.

Closure of Foothills Nature Preserve announced for Wednesday and Thursday.The City will be closing Foothills Nature Preserve on both Wednesday, January 4 and Thursday, January 5 due to the incoming storm.

El Camino Real remains flooded and closed in both directions under University Avenue.Please continue to take alternate routes. The time of re-opening El Camino Real remains unknown. As El Camino Real is a state-owned roadway, the City is coordinating with CalTrans as they have primary jurisdiction. City crews are prioritizing work that prepares the storm drainage system for the coming storm later this week.

All other roadways are open.

Prepare now, assist neighbors.Residents in flood risk areas should take precautions and prepare now to safeguard your home as much as possible, particularly if your neighborhood experienced flooding during the December 31 storm event. Please be a good neighbor and offer your assistance to your neighbors if you're able.

For other ways to be storm-ready, visit our website atwww.cityofpaloalto.org/storms.

7:00 P.M. UPDATE

CURRENT CONDITIONS

Significant storm with rain expected Wednesday to Thursday. During a briefing with the National Weather Service this afternoon, staff learned that the latest forecast indicates that a strong storm will arrive on Wednesday, with the period of highest rainfall occurring beginning Wednesday afternoon and lasting overnight into early Thursday morning. This means that the majority of the rain will fall after dark, and any flooding risk that may occur will likely happen during the nighttime hours. There is also a high wind watch in effect for the same period, with gusts of wind exceeding 50 mph. Compared to the impacts of the December 31 storm, the National Weather Service says to expect similar or worse impacts as a result of the storm arriving on Wednesday.

Long-range forecast.After a period of light rain on Friday, the National Weather Service predicts a continuation of wet weather into the second week of January, with moderate rain arriving this weekend into early next week.

Storm preparations underway.A multi-departmental City response is underway to prepare for the upcoming storm. Crews will be staging equipment near where it will be needed most to facilitate a quick response once the storm hits.

Closure of Foothills Nature Preserve announced for Wednesday and Thursday this week.The City will be closing Foothills Nature Preserve on both Wednesday, January 4 and Thursday, January 5 due to the incoming storm.

Creek sensors fixed and staff continue to monitoring.The Chaucer Street bridge and Waverley Street sensors were both damaged during Saturday's storm. Both sensors are up and running again, with staff monitoring the sensors and creek levels regularly.

PREPARE FOR THE NEXT STORM

Prepare now, assist neighbors.Residents in flood risk areas should take precautions and prepare now to safeguard your home as much as possible, particularly if your neighborhood experienced flooding during the December 31 storm event. Please be a good neighbor and offer your assistance to your neighbors if you're able.

For other ways to be storm-ready, visit our website atwww.cityofpaloalto.org/storms.

To monitor creek water levels and learn about other resources, visit our website atwww.cityofpaloalto.org/creekmonitor

1:00 P.M. UPDATE

Here's an update on current conditions. Please be aware that more storms are headed our way. Take precautions now for these upcoming weather events.

CURRENT CONDITIONS

Staff are continuously monitoring water levels in our creeks.Flood risk remains low at this time, but a series of storms will be impacting the Bay Area this week and lasting for several days. The next large storm, which is currently forecast to arrive on Wednesday, January 4, is anticipated to be potentially more significant than the rain event we experienced on Saturday.

City crews are continuing to clean up and address the problems caused by Saturday's storm, as well as prepare for the upcoming storms.Crews are continuing to work on removing mud and debris from affected streets near San Francisquito Creek, which will help get the storm drain system ready for the next storm.

City staff are also continuing to assess flood damage to homes from Saturday's storm. Pleaseuse caution with home appliances(particularly water heaters and furnaces) that may have been exposed to flood water and may need to be serviced by a qualified service provider or replaced. Information on how to obtain City building permits to replace this equipment can be foundhere.

Staff is continuing to troubleshoot problems with the sensors that feed information to the Creek Monitor webpage (www.cityofpaloalto.org/creekmonitor) at both the Chaucer Street bridge and Waverley Street. Both sensors received damage during Saturday's storm. Staff hopes to be able to fix them prior to the arrival of the next large storm.

STREET CLOSURES IN EFFECT

El Camino Real remains flooded and closed in both directions under University Avenue.Please continue to take alternate routes. The time of re-opening El Camino Real remains unknown. As El Camino Real is a state-owned roadway, the City is coordinating with CalTrans as they have primary jurisdiction.City crews are prioritizing work that prepares the storm drainage system for the coming storm later this week.

All other roadways are open.

REPORT DAMAGE & HOW TO RECEIVE SUPPORT

Steps to report damage.For residents who have flood damage to their homes, please fill outthis formto report flood damage. Alternatively, residents can e-mail the City [email protected]nd include the following information:First and last name, Mobile phone number, Whether or not you have flood insurance coverage, A brief description of the damage: did water get inside your home? What is the extent of damage to your home?

Staff will follow-up with these residents. The City has established a process to offer three nights of hotel accommodations at select hotels for those who we confirm have been displaced from their homes as a result of flooding. Please use the same email above to request accommodations.

If you are taking photos of water damage to your home, consider including something in the photo to show proper perspective and document the depth of the water (for example, a measuring tape or a piece of furniture). This may help you accurately document damage for your home insurance company.

Pumping water out of homes.Due to resource limitations, the City is unable to assist with pumping water out of homes or basements. Please contact your home insurance company to determine what assistance they may be able to provide or recommend.

PREPARE FOR THE NEXT STORM

There are several rain events anticipated over the next 10 days. Residents in flood risk areas should take precautions and prepare now to safeguard your home as much as possible, particularly if your neighborhood experienced flooding during yesterday's event.

12:30 P.M. Update

Happy New Year! Today's weather brings a welcome brief respite in the storm systems. Please be aware that more storms are headed our way. Take precautions now for additional weather events.

CURRENT CONDITIONS

Staff are continuously monitoring water levels in our creeks.Flood risk remains low at this time, but a series of storms will be impacting the Bay Area beginning tomorrow and lasting for several days. The next large storm, which is currently forecast to arrive on Wednesday, January 4, is anticipated to be potentially more significant than the rain event we experienced yesterday.

City crews are actively cleaning up and addressing the problems caused by yesterday's storm.Several street sweepers are driving through the City today to remove debris from gutters and inlets.

Creek sensors were damaged in the storm.The Creek Monitor webpage (www.cityofpaloalto.org/creekmonitor) provides helpful information during a storm to track water levels. Staff are actively working to troubleshoot problems with the sensors at both the Chaucer Street bridge and Waverley Street. The sensor at Chaucer Street was damaged by moving debris, while the network that serves the Waverley Street sensor was damaged. If possible, staff will fix both sensors prior to the arrival of the next large storm.

STREET CLOSURES IN EFFECT

El Camino Real remains flooded and closed in both directions under University Avenue. Please take alternate routes. At this time, the time of re-opening El Camino Real is unknown.

All other roadways are open.

REPORT DAMAGE & HOW TO RECEIVE SUPPORT

For residents who have flood damage to their homes, please e-mail the City [email protected]nd include the following information:

Staff will follow-up with these residents. The City has established a process to offer three nights of hotel accommodations at select hotels for those who we confirm have been displaced from their homes as a result of flooding. Please use the same email above to request accommodations.

Due to resource limitations, the City is unable to assist with pumping water out of homes or basements. Please contact your home insurance company to determine what assistance they may be able to provide or recommend.

If you are taking photos of water damage to your home, consider including something in the photo to show proper perspective and document the depth of the water(for example, a measuring tape or a piece of furniture). This may help you accurately document damage for your home insurance company.

PREPARE FOR THE NEXT STORM

There are several rain events anticipated over the next 10 days. Residents in flood risk areas should take precautions and prepare now to safeguard your home as much as possible, particularly if your neighborhood experienced flooding during yesterday's event.

For other ways to be storm-ready, visit our website atwww.cityofpaloalto.org/storms.

To monitor creek water levels and learn about other resources, visit our website atwww.cityofpaloalto.org/creekmonitor

WAYS TO HELP

We are stronger as a community when we help those around us and work together during times of adversity. If your home is safe from flooding and you'd now like to help others, here are some suggestions for what you could do:

STAY SAFE - REMINDERS

Please do your best to stay safe during adverse weather events. Here are some safety reminders:

STAY INFORMED

Stay apprised of current and forecast conditions.Monitor changes in the weather forecast. Get notifications from the City viaSCC Alert, City of Palo Alto Twitter, Facebook, Nextdoor, and the Police Department'sNixlefeed.Click here to connect.

Stay connected on social media.If you are posting storm-related photos and/or videos that were taken in Palo Alto on your social media accounts, please consider adding the hashtag #PaloAltoStorm to your post. This will provide an easy way for everyone on that platform, as well as the City, to share relevant Palo Alto-specific information with one another. Please note that the City will not be able to monitor that hashtag in real-time, and that any emergencies requiring a City response should be reported via 9-1-1 and NOT social media.

8:40 P.M. Update

Good news, San Francisquito Creek water levels are receding, and the storm is passing, with flood risk at a lower level. Please note that the National Weather Service predicts a larger storm to hit our area by January 4-5. Staff will continue to monitor creek levels and share updates, as needed.

For residents that have flood damage to their homes, please email the City [email protected]nd staff will follow-up. Please include the following details:First Name, Last Name, Email Address, Mobile Phone Number, Do you have flood insurance?Did water get inside your home? What is the level of damage to your residence.The City is establishing a process to offer three nights of hotel accommodations at select hotels for those who we confirm are flooded out of their homes. Please provide contact information at the above email address to coordinate this service.

See the previous update for additional details on ways to prepare for the next storm.

5:30 P.M. UPDATE

The following update providesa statusand ways for the community to prepare for the next storm, which is expected byJanuary4-5,based on the National Weather Service predictions.

CURRENT CONDITIONS:

PREPARING FOR THE NEXT RAIN EVENT:

There are several rain events anticipated over the next10days. Residents in flood risk areas should take precautions and prepare now.

For other ways to be storm ready, go here:www.cityofpaloalto.org/storms.

STEPS TO TAKE IF YOUR HOME HAS FLOOD DAMAGE:

Overnight rainlevels werethree timeswhatthe National Weather Systemhad originallyforecast from December 30 to December 31, and water levels rose very quickly this morning. ThecurrentNational Weather Service forecast notes clearing for the next few days and then further rain anticipated (much more expected than the December 30/31 rain incident).

2:40 P.M. UPDATE

The National Weather Service is noting rain to be intermittent/lighter rain in the forecast for the rest of the day, and clearing up for the next few days. Staff is monitoring water levels of the San Francisquito Creek and at this time, Pope Chaucer Bridge water levels are receding.

CREEK MONITORS:

SAFETY REMINDERS:

MINOR STREET FLOODING LOCATIONS:

CURRENT ROAD CLOSURES IN EFFECT/OTHER CLOSURES:

TAKE PRECAUTIONS:

LIBRARY LOCATIONS OPEN:

12:45 UPDATE

National Weather Service is noting lighter rain in the forecast for the rest of the day, and clearing up for the next few days.Flooding at Pope Chaucer Bridge is still occurring.Take protective actions at this time if you are near the San Francisquito Creek near the Bridge. There are potential impacts to areas in the flood zone from the creek.

SAFETY REMINDERS:

MINOR STREET FLOODING LOCATIONS:

CURRENT ROAD CLOSURES IN EFFECT/UPDATES:

TAKE PRECAUTIONS:

LIBRARY LOCATIONS OPEN:

11:30 A.M. UPDATE FLOODING ALERT

Flooding at Pope Chaucer Bridge is occurring.

Don't call 9-1-1 unless there is an imminent threat to life or other serious emergency.

Do NOT removemanhole covers.

Take protective actions at this time if you are near the San Francisquito Creek near the Bridge. There are potential impacts to areas in the flood zone from the creek.

MINOR STREET FLOODING LOCATIONS:

CURRENT ROAD CLOSURES IN EFFECT:

TAKE PRECAUTIONS:

Sandbags are available for use at the following locations:

FLOODING ALERT: 10:10 a.m.

Flooding at Pope Chaucer Bridge is likely. Minor flooding is occurring at Seneca and Hale Streets by the Creek. Take protective actions at this time if you are near the San Francisquito Creek near the Bridge. There are potential impacts to areas in the flood zone from the creek. Place sandbags if you have them by entrances to homes, raise valuables from low to higher places in your home, make sure your vehicle is ready in case you need to evacuate.

FLOODING ALERT

San Francisquito Creek has reached flood monitoring stage and is continuing to rise. Please be aware of potential flooding and further flooding likely.

Flooding at Pope Chaucer bridge is likely within the next 30 minutes. Take protective actions at this time if you are near the San Francisquito Creek.

Sandbags are available for use at the following locations:

Don't call 9-1-1 unless there is an imminent threat to life or other serious emergency.

Other Helpful Resources

Report Flood Damage

Find Frequently Asked Questions here

www.cityofpaloalto.org/storms

www.cityofpaloalto.org/creekmonitor

Be Prepared for Emergencies

Sign Up for Alerts from the Palo Alto Police Department via Nixle

Sign Up for Emergency Alerts

View the National Weather Service's Bay Area weather forecast

View the California Nevada River Forecast Center's San Francisquito Creek River Level Probabilities For any query with respect to this article or any other content requirement, please contact Editor at [email protected]

Copyright © HT Media Ltd. Provided by SyndiGate Media Inc. (Syndigate.info).

Web sites - Business Management - Business Line
October 19, 2023 25619 mots
Share Market Highlights 19 October 2023: Sensex falls 247 pts, Nifty closes at 19,624; Bajaj Auto jumps 6%; LTIMindtree surges 5%

Sensex, Nifty updates on 19 October 2023: Equity benchmark indices declined for the second consecutive session on Thursday amid weak trends in global markets and fresh foreign fund outflows. Disappointing quarterly... Voir l'article

Ce document référence un lien URL de site non hébergé par Cision.

Reports - Transport - Eurail

Publication date: November 17, 2023 45445 mots

View document - Annex to MB Decision 336 - SPD 2024-2026.pdf

142 pages

Please note : This extract may not display a well formed paragraph

... SPD 2024-2026 MB decision 336 Moving Europe towards a sustainable and safe railway system without frontiers. 120 Rue Marc Lefrancq | BP 20392 | FR-59307 Valenciennes Cedex 0 / 142 Tel. +33...

Full report:
https://www.era.europa.eu/system/files/2023-11/Annex%20to%20MB%20Decision%20336%20-%20SPD%202024-2026.pdf

Reports - Banks and Financial Institutions - Bank of England

Publication date: October 13, 2023 42773 mots

Self-assessment of the Bank of England's Real-Time Gross Settlement and CHAPS services against the Principles for Financial Market Infrastructures - Self-assessment of the Bank of England's Real-Time Gross Settlement and CHAPS services against the ...

119 pages

Please note : This extract may not display a well formed paragraph

... Self-assessment of the Bank of England’s Real-Time Gross Settlement and CHAPS services against the Principles for Financial Market Infrastructures This page is the Bank’s disclosure of its...

Full report:
https://www.bankofengland.co.uk/-/media/boe/files/payments/rtgs-and-chaps-2022-pfmi-self-assessment.pdf
EDGAR Online-Prospectus and Proxies
Friday, October 13, 2023 73603 mots, p. NA

424B4: Agape ATP Corp.

(EDGAR Online via COMTEX) -- PROSPECTUS FILED PURSUANT TO RULE 424(b)(4)

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

This is a firm commitment initial public offering of 1,650,000 of our shares of common stock, $0.0001 par value per share. The initial public offering price of our shares is US$4.00 per share. The Underwriter is obligated to take and pay for all of the shares if any such shares are taken. We have granted the Underwriter a 15% over-allotment option, exercisable one or more times in whole or in part, to purchase up to 247,500 additional common stock from us at the public offering price, less the underwriting discounts, for 45 days from the closing of this offering to cover over-allotments, if any. If the Underwriter exercises the option in full, the total underwriting discounts payable will be $607,200, and the total proceeds to us, before expenses, will be $6,982,800.

We are a reporting company under Section 15(d) of the Securities Exchange Act of 1934, as amended. Our common stock started trading on the NASDAQ Capital Market ("NASDAQ") under the symbol "ATPC" on October 11, 2023.

Investing in our common stock is highly speculative and involves a significant degree of risk. See "Risk Factors" beginning on page 8 of this prospectus for a discussion of information that should be considered before making a decision to purchase our common stock.

Neither the U.S. Securities and Exchange Commission nor any state securities commission has approved or disapproved of these securities or passed upon the adequacy or accuracy of this prospectus. Any representation to the contrary is a criminal offense.

    REGISTRATION NO. 333-239951

Per Share of Common Stock $ 4.00 $ 0.32 $ 3.68

Total(2) $ 7,590,000 $ 607,200 $ 6,982,800

    REGISTRATION NO. 333-239951

Delivery of the shares of common stock is expected to be made on or about October 13, 2023.

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

You should rely only on the information contained in this prospectus or contained in any free writing prospectus prepared by or on behalf of us or to which we have referred you. We have not, and the Underwriter has not, authorized anyone to provide you with information that is different from that contained in such prospectuses. We are offering to sell shares of our common stock, and seeking offers to buy shares of our common stock, only in jurisdictions where such offers and sales are permitted. The information in this prospectus is accurate only as of the date of this prospectus, regardless of the time of delivery of this prospectus or any sale of our common stock. Our business, financial condition, results of operations and prospects may have changed since that date.

In this prospectus, we rely on and refer to information and statistics regarding our industry. We obtained this statistical, market and other industry data and forecasts from publicly available information. While we believe that the statistical data, market data and other industry data and forecasts are reliable, we have not independently verified the data.

For investors outside of the United States: neither we nor the Underwriter have done anything that would permit this offering or possession or distribution of this prospectus in any jurisdiction where action for that purpose is required, other than in the United States. You are required to inform yourselves about and to observe any restrictions relating to this offering and the distribution of this prospectus.

2

    REGISTRATION NO. 333-239951

This summary highlights information contained elsewhere in this prospectus. Because this is only a summary, it does not contain all of the information that may be important to you. You should read this entire prospectus and should consider, among other things, the matters set forth under "Risk Factors," "Management's Discussion and Analysis of Financial Condition and Results of Operations", and our consolidated financial statements and related notes thereto appearing elsewhere in this prospectus before making your investment decision.

Overview

Agape ATP Corporation provides health solution advisory services to its clients. We primarily focus our efforts on attracting customers in Malaysia. We have an advisory services center called the "ATP Zeta Health Program", which is a health program designed to effectively prevent diseases caused by polluted environments, unhealthy dietary intake and unhealthy lifestyles, and the promotion of health. The program aims to promote improved health and longevity through a combination of modern health supplements, proper nutrition and advice from skilled nutritionists and/or dieticians. For the six months ended June 30, 2023 and 2022, our revenue was approximately $0.7 million and $0.8 million, respectively, and our gross profit was approximately $0.4 million and $0.6 million, respectively. For the years ended December 31, 2022 and 2021, our revenue was approximately $1.9 million and $1.0 million, respectively, and our gross profit was approximately $1.2 million and $0.7 million, respectively.

In order to strengthen the Company's supply chain, on May 8, 2020, the Company acquired approximately 99.99% of Agape Superior Living Sdn Bhd, a Malaysia company ("ASL"), with the goal of securing an established network marketing sales channel that has been established in Malaysia for the past 18 years. ASL has been offering the Company's ATP Zeta Health Program as part of its product lineup. As such, the acquisition creates synergy in the Company's operation by boosting the Company's retail and marketing capabilities. The acquired subsidiary allows the Company to fulfill its mission of "helping people to create health and wealth" by providing a financially rewarding business opportunity to distributors and quality products to distributors and customers who seek a healthy lifestyle.

The Company deems creating public awareness on wellness and wellbeing lifestyle as essential to enhance the provision of its health solution advisory services; and therefore, on September 11, 2020, incorporated Wellness ATP International Holdings Sdn, Bhd. ("WATP"). Upon its establishment, WATP started collaborating with ASL to carry out various wellness programs.

On November 11, 2021, Agape ATP Corporation (Labuan) formed a joint-venture entity, DSY Wellness International Sdn. Bhd. ("DSY Wellness") with Mr. Steve Yap following which Agape ATP Corporation (Labuan) owns 60% of the equity interest of DSY Wellness, to pursue the business of providing complementary health therapies. The establishment of DSY Wellness is a further expansion of our business into the health and wellness industry. Mr. Steve Yap owns 33 proprietary formulas (the "Proprietary Formulas") for treating non-communicable disease and the Company is currently in discussion with Mr. Steve Yap to bring the Proprietary Formulas into the company for joint commercialization. Mr. Steve Yap also has existing clients receiving traditional complimentary medicine or "TCM" in Indonesia and China.

Our Products

We offer three series of programs which consist of different services and products: ATP Zeta Health Program, ENERGETIQUE and BEAUNIQUE.

Our ATP Zeta Health Program is a health program designed to promote health and general wellbeing designed to prevent health diseases caused by polluted environments, unhealthy dietary intake and unhealthy lifestyles. The program aims to promote improved health and longevity through a combination of modern health supplements, proper nutrition and advice from skilled dieticians as well as trained members and distributors.

Our ENERGETIQUE series aims to provide a total dermal solution for a healthy skin beginning from the cellular level. The series is comprised of the Energy Mask series, Hyaluronic Acid Serum and Mousse Facial Cleanser.

Our BEAUNIQUE product series focuses on the research of our diet's impact on modifying gene expressions in order to address genetic variations and deliver a nutrigenomic solution for every individual.

The newly established subsidiary DSY Wellness is a further expansion of our business into the health and wellness industry and aims to pursue the business of providing traditional and complementary health therapies.

Our Strategies

We intend to pursue the following strategies in order to further develop and expand our business:

    REGISTRATION NO. 333-239951

? Further penetrate existing markets;

? Deepen our relationship with existing distributors and members;

3

    REGISTRATION NO. 333-239951

? Expand into other geographies outside of Malaysia; and

    REGISTRATION NO. 333-239951

Our Competitive Strengths

We believe the following competitive strengths contribute to our success and differentiate us from our competitors:

? Well established reputation;

? Well-established product portfolio;

    REGISTRATION NO. 333-239951

? Scalable business model; and

? Founder-led and deeply experienced management team.

Our Challenges

Our ability to realize our mission and execute our strategies is subject to risks and uncertainties, including those relating to our ability to:

? Respond to a highly competitive market;

    REGISTRATION NO. 333-239951

? Maintain quality product and value;

? Create brand influence;

? Expand our product offerings; and

? Expand our business in Malaysia and globally.

Please see "Risk Factors" and other information included in this prospectus for a discussion of these and other risks and uncertainties that we face.

Risk Factors

An investment in our common stock involves a high degree of risk. You should consider and read carefully all of the risks and uncertainties described in "Risk Factors" beginning on page 8, together with all of the other information contained in this prospectus, including our consolidated financial statements and related notes thereto appearing elsewhere in this prospectus, before investing in our common stock. These risks could materially affect our business, financial condition and results of operations and cause the trading price of our common stock to decline. You could lose part or all of your investment. You should bear in mind, in reviewing this prospectus, that past experience is no indication of future performance. You should read "Special Note Regarding Forward-Looking Statements" for a discussion of what types of statements are forward-looking statements, as well as the significance of such statements in the context of this prospectus.

Corporate Information

Our principal executive offices are located at 1705 - 1708, Level 17, Tower 2, Faber Towers, Jalan Desa Bahagia, Taman Desa, Kuala Lumpur, Malaysia (Post Code: 58100). Our telephone number at this address is +(60) 327325716. Our registered office in Nevada is located at 1645 Village Center Circle, Suite 170, Las Vegas, Nevada, United States, 89134.

Our website is http://agapeatpgroup.com/. The information contained on our website or any third-party websites is not a part of this prospectus.

4

Corporate Structure

The following diagram illustrates our corporate structure as of the date of this prospectus and upon closing of this offering:

    REGISTRATION NO. 333-239951

*As of the date of this prospectus.

** Upon closing of this offering and assuming no exercise of the Underwriter's Warrants and full exercise of the over-allotment option.

Note:

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

However, Agape S.E.A.'s impact to our consolidated financial statements constitutes less than 1% of our total consolidated assets and Agape S.E.A. did not contribute any revenues for us as of December 31, 2020.

4. Agape ATP Corporation was incorporated in Labuan, Malaysia on March 6, 2017.

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Conventions That Apply to This Prospectus

Unless otherwise indicated or the context otherwise requires, references in this prospectus to:

? "dollar," "USD," "US$," or "$" are to U.S. dollars;

? "RM" and "Ringgit" are to the legal currency of Malaysia; and

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

5

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Common stock outstanding prior to this 75,452,012 shares of common stock. offering Common stock outstanding immediately 77,102,012 shares of common stock, after this offering assuming the sale of all the shares offered in this prospectus, 77,349,512 shares of common stock if the underwriter exercise the over-allotment in full.

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Trading Symbol "ATPC"

    REGISTRATION NO. 333-239951

6

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

The following tables summarize our historical consolidated financial data. We have derived the historical consolidated statements of operations data for the three and six months ended June 30, 2023 and 2022 from our unaudited condensed consolidated financial statements, and for the years ended December 31, 2022 and 2021 from our audited consolidated financial statements included elsewhere in this prospectus. The following summary consolidated financial data should be read in conjunction with the respective section titled "Management's Discussion and Analysis of Financial Condition and Results of Operations" and our condensed consolidated financial statements and related notes, and consolidated financial statements and related notes included elsewhere in this prospectus. Our historical results are not necessarily indicative of the results that may be expected in the future, and our results for any interim period are not necessarily indicative of the results to be expected for a full fiscal year.

Consolidated Statements of Operations Data for the:

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Consolidated Balance Sheet Data as of:

    REGISTRATION NO. 333-239951

Total assets $ 1,905,283 $ 2,791,749 $ 4,724,535 Total liabilities $ 1,154,629 $ 1,229,295 $ 1,411,899

7

    REGISTRATION NO. 333-239951

Any investment in our securities involves a high degree of risk. You should carefully consider the risks described below, which we believe represent certain of the material risks to our business, together with the information contained elsewhere in this prospectus, before you make a decision to invest in our shares of common stock. Please note that the risks highlighted here are not the only ones that we may face. For example, additional risks presently unknown to us or that we currently consider immaterial or unlikely to occur could also impair our operations. If any of the following events occur or any additional risks presently unknown to us actually occur, our business, financial condition and operating results may be materially adversely affected. In that event, the trading price of our securities could decline and you could lose all or part of your investment.

Risks Related to Our Business and Industry

Our business and reputation may be affected by product liability claims, litigation, customer complaints, product tampering, food safety issues, food-borne illnesses, health threats, quality control concerns or adverse publicity relating to our products. Product liability insurance of our supplier may not cover our liability sufficiently or at all.

Like other consumer product manufacturers, the sale of our products involves an inherent risk of our products being found to be unfit for consumption or cause illness. Products may be rendered unfit for consumption due to raw materials or product contamination or degeneration, presence of microbials, illegal tampering of products by unauthorized third parties or other problems arising during the various stages of the procurement, production, transportation and storage processes. The occurrence of such problems may result in customer complaints, fines, penalties or adverse publicity causing serious damage to our reputation and brand, as well as product liability claims, other legal disputes and loss of revenues. Under certain circumstances, we may be required to recall our products. Even if a situation does not necessitate a product recall, we cannot assure you that product liability claims or other legal disputes will not be asserted against us as a result. Product liability insurance of our supplier may not cover our liability sufficiently or at all and will not cover liability that arises out of our default such as mishandling, poor storage condition and/or contamination of the products by us. As a result, a product liability or other judgment against us, or a product recall, could have a material adverse effect on our business, financial condition or results of operations.

Our business is susceptible to food-borne illnesses. We cannot assure you that we are able to effectively prevent all diseases or illnesses caused by our products or contamination of our products. Furthermore, our reliance on third-party product suppliers means that food-borne illness incidents could be caused by our suppliers outside of our control. New illnesses may develop in the future, or diseases with long incubation periods could arise that could give rise to claims or allegations on a retroactive basis. Reports in the media of instances of food-borne illnesses or health threats of our products or any of their major ingredients could adversely and significantly affect our sales, and have significant negative impact on our results of operations. This risk exists even if it were later determined that the illness or health threat in fact was not caused by our products.

In addition, adverse publicity about health and safety concerns, whether unfounded or not, may discourage consumers from buying our products. Even if a product liability claim is unsuccessful or is not fully pursued, the negative publicity surrounding any assertion that our products caused personal injury or illness could adversely affect our reputation and our corporate and brand image. If consumers were to lose confidence in our brand and reputation, we could suffer long-term or even permanent declines in our sales and results of operation. The amount of negative news, customers complaints and claims against us may also be very costly and may divert our management's attention from our business operation.

We operate in a highly competitive market. If we do not compete effectively, our prospects, operating results, and financial condition could be materially and adversely affected.

The health and wellness market in Malaysia is a mature and a highly competitive market, with companies offering a variety of competitive products and services. We expect competition in our market to intensify in the future as new and existing competitors introduce new or enhanced products and services that are potentially more competitive than our products and services. The health and wellness market has a multitude of participants in the domestic market, including, but not limited, to retail health supplement providers, pharmaceutical companies, and network marketing company which supply health supplement products, such as Elken Group, USANA Group, NHF Group, Young Living, Jeunesse Global Holdings LLC, USA, Shaklee Corporation, VASAYO LLC, Amway Corporation, Sami Direct, Kyani, Inc., Melaleuca, Inc.

We believe many of our competitors and potential competitors may have significant competitive advantages, including but not limited to, longer operating histories, ability to leverage their sales efforts and marketing expenditures across a broader portfolio of products and services, larger and broader customer bases, more established relationships with a larger number of suppliers, greater brand recognition, ability to leverage stores which they may operate, and greater financial, research and development, marketing, distribution, and other capabilities and resources than we do. Our competitors and potential competitors may also be able to develop products and services that are equal or more superior to ours, achieve greater market acceptance of their products and services, and increase sales by utilizing different distribution channels than we do. Some of our competitors may aggressively discount their products in order to gain market share, which could result in pricing pressures, reduced profit margins, lost market share, or a failure to grow market share for us. If we are not able to compete effectively against our current or potential competitors, our prospects, operating results, and financial condition could be materially and adversely affected.

We are exposed to concentration risk of heavy reliance on our three largest suppliers for the supply of our products, and any shortage of, or delay in, the supply may significantly impact on our business and results of operation.

For the six months ended June 30, 2023, we purchased $116,269, $65,338 and $33,507 from three of our major suppliers, one of them being a related party, which represented approximately 47.2%, 26.5% and 13.6%, respectively, of our total purchases for such period. For the year ended December 31, 2022, we purchased $198,376, $82,434 and $79,365 from three of our major suppliers, one of them being a related party, which represented approximately 53.3%, 22.1% and 21.3%, respectively, of our total purchases for such period. For the year ended December 31, 2021, we purchased $28,969 and $27,707 from two of our major suppliers, represented approximately 47.3% and 45.2%, respectively, of our total purchases. Our business, financial condition and operating results depend on the continuous supply of products from our major suppliers and our continuous supplier-customer relationships with them. Our heavy reliance on our major suppliers for the supply of our products will have a significant impact on our business and results of operation in the event of any shortage of, or delay in the supply.

We currently do not have long term supply agreements with our three largest suppliers for the six months ended June 30, 2023, and we typically make ad hoc purchases through submission of purchase order forms. There is no assurance that our major suppliers will continue to supply their products in the quantities and timeframes required by us to meet the needs of our customers or comply with their supply agreements with us. Our product supply may also be disrupted by potential labor disputes, strike action, natural disasters or other accidents, epidemic and pandemic affecting the supplier. If our major suppliers do not supply products to us in a timely manner or in sufficient quantities, our business, financial condition and operating results may be materially and adversely affected.

8

Furthermore, in the event of any delay in delivery of the products to us, our cash flow or working capital may be materially and adversely affected as a result of the corresponding delay in delivery of our products to our customers, and hence the delay in our receipt of payment from our customers.

Our major suppliers may change their existing sales or marketing strategy in respect of the products supplied to us by changing their export strategy, reducing its sales or production volume or changing its selling prices. Consequently, there are no assurances that our major suppliers will not appoint other dealers or distributors which may compete with us in the market where we operate. Furthermore, any significant increase in the selling prices of the products which we source from our suppliers will increase our costs and may adversely affect our profit margin if we are not able to pass the increased costs on to our customers.

There are no assurances that there will be no deterioration in our relationships with our major suppliers which could affect our ability to secure sufficient supply of products for our business. In the event that our major suppliers change their sales or marketing strategy or otherwise appoint other dealers or distributors who may compete with us, our business, financial condition and operating results may be materially and adversely affected.

We could be adversely affected by a change in consumer preferences, perception and spending habits and failure to develop or enrich our product offering or gain market acceptance of our new products could have a negative effect on our business.

The market we operate is subject to changes in consumer preference, perception and spending habits. Our performance depends significantly on factors which may affect the level and pattern of consumer spending in the market we operate. Such factors include consumer preference, consumer confidence, consumer income and consumer perception of the safety and quality of our products. Media coverage regarding the safety or quality of, or diet or health issues relating to, our products or the raw materials, ingredients or processes involved in their manufacturing, may damage consumer confidence in our products. A general decline in the consumption of our products could occur as a result of change in consumer preference, perception and spending habits at any time.

Any failure to adapt our product offering to respond to such changes may result in a decrease in our sales if such changes are related to certain of our products. Any changes in consumer preference could result in lower sales of our products, put pressure on pricing or lead to increased levels of selling and promotional expenses. In any event a decrease in customer demand on our products may also result in lower sales and slow down the consumption of our inventory to a low inventory turnover level. Any of these changes could result in a material adverse effect on our business, financial conditions or results of operations.

The success of our products depends on a number of factors including our ability to accurately anticipate changes in market demand and consumer preferences, our ability to differentiate the quality of our products from those of our competitors, and the effectiveness of our marketing and advertising campaigns for our products. We may not be successful in identifying trends in consumer preferences and developing products that respond to such trends in a timely manner. We also may not be able to effectively promote our products by our marketing and advertising campaigns and gain market acceptance. If our products fail to gain market acceptance, are restricted by regulatory requirements, or have quality problems, we may not be able to fully recover our costs and expenses incurred in our operation, and our business prospects, financial condition or results of operations may be materially and adversely affected.

If we fail to maintain quality products and value, our sales are likely to be negatively affected.

Our success depends on the safety and quality of products that we obtain from our suppliers for our customers. Our future customers will identify our brand name with a certain level of quality and value. If we cannot meet this perceived value or level of quality, we may be negatively affected and our operating results may suffer. In addition, any failure on the part of our suppliers to maintain the quality of their products, will in turn substantially harm the results of our business operations, potentially forcing us to identify other suppliers or alter our business strategy significantly.

If we are unable to create brand influence, we may not be able to maintain current or attract new users and customers for our products.

Our operational and financial performance is highly dependent on the strength of our brand. We believe brand familiarity and preference will continue to have a significant role in winning customers as the decision to buy our products and services. In order to further expand our customer base, we may need to substantially increase our marketing expenditures to enhance brand awareness through various online and offline means. Moreover, negative coverage in the media of our company could threaten the perception of our brand, and we cannot assure you that we will be able to defuse negative press coverage about our company to the satisfaction of our investors, customers and suppliers. If we are unable to defuse negative press coverage about our company, our brand may suffer in the marketplace, our operational and financial performance may be negatively impacted and the price of our shares may decline.

Currently, we sell our products, with or without customization, under our brand name "ATP", to domestic customers in Malaysia and to overseas customers. However, if our competitors initiate a lawsuit against us for infringing their trademark, we may be forced to adopt a new brand name for our products. As a result, we may incur additional marketing cost to raise awareness of such new brand name. We may also be ordered to pay a significant amount of damages, and our business, results of operations and financial condition could be materially and adversely affected.

9

We may be unable to protect our intellectual property rights.

We rely on intellectual property laws in Malaysia and other jurisdictions to protect our trademarks. We are the registered owner of two trademarks. We have recently applied to register an additional three trademarks in Malaysia. We cannot assure you that counterfeiting or imitation of our products will not occur in the future or, if it does occur, that we will be able to address the problem in a timely and effective manner. Any occurrence of counterfeiting or imitation of our products or other infringement of our intellectual property rights could negatively affect our brand and our reputation, which in turn adversely affects the results of our operations.

Litigation to prosecute infringement of our intellectual property rights could be costly and lengthy and will divert our managerial and financial resources. We will have to bear costs of the intellectual property litigation and may be unable to recover such costs from our opposite parties. Protracted litigation could also result in our customers deferring or limiting their purchase or use of or products until such litigation is resolved. The occurrence of any of the foregoing will have a material adverse effect on our business, financial condition and results of operations.

We may incur losses resulting from product liability claims or product recalls or adverse publicity relating to our products.

We may incur losses resulting from product liability claims with respect to our products supplied by our supplier. We may face claims or liabilities which may arise if there exist any defects in quality of these products or any of these products are deemed or proven to be unsafe, defective or contaminated. In the event that the use or misuse of any product distributed by us results in personal injury or death, product liability and/or indemnity claims may be brought against us, in addition to our product recalls, and the relevant regulatory authorities in the market we operate may close down some of our related operations and take administrative actions against us. If we experience any business disruption and litigation, we may incur additional costs and have to divert our management's attention and resources on such matters, which may adversely affect our business, financial condition and results of operations.

If we are unable to successfully develop and timely introduce new products or services or enhance existing products or services, our business, financial condition and results of operations may be materially and adversely affected.

We must continually source, develop and introduce new products and services as well as improve and enhance our existing products and services to maintain or increase our sales. The success of new or enhanced products or services may depend on a number of factors including, anticipating and effectively addressing user preferences and demand, the success of our sales and marketing efforts, effective forecasting and management of products and services demands, purchase commitments, and the quality of or defects in our products. The risk of not meeting our customers' preferences and demands through our products and services may result in a shift in market shares, as customers instead choose products and services offered by our competitors. This may result in lower sales revenue, materially and adversely affecting our business, financial condition and results of operations.

We may not be able to manage the growth of our business and our expansion plans and operations or implement our business strategies on schedule or within our budget, or at all.

We are continually executing a number of growth initiatives, strategies and operating plans designed to enhance our business. In 2023, we plan to increase our revenue stream from health solution advisory services from our "ATP Zeta Health Program", "ENERGETIQUE" and "BEAUNIQUE" series to align with our growth strategies. The company expects the initiative to materialize in the second half of 2023, despite competition from other health and wellness brands, and challenge in recruiting due to expanding employment market. Any expansion may increase the complexity of our operations and place a significant strain on our managerial, operational, financial and human resources. Our current and planned personnel, systems, procedures and controls may not be adequate to support our future operations. We cannot assure you that we will be able to effectively manage our growth or to implement all these systems, procedures and control measures successfully. Furthermore, the anticipated benefits from these growth initiatives, strategies and operating plans are based on assumptions that may prove to be inaccurate. Moreover, we may not be able to successfully complete these growth initiatives, strategies and operating plans and realize all of the benefits that we expect to achieve or it may be more costly to do so than we anticipate. If, for any reason, we are not able to manage our growth effectively, the benefits we realize are less than our estimates or the implementation of these growth initiatives, strategies and operating plans adversely affects our operations or costs more or takes longer to effectuate than we expect, and/or if our assumptions prove to be inaccurate, our business and prospects may be materially and adversely affected.

In addition, we may seek and pursue opportunities through joint ventures or strategic partnerships for expansion from time to time, and we may face similar risks and uncertainties as listed above. Failure to properly address these risks and uncertainties may materially and adversely affect our ability to carry out acquisitions and other expansion plans, integrate and consolidate newly acquired or newly formed businesses, and realize all or any of the anticipated benefits of such expansion, which may have a material adverse effect on our business, financial condition, results of operations and prospects.

We have a limited operating history in the Malaysia health and wellness industry, which makes it difficult to evaluate our future prospects.

We launched our ATP Zeta Super Health Program business in June 2016, the same month in which our Company was incorporated, followed by our ENERGETIQUE" and "BEAUNIQUE" series in July 2018 and March 2019, respectively, and thus, we have a limited operating history. We have limited experience in most aspects of our business operation, such as sourcing products for and offering advisory services on all the three programs. As our business develops and as we respond to competition, we may continue to introduce new product and services offerings and make adjustments to our existing product line and services and to our business operation in general. Any significant change to our business model that does not achieve expected results may have a material and adverse impact on our financial condition and results of operations. It is therefore difficult to effectively assess our future prospects.

The Malaysia health and wellness industry may not develop as expected. Prospective retail and corporate customers may not be familiar with the development of the market and may have difficulties distinguishing our products from those of our competitors. Convincing prospective customers or distributors of the value of our products or services is important to the success of our business. The risk of failing to convince potential customers or distributors to purchase products or services from us may result in the failure of our business plan. Many customers or distributors may not be interested in purchasing products and services we sell because there is no certainty that our business will succeed.

You should consider our business and prospects in light of the risks and challenges we encounter or may encounter given the rapidly evolving market in which we operate and our limited operating history. These risks and challenges include our ability to, among other things:

? manage our future growth;

? increase the utilization of our products by existing and new customers;

? maintain and enhance our relationships with customers and distributors;

? improve our operational efficiency;

? attract, retain and motivate talented employees;

? cope with economic fluctuations;

? navigate the evolving regulatory environment; and

? defend ourselves against legal and regulatory actions.

Our historical growth rates may not be indicative of our future growth. If we are unable to manage the growth and increased complexity of our business, fail to control our costs and expenses, or fail to execute our strategies effectively, our business and business prospects may be materially and adversely affected.

Our historical growth rates may not be indicative of our future growth, and we may not be able to generate similar growth rates in future periods. Our revenue growth may slow, or our total revenues may decline for a number of possible reasons, including change in consumers' preferences, changes in regulations and government policies, increasing competition, emergence of alternative business models, and general economic conditions.

10

Our total revenues decreased by approximately 15.0% from approximately 0.8 million for the six months ended June 30, 2022 to approximately 0.7 million for the six months ended June 30, 2023. Our total revenues increased by approximately 82.6% from approximately 1.0 million for the year ended December 31, 2021 to approximately 1.9 million for the year ended December 31, 2022. Our gross profits decreased by approximately 28.0% from approximately $0.6 million for the six months ended June 30, 2022 to approximately $0.4 million for the six months ended June 30, 2023.

If our growth rate declines, investors' perceptions of our business and business prospects may be materially and adversely affected and the market price of our shares could decline.

Our lack of insurance could expose us to significant costs and business disruption.

The health and wellness industry in Malaysia is a mature market. We currently do not have any product liability or disruption insurance to cover our operations in Malaysia or overseas, which, based on public information available to us relating to Malaysia-based health and wellness companies, is consistent with customary industry practice in Malaysia. We have determined that the costs of insuring for these risks and the difficulties associated with acquiring such insurance on commercially reasonable terms make it impractical for us to have such insurance. If we suffer any losses, damages or liabilities in the course of our business operations, we may not have adequate insurance coverage to provide sufficient funds to cover any such losses, damages or product claim liabilities. Therefore, there may be instances when we will sustain losses, damages and liabilities because of our lack of insurance coverage, which may in turn materially and adversely affect our financial condition and results of operations.

A decline in general economic condition could lead to reduced consumer demand and could negatively impact our business operation and financial condition, which in turn could have a material adverse effect on our business, financial condition and results of operations.

Our operating and financial performance may be adversely affected by a variety of factors that influence the general economy. Consumer spending habits, including spending for health related products and services we sell, are affected by, among other things, prevailing economic conditions, levels of unemployment, salaries and wage rates, prevailing interest rates, income tax rates and policies, consumer confidence and consumer perception of economic conditions. In addition, consumer purchasing patterns may be influenced by consumers' disposable income. In the event of an economic slowdown, consumer spending habits could be adversely affected and we could experience lower net sales than expected on a quarterly or annual basis which could have a material adverse effect on our business, financial condition and results of operations.

We operate in a heavily regulated industry.

Our business is principally regulated by various laws and regulations in the market we operate, such as in Malaysia the Food Act 1983 (ACT 281) and Regulations, Control of Drugs and Cosmetics Regulations 1984 mandate authorization from the Food Safety and Quality Division and National Pharmaceutical Regulatory Agency of the Ministry of Health for our Company's products to be sold in the country. Various registrations, certificates and/or licenses for the conduct of our business are required under the above laws, which also contain provisions for requirements on the storage, labelling, advertising and importation of some of our products.

Based on our experience, some of the laws and regulations of the place where we operate our business are subject to amendments, uncertainty in interpretation and administrative actions from time to time. Therefore, we cannot assure you that, for the implementation of our business plans and the introduction of any new product, we will be able to obtain all the necessary registrations, certificates and/or licenses. Any failure to comply with the above laws and regulations may give rise to fines, administrative penalties and/or prosecution against us, which may adversely affect our reputation, financial condition or results of operation.

11

We may be adversely affected by the performance of third-party contractors.

We engaged third-party contractors to carry out logistics services. We endeavor to engage third-party companies with a strong reputation and track record, high performance reliability and adequate financial resources. However, any such third-party contractor may still fail to provide satisfactory logistics services at the level of quality or within the timeframe required by us or our customers. While we generally require our logistics contractors to fully reimburse us for any losses arising from delay in delivery or non-delivery, our results of operation and financial condition may be adversely affected if any of the losses are not borne by them. If the performance of any third-party contractor is not satisfactory, we may need to replace such contractor or take other remedial actions, which could adversely affect the cost structure and delivery schedule of our products and services and thus have a negative impact on our reputation, financial position and business operations. In addition, as we expand our business into overseas markets, there may be a shortage of third-party contractors that meet our quality standards and other selection criteria in such locations and, as a result, we may not be able to engage a sufficient number of high-quality third-party contractors in a timely manner, which may adversely affect our delivery schedules and delivery costs and hence our business, results of operations and financial conditions.

We may need additional capital, and financing may not be available on terms acceptable to us, or at all.

There is no guarantee that in the future we will generate enough profits to support our business. Although we believe that our anticipated cash flows from operating activities together with cash on hand will be sufficient to meet our anticipated working capital requirements and capital expenditures in the ordinary course of business for the next twelve months, we cannot assure you this will be the case. We may need additional cash resources in the future if we experience changes in business conditions or other developments. We may also need additional cash resources in the future if we find and wish to pursue opportunities for investment, acquisition, capital expenditure or similar actions. If we determine that our cash requirements exceed the amount of cash and cash equivalents we have on hand at the time, we may seek to issue equity or debt securities or obtain credit facilities. The issuance and sale of additional equity would result in further dilution to our stockholders. The incurrence of indebtedness would result in increased fixed obligations and could result in operating covenants that would restrict our operations. We cannot assure you that financing will be available in amounts or on terms acceptable to us, if at all.

Adverse developments in our existing areas of operation could adversely impact our results of business, results of operations and financial condition.

Our operations are focused on utilizing our sales efforts which are principally located in Malaysia. As a result, our results of operations, cash flows and financial condition depend upon the demand for our products in Malaysia. Due to the lack of broad diversification in industry type and geographic location, adverse developments in our current segment of the industry, or our existing areas of operation, could have a significantly greater impact on our business, results of operations and financial condition than if our operations were more diversified.

Our internal controls may be inadequate, which could cause our financial reporting to be unreliable and lead to misinformation being disseminated to the public.

Our management is responsible for establishing and maintaining adequate internal control over our financial reporting. As defined in Exchange Act Rule 13a-15(f), internal control over financial reporting is a process designed by, or under the supervision of, the principal executive and principal financial officer and effected by the board of directors, management and other personnel, to provide reasonable assurance regarding the reliability of financial reporting and the preparation of financial statements for external purposes in accordance with generally accepted accounting principles and includes those policies and procedures that: pertain to the maintenance of records in reasonable detail accurately and fairly reflect the transactions and dispositions of the assets of the Company; provide reasonable assurance that transactions are recorded as necessary to permit preparation of financial statements in accordance with generally accepted accounting principles, and that receipts and expenditures of the Company are being made only in accordance with authorizations of management and/or directors of the Company; and provide reasonable assurance regarding prevention or timely detection of unauthorized acquisition, use or disposition of the Company's assets that could have a material effect on the financial statements.

12

In connection with the audit of our consolidated financial statements as of December 31, 2022 and the review of our unaudited condensed consolidated financial statements as of June 30, 2023, we identified three "material weaknesses", and other control deficiencies including significant deficiencies in our internal control over financial reporting. A "material weakness" is a deficiency, or a combination of deficiencies, in internal control over financial reporting, such that there is a reasonable possibility that a material misstatement of the company's annual or interim financial statements will not be prevented or detected on a timely basis. The material weaknesses identified related to the Company were: (i) insufficient full-time personnel with appropriate levels of accounting knowledge and experience to monitor the daily recording of transactions, address complex U.S. GAAP accounting issues and to prepare and review financial statements and related disclosures under U.S. GAAP; (ii) lack of a functional internal audit department or personnel that monitors the consistencies of the preventive internal control procedures and lack of adequate policies and procedures in internal audit function to ensure that the Company's policies and procedures have been carried out as planned; (iii) lack of proper IT policies and procedures developed for system change management, user access management, backup management and service organization management.

The plans for the Company's implementation of remediation of the material weaknesses are as follows:

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

As a public company, we will become subject to the Sarbanes-Oxley Act of 2002. Section 404 of the Sarbanes-Oxley Act, or SOX 404, will require that we include a report from management on the effectiveness of our internal control over financial reporting in our annual report on Form 10-K and in our quarterly report on Form 10-Q if we are qualified as an accelerated filer. Our management may conclude that our internal control over financial reporting is not effective. Moreover, even if our management concludes that our internal control over financial reporting is effective, our independent registered public accounting firm, after conducting its own independent testing, may issue a report that is qualified if it is not satisfied with our internal controls or the level at which our controls are documented, designed, operated or reviewed, or if it interprets the relevant requirements differently from us. In addition, after we become a public company, our reporting obligations may place a significant strain on our management, operational and financial resources and systems for the foreseeable future. We may be unable to timely complete our evaluation testing and any required remediation.

During the course of documenting and testing our internal control procedures, in order to satisfy the requirements of SOX 404, we may identify other weaknesses and deficiencies in our internal control over financial reporting. In addition, if we fail to maintain the adequacy of our internal control over financial reporting, as these standards are modified, supplemented or amended from time to time, we may not be able to conclude on an ongoing basis that we have effective internal control over financial reporting in accordance with SOX 404. If we fail to achieve and maintain an effective internal control environment, we could suffer material misstatements in our financial statements and fail to meet our reporting obligations, which would likely cause investors to lose confidence in our reported financial information. This could in turn limit our access to capital markets, harm our results of operations, and lead to a decline in the trading price of our shares. Additionally, ineffective internal control over financial reporting could expose us to increased risk of fraud or misuse of corporate assets and subject us to potential delisting from the stock exchange on which we list, regulatory investigations and civil or criminal sanctions. We may also be required to restate our financial statements from prior periods.

13

Legal disputes or proceedings could expose us to liability, divert our management's attention and negatively impact our reputation.

We may at times be involved in potential legal disputes or proceedings during the ordinary course of business operations relating to product or other types of liability, employees' claims, labor disputes or contract disputes that could have a material and adverse effect on our reputation, operation and financial condition. If we become involved in material or protracted legal proceedings or other legal disputes in the future, the outcome of such proceedings could be uncertain and could result in settlements or outcomes which materially and adversely affect our financial condition. In addition, any litigation or legal proceedings could incur substantial legal expenses as well as significant time and attention of our management, diverting their attention from our business and operations.

Our failure to comply with anti-corruption laws and regulations, or effectively manage our employees, customers and business partners, could severely damage our reputation, and materially and adversely affect our business, financial condition, results of operations and prospects.

We are subject to risks in relation to actions taken by us, our employees, third-party customers or third-party suppliers that constitute violations of the anti-corruption laws and regulations. While we adopt strict internal procedures and work closely with relevant government agencies to ensure compliance of our business operations with relevant laws and regulations, our efforts may not be sufficient to ensure that we comply with relevant laws and regulations at all times. If we, our employees, third-party customers or third-party suppliers violate these laws, rules or regulations, we could be subject to fines and/or other penalties. Actions by Malaysia regulatory authorities or the courts to provide an alternative interpretation of the laws and regulations or to adopt additional anti-bribery or anti-corruption related regulations could also require us to make changes to our operations. Our reputation, corporate image, and business operations may be materially and adversely affected if we fail to comply with these measures or become the target of any negative publicity as a result of actions taken by us, our employees, third-party customers or third-party suppliers.

An overall decline in the health of the economy and other factors impacting consumer spending, such as natural disasters, outbreak of viruses, illnesses, infectious diseases, contagions and the occurrence of unforeseen epidemics may affect consumer purchases, reduce demand for our products and materially harm our business, results of operations and financial condition.

Our business depends on consumer demand for our products and, consequently, is sensitive to a number of factors that influence consumer confidence and spending, including but not limited to, general current and future economic and political conditions, consumer disposable income, recession and fears of recession, unemployment, minimum wages, availability of consumer credit, consumer debt levels, interest rates, tax rates and policies, inflation, war and fears of war, inclement weather, natural disasters, terrorism, active shooter situations, outbreak of viruses, illnesses, infectious diseases, contagions and the occurrence of unforeseen epidemics (including the outbreak of the coronavirus and its potential impact on our financial results) and consumer perceptions of personal well-being and security. For example, in recent years, there have been outbreaks of epidemics in various countries, including Malaysia. Recently, there was an outbreak of a novel strain of coronavirus (COVID-19), which has spread rapidly to many parts of the world, including Malaysia. In March 2020, the World Health Organization declared the COVID-19 a pandemic. The epidemic has resulted in intermittent quarantines, travel restrictions, and the temporary closure of stores and facilities in Malaysia.

Substantially all of our revenues are concentrated in Malaysia. Consequently, our results of operations were adversely affected as a result of the implementation of Movement Control Order (MCO) by the Malaysian government. The impact on the company as a result of the MCO includes:

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

14

    REGISTRATION NO. 333-239951

Because of the uncertainty surrounding the COVID-19 outbreak, the financial impact related to the outbreak of and response to the coronavirus cannot be reasonably estimated at this time. There is no guarantee that our total revenues will grow or remain at the similar level year over year in the fiscal year 2023. We may have to record downward adjustments or impairment in the fair value of investments in the fiscal year 2023, if conditions have not been significantly improved and global stock markets have not recovered from recent declines.

In general, our business could be adversely affected by the effects of epidemics, pandemic or, including, but not limited to, the COVID-19, avian influenza, severe acute respiratory syndrome (SARS), the influenza A virus, Ebola virus, severe weather conditions such as flood or hazardous air pollution, or other outbreaks. In response to an epidemic, severe weather conditions, or other outbreaks, government and other organizations may adopt regulations and policies that could lead to severe disruption to our daily operations, including temporary closure of our offices and other facilities. These severe conditions may cause us and/or our partners to make internal adjustments, including but not limited to, temporarily closing down business, limiting business hours, and setting restrictions on travel and/or visits with clients and partners for a prolonged period of time. Various impact arising from a severe condition may cause business disruption, resulting in material, adverse impact to our financial condition and results of operations.

We face risks related to health epidemics, severe weather conditions and other outbreaks.

In recent years, there have been outbreaks of epidemics in various countries, including Malaysia. Recently, there was an outbreak of a novel strain of coronavirus (COVID-19), which has spread rapidly to many parts of the world, including Malaysia. In March 2020, the World Health Organization declared the COVID-19 a pandemic. The epidemic has resulted in quarantines, travel restrictions, and the temporary closure of stores and facilities in Malaysia for prolong periods.

Substantially all of our revenues are concentrated in Malaysia. Consequently, our results of operations will likely be adversely, and may be materially, affected, to the extent that the COVID-19 or any other epidemic harms the Malaysia and global economy in general. Any potential impact to our results will depend on, to a large extent, future developments and new information that may emerge regarding the duration and severity of the COVID-19 and the actions taken by government authorities and other entities to contain the COVID-19 or treat its impact, almost all of which are beyond our control. Potential impacts include, but are not limited to, the following:

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Fluctuations in foreign currency exchange rates could have a material adverse effect on our financial results.

We earn revenues, pay expenses, own assets and incur liabilities in countries using currencies other than the U.S. dollar, including Australian Dollars, Malaysian Ringgit and Hong Kong Dollars. Since our consolidated financial statements are presented in U.S. dollars, we must translate revenues, income and expenses, as well as assets and liabilities, into U.S. dollars at exchange rates in effect during or at the end of each reporting period. Therefore, increases or decreases in the value of the U.S. dollar against other currencies affect our net operating revenues, operating income and the value of balance sheet items denominated in foreign currencies. We cannot assure you that fluctuations in foreign currency exchange rates, particularly the strengthening or weakening of the U.S. dollar against major currencies would not materially affect our financial results.

Our business depends on the continued contributions made by Dr. How Kok Choong, as our founder, chief executive officer, chief operating officer, chairman of the board of Directors, Director and secretary, the loss of who may result in a severe impediment to our business.,

Our success is dependent upon the continued contributions made by our CEO and President, Dr. How Kok Choong. We rely on his expertise in business operations when we are developing our business. We have no "Key Man" insurance to cover the resulting losses in the event that any of our officer or directors should die or resign.

If Dr. How Kok Choong cannot serve the Company or is no longer willing to do so, the Company may not be able to find alternatives in a timely manner or at all. This would likely result in a severe damage to our business operations and would have an adverse material impact on our financial position and operating results. To continue as a viable operation, the Company may have to recruit and train replacement personnel at a higher cost. Additionally, if Dr. How Kok Choong joins our competitors or develops similar businesses that are in competition with our Company, our business may also be negatively impacted.

Our future success depends on our ability to attract and retain qualified long-term staff to fill management, technology, sales, marketing, and customer services positions. We have a great need for qualified talent, but we may not be successful in attracting, hiring, developing, and retaining the talent required for our success.

15

If we are not able to achieve our overall long-term growth objectives, the value of an investment in our Company could be negatively affected.

We have established and publicly announced certain long-term growth objectives. These objectives were based on, among other things, our evaluation of our growth prospects, which are generally driven by the sales potential of many product types, some of which are more profitable than others, and on an assessment of the potential price and product mix. There can be no assurance that we will realize the sales potential and the price and product mix necessary to achieve our long-term growth objectives.

We may incur losses resulting from product liability claims or product recalls or adverse publicity relating to our products.

We may incur losses resulting from product liability claims with respect to our products supplied by our suppliers. We may face claims or liabilities which may arise if there exist any defects in quality of these products or any of these products are deemed or proven to be unsafe, defective or contaminated. In the event that the use or misuse of any product distributed by us results in personal injury or death, product liability and/or indemnity claims may be brought against us, in addition to our product recalls, and the relevant regulatory authorities in the market we operate may close down some of our related operations and take administrative actions against us. If we experience any business disruption and litigation, we may incur additional costs and have to divert our management's attention and resources on such matters, which may materially and adversely affect our business, financial condition and results of operations.

We had previously relied on the variable interest entity, Agape S.E.A. Sdn Bhd, in Malaysia for our business operations, which may not be as effective in providing operational control or enabling us to derive economic benefits as through ownership of controlling equity interests. While we no longer rely on Agape S.E.A. Sdn Bhd for our operations, we may do so in the future.

Agape S.E.A. Sdn Bhd's equity at risk was insufficient to finance its business activities and it provided all of the Company's purchases during the fiscal years ended December 31, 2020 and 2019. For the six months ended June 30, 2023, Agape S.E.A. Sdn Bhd did not provide any purchase to the Company. As a result, it is considered to be a variable interest entity ("VIE") and the Company is the primary beneficiary since it has both of the following characteristics, (a) the power to direct the activities of the VIE that most significantly impact the VIE's economic performance; and (b) the obligation to absorb losses of the VIE that could potentially be significant to the VIE or the right to receive benefits from the VIE that could potentially be significant to the VIE. However, the Company no longer relied on the VIE after the fiscal year ended December 31, 2020. For the years ended December 31, 2022 and 2021, Agape S.E.A. Sdn Bhd did not provide any purchase to the Company. In addition, Agape S.E.A.'s impact to our consolidated financial statements constitutes less than 1% of our total consolidated assets. While the Company have not made any purchases from the VIE for the six month ended June 30, 2023, we may expect to continue to rely on ASL's beneficiary ownership structure with Agape S.E.A. to operate our business. If we fail to continue our beneficiary ownership structure with Agape S.E.A. in the future, it could have a material adverse effect on our financial condition and results of operations.

16

Risks Related to Doing Business in Malaysia

Developments in the social, political, regulatory and economic environment in Malaysia may have a material adverse impact on us.

Our business, prospects, financial condition and results of operations may be adversely affected by social, political, regulatory and economic developments in Malaysia. Such political and economic uncertainties include, but are not limited to, the risks of war, terrorism, nationalism, nullification of contract, changes in interest rates, imposition of capital controls and methods of taxation.

Negative developments in Malaysia's socio-political environment may adversely affect our business, financial condition, results of operations and prospects. The Malaysian economy registered modest growth of approximately 8.7% and 3.1% in 2022 and 2021 respectively, according to the Department of Statistics Malaysia. Although the overall Malaysian economic environment (in which we predominantly operate) appears to be positive, there can be no assurance that this will continue to prevail in the future. Economic growth is determined by countless factors, and it is extremely difficult to predict with any level of absolute certainty.

Furthermore, on March 11, 2020, the World Health Organization or WHO declared the corona virus or COVID-19 a pandemic. To help counter the transmission of COVID-19, from March 18, 2020 to April 26, 2022, the government of Malaysia initiated (i) Movement control orders ("MCO"). The MCO had resulted in quarantines, travel restrictions, and the temporary closure of stores and facilities in Malaysia. (ii) Conditional Movement Control Order ("CMCO") where most business sectors were allowed to operate under strict rules and Standard Operating Procedures mandated by the government of Malaysia. (iii) Recovery Movement Control Order ("RMCO"). At the height of the pandemic, on January 12, 2021, the Malaysian government even declared a state of emergency nationwide to combat COVID-19. On April 27, 2022, the Malaysian government announced the country had entered into the endemic phase with further easing of restrictions. We are witnessing the adverse impact on the purchasing power of consumers in Malaysia, where our products are mainly sold as a direct result of the prolonged pandemic. As such, the extent to which the coronavirus may continue to adversely impact the Malaysian economy is uncertain. In the event that the Malaysia economy suffers, demand for our products may diminish, which would in turn result in our profitability. This could in turn result in a substantial need for restructuring of our business objectives and could result in a partial or entire loss of an investment in our Company.

We are subject to foreign exchange control policies in Malaysia.

The ability of our subsidiaries to pay dividends or make other payments to us may be restricted by the foreign exchange control policies in the countries where we operate. For example, there are foreign exchange policies in Malaysia which support the monitoring of capital flows into and out of the country in order to preserve its financial and economic stability. The foreign exchange policies are administered by the Foreign Exchange Administration, an arm of Bank Negara Malaysia ("BNM"), the central bank of Malaysia. The foreign exchange policies monitor and regulate both residents and non-residents. Under the current Foreign Exchange Administration rules issued by BNM, non-residents are free to repatriate any amount of funds from Malaysia in foreign currency other than the currency of Israel at any time (subject to limited exceptions), including capital, divestment proceeds, profits, dividends, rental, fees and interest arising from investment in Malaysia, subject to any withholding tax. In the event BNM or any other country where we operate introduces any restrictions in the future, we may be affected in our ability to repatriate dividends or other payments from our subsidiaries in Malaysia or in such other countries. Since we are a holding company and rely principally on dividends and other payments from our subsidiaries for our cash requirements, any restrictions on such dividends or other payments could materially and adversely affect our liquidity, financial condition and results of operations.

Economic, market and political developments in the countries where we operate could have a material and adverse effect on our business.

As with all organizations that seek to reduce business risks via geographical expansion, the economic, market and political conditions in other countries, particularly emerging market conditions in Southeast Asia, could have an influence on our business. Any widespread global financial instability or a significant loss of investor confidence in emerging market economies may materially and adversely affect our business, financial condition, results of operations, prospects or reputation.

Examples of such external factors or conditions that are outside our control include, but are not limited to the following:

? general economic, political and social conditions in Southeast Asian markets;

17

? consumer spending patterns in our key markets;

? currency and interest rate fluctuations;

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

For example, the global financial markets experienced significant disruptions in 2008 and the United States, Europe and other economies went into recession. The recovery from the lows of 2008 and 2009 was uneven and the global economy has continued to face new challenges. There is considerable uncertainty over the long-term effects of the expansionary monetary and fiscal policies that have been adopted by the central banks and financial authorities of some of the world's leading economies, including the United States. For example, in 2013, the Federal Reserve Bank in the United States announced the tapering of its bond-buying program which led to a high degree of volatility in equity markets and substantial devaluations in the currencies of many emerging economies, including markets where we operate. Economic conditions in the countries where we operate might be sensitive to global economic conditions, as well as changes in domestic economic and political policies and the expected or perceived overall economic growth rate in emerging markets. We are witnessing the adverse impact on the purchasing power of consumers in Malaysia, where our products are mainly sold, as a direct result of these worldwide developments.

Management and Governance Risks

Risks Related to our Common Stock and this Offering

Volatility in our shares price may subject us to securities litigation.

The market for our shares may have, when compared to seasoned issuers, significant price volatility and we expect that our share price may continue to be more volatile than that of a seasoned issuer for the indefinite future. In the past, plaintiffs have often initiated securities class action litigation against a company following periods of volatility in the market price of its securities. We may, in the future, be the target of similar litigation. Securities litigation could result in substantial costs and liabilities and could divert management's attention and resources.

We may never be able to pay dividends and are unlikely to do so.

To date, we have not paid, nor do we intend to pay in the foreseeable future, dividends on our common stock, even if we become profitable. Earnings, if any, are expected to be used to advance our activities and for working capital and general corporate purposes, rather than to make distributions to stockholders. Since we are not in a financial position to pay dividends on our common stock and future dividends are not presently being contemplated, investors are advised that return on investment in our common stock is restricted to an appreciation in the share price. The potential or likelihood of an increase in share price is uncertain.

18

In addition, under Nevada law, we may only pay dividends subject to our ability to service our debts as they become due and provided that our assets will exceed our liabilities after the dividend. Our ability to pay dividends will therefore depend on our ability to generate sufficient profits. Furthermore, because of the various rules applicable to our operations in Malaysia and the regulations on foreign investments as well as the applicable tax law, we may be subject to further limitations on our ability to declare and pay dividends to our stockholders.

Stockholders may be diluted significantly through our efforts to obtain financing and satisfy obligations through the issuance of securities.

Wherever possible, our board of directors will attempt to use non-cash consideration to satisfy obligations. In many instances, we believe that the non-cash consideration will consist of shares of our common stock, warrants to purchase shares of our common stock or other securities. In the future, we may issue our authorized but previously unissued equity securities, resulting in the dilution of the ownership interests of our stockholders. We are authorized to issue an aggregate of 1,000,000,000 shares of common stock and 200,000,000 shares of preferred stock. We may issue additional shares of common stock or other securities that are convertible into or exercisable for our common stock in connection with hiring or retaining employees, future acquisitions, future sales of our securities for capital raising purposes, or for other business purposes. The future issuance of any such additional shares of our common stock may create downward pressure on the trading price of the common stock. We expect we will need to raise additional capital in the near future to meet our working capital needs, and there can be no assurance that we will not be required to issue additional shares, warrants or other convertible securities in the future in conjunction with these capital raising efforts, including at a price (or exercise prices) below the price you paid for your stock.

We are a "smaller reporting company," and we cannot be certain if the reduced disclosure requirements applicable to smaller reporting companies will make our common stock less attractive to investors.

We are currently a "smaller reporting company", meaning that we are not an investment company, an asset- backed issuer, or a majority-owned subsidiary of a parent company that is not a smaller reporting company and annual revenues of less than $50.0 million during the most recently completed fiscal year. In the event that we are still considered a "smaller reporting company," at such time as we cease being an "emerging growth company," we will be required to provide additional disclosure in our SEC filings. However, similar to an "emerging growth companies", "smaller reporting companies" are able to provide simplified executive compensation disclosures in their filings; are exempt from the provisions of Section 404(b) of the Sarbanes-Oxley Act requiring that independent registered public accounting firms provide an attestation report on the effectiveness of internal control over financial reporting; and have certain other decreased disclosure obligations in their SEC filings, including, among other things, only being required to provide two years of audited financial statements in annual reports. Decreased disclosures in our SEC filings due to our status as a "smaller reporting company" may make it harder for investors to analyze our results of operations and financial prospects.

19

The offering price of our shares of common stock offered in the Resale Prospectus Resale is fixed.

The selling stockholders of the Resale Prospectus will offer and sell their shares of common stock being offered under the Resale Prospectus at $4.00 per share for the duration of the offering or until the shares are listed on a national securities exchange at which time the shares offered under the Resale Prospectus may be sold at prevailing market prices or privately negotiated prices or in transactions that are not in the public market.

Our common stock have started trading on the NASDAQ Capital Market ("NASDAQ") under the symbol "ATPC" on October 11, 2023.

We plan to list our common stock on NASDAQ. We may not be able to maintain our listing on NASDAQ which could limit investors' ability to make transactions in our securities and subject us to additional trading restrictions.

Our common stock have started trading on the NASDAQ Capital Market ("NASDAQ") under the symbol "ATPC" on October 11, 2023. Even if our common stock is approved to be listed on NASDAQ, we cannot assure you that our common stock will continue to be listed on NASDAQ in the future. In order to continue listing our securities on NASDAQ, we must maintain certain financial, distribution and share price levels. Moreover, we must comply with certain listing standards regarding the independence of our board of directors and members of our audit committee. We intend to fully comply with these requirements, but we may not continue to be able to meet these requirements in the future.

If NASDAQ delists our securities from trading on its exchange and we are not able to list our securities on another national securities exchange, we expect our securities could be quoted on an over-the-counter market. If this were to occur, we could face significant material adverse consequences, including:

? a limited availability of market quotations for our securities;

? reduced liquidity for our securities;

    REGISTRATION NO. 333-239951

? a limited amount of news and analyst coverage; and

    REGISTRATION NO. 333-239951

The National Securities Markets Improvement Act of 1996, which is a federal statute, prevents or preempts the states from regulating the sale of certain securities, which are referred to as "covered securities." Because we expect that our common stock will be listed on NASDAQ, such securities will be covered securities. Although the states are preempted from regulating the sale of our securities, the federal statute does allow the states to investigate companies if there is a suspicion of fraud, and, if there is a finding of fraudulent activity, then the states can regulate or bar the sale of covered securities in a particular case. Furthermore, if we were no longer listed on NASDAQ, our securities would not be covered securities and we would be subject to regulations in each state in which we offer our securities.

The price of our common stock may rapidly fluctuate or may decline regardless of our operating performance, resulting in substantial losses for investors.

The trading price of our common stock following this offering may be subject to instances of extreme stock price run-ups followed by rapid price declines and stock price volatility unrelated to both our actual and expected operating performance and financial condition or prospects, making it difficult for prospective investors to assess the rapidly changing value of our stock. Further, the trading price of our common stock following this offering is likely to be highly volatile and could be subject to wide fluctuations in response to various factors, some of which are beyond our control, including limited trading volume, actual or anticipated fluctuations in our results of operations; the financial projections we may provide to the public, any changes in these projections or our failure to meet these projections; failure of securities analysts to initiate or maintain coverage of our Company, changes in financial estimates or ratings by any securities analysts who follow our Company or our failure to meet these estimates or the expectations of investors; announcements by us or our competitors of significant innovations, acquisitions, strategic partnerships, joint ventures, operating results or capital commitments; changes in operating performance and stock market valuations of other companies in our industry; price and volume fluctuations in the overall stock market, including as a result of trends in the economy as a whole; changes in our Board or management; sales of large blocks of our common stock, including sales by our executive officers, directors and significant stockholders; lawsuits threatened or filed against us; changes in laws or regulations applicable to our business; the expiration of lock-up agreements; changes in our capital structure, such as future issuances of debt or equity securities; short sales, hedging and other derivative transactions involving our capital stock; general economic and geopolitical conditions, including the current or anticipated impact of military conflict and related sanctions imposed on Russia by the United States and other countries due to Russia's recent invasion of Ukraine; and the other factors described in this section of the prospectus captioned "Risk Factors."

Certain recent initial public offerings of companies with relatively small public floats have experienced extreme volatility that was seemingly unrelated to the underlying performance of the respective company. Our common stock may potentially experience rapid and substantial price volatility, which may make it difficult for prospective investors to assess the value of our common stock.

In addition to the risks addressed above under "the price of our common stock may rapidly fluctuate or may decline regardless of our operating performance, resulting in substantial losses for investors," our common stock may be subject to rapid and substantial price volatility. We may experience extreme stock price volatility unrelated to our actual or expected operating performance, financial condition or prospects, making it difficult for prospective investors to assess the rapidly changing value of our common stock. Recently, there have been instances of extreme stock price run-ups followed by rapid price declines and strong stock price volatility with a number of recent initial public offerings, especially among companies with relatively smaller public floats. As a relatively small-capitalization company, we may experience greater stock price volatility, extreme price run-ups, lower trading volume and less liquidity than large-capitalization companies. In particular, our common stock may be subject to rapid and substantial price volatility, low volumes of trades and large spreads in bid and ask prices. Such volatility, including any stock-run up, may be unrelated to our actual or expected operating performance, financial condition or prospects, making it difficult for prospective investors to assess the rapidly changing value of our common stock.

In addition, if the trading volumes of our common stock are low, persons buying or selling in relatively small quantities may easily influence prices of our common stock. This low volume of trades could also cause the price of our common stock to fluctuate greatly, with large percentage changes in price occurring in any trading day session. Holders of our common stock may also not be able to readily liquidate their investment or may be forced to sell at depressed prices due to low volume trading. Broad market fluctuations and general economic and political conditions may also adversely affect the market price of our common stock. As a result of this volatility, investors may experience losses on their investment in our common stock. A decline in the market price of our common stock also could adversely affect our ability to issue additional common stock or other securities and our ability to obtain additional financing in the future. No assurance can be given that an active market in our common stock will develop or be sustained. If an active market does not develop, holders of our common stock may be unable to readily sell the shares they hold or may not be able to sell their shares at all.

20

    REGISTRATION NO. 333-239951

This prospectus contains forward-looking statements, including, without limitation, in the sections captioned "Risk Factors", "Management's Discussion and Analysis of Financial Condition and Plan of Operations", and "Business". Known and unknown risks, uncertainties and other factors, including those listed under "Risk Factors," may cause our actual results, performance or achievements to be materially different from those expressed or implied by the forward-looking statements.

You can identify some of these forward-looking statements by words or phrases such as "may," "will," "expect," "anticipate," "aim," "estimate," "intend," "plan," "believe," "is/are likely to," "potential," "continue" or other similar expressions. We have based these forward-looking statements largely on our current expectations and projections about future events that we believe may affect our financial condition, results of operations, business strategy and financial needs. These forward-looking statements include statements relating to:

? Our goals and strategies;

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

? Our ability to attract and retain management;

    REGISTRATION NO. 333-239951

? The intensity of competition;

? General economic conditions;

? Changes in regulations;

? Relevant government policies and regulations relating to our industry;

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

? The impact of COVID-19 on business environment and consumer preference.

These forward-looking statements involve various risks and uncertainties. Although we believe that our expectations expressed in these forward-looking statements are reasonable, our expectations may later be found to be incorrect. Our actual results could be materially different from our expectations. Important risks and factors that could cause our actual results to be materially different from our expectations are generally set forth in "Risk Factors," "Management's Discussion and Analysis of Financial Condition and Results of Operations," "Business" and other sections in this prospectus. You should thoroughly read this prospectus and the documents that we refer to with the understanding that our actual future results may be materially different from and worse than what we expect. We qualify all of our forward-looking statements by these cautionary statements.

This prospectus contains certain data and information that we obtained from private publications. Statistical data in these publications also include projections based on a number of assumptions. Our industry may not grow at the rate projected by market data, or at all. Failure of this market to grow at the projected rate may have a material and adverse effect on our business and the market price of our common stock. In addition, the rapidly changing nature of the health and wellness industry results in significant uncertainties for any projections or estimates relating to the growth prospects or future condition of our market. Furthermore, if any one or more of the assumptions underlying the market data are later found to be incorrect, actual results may differ from the projections based on these assumptions. You should not place undue reliance on these forward-looking statements.

The forward-looking statements made in this prospectus relate only to events or information as of the date on which the statements are made in this prospectus. Except as required by law, we undertake no obligation to update or revise publicly any forward-looking statements, whether as a result of new information, future events or otherwise, after the date on which the statements are made or to reflect the occurrence of unanticipated events. You should read this prospectus and the documents that we refer to in this prospectus and have filed as exhibits to the registration statement, of which this prospectus is a part, completely and with the understanding that our actual future results may be materially different from what we expect.

21

    REGISTRATION NO. 333-239951

We estimate that we will receive net proceeds from this offering of approximately $5.76 million, or approximately $6.66 million if the Underwriter exercises its over-allotment option in full, after deducting underwriting discounts, non-accountable expense allowance and the estimated offering expenses payable by us.

The primary purposes of this offering are to create a public market of our shares for the benefit of all stockholders, retain talented employees, and obtain additional capital. We plan to use the net proceeds of this offering as follows:

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

The amounts and timing of our actual expenditures will depend on numerous factors, including the factors described under "Risk Factors." The foregoing represents our current intentions based upon our present plans and business conditions to use and allocate the net proceeds of this offering. Our management, however, will have significant flexibility and discretion to apply the net proceeds of this offering. If an unforeseen event occurs or business conditions change, we may use the proceeds of this offering differently than as described in this prospectus.

22

    REGISTRATION NO. 333-239951

We have never declared or paid any cash dividends on our common stock. We currently intend to retain all of our future earnings, if any, to finance the growth and development of our business. We do not intend to pay cash dividends to holders of our common stock in the foreseeable future.

23

    REGISTRATION NO. 333-239951

The following table describes our capitalization as of June 30, 2023:

? on an actual basis; and

    REGISTRATION NO. 333-239951

The as adjusted information below is illustrative only and our capitalization following the completion of this offering is subject to adjustment based on the public offering price of our common stock and other terms of this offering determined at pricing. In addition, except for the last column in the first table below, the tables below assume that the Underwriter over-allotment option has not been exercised. You should read this capitalization table together with our consolidated financial statements and the related notes appearing elsewhere in this prospectus and the "Management's Discussion and Analysis of Financial Condition and Results of Operations" section and other financial information included elsewhere in this prospectus.

    REGISTRATION NO. 333-239951

(1) Gives effect to the sale of common stock at a public offering price of $4.00 per share and to reflect the application of the proceeds after deducting our estimated offering expenses.

(2) Pro forma adjusted for IPO additional paid in capital reflects the net proceeds we expect to receive, after deducting the Underwriter discount of 8%, non-accountable expense allowance of 1% and other expenses (all the accountable expenses). We expect to receive net proceeds of $5,759,228 ($6,600,000 offering, less underwriting fee of $528,000, non-accountable expenses of $66,000 and other offering expenses of $768,834, including $522,062 which has already been paid by the Company). For an itemization of an estimation of the total offering expenses, see "Item 13. Other Expenses of issuance and Distribution" beginning on page II-1 of this prospectus.

(3) Pro forma adjusted for IPO additional paid in capital including the Underwriter's over-allotment option reflects the net proceeds we expect to receive after the under exercise the over-allotment option in full and after deducting the underwriting discount of 8%, non-accountable expense allowance of 1% and other expenses (all the accountable expenses). We expect to receive net proceeds of $6,660,128 ($7,590,000 offering, less underwriting fee of $607,200, non-accountable expenses of $75,900 and other offering expenses of $768,834, including $522,062 which has already been paid by the Company). For an itemization of an estimation of the total offering expenses, see "Item 13. Other Expenses of issuance and Distribution" beginning on page II-1 of this prospectus.

24

    REGISTRATION NO. 333-239951

If you invest in our common stock in this offering, your ownership interest will be diluted immediately to the extent of the difference between the public offering price per share of our common stock and the as adjusted net tangible book value per share of our common stock immediately after this offering.

Dilution results from the fact that the per share offering price is substantially in excess of the book value per share of common stock attributable to the existing stockholders for our presently outstanding shares of common stock. Net tangible book value per share is determined by dividing our total tangible assets less our total liabilities by the number of shares of our common stock outstanding. Our historical net tangible book value as of June 30, 2023, was $(82,699) or $(0.00) per share.

Our post offering as adjusted net tangible book value, which gives effect to receipt of the net proceeds from the offering and issuance of additional shares in the offering but does not take into consideration any other changes in our net tangible book value after June 30, 2023, will be approximately $5,676,529 or approximately $0.07 per share. This would result in dilution to investors in this offering of approximately $3.93 per share or approximately 98.16% from the assumed offering price of $4.00 per share. Net tangible book value per share would increase to the benefit of present stockholders by $0.07 per share attributable to the purchase of the shares by investors in this offering.

The following table sets forth the estimated net tangible book value per share after the offering and the dilution to persons purchasing shares.

    REGISTRATION NO. 333-239951

(1) Assumes gross proceeds from offering of 1,650,000 shares of common stock. (2) Assumes gross proceeds from offering of 1,897,500 shares of common stock, if over-allotment option is exercised in full.

The following chart illustrates our pro forma proportionate ownership, upon completion of the offering, by present stockholders and investors in this offering, compared to the relative amounts paid by each. The charts reflect payment by present stockholders as of the date the consideration was received and by investors in this offering at the offering price without deduction of the estimated underwriting discount, non-accountable expense allowance and our estimated offering expenses. The charts further assume no changes in net tangible book value other than those resulting from the offering.

    REGISTRATION NO. 333-239951

(1) Assuming the offering is fully subscribed.

25

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

The following table presents selected consolidated financial data for the periods and at the dates indicated. The selected condensed consolidated statements of operations data for the three and six months ended June 30, 2023 and 2022, and the selected condensed consolidated balance sheet data as of June 30, 2023 and December 31, 2022 have been derived from our condensed consolidated financial statements, included elsewhere in this prospectus. The selected consolidated statements of operations data for the years ended December 31, 2022 and 2021, and the selected consolidated balance sheet data as of December 31, 2022 and 2021 have been derived from our consolidated financial statements, included elsewhere in this prospectus. Our historical results for any prior period are not necessarily indicative of results to be expected in any future period, and our results for any interim period are not necessarily indicative of the results expected for a full fiscal year.

You should read the following financial information together with the information under "Agape ATP Corporation Management's Discussion and Analysis of Financial Condition and Results of Operations" and our consolidated financial statements and the related notes included elsewhere in this prospectus.

Consolidated Statements of Operations Data:

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Consolidated Balance Sheets Data:

    REGISTRATION NO. 333-239951

Current assets $ 941,436 $ 2,028,534 $ 3,912,122 Total assets $ 1,905,283 $ 2,791,749 $ 4,724,535 Current liabilities $ 968,329 $ 1,229,295 $ 1,312,841 Total liabilities $ 1,154,629 $ 1,229,295 $ 1,411,899 Total equity $ 750,654 $ 1,562,454 $ 3,312,636

26

    REGISTRATION NO. 333-239951

MANAGEMENT'S DISCUSSION AND ANALYSIS OF FINANCIAL CONDITIONS AND

    REGISTRATION NO. 333-239951

You should read the following discussion and analysis of our financial condition and results of operations in conjunction with the section headed "Selected Consolidated Financial and Operating Data" and our consolidated financial statements and the related notes included elsewhere in this prospectus. This discussion contains forward-looking statements that involve risks and uncertainties. Our actual results and the timing of selected events could differ materially from those anticipated in these forward-looking statements as a result of various factors, including those set forth under "Risk Factors" and elsewhere in this prospectus.

Company Overview

The Company and its subsidiaries are principally engaged in the health and wellness industry. The principal activity of the Company is to supply high-quality health and wellness products, including supplements to assist in cell metabolism, detoxification, blood circulation, anti-aging and products designed to improve the overall health system of the human body and various wellness programs.

Agape ATP Corporation, a Nevada corporation ("the Company") was incorporated under the laws of the State of Nevada on June 1, 2016.

Agape ATP Corporation operates through its subsidiaries, namely, Agape ATP Corporation, a company incorporated in Labuan, Malaysia, and Agape Superior Living Sdn. Bhd. ("ASL"), a company incorporated in Malaysia.

Agape ATP Corporation is an investment holding company that holds 100% of the equity interest in Agape ATP International Holding Limited, a company incorporated in Hong Kong.

On May 8, 2020, the Company entered into a Share Exchange Agreement with Dr. How Kok Choong, CEO and director of the Company to acquire 9,590,596 ordinary shares, no par value, equivalent to approximately 99.99% of the equity interest in ASL.

On September 11, 2020, the Company incorporated WATP, a wholly owned subsidiary under the laws of Malaysia, to pursue the business of promoting wellness and wellbeing lifestyle of the community by providing services that includes online editorials, programs, events and campaigns on how to achieve positive wellness and lifestyle. On September 15, 2020, WATP entered into a business collaboration agreement with ASL to carry out certain wellness programs.

On November 11, 2021, Agape ATP Corporation (Labuan) formed a joint-venture entity, DSY Wellness International Sdn. Bhd. ("DSY Wellness") with Mr. Steve Yap. to pursue the business of providing complementary health therapies. Agape ATP Corporation (Labuan) owns 60% of the equity interests in DSY Wellness.

Agape ATP Corporation is a company that provides health and wellness products and health solution advisory services to our clients. The Company primarily focuses its efforts on attracting customers in Malaysia. Its advisory services center on the "ATP Zeta Health Program", which is a health program designed to prevent diseases caused by polluted environments, unhealthy dietary intake and unhealthy lifestyles, and the promotion of health. The program aims to promote improved health and longevity through a combination of modern medicine, proper nutrition and advice from skilled nutritionists and/or dieticians.

27

In order to strengthen the Company's supply chain, on May 8, 2020, the Company successfully acquired approximately 99.99% of ASL, with the goal of securing an established network marketing sales channel that has been established in Malaysia for the past 18 years. ASL has been offering the Company's ATP Zeta Health Program as part of its product lineup. As such, the acquisition creates synergy in the Company's operation by boosting the Company's retail and marketing capabilities. The acquired subsidiary allows the Company to fulfill its mission of "helping people to create health and wealth" by providing a financially rewarding business opportunity to distributors and quality products to distributors and customers who seek a healthy lifestyle.

Via ASL, the Company offers three series of programs which consist of different services and products: ATP Zeta Health Program, ENERGETIQUE and BEAUNIQUE.

The ATP Zeta Health Program is a health program designed to promote health and general wellbeing designed to prevent health diseases caused by polluted environments, unhealthy dietary intake and unhealthy lifestyles. The program aims to promote improved health and longevity through a combination of modern health supplements, proper nutrition and advice from skilled dieticians as well as trained members and distributors.

The ENERGETIQUE series aims to provide a total dermal solution for a healthy skin beginning from the cellular level. The series is comprised of the Energy Mask series, Hyaluronic Acid Serum and Mousse Facial Cleanser.

The BEAUNIQUE product series focuses on the research of our diet's impact on modifying gene expressions in order to address genetic variations and deliver a nutrigenomic solution for every individual.

The Company deems creating public awareness on wellness and wellbeing lifestyle as essential to enhance the provision of its health solution advisory services; and therefore incorporated WATP in September 2020. Upon its establishment, WATP started collaborating with ASL to carry out various wellness programs.

To further its reach in the Health and Wellness Industry, on November 11, 2021, Agape ATP Corporation (Labuan) formed a joint-venture entity, DSY Wellness International Sdn. Bhd. ("DSY Wellness") with Mr. Steve Yap to pursue the business of providing complementary health therapies. Agape ATP Corporation (Labuan) owns 60% of the equity interests in DSY Wellness.

Results of Operation

For the three months ended June 30, 2023 and 2022

Revenue

We generated revenue of $303,935, which comprised revenue from the Company's network marketing business of $90,662 (approximately 29.8%); and revenue from the Company's operations in the provision of complementary health therapies of $213,273 (approximately 70.2%) for the three months ended June 30, 2023 as compared to $396,707, which comprised revenue from the Company's network marketing business of $184,534 (approximately 46.5%); and revenue from the Company's operations in the provision of complementary health therapies of $212,173 (approximately 53.5%) for the three months ended June 30, 2022. Revenue from the Company's network marketing business decreased significantly by $93,872, or approximately 50.9%. Revenue from the Company's operations in the provision of complementary health therapies increased marginally by $1,100, or approximately 0.5%. Total revenue decreased by $92,772, or approximately 23.4%. The decrease was predominately due to the anticipated poor performance from the Company's network marketing business. The Company is in the process of introducing a new range of products for its networking marketing business. Distributors and members curtailed the purchases of the Company's existing products, awaiting the Company's new products range. The launch of the Company's new products was delayed and is expected to take place in Q2 2024.

Cost of Revenue

Cost of revenue for the three months ended June 30, 2023 amounted to $107,931 as compared to $109,383 for the three months ended June 30, 2022, a marginal decrease of $1,452, or approximately 1.3%. Cost of revenue did not decrease in tandem with decrease in revenue for the period due to the varying gross profit margins associated with the provision of complementary health therapies.

Cost of revenue typically comprise of freight-in, cost of goods purchased, packing materials and services acquired.

28

Gross Profit

Gross profit for the three months ended June 30, 2023 amounted to $196,004 and represented a gross margin of approximately 64.5% as compared to $287,324 for the three months ended June 30, 2022, equivalent to a gross margin of approximately 72.4%. The decrease in gross margin was predominantly due to lower gross margin associated with the provision of complementary health therapies as compared to the Company's network marketing business.

Operating Expenses

Our operating expenses consist of selling expenses, commission expenses and G&A expenses (as defined below). Total operating expenses were $555,537 for the three months ended June 30, 2023, increased by $37,970 or approximately 6.4% from $593,507 for the three months ended June 30, 2022.

Selling expenses

Selling expenses for the three months ended June 30, 2023 amounted to $64,126 as compared to $79,587 for the three months ended June 30, 2022, a decrease of $15,461, or approximately 19.4%. The Company's selling expenses are comprised of salaries and benefits expenses which represented approximately 70% to 85% of total selling expenses, credit card processing fees and promotional expenses.

Commission expenses

Commission expenses were $21,942 and $62,557 for the three months ended June 30, 2023 and 2022, respectively. The decrease in commission expenses was in line with the decrease in revenue.

General and administrative expenses ("G&A Expenses")

G&A expenses for the three months ended June 30, 2023 amounted to $469,469, as compared to $451,363 for the three months ended June 30, 2022, an increase of $18,106, or approximately 4.0%. The Company's G&A expenses are comprised of salaries and benefits expenses, rental expenses, professional expenses and depreciation expenses.

Other Expenses, Net

For the three months ended June 30, 2023, we recorded an amount of $22,355 as other expenses, net, as compared to $97,769 other expenses, net, for the three months ended June 30, 2022, which represented a decrease of $75,414, or approximately 77.1%.

The net other expenses of $22,355 incurred during the three months ended June 30, 2023 comprised foreign currency exchange loss of $33,700, unrealized holding gain on marketable securities of $3,790, other income, net of $4,134, interest income of $1,634 and gain on disposal of property and equipment of $1,787. The net other expenses of $97,769 incurred during the three months ended June 30, 2022 comprised foreign currency exchange loss of $67,417, unrealized holding loss on marketable securities of $35,219, other income, net of $1,341 and interest income of $3,526.

Benefit of (Provision for) Income Taxes

The Company recorded benefit of income taxes of $2,439 and provision for income taxes of $392 for the three months ended June 30, 2023 and 2022, respectively. Both the benefit of income taxes as well as the provision for income taxes were in respect of the Company's operations in Malaysia.

29

Net Loss

Net loss decreased by $24,895 from net loss of $404,344 for the three months ended June 30, 2022 to net loss of $379,449 for the three months ended June 30, 2023, mainly due to the reasons discussed above.

For the six months ended June 30, 2023 and 2022

Revenue

We generated revenue of $684,703, which is comprised of revenue from the Company's network marketing business of $229,521 (approximately 33.5%); and revenue from the Company's operations in the provision of complementary health therapies of $455,182 (approximately 66.5%) for the six months ended June 30, 2023 as compared to $805,667, which is comprised of revenue from the Company's network marketing business of $558,340 (approximately 69.3%); and revenue from the Company's operations in the provision of complementary health therapies of $247,327 (approximately 30.7%) for the six months ended June 30, 2022. Revenue from the Company's network marketing business decreased significantly by $329,819, or approximately 58.9%. Revenue from the Company's operations in the provision of complementary health therapies increased significantly by $207,855, or approximately 84.0%. Total revenue decreased by $120,964, or approximately 15.0%. The decrease was predominately due to the anticipated poor performance from the Company's network marketing business. The Company is in the process of introducing a whole new range of products for its networking marketing business. Distributors and members curtailed the purchases of the Company's existing products, awaiting the Company's new products range. The shortfall in revenue of the Company's network marketing business was significantly compensated by the significant increase in revenue in the Company's operations in the provision of complementary health therapies. This new division which commenced in February 2022 is witnessing modest growth.

Cost of Revenue

Cost of revenue for the six months ended June 30, 2023 amounted to $236,289 as compared to $182,814 for the six months ended June 30, 2022, an increase of $53,475, or approximately 29.3%. The increase was due to the varying gross profit margins in the Company's operations in the provision of complementary health therapies.

Cost of revenue typically comprise of freight-in, cost of goods purchased, packing materials and services acquired.

Gross Profit

Gross profit for the six months ended June 30, 2023, amounted to $448,414, which represented a gross margin of approximately 65.5% as compared to $622,853 for the six months ended June 30, 2022, equivalent to a gross margin of approximately 77.3%. The decrease in gross margin was predominantly due to lower gross margin associated with the provision of complementary health therapies as compared to the Company's network marketing business.

30

Operating Expenses

Our operating expenses consist of selling expenses, commission expenses, general and administrative expenses. Total operating expenses were $1,261,831 for the six months ended June 30, 2023, increased by $60,563 or approximately 5.0% from $1,201,268 for the six months ended June 30, 2022.

Selling expenses

Selling expenses for the six months ended June 30, 2023 amounted to $140,224 as compared to $194,198 for the six months ended June 30, 2022, a decrease of $53,974, or approximately 27.8%, predominantly due to decrease in promotional expenses. Promotional activities on the Company's network marketing business were scaled back during the time lag between phasing out of the old products range awaiting the upcoming new range of products. The Company's selling expenses are typically comprised of salaries and benefits expenses which represented approximately 70% to 85% of total selling expenses, credit card processing fees and promotional expenses. There was also a small reduction in the number of headcounts in the recent six months ended June 30, 2023.

Commission expenses

Commission expenses were $55,884 and $176,666 for the six months ended June 30, 2023 and 2022, respectively. The decrease in commission expenses was in line with the decrease in revenue.

General and administrative expenses ("G&A expenses")

G&A expenses for the six months ended June 30, 2023 amounted to $1,065,723, as compared to $830,404 for the six months ended June 30, 2022, an increase of $235,319, or approximately 28.3%. The increase in G&A expenses was mainly due to G&A expenses associated with the provision of complementary health therapies and expenses incurred by the Company on its on-going uplisting exercise to Nasdaq. The Company's G&A expenses are typically comprised of salaries and benefits expenses, rental expenses, professional expenses and depreciation expenses.

Other Expenses, Net

For the six months ended June 30, 2023, we recorded an amount of $6,762 as other expenses, net, as compared to $115,695 other expenses, net, for the six months ended June 30, 2022, represented a decrease of $108,933 or approximately 94.2%.

The net other expenses of $6,762 incurred during the six months ended June 30, 2023 comprised foreign currency exchange loss of $34,576, unrealized holding gain on marketable securities of $8,710, other income, net of $12,500, interest income of $4,817 and gain on disposal of property and equipment of $1,787. The net other expenses of $115,695 incurred during the six months ended June 30, 2022 comprised foreign currency exchange loss of $83,883, unrealized holding loss on marketable securities of $52,889, other income, net of $12,826 and interest income of $8,251.

Benefit of (Provision for) Income Taxes

The Company recorded benefit of income taxes of $6,655 and provision for income taxes of $8,680 for the six months ended June 30, 2023 and 2022, respectively. Both the benefit of income taxes as well as the provision for income taxes were in respect of the Company's operations in Malaysia.

Net Loss

Net loss increased by $110,734 from net loss of $702,790 for the six months ended June 30, 2022 to net loss of $813,524 for the six months ended June 30, 2023, mainly due to reasons as discussed above.

Liquidity and Capital Resources

Malaysia, where the operations of the Company predominantly reside, officially transitioned to the endemic phase of COVID-19 effective April 1, 2022.

Substantially all of our revenues are concentrated in Malaysia. Consequently, our results of operations will likely be adversely, and may be materially, affected, to the extent that the COVID-19 or any other epidemic harms the Malaysia and global economy in general. Any potential impact to our results will depend on, to a large extent, future developments and new information that may emerge regarding the duration and severity of the COVID-19 and the actions taken by government authorities and other entities to contain the COVID-19 or treat its impact, almost all of which are beyond our control. Potential impacts include, but are not limited to, the following:

    REGISTRATION NO. 333-239951

31

There could still be supply chain disruptions. From our experiences operating under the much-restricted COVID-19 environment, we have modified our methods of operations, to build in sufficient buffer in the management of inventories. We may experience slight delay in products delivery lead time but barring unforeseen circumstances, the setback should be temporary.

We are currently operating primarily in Malaysia and anticipate expanding into the Asian markets in the future, with a particular focus, at least initially, on expanding into Thailand, Indonesia and Taiwan. We will explore expansion via e-commerce. Now that most nations are living alongside COVID-19, we will re-assess our plans to set up offices in the countries in which we operate to better service our customers.

There is no guarantee that the Company's total revenues will grow or remain at similar levels year over year in 2023 and beyond.

As of June 30, 2023, we had working capital deficit of $26,893, consisting of cash and cash in bank of $332,431 and time deposits of $321,323 as compared to working capital of $799,239 consisting of cash and cash in bank of $523,619 and time deposits of $914,811 as of December 31, 2022. The Company had a net loss of $813,524 for the six months ended June 30, 2023 and accumulated deficits of $5,746,112 as of June 30, 2023 as compared to net loss of $1,666,079 for the year ended December 31, 2022 and accumulated deficits of $4,945,586 as of December 31, 2022.

In assessing our liquidity and going concern, management is projecting that the company's revenue will revert to pre-pandemic level by Q2 2024, generating sufficient cash therefrom to cover our operating expenses. The timeline is subject to the availability of talents for sales and marketing and product development personnel as the recruitment market has become increasingly competitive post COVID-19 as many companies are ramping up to increase their workforce.

If our Company is unable to generate sufficient cash flow within the normal operating cycle of a twelve-month period to pay for its future payment obligations, we may have to consider supplementing our available sources of funds through the following sources, however, there is no assurance that management will be successful in its plans:

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Based on the above measures, management is of the opinion that the Company will probably not have sufficient funds to meet its working capital requirements and debt obligations as they become due one year from the filing date of these unaudited condensed consolidated financial statements..

The following summarizes the key components of our cash flows for the six months ended June 30, 2023 and 2022:

    REGISTRATION NO. 333-239951

Net cash used in operating activities $ (742,175) $ (495,727) Net cash used in investing activities (6,499) (750) Net cash used in financing activities (22,861) (178,926) Effect of exchange rate on cash and cash equivalents (13,141) (115,008) Net change in cash and cash equivalents $ (784,676) $ (790,411)

32

Operating activities

Net cash used in operating activities for the six months ended June 30, 2023 was $742,175, comprised of net loss of $813,524, increase in accounts receivables of $2,751, increase in amount due from related parties of $209, increase in inventories of $23,013, decrease in accounts payable - related parties of $4,758, decrease in customer deposits of $31,655, decrease in other payables and accrued liabilities of $228,812, payment of operating lease liabilities of $79,551, decrease in other payable -related parties of $3,457, the non-cash expenses on unrealized holding gain on marketable securities of $8,710, deferred tax benefit of $6,655, offset by the non-cash depreciation and amortization expense of $39,264, amortization of operating right-of-use assets of $78,333, decrease in prepaid taxes of $238,064, decrease in prepayments and deposits of $80,651 and increase in accounts payable of $24,608.

Net cash used in operating activities for the six months ended June 30, 2022 was $495,727 and were mainly comprised of the net loss of $702,790, increase in accounts receivables of $214, decrease in customer deposits of $175,936, payment of operating lease liabilities of $75,200 and decrease in other payables and accrued liabilities (including related party) of $164,056. The net cash used in operating activities was mainly offset by the non-cash depreciation and amortization expense of $37,558, amortization of operating right-of-use assets of $75,241, unrealized holding loss on marketable securities of $52,889, decrease in amount due from related parties of $2,201, the decrease in inventories of $28,790, refund in prepaid taxes of $296,219, decrease in prepayments and deposits of $102,099, increase in accounts payable (including related party) of $22,211 and increase in income tax payables of $5,261.

Investing activities

Net cash used in investing activities for the six months ended June 30, 2023 was $6,499, which was in respect of purchase of equipment.

Net cash used in investing activities for the six months ended June 30, 2022 was $750, which was in respect of purchase of equipment.

Financing activities

Deferred offering cost made up the entire net cash used in financing activities for the six months ended June 30, 2023 and 2022 of $22,861 and $178,926, respectively.

Credit Facilities

We do not have any credit facilities or other access to bank credit.

Off-Balance Sheet Arrangements

As of June 30, 2023, we have no significant off-balance sheet arrangements that have or are reasonably likely to have a current or future effect on our financial condition, changes in our financial condition, revenues or expenses, results of operations, liquidity, capital expenditures or capital resources that are material to our stockholders.

Critical Accounting Estimates

The preparation of unaudited condensed consolidated financial statements in conformity with U.S. GAAP requires management to make estimates and assumptions that affect the reported amounts of assets and liabilities and disclosures of contingent assets and liabilities as of the date of the unaudited condensed consolidated financial statements and the reported amounts of revenues and expenses during the periods presented. Significant accounting estimates reflected in the Company's unaudited condensed consolidated financial statements include allowance for inventories obsolescence, impairment of long-lived assets and allowance for deferred tax assets. Following are the methods and assumptions used in determining our estimates.

Estimated allowance for inventories obsolescence

Management reviews inventory on hand for estimated obsolescence or unmarketable items, as compared to future demand requirements and the shelf life of the various products. Based on the review, the Company records inventory write-downs, when necessary, when costs exceed expected net realizable value. The Company did not recognize any inventory write-downs nor inventory write-off for the six months ended June 30, 2023 and 2022.

Impairment of long-lived assets

Operating right-of-use assets and property and equipment are stated at costs less accumulated depreciation and impairment, if any. In determining whether an asset is impaired, the Company has to exercise judgment and make estimation, particularly in assessing: (1) whether an event has occurred or any indicators that may affect the asset value; (2) whether the carrying value of an asset is not recoverable that is its carrying amount exceeds the amount of expected undiscounted future cash flows result from the use of the asset. Once it is established that impairment has occurred, the amount of impairment expense is determined as the difference between the carrying value of the asset and its estimated fair value based on a discounted cash flows approach.

As of June 30, 2023 and December 31, 2022, the carrying amounts of operating right-of-use assets and property and equipment amounted to $284,670 and $105,674 (December 31, 2022: $81,133 and $142,149), respectively. No impairment losses on operating right-of-use assets and property and equipment were recognized as of June 30, 2023 and 2022.

33

Allowance for deferred tax assets

The Company conducts much of its business activities in Malaysia and Hong Kong and is subject to tax in each of these jurisdictions. Significant estimates are required in determining the provision for income taxes. There are many transactions and calculations for which the ultimate tax determination is uncertain during the ordinary course of business. Where the final tax outcome of these matters is different from the amounts that were initially recorded, such differences will impact the income tax and deferred tax provisions in the period in which such determination is made.

Deferred tax assets relating to certain temporary differences and tax losses are recognized as management considers it is probable that future taxable profit will be available against which the temporary differences or tax losses can be utilized. Where the expectation is different from the original estimate, such differences will impact the recognition of deferred taxation assets and taxation in the periods in which such estimate is changed.

Critical Accounting Policies

Revenue recognition

The Company adopted Accounting Standards Update ("ASU") 2014-09, Revenue from Contracts with Customers (ASC Topic 606). The core principle underlying the revenue recognition of this ASU allows the Company to recognize - revenue that represents the transfer of goods and services to customers in an amount that reflects the consideration to which the Company expects to be entitled in such exchange. This will require the Company to identify contractual performance obligations and determine whether revenue should be recognized at a point in time or over time, based on when control of goods and services transfers to a customer. The Company's revenue streams are recognized at a point in time for the Company's sale of health and wellness products.

The ASU requires the use of a new five-step model to recognize revenue from customer contracts. The five-step model requires that the Company (i) identify the contract with the customer, (ii) identify the performance obligations in the contract, (iii) determine the transaction price, including variable consideration to the extent that it is probable that a significant future reversal will not occur, (iv) allocate the transaction price to the respective performance obligations in the contract, and (v) recognize revenue when (or as) the Company satisfies the performance obligation.

The Company accounts for a contract with a customer when the contract is committed in writing, the rights of the parties, including payment terms, are identified, the contract has commercial substance and consideration is probable of substantially collection.

Sales of Health and Wellness products

- Performance obligations satisfied at a point in time

The Company derives its revenues from sales contracts with its customers with revenues being recognized when control of the health and wellness products are transferred to its customer at the Company's office or shipment of the goods. The revenue is recorded net of estimated discounts and return allowances. Products are given 60 days for returns or exchanges from the date of purchase. Historically, there were insignificant sales returns.

Under the Company's network marketing business, the Company issues product coupons to members and distributors when these customers made purchases above certain thresholds set by the Company. Depending on the type of product coupons issued, the coupons carry varying values and can be used by the customers for reduction in the transaction price of product purchases within the coupon validity period. The value of the product coupons issued is recorded as a reduction of the Company's revenue account upon issuance; the corresponding amount credited to the customer deposits account. Amounts in customer deposits will be reversed when the coupons are used. The Company's coupons have a validity period of between six and twelve months. If the Company's customers did not utilize the coupons after the validity period, the Company would recognize the forfeiture of the originated sales value of the coupons as net revenues.

Provision of Health and Wellness services

- Performance obligations satisfied at a point in time

The Company carries out its Wellness program, where the Company's products are bundled with health screening test and a health camp program. The health screening test and the health camp programs are considered as separate performance obligations. The promises to deliver the health screening test report and the attendance at the health camp are separately identifiable, which are evidenced by the fact that the Company provides separate services of delivering the health screening test report and allowing admission of the customers to attend the health camp. The Company derives its revenues from sales contracts with its customers with revenues being recognized when the test reports are completed and delivered to its customers during the consultation section in person. The Company also separately derives its revenues from sales contracts with its customers with revenues being recognized when the health camp program was completed in the final day of the health camp.

34

Fair value of financial instruments

The accounting standard regarding fair value of financial instruments and related fair value measurements defines financial instruments and requires disclosure of the fair value of financial instruments held by the Company.

The accounting standards define fair value, establish a three-level valuation hierarchy for disclosures of fair value measurement and enhance disclosure requirements for fair value measures. The three levels are defined as follow:

    REGISTRATION NO. 333-239951

Financial instruments included in current assets and current liabilities are reported in the consolidated balance sheets at face value or cost, which approximate fair value because of the short period of time between the origination of such instruments and their expected realization and their current market rates of interest.

Accounting Standards Adopted in 2023

On January 1, 2023, the Company adopted Accounting Standards Update ("ASU") 2016-13, Financial Instruments - Credit Losses (Topic 326): Measurement of Credit Losses on Financial Instruments ("ASC 326"). This standard replaced the incurred loss methodology with an expected loss methodology that is referred to as the current expected credit loss ("CECL") methodology.

In addition, CECL made changes to the accounting for available-for-sale debt securities. One such change is to require credit losses to be presented as an allowance rather than as a write-down on available-for-sale debt securities if management does not intend to sell and does not believe that it is more likely than not, they will be required to sell.

As ASU 2016-13 has been adopted from January 1, 2023, the Company adopted ASU 2019-05, Financial instruments - Credit Losses (Topic 326) Targeted Transition Relief at the same time.

The AUS 2019-05 provides entities that have certain instruments with an option to irrevocably elect the fair value option applied on an instrument-by-instrument basis for eligible instruments. The fair value option election does not apply to held-to-maturity debt securities.

The adoption of these ASUs did not have a material impact on the unaudited condensed consolidated financial statements for the six months ended and as at June 30, 2023.

Recent accounting pronouncements

The Company has reviewed all recently issued, but not yet effective, considers the applicability and impact of all accounting standards updates ("ASUs"). Management periodically reviews new accounting standards that are issued.

In March 2023, the FASB issued ASU No. 2023-01, "Leases (Topic 842) Common Control Arrangements". This ASU provides guidance in ASC Topic 842 that leasehold improvements associated with common control leases should be (i) amortized by the lessee over the useful life of the leasehold improvements to the common control group, regardless of the lease term, as long as the lessee controls the use of the underlying asset through a lease, and (ii) accounted for as a transfer between entities under common control through an adjustment to equity if and when the lessee no longer controls the use of the underlying asset. The ASU 2023-01 is effective for reporting periods beginning after December 15, 2023. Early adoption is permitted for both interim and annual financial statements that have not yet been issued. When adopted in an interim period, it must be adopted from the beginning of the year that includes that interim period. The Company is currently evaluating the impact of this ASU may have on its unaudited condensed consolidated financial statements.

Except for the above-mentioned pronouncements, there are no othernew recent issued accounting standards that will have a material impact on the consolidated financial position, statements of operations and cash flows.

For the years ended December 31, 2022 and 2021

Revenue

We generated revenue of $1,856,564, which comprised revenue from the Company's network marketing business of $1,141,307 (approximately 61.5%); and revenue from the Company's operations in the provision of complementary health therapies of $715,257 (approximately 38.5%) for the year ended December 31, 2022 as compared to $1,016,962, which amount was solely attributable to revenue from the Company's network marketing business for the year ended December 31, 2021. Revenue from the Company's network marketing business increased marginally by $124,345 or approximately 12.2%. Total revenue increased by a $839,602 or approximately 82.6%. The increase was predominately due to: (i) the recovery from COVID-19 in Malaysia after April 2022. The Company made progress in revenue generating as Malaysia, where the Company's operations predominantly reside, has moved to a COVID-19 endemic phase with minimal restrictions on businesses and people movements in the country; and (ii) the Company's operations in the provision of complementary health therapies since February 2022.

Cost of Revenue

Cost of revenue for the year ended December 31, 2022 amounted to $666,042 as compared to $297,333 for the year ended December 31, 2021, representing an increase of $368,709 or approximately 124.0%. The increase was in line with the increase in revenue as explained in the above.

Cost of revenue typically comprise of freight-in, cost of goods purchased, packing materials and services acquired.

35

Gross Profit

Gross profit for the year ended December 31, 2022 amounted to $1,190,522, represented a gross margin of, approximately 64.1%, as compared to $719,629 for the year ended December 31, 2021, which was equivalent to a gross margin of approximately 70.8%. The decrease in gross margin was predominantly due to a lower gross margin associated with the provision of complementary health therapies as compared to the Company's network marketing business; and promotional activities undertaken by the Company to increase revenue from its network marketing business.

Operating Expenses

Our operating expenses consist of selling expenses, commission expenses, general and administrative expenses and provision for doubtful accounts.

Selling expenses

Selling expenses for the year ended December 31, 2022 amounted to $361,414 as compared to $394,682 for the year ended December 31, 2021, a decrease of $33,268 or approximately 8.4%. The Company's selling expenses typically comprise salaries and benefits expenses, credit card processing fees and promotional expenses. The decrease in selling expenses was predominantly due to decrease in salaries and benefits expenses.

Commission expenses

Commission expenses were $405,351 and $316,267 for the years ended December 31, 2022 and 2021, respectively, representing an increase of $89,084 or approximately 28.2%. The increase in commission expenses was in line with the increase in revenue.

General and administrative expenses ("G&A expenses")

G&A expenses for the year ended December 31, 2022 amounted to $1,957,023, as compared to $1,745,734 for the year ended December 31, 2021, representing an increase of $211,289, or approximately 12.1%. The increase in G&A expenses was mainly due to G&A expenses associated with the provision of complementary health therapies. The Company's G&A expenses typically comprise of salaries and benefits expenses, rental expenses, professional expenses and depreciation expenses.

Provision for doubtful accounts

Provision for doubtful accounts were $0 and $121,514 for the years ended December 31, 2022 and 2021 respectively. The provision for doubtful accounts brought forward was in respect of prepayments to a supplier. As the Company's attempts to recover the prepayments were futile, the entire provision for doubtful accounts of $121,514 was written-off during the year ended December 31, 2022.

Other (Expenses) Income

For the year ended December 31, 2022, we recorded an amount of $136,868 as other expenses, net as compared to $529,045 other expenses, net for the year ended December 31, 2021, representing a significant decrease of $392,177, or approximately 74.1%, in other expenses, net. The net other expenses of $136,868 incurred during the year ended December 31, 2022 comprised of other expenses of $79,539, interest income of $16,190 and unrealized holding loss on marketable securities of $73,519. The net other expenses of $529,405 incurred during the year ended December 31, 2021 comprised of other expense of $68,323, interest income of $25,570, unrealized holding loss on marketable securities of $505,231 and dividend income from marketable securities of $18,939. The significant decrease of other expenses, net was mainly due to the decrease of unrealized holding loss on marketable securities as a result of market price changes during the year of those investments held by the Company.

Benefit of (Provision for) Income Taxes

We had benefits of income taxes of $4,055 and provision for income taxes of $137,067 for the years ended December 31, 2022 and 2021, respectively. During the year ended December 31, 2022, our operations in Malaysia recorded benefits of income taxes due to overprovision of taxes in prior years.

During the year ended December 31, 2021, we had provision for income taxes of $114,862 due to certain permanent items required for the income taxes provision in Malaysia jurisdiction after our Malaysia local tax audit and had provision for income taxes of $22,205 on U.S. GILTI taxes provision.

36

Net Loss

We generated a net loss of $1,666,079 for the year ended December 31, 2022, as compared to $2,524,680 for the year ended December 31, 2021, a decrease of $858,601 or approximately 34.0%, predominately due to reasons as discussed above.

Liquidity and Capital Resources

Malaysia, where the operations of the Company predominantly reside, officially transitioned to the endemic phase of COVID-19 effective April 1, 2022. Restrictions on businesses and people are minimal.

Meanwhile, the government continues to encourage inoculation for those between the ages of 5 to 11 years and its adolescent group which comprised those between the ages 12 and 17. Adults who have been fully vaccinated, i.e. received two doses of the COVID-19 vaccine are encouraged to take booster shots.

Substantially all of our revenues are concentrated in Malaysia. Consequently, our results of operations will likely be adversely, and may be materially, affected, to the extent that the COVID-19 or any other epidemic harms the Malaysia and global economy in general. Any potential impact to our results will depend on, to a large extent, future developments and new information that may emerge regarding the duration and severity of the COVID-19 and the actions taken by government authorities and other entities to contain the COVID-19 or treat its impact, almost all of which are beyond our control. Potential impacts include, but are not limited to, the following:

    REGISTRATION NO. 333-239951

From our experiences operating under the much-restricted COVID-19 environment, we have modified our methods of operations, to build in sufficient buffer in the management of inventories. We may experience slight delay in products delivery lead time but barring unforeseen circumstances, the setback should be temporary.

We are currently operating primarily in Malaysia and anticipate expanding into the Asian markets in the future, with a particular focus, at least initially, on expanding into Thailand, Indonesia and Taiwan. We will explore expansion via e-commerce. Now that most nations are living alongside COVID-19, we will re-assess our plans to set up offices in the countries in which we operate to better service our customers.

Because of the uncertainty surrounding the COVID-19 outbreak, the financial impact related to the outbreak of and response to the COVID-19 cannot be reasonably estimated at this time. There is no guarantee that the Company's total revenues will grow or remain at similar levels year over year in 2023 and beyond.

As of December 31, 2022, we had working capital of $799,239 consisting of cash and cash in bank of $523,619 and time deposits of $914,811 as compared to working capital of $2,599,281 consisting of cash and cash in bank of $622,501 and time deposits of $1,975,347 as of December 31, 2021. The Company had a net loss of $1,666,079 for the year ended December 31, 2022 and accumulated deficits of $4,945,586 as of December 31, 2022 as compared to net loss of $2,524,680 for the year ended December 31, 2021 and accumulated deficits of $3,258,687 as of December 31, 2021.

In assessing our liquidity and going concern, management is projecting that the company's revenue will revert to pre-pandemic level, generating sufficient cash therefrom to cover our operating expenses.

37

If our Company is unable to generate sufficient cash flow within the normal operating cycle of a twelve-month period to pay for its future payment obligations, we may have to consider supplementing our available sources of funds through the following sources:

    REGISTRATION NO. 333-239951

? financial support from our related parties and shareholders.

Based on the above initiatives, management is of the opinion that the Company shall have sufficient funds to meet its working capital requirements and debt obligations as they become due in the foreseeable future twelve months from the date of issuance of this Annual Report. However, there is no assurance that management will be successful in its plans.

The following summarizes the key components of our cash flows for the years ended December 31, 2022 and 2021:

    REGISTRATION NO. 333-239951

Net cash used in operating activities $ (811,683) $ (845,842) Net cash used in investing activities (32,119) (3,959) Net cash used in financing activities (234,466) (19,061) Effect of exchange rate on cash and cash equivalents (81,150) (50,890) Net change in cash and cash equivalents $ (1,159,418) $ (919,752)

Operating activities

Net cash used in operating activities for the year ended December 31, 2022 was $811,683 and were mainly comprised of the net loss of $1,666,079, the non-cash deferred tax benefit of $14,751, the increase in accounts receivables of $2,824, the increase in amount due from related parties of $3,786, the payment of operating lease liabilities of $145,197 and the decrease in other payables (including related parties) and accrued liabilities of $115,085. The net cash used in operating activities was mainly offset by the non-cash depreciation and amortization expense of $73,876, amortization of operating right-of-use assets of $144,064, the unrealized holding loss on marketable securities of $73,519, inventory write-downs of $5,307, the decrease in inventories of $343,483, the refund in prepaid taxes of $263,404, the decrease in prepayments and deposits of $89,113, the increase in accounts payable (including related parties) of $41,422, increase in customer deposits of $94,877 and increase in income tax payables of $6,974.

Net cash used in operating activities for the year ended December 31, 2021 was $845,842 and were mainly comprised of the net loss of $2,524,680, dividend income from marketable securities of $18,939, the increase in prepayments and deposits of $128,363, and the payment of operating lease liabilities of $138,143. The net cash used in operating activities was mainly offset by the non-cash depreciation and amortization expense of $77,758, amortization of operating right-of-use assets of $139,451, the unrealized holding loss on marketable securities of $505,231, the non-cash deferred tax expense of $10,127, inventories write-down of $36,241, provision for doubtful accounts of $121,514, the decrease of accounts receivables of $167,566, the decrease in inventories of $192,713, the refund in prepaid taxes of $430,062, the increase in customer deposits of $52,981, the increase in income tax payables of $3,988, and the increase in other payables and accrued liabilities of $226,651.

Investing activities

Net cash used in investing activities for the year ended December 31, 2022 was $32,119, the amount entirely for the purchase of equipment and intangible assets.

Net cash used in investing activities for the year ended December 31, 2021 was $3,959, the amount entirely for the purchase of equipment.

Financing activities

Net cash used in financing activities for the year ended December 31, 2022 was $234,466, the amount entirely payment of deferred offering cost.

38

Net cash used in financing activities for the year ended December 31, 2021 was $19,061, mainly comprised of payment of deferred offering cost of $15,210 and advances to related parties of $3,851.

Credit Facilities

We do not have any credit facilities or other access to bank credit.

Off-Balance Sheet Arrangements

As of December 31, 2022, we have no significant off-balance sheet arrangements that have or are reasonably likely to have a current or future effect on our financial condition, changes in our financial condition, revenues or expenses, results of operations, liquidity, capital expenditures or capital resources that are material to our stockholders.

Critical Accounting Estimates

The preparation of consolidated financial statements in conformity with U.S. GAAP requires management to make estimates and assumptions that affect the reported amounts of assets and liabilities and disclosures of contingent assets and liabilities as of the date of the consolidated financial statements and the reported amounts of revenues and expenses during the periods presented. Significant accounting estimates reflected in the Company's consolidated financial statements include allowance for inventories obsolescence, impairment of long-lived assets, allowance for deferred tax assets. Following are the methods and assumptions used in determining our estimates.

Estimated allowance for inventories obsolescence

Management reviews inventory on hand for estimated obsolescence or unmarketable items, as compared to future demand requirements and the shelf life of the various products. Based on the review, the Company records inventory write-downs, when necessary, when costs exceed expected net realizable value. For the years ended December 31, 2022 and 2021, the Company recognize an inventory write-downs of $5,307 and $36,241 respectively.

Impairment of long-lived assets

Operating right-of-use assets and property, plant and equipment are stated at costs less accumulated depreciation and impairment, if any. In determining whether an asset is impaired, the Company has to exercise judgment and make estimation, particularly in assessing: (1) whether an event has occurred or any indicators that may affect the asset value; (2) whether the carrying value of an asset can be supported by the recoverable amount, in the case of value in use, the present value of future cash flows which are estimating the recoverable amounts including cash flow projections and an appropriate discount rate. Changing the assumptions and estimates, including the discount rates or the growth rate in the cash flow projections, could materially affect the net present value used in the impairment test.

As of December 31, 2022 and 2021, the carrying amounts of operating right-of-use assets and property, plant and equipment amounted to $81,133 and $142,149 (December 31, 2021: $237,718 and $215,799), respectively. No impairment losses on operating right-of-use assets and property, plant and equipment were recognized as of December 31, 2022 and 2021.

Allowance for deferred tax asset

The Company conducts much of its business activities in Malaysia and Hong Kong and is subject to tax in each of these jurisdictions. Significant estimates are required in determining the provision for income taxes. There are many transactions and calculations for which the ultimate tax determination is uncertain during the ordinary course of business. Where the final tax outcome of these matters is different from the amounts that were initially recorded, such differences will impact the income tax and deferred tax provisions in the period in which such determination is made.

Deferred tax assets relating to certain temporary differences and tax losses are recognized as management considers it is probable that future taxable profit will be available against which the temporary differences or tax losses can be utilized. Where the expectation is different from the original estimate, such differences will impact the recognition of deferred taxation assets and taxation in the periods in which such estimate is changed.

39

Critical Accounting Policies

Revenue recognition

The Company adopted Accounting Standards Update ("ASU") 2014-09, Revenue from Contracts with Customers (ASC Topic 606). The core principle underlying the revenue recognition of this ASU allows the Company to recognize - revenue that represents the transfer of goods and services to customers in an amount that reflects the consideration to which the Company expects to be entitled in such exchange. This will require the Company to identify contractual performance obligations and determine whether revenue should be recognized at a point in time or over time, based on when control of goods and services transfers to a customer. The Company's revenue streams are recognized at a point in time for the Company's sale of health and wellness products.

The ASU requires the use of a new five-step model to recognize revenue from customer contracts. The five-step model requires that the Company (i) identify the contract with the customer, (ii) identify the performance obligations in the contract, (iii) determine the transaction price, including variable consideration to the extent that it is probable that a significant future reversal will not occur, (iv) allocate the transaction price to the respective performance obligations in the contract, and (v) recognize revenue when (or as) the Company satisfies the performance obligation.

The Company accounts for a contract with a customer when the contract is committed in writing, the rights of the parties, including payment terms, are identified, the contract has commercial substance and consideration is probable of substantially collection.

Sales of Health and Wellness products

- Performance obligations satisfied at a point in time

The Company derives its revenues from sales contracts with its customers with revenues being recognized when control of the health and wellness products are transferred to its customer at the Company's office or shipment of the goods. The revenue is recorded net of estimated discounts and return allowances. Products are given 60 days for returns or exchanges from the date of purchase. Historically, there were insignificant sales returns.

Under the Company's network marketing business, the Company issues product coupons to members and distributors when these customers made purchases above certain thresholds set by the Company. Depending on the type of product coupons issued, the coupons carry varying values and can be used by the customers for reduction in the transaction price of product purchases within the coupon validity period. The value of the product coupons issued is recorded as a reduction of the Company's revenue account upon issuance; the corresponding amount credited to the customer deposits account. Amounts in customer deposits will be reversed when the coupons are used. The Company's coupons have a validity period of between six and twelve months. If the Company's customers did not utilize the coupons after the validity period, the Company would recognize the forfeiture of the originated sales value of the coupons as net revenues.

40

Provision of Health and Wellness services

- Performance obligations satisfied at a point in time

The Company carries out its Wellness program, where the Company's products are bundled with health screening test and a health camp program. The health screening test and the health camp programs are considered as separate performance obligations. The promises to deliver the health screening test report and the attendance at the health camp are separately identifiable, which are evidenced by the fact that the Company provides separate services of delivering the health screening test report and allowing admission of the customers to attend the health camp. The Company derives its revenues from sales contracts with its customers with revenues being recognized when the test reports are completed and delivered to its customers during the consultation section in person. The Company also separately derives its revenues from sales contracts with its customers with revenues being recognized when the health camp program was completed in the final day of the health camp.

Fair value of financial instruments

The accounting standard regarding fair value of financial instruments and related fair value measurements defines financial instruments and requires disclosure of the fair value of financial instruments held by the Company.

The accounting standards define fair value, establish a three-level valuation hierarchy for disclosures of fair value measurement and enhance disclosure requirements for fair value measures. The three levels are defined as follow:

    REGISTRATION NO. 333-239951

Financial instruments included in current assets and current liabilities are reported in the consolidated balance sheets at face value or cost, which approximate fair value because of the short period of time between the origination of such instruments and their expected realization and their current market rates of interest.

Recent accounting pronouncements

The Company has reviewed all recently issued, but not yet effective, considers the applicability and impact of all accounting standards updates ("ASUs"). Management periodically reviews new accounting standards that are issued.

In November 2019, the FASB issued ASU No. 2019-10, which to update the effective date of ASU No. 2016-13 for private companies, not-for-profit organizations and certain smaller reporting companies applying for credit losses, leases, and hedging standard. The new effective date for these preparers is for fiscal years beginning after December 15, 2022. ASU 2019-05 is effective for the Company for annual and interim reporting periods beginning January 1, 2023 as the Company is qualified as a smaller reporting company. The Company is currently evaluating the impact ASUs 2016-13 and 2019-05 may have on its consolidated financial statements.

Except for the above-mentioned pronouncements, there are no new recent issued accounting standards that will have a material impact on the consolidated financial position, statements of operations and cash flows.

41

    REGISTRATION NO. 333-239951

Overview

We are a provider of health and wellness products and advisory services in the Malaysian market. We pursue our mission of helping people to create health and wealth by providing quality products to distributors and customers who seek a healthy lifestyle. We believe the quality of our products coupled with the effectiveness of our distribution network have been the primary reasons for our success and will allow us to pursue future business expansion. In order to further our supply chain, on May 8, 2020, we acquired 99.99% of Agape Superior Living Sdn Bhd, with the goal of securing an established network marketing sales channel that has been in existence in Malaysia for the past 18 years. On September 11, 2020, the Company incorporated Wellness ATP International Holdings Sdn. Bhd., a wholly owned subsidiary in Malaysia, with the aim to pursue the business of promoting wellness and wellbeing lifestyle of the community through the provision of services including online editorials, programs, events and campaigns on how to achieve positive wellness and lifestyle. On September 15, 2020, Wellness ATP International Holdings Sdn. Bhd. Entered into a business collaboration agreement with ASL to carry out certain wellness programs.

We currently offer three series of products: ATP Zeta Health Program, ENERGETIQUE and BEAUNIQUE. Our ATP Zeta Health Program is a health program designed to assist in the elimination of various diseases caused by environmental pollutants, unhealthy dietary intake and unhealthy lifestyles. The program aims to promote improved health and longevity through a combination of modern health supplements, proper nutrition and advice from skilled dieticians. Our ENERGETIQUE series aims to provide a total dermal solution for healthy skin beginning from the cellular level. The series is comprised of the Energy Mask series, Hyaluronic Acid and Mousse Facial Cleanser. Our BEAUNIQUE product series focuses on the research of our diet's impact on modifying gene expressions to address genetic variations and deliver a personalized nutrigenomic solution for every individual.

On November 11, 2021, Agape ATP Corporation (Labuan) formed a joint-venture entity, DSY Wellness International Sdn. Bhd. ("DSY Wellness") with Mr. Steve Yap, following which Agape ATP Corporation (Labuan) owns 60% of the equity interests in DSY Wellness, to pursue the business of providing complementary health therapies. The establishment of DSY Wellness is a further expansion of our business into the health and wellness industry. Mr. Steve Yap owns 33 proprietary formulas (the "Proprietary Formulas") for treating non-communicable disease and the Company is currently in discussion with Mr. Steve Yap to bring the Proprietary Formulas into the company for joint commercialization. Mr. Steve Yap also has existing clients receiving traditional complimentary medicine or "TCM" in Indonesia and China.

Industry and Market Opportunities

Increasing demand in Dietary Supplement products in the Association of Southeast Asian Nations ("ASEAN") region.

ASEAN markets have seen increasing demand for dietary supplement products since 2016 and we believe will continue to do for the foreseeable future. We believe that the ASEAN market for health supplements hold great potential for growth. According to a report published by Zion Market Research entitled "Dietary Supplements Market by Ingredients (Botanicals, Vitamins, Minerals, Amino Acids, Enzymes) for Additional Supplements, Medicinal Supplements, and Sports Nutrition Applications - Global Industry Perspective, Comprehensive Analysis and Forecast, 2020 - 2028" issued in March 2023, it is estimated that while the global dietary supplements market stood at US$191.1 billion in 2020, it is set to reach US$307.8 billion by 2028, representing a compounded annual growth rate (CAGR) of 5.9% between 2021-2028.

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

According to an article published by Janio, a cross-border platform providing integrated logistics solutions to e-commerce brands, logistics service providers and marketplaces in Southeast Asia, in December 2019, the nutritional and dietary supplements in the ASEAN region are being prioritized by individuals in order to maintain a balanced diet and lifestyle. (Source: https://www.janio.asia/resources/articles/health-supplement-trends-in-southeast-asia-and-how-cross-border-ecommerce-plays-a-role) Consumers believe that they can make up for certain vitamin deficiencies or dietary deficiencies by consuming nutritional and dietary supplements. Many consumers also use nutritional and dietary supplements for cosmetics purposes, namely, skincare, hair strengthening, and fat burning, particularly in countries such as Malaysia and Vietnam.

For example, in Indonesia, the nutritional and dietary supplements market has recorded strong growth due to changes in consumers' lifestyle habits and increasing awareness of preventive health measures. This is prevalent among the middle-class that has grown from approximately 37.7% of the population in 2003 to approximately 50% the population in 2020. Similarly, according to Siam Commercial Bank (SCB) Economic Intelligence Center, the prospects for the dietary supplements market in Thailand has been growing since 2015 and is predicted to grow at an average of approximately 7% per year until 2030. (source: https://www.scbeic.com/en/detail/file/product/3218/emyjfdtqlc/Note_EN_Supplement_20170209.pdf) In the Philippines, a stable economy has also been contributing to increased financial capability and the desire of Filipino consumers to improve both their mental and physical health through supplements. Conversely, Malaysia is ranked as the top country within ASEAN for both obesity and diabetes. Obesity and diabetes have been connected to heart disease and hypertension. As a result, consumers in Malaysia are increasingly aware of such potential health issues associated with eating habits and have become more proactive in searching for consumer health products to prevent such chronic diseases like diabetes and hypertension.

42

Continued Growth in the Skincare products in regions such as Asia-Pacific.

We believe that skincare products will remain highly lucrative with further potential for growth. According to Euromonitor, a global strategic market research company based in London, Asia generates approximately 51% of the world's skin care sales, surpassing Western Europe and North America. In June 2023, Fortune Business Insights, a global market study and consulting services provider, puts the Asia-Pacific skincare sector as the largest market in the world. (source: https://www.fortunebusinessinsights.com/skin-care-market-102544) According to them, the global skincare market was valued at approximately US$104.24. billion in 2022, with the Asia-Pacific region accounted for US$54 billion, or 51.8%. The global skincare market is expected to grow from approximately US$109.71 billion to US$167.22 billion by 2030, representing a compound annual growth rate ("CAGR") of approximately 6.21%. In terms of volume, according to Fortune Business Insights, the Asia-Pacific region is expected to grow from approximately 8.4 billion units in 2019 to approximately 9.5 billion units in 2024, representing a CAGR of approximately 2.5%.

Growth Drivers in the ASEAN Region

We believe that the market for the health and wellness industry will continue to see rapid growth, in part due to the rising wealth in the ASEAN region resulting in increased purchase power. According to an article by the Boston Consulting Group (BCG) published in May 2023, the trade in ASEAN grew by 33% between 2017 to 2021, outpaced the global trade at 24% during this period. BCG also forecasts exports from ASEAN will surge by 90% to US$3.2 trillion annually by 2031, and ASEAN's combined GDP is projected to grow by a CAGR of 4.6% till 2030, becoming the world's fourth largest market if viewed as single economy. (source: https://www.bcg.com/publications/2023/asean-free-trade-advantage-to-power-ahead) ASEAN countries have established six Free Trade Agreements with seven of the region's main trading partners - Australia and New Zealand, China, India, South Korea, Japan, and Hong Kong. The Comprehensive and Progressive Agreement for Trans-Pacific Partnership (CPTPP) is one of the largest Free Trade Agreements in the world and accounts for almost 13.5% of global GDP. The agreement brings together Australia, Brunei Darussalam, Canada, Chile, Japan, Malaysia, Mexico, New Zealand, Peru, Singapore, and Vietnam, offering these countries investment access and free trade. For example, a study by the World Bank in 2018 pointed out that, conservatively, CPTPP will increase Vietnam's GDP by 1.1% by 2030. (source: https://www.worldbank.org/en/news/press-release/2018/03/09/cptpp-brings-vietnam-direct-economic-benefits-and-stimulate-domestic-reforms-wb-report-says#:~:text=%E2%80%9CEven%20under%20conservative%20assumptions%2C%20the,Bank%20Country%20Director%20for%20V.) Furthermore, in January 2022 the Regional Comprehensive Economic Partnership (RCEP) took effect and the bloc accounts for roughly 30% of the world GDP. According to a report by Asian Development Bank, RCEP is expected to increase the income of member economies by 0.6% while adding US$245 billion to the regional economy. (source: https://blogs.adb.org/blog/three-areas-where-rcep-may-help-region-s-post-pandemic-recovery) Economic wealth has allowed for social development with more than 100 million people estimated to have joined ASEAN's workforce over the past 20 years and another 59 million people are projected to be added by 2030. (source: https://www.sydney.edu.au/sydney-southeast-asia-centre/news/5-facts-about-asean.html#:~:text=More%20than%20100%20million%20people,third%2Dlargest%20labour%20force%20worldwide.) We believe a direct advantage of such economic growth is a fast-emerging middle class that will be attracted to our company and its products.

We believe that generally unhealthy lifestyles in the ASEAN population continues to form a basis for the growth in the health and wellness industry in the region. In a MarketWatch article citing Astute Analytica in June 2023, it was noted that the ASEAN Nutritonal Supplement market size is set to reach US$14.85 billion by 2031 from US$7.37 billion representing a CAGR of 8.40% during the forecast period. Increasing prevalence of lifestyle-induced disorders, or Non-Communicable Diseases (NCDs), such as diabetes and cancer, will be a key factor driving food supplements market growth. (source: https://www-marketwatch-com.univ-eiffel.idm.oclc.org/press-release/asean-nutritional-supplements-market-research-uncovering-insights-for-strategic-decision-making-forecast-2023-to-2031-2023-06-08) Estimates computed by the World Health Organization (WHO) state that close to 8 million people die every year in Southeast Asia due to NCDs, amounting to 55% of the total deaths in the region in a given year. According to the WHO, four risk factors tobacco, alcohol, lack of exercise, and poor diets are primarily responsible for the spread of NCDs in the region. For instance, the WHO found that at least 25% of boys in Malaysia and Thailand are obese and a large number of school children across Southeast Asia are largely physically inactive. Such conditions will contribute to a growth in demand for dietary supplement products, in order to promote a healthier lifestyle.

A rapidly aging population in the ASEAN region also promotes the need for preventive measures to mitigate against rising healthcare costs. An International Monetary Fund publication in April 2017 found that in East Asia, the population is projected to be the world's fastest-aging region with its old-age dependency ratio roughly tripling by current rends by 2050. According to an article by Fortune Business Insights published in April 2020, the aging population in Southeast Asia has led to a significant rise in incidences of lifestyle-related diseases. As a result, healthcare costs will inevitably rise, leading to increased demand in the use of supplements in preventing deteriorative health conditions.

43

Industry Challenges

In spite of its high growth, the health and wellness industry also faces certain challenges. We believe the following are some key challenges to the industry:

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Competitive Landscape

The health and wellness industry in ASEAN remains highly competitive and fragmented. Key entry barriers of the industry include the following:

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Our Strategies

We intend to pursue the following strategies to further develop and expand our business:

Expand the product range in each of our ATP Zeta Health Program, ENERGETIQUE and BEAUNIQUE series

We intend to continue to expand the product range in each of our product lines, namely, ATP Zeta Health Program, ENERGETIQUE and BEAUNIQUE series.

Further Penetrate Existing Markets.

We believe that there are several opportunities to further penetrate our existing markets. For example, besides offering dietary products and services through our ATP Zeta Health Program, we have also expanded our products and services to include beauty and wellness products via the introduction of ENERGETIQUE and BEAUNIQUE series in July 2018 and March 2019, respectively, with the goal of diversifying our product offerings and catering to broader market demands. Currently we maintain three sales branches in different locations in Malaysia, namely, Kuala Lumpur, Johor Bahru and Ipoh, and appointed three stockists, to whom the Company can assign its products, at two other locations in Malaysia to further cater to our distributors, members and customers.

Currently, the Company's distributors and members mainly consists of the ethnic Chinese community. As a multi-racial country, the majority of the population in Malaysia is comprised of Bumiputera, which is comprised of Malays and other indigenous peoples, accounting for 62% of the entire Malaysia population, with an estimated population at approximately 33.9 million (as compared to the ethnic Chinese community which accounts for less than 22.8%). (source: https://www.igi-global.com/dictionary/innovation-culture-as-a-mediator-between-specific-human-capital-and-innovation-performance-among-bumiputera-smes-in-malaysia/58789). We believe there is opportunity for further penetration of our products into other ethnicity group within the existing Malaysian market.

As we further grow our business, we may further expand our local sales centers to additional locations with the aim to further distribute our products and appeal to local demand.

On November 11, 2021, Agape ATP Corporation (Labuan) formed a joint-venture entity, DSY Wellness with Mr. Steve Yap following which Agape ATP Corporation (Labuan) owns 60% of the equity interests in DSY Wellness, to pursue the business of providing complementary health therapies. The establishment of DSY Wellness is a further expansion of our business into the health and wellness industry, with target customers including patients with chronic health disorder, chronic health issues and non-communicable diseases. We will also promote the prevention of chronic health disorder through lifestyle and nutrition programs supported by the health therapies of DSY Wellness.

44

Deepening our Relationships with Existing Members.

We offer membership and distributor discounts on all our product offerings. Customers are able to become lifetime members by paying a one-time membership fee with the purchase of specific products. Members who reach a predetermined amount of purchases per year are automatically promoted to become a distributor who also enjoys bonuses for products that they sell to other customers, as well as bonuses from the collective performance of their network group. As our members and distributors recognize the value of our platform and the quality of our products, they typically purchase additional products utilizing their membership and discount entitlements. Our sales strategy is focused on expanding our revenue per member. We believe there is significant opportunity for existing members to become distributers, as well as for distributors to further recruit new distributors under their network.

Further Investment into Information Technology such the Establishment of an E-Commerce platform.

In 2019, we embarked upon a strategic initiative to sell our products on an existing Malaysian e-trading platform to increase the efficiency of our supply chain, to better support and service our distributors and members, and to establish a global reach.

In 2022, we launched our e-trading website (https://www.agapeatp.com/index.php/en/) to provide better customer experience. We will continue to actively promote our e-trading platformfor online recruitment of new members by existing distributors, as well as to provide direct sales to customers.

Once the e-trading platform has provided tangible results in the Malaysia market, we intend to expand the platform to other geographic markets in order to duplicate its success.

In line with the current popularity of using social influencers to boost product demand, the Company is also exploring the future appointment of key social influencers with significant numbers of followers as ambassadors for the Company's products.

Geographic Expansion.

A key component of our strategy is to enter into and expand into new markets with similar cultures and a high demand for health and nutrition products. For example, the majority of our product information sessions and training seminars for distributors are currently conducted in Mandarin, which is the common language spoken amongst the majority of our distributors. We intend to invest into other Asian markets such as Taiwan, where Mandarin is also widely used and understood, allowing for the seamless transition in distributor training and membership recruitment.

With a view to facilitate geographical expansion, our future e-trading platform will also increase efficiency of our supply chain to better support and service our distributors and members as well as to provide online recruitment of new members by existing distributors and to provide direct sales to customers.

In 2022, we had launched our e-trading website (https://www.agapeatp.com/index.php/en/) to entice and provide better customer experience. We will continue to actively promote our e-trading platform for online recruitment of new members by existing distributors, as well as to provide direct sales to customers. Upon our e-trading platform having reached tangible results in the Malaysia market, we intend to expand the platform to other geographic markets in order to duplicate its success.

Pursue Growth Through the Acquisition of Other Health and Wellness Services Providers

The health and wellness industry is highly fragmented, and we intends to pursue growth through the acquisitions of services providers in the ASEAN with a strong brand presence in their area of operations. In reviewing potential targets, we identified target companies matching the following criterial (i) with profitability and customer base comprising customers from health care industry; and (ii) with established knowledge base of empirical/holistic skills, knowledge and technologies which are applicable to transform our company into a wellness ecosystem company such as skin care, cosmetic biological lab production, wellness center or complementary medicine therapies for chronic health problems, manufacturers of water filtration system, etc.

Our Competitive Strengths

We believe the following competitive strengths contribute to our success and differentiate us from our competitors:

Well Established Reputation.

We have a well-established reputation in the Malaysia market, where our newly acquired subsidiary, Agape Superior Living Sdn Bhd has been operating as a reputable provider of our ATP Zeta Health Program for over 18 years.

Well-Established Product Portfolio.

We are committed to building our brand, and distributor and customer loyalty by providing quality health-oriented and wellness products. We have no expenditures or expenses relating to research and development of our products as all of our products are acquired from unrelated third parties and rebranded by us. Due to the high costs associated with research and development of nutrition and health products, we do not maintain any facilities to produce our products. We leverage our team of in-house nutritional consultants with rich experience gained in the area of nutritionist work, in collaborating with our customers and clients to understand the health and wellness market via a process of consultative review. We then communicate our findings and proposals to third-party suppliers to improve formulations, and to bring about new products for distributors and members who are ready to market to end-users.

45

Large, Highly-Motivated Distributor Base, Supported By Successful Training Methodology.

We had over 128,652 members, including 56,462 distributors, as of June 30, 2023. Because we believe the direct sales model is the most effective way to sell our products, we devote significant resources and management attention to assist our distributors in recruiting and retaining our members. We provide our distributors with successful training methodology, which includes meetings, workshops and activities to create social connections among distributors to develop proficiency of knowledge, confidence and skills to build recruitment strength. We structured our compensation system to encourage distributors to remain active in the business and to build a distributor network of their own, which can serve to increase their income and to increase our product sales. In order to encourage entrepreneurship within our distributors, we also maintain six service centers, including three operated by our stockists, to better service our distributors and members.

Scalable Business Model.

Our business model enables us to grow our business with minimal investment in our infrastructure and other fixed costs. We do not require a company-employed sales force to market and sell our products. As a result, we do not incur direct incremental cost to add a new distributor. Our distributor compensation varies directly with sales. In addition, our distributors bear the majority of our consumer marketing expenses. Furthermore, we can readily increase inventory and distribution of our products as a result of our partnerships with our third-party suppliers.

Deeply Experienced Founder-led Management Team.

Our founder, Dr. How Kok Choong, has led our company for over 18 years. In Malaysia, Dr. How Kok Choong was recognized by the Junior Chamber Malaysia (JCM) as an Outstanding Young Malaysian 2003, and was awarded the title of Justice of Peace of Malaysia since 2005. Dr. How received the Outstanding Asian Community Contribution Award in 2011, Malaysia Top Team 50 Enterprise Award in 2011 and 2016, The Contributor Award (Medical and Health Research) in 2012, "Man of The Year" in Worldwide Excellence Award in 2015, "Man of The Year" in McMillan Global Award in 2016, The Distinguished Asia Pacific Outstanding Entrepreneur Lifetime Achievement Award in 2019, World Outstanding Chinese Entrepreneur Lifetime Award in 2019 and Certified Professional Trainer of The International Professional Managers Association in 2019. In 2023, Dr. How was awarded the Global Business Icon Leadership Lifetime Achievement Award by KSI Strategic Institute for Asia Pacific in Kiala Lumpur, Malaysia. In the same year, he was awarded the ASEAN Outstanding Entrepreneur Lifetime Achievement Award in Jakarta, Indonesia.

Mr. Lee Kam Fan, Andrew has served as our chief financial officer since January 2021. Prior to joining the Company in January 2021, Mr. Lee had approximately 38 years of accounting and finance related experience. Since July 2014, Mr. Lee has been the proprietor of Andrew Lee & Company, a Certified Public Accountants Firm in Hong Kong that provides audit and taxation services. Mr. Lee is an associate member of the Institute of Chartered Accountants in England and Wales since April 2019, a certified public accountant (practicing) of the Hong Kong Institute of Certified Public Accountants since May 2010, a fellow member of the Association of International Accountants since December 2006, and an associate member and certified tax advisor of the Tax Institute of Hong Kong since July 2010. Mr. Lee received his bachelor's degree in business administration at the Open University of Hong Kong in June 2004 and his master's degree in professional accounting from the Hong Kong Polytechnic University in November 2010.

Mr. Steve Yap serves as the director since 2021 and is responsible for the operation of DSY Wellness International Sdn Bhd. Mr. Steve Yap is a well-respected figure in the field of nutritional, metabolic and anti-ageing medicine in Malaysia, and is a certified nutritional practitioner. Mr. Steve Yap is committed to developing and promoting self-empowering health preventive programs for the public to cope with chronic health disorders. Over the years, Mr. Steve Yap has served in various technical committees within the Ministry of Health Malaysia. Currently, he is a member of the traditional & complementary medicine council, which involved in the drafting of the Traditional and Complementary Medicine (T&CM) Act 2016 in Malaysia. Mr. Steve Yap is also president for the Association of Nutritional Medicine Practitioners. With Mr. Steve Yap's involvement, we believe he will significantly enhance the technical capability of the company and accelerate the development of the group in the field of wellness.

Collectively, our senior leadership team has extensive management skills, accounting, financial and nutritional knowledge and expertise.

Product Overview

We offer three series of products: (i) ATP Zeta Health Program, (ii) ENERGETIQUE and (iii) BEAUNIQUE.

Our ATP Zeta Health Program is a health program designed to promote health and general wellbeing, as well as to prevent diseases caused by polluted environments, unhealthy dietary intake and unhealthy lifestyles. At its core, the ATP Zeta Super Health Program is focused upon biological energy, Adenosine Triphosphate (ATP), at the cellular level. The stimulation of ATP production at the cellular level can increase an individual's metabolic rate in order to promote and maintain normal and healthy functioning of the body's systems. Our program emphasizes nutrient absorption through the membrane ion channel in order to provide complete and balanced nutrients to improve cellular health. Thus, ATP Zeta Super Health Program provides ionized and high zeta potential (high bioavailability) nutrients to enhance the absorption at the cellular level.

Our ENERGETIQUE product series is comprised of the ENERGETIQUE Mask series, Hyaluronic Acid Serum and Mousse Facial Cleanser.

The ENERGETIQUE Mask series is formulated with triple action natural ingredients and advanced technology. The innovative combination of award-winning liposome encapsulating the customized fast acting essence, produces micro-particle liposome which, when combined with collagen peptide Tencel film, creates a formulation designed to benefit the skin at the cellular level. The ENERGETIQUE series aims to provide a total dermal solution for healthy skin beginning at the cellular level. There are three types of face masks in the ENERGETIQUE Mask Series, each addressing a specific skin condition Med-Hydration, Med-Whitening and Med-Firming. The ENERGETIQUE Mask Series has clinically shown deep penetration of liposomal essence into deep skin layers within 5 minutes of application, in order to deliver immediate, deep-reaching and long-lasting benefits of skin hydration, whitening, and firming.

46

The ENERGETIQUE Hyaluronic Acid Serum is formulated with four functional hyaluronic acids and a unique peptide. It is a scientifically advanced and intensive quintuple action serum designed to promote skin hydration, reparation and regeneration to enhance skin viscoelasticity for improved skin firmness.

The ENERGETIQUE Mousse Facial Cleanser is formulated with the mildest surface-active agents available on the market. It takes the form of a unique mousse like-foam that delivers a comfortable and soft feeling to the skin during and after use without compromising the moisturizing level and viscoelastic properties of the skin. Its PH-balanced formula is suitable for all skin types for an effortless cleansing routine.

Our BEAUNIQUE product series focuses on the research of our diet's impact on modifying gene expressions in order to address genetic variations and deliver a personalized nutrigenomic solution for every individual.

ATP Zeta Health Program

The following is a list of our ATP Zeta Health Program products:

ATP1s Survivor Select

ATP1s Survivor Select contains various essential nutrients required by the human body to maintain normal metabolism, which includes production of biological energy (ATP). Effective production of ATP enhances both physical and mental health and helps the body build resistance to diseases.

    REGISTRATION NO. 333-239951

ATP2 Energized Mineral Concentrate

ATP2 is a nutritional supplement made from the finest plant substances and also is a proprietary formulation of a super-energized colloidal concentrate developed from a dibase solution. Its formula supports and enhances nutritional biochemical activities.

47

    REGISTRATION NO. 333-239951

ATP3 Ionized Cal-Mag

ATP3 Ionized Cal-Mag is a specialized calcium and magnesium minerals supplement that is designed to transform into an ionic form completely before entering the body. This is compatible to the cellular ion channel theory, that all cellular metabolisms are dependent on ionic transmission, in order to achieve the highest absorption rate. This product was tested for its nanoparticle by the National Measurement Institute of Australian Government, with proven content of nanosized calcium and magnesium that has better absorption and bio-availability.

    REGISTRATION NO. 333-239951

48

ATP4 Omega Blend

ATP4 Omega Blend is a proprietary oil blend that is rich in undamaged polyunsaturated essential fatty acid, which is fully extracted from plant-based ingredients. It provides a bio-effective balance of both essential fatty acids, Omega 3 and Omega 6 which are the important structural components of cell membranes that cannot be synthesized by humans.

    REGISTRATION NO. 333-239951

ATP5 BetaMaxx

ATP5 BetaMaxx is derived from the cell wall of premium food-grade baker's yeast and is a medical breakthrough result of more than 50 years of intensive research and studies by scientists and physicians. This product combines the immunostimulatory properties of molecularly structured beta 1-3, 1-6-D-glucan with other immunomodulating compounds that work to make ATP5 a unique and effective natural product.

    REGISTRATION NO. 333-239951

49

AGN-Vege Fruit Fiber

AGN-Vege Fruit Fiber is a special nutrition-based formula for intestines and the stomach. It consists of four essential components for gastrointestinal health effects - fiber, probiotic the "friendly bacteria,", prebiotic fructooligosaccharides (FOS) and digestive enzymes.

    REGISTRATION NO. 333-239951

AGP1-Iron

AGP1-Iron is the purest and most advanced Colloidal Iron that is sourced from the remains of an ancient rainforest which contains the most active plant-based element from nature. The colloidal nanosized iron provides high zeta potential that promotes better absorption and cellular iron uptake through the ion channel.

50

    REGISTRATION NO. 333-239951

YFA-Young Formula

YFA-Young Formula is a 100% natural unique formula, a combination of amino acid, vitamins, and minerals. It is an anti-aging and youthful maintenance supplement. It stimulates the pituitary gland to release endocrine hormones such as human growth hormone (HGH) to stimulate synergies, thus achieving the efficacy of anti-ageing through the promotion of cells vitality and strengthening of organ functionality.

    REGISTRATION NO. 333-239951

51

    REGISTRATION NO. 333-239951

BEAUNIQUE Mito+ and Mitogize

We discontinued ATP Regal Mitogize on October 1, 2019. In its stead, an enhanced formula, the BEAUNIQUE Mito+ was introduced in November 2019. As a strong antioxidant drink with great flavor and taste, the preeminence of BEAUNIQUE Mito+ is its ability to further protect and stimulate mitochondria (the membrane-bound organelles which produces energy for cells) in cellular energy (ATP) production with the added advantage of fewer total sugars and calories. The new formula is comprised of 11 food groups, including potent mangosteen skin extract. Backed by advanced scientific research and tested on 88 nutrigenomic profiles, the new formulation revealed enhanced antioxidant properties. 96.34% DPPH Radical Scavenging activity, an approximate 22% increase compared to Mitogize.

DSY Wellness

On November 11, 2021, Agape ATP Corporation (Labuan) formed a joint-venture entity, DSY Wellness with Mr. Steve Yap following which Agape ATP Corporation (Labuan) owns 60% of the equity interest, to pursue the business of providing complementary health therapies. The establishment of DSY Wellness is a further expansion of our business into the health and wellness industry. DSY Wellness offers health consultancy and advice, as well as nutritional supplements at medical dosages, as prescribed by in-house nutritional practitioners.

52

ORYC-Organic Youth Care Cleansing Bar

ORYC-Organic Youth Care Cleansing Bar is a natural, organic cleansing soap for skin. It contains pure Australian-accredited natural and organic plant oils acting as a high quality and natural skin lubricant. It maintains the softness of the skin while promoting skin beauty and radiance.

    REGISTRATION NO. 333-239951

ENERGETIQUE

The following is a list of our ENERGETIQUE products:

N1 Med-Hydration

Formulated with a Sea Grape (Caulerpa lentillifera) extract, the N1 Med-Hydration enhances skin moisture and luminosity. This treatment effectively improves the moisture content of the inner skin layer and rejuvenate the skin barrier function in order to avoid moisture loss.

    REGISTRATION NO. 333-239951

53

N2 Med-Whitening

Formulated with Peach Blossom Stem Cell Extract, N2 Med-Whitening has clinically shown its efficacy in inhibiting the melanin synthesis, down-regulating the melanin synthesis gene, boosting skin moisture level and protecting skin against UV radiation.

    REGISTRATION NO. 333-239951

N3 Med-Firming

Formulated with the Djulis (Chenopodium formosanum Koidz) Seed Extract, the native cereal plant in Taiwan is traditionally called "ruby of cereals." The formulation is clinically proven to be effective in stimulation of collagen secretion and anti-advances glycation end-products (AGEs) reducing the glycation of skin collagen, providing protection and maintenance of the basal skin collagen production.

54

    REGISTRATION NO. 333-239951

BEAUNIQUE

The Company's BEAUNIQUE product series focuses on the research of our diet's impact on modifying gene expressions in order to address genetic variations and deliver personalized nutrigenomic solutions for every individual.

Trim+

Trim+ is the first product launched under this series, which utilizes advanced technology to extract active ingredients in foods. Trim+ has been scientifically proven to be effective in inhibiting the activities of carbohydrates digestive enzymes, which results in a reduction of the breakdown and absorption of sugars.

    REGISTRATION NO. 333-239951

55

ENERGETIQUE

On November 3, 2019, the Company expanded its beauty products under the ENERGETIQUE series, to include beauty essentials of the skincare routine, i.e. the ENERGETIQUE Hyaluronic Acid Serum and ENERGETIQUE Mousse Facial Cleanser. These products have extended the ENERGETIQUE brand vision in offering a total dermal solution for a healthy skin beginning from the cellular level.

ENERGETIQUE Hyaluronic Acid (HA) Serum

Formulated with four functional hyaluronic acids and a unique peptide, this scientifically advanced and intensive quintuple action serum has been proven to deliver 5Rs dermal benefits. Filled in an innovative yet convenient and hygienics syringe packaging, this HA serum also ensures consumer benefits for every skin type.

    REGISTRATION NO. 333-239951

56

ENERGETIQUE Mousse Facial Cleanser

Formulated with mild surface-active agents available on the market, this facial cleanser is designed to deliver a distinct cleansing benefits to consumers. The unique mousse like-foam delivers a comfortable and soft feeling of the skin during and after use without compromising the moisturizing level and viscoelastic properties of the skin.

    REGISTRATION NO. 333-239951

Our Business Model

We believe that the direct-selling channel is ideally suited to market our products, because sales of health solution and personal care products are strengthened by ongoing personal contact between retail consumers and distributors. This personal contact may enhance consumers' nutritional and health education and motivate consumers to begin and maintain wellness and weight management programs. In addition, by using our products themselves, distributors can provide first-hand testimonials of product effectiveness, which can serve as a powerful sales tool.

57

We are focused on building and maintaining our distributor network by offering financially rewarding and flexible career opportunities through the sale of quality, innovative products to health conscious consumers. We believe the income opportunity provided by our bonus program appeals to a broad cross-section of our members, particularly those seeking to supplement family income, start a home business or pursue entrepreneurial, full and part-time, employment opportunities. Our distributors, who are all independent third parties, profit from selling our products and also earning bonuses through performance of their network group, the establishment of their own network group and the performance of distributors recruited under their own network group. Top performing distributors with their own physical stores may also become stockists of the company, whereby they enjoy benefits such as maintaining a certain amount of the Company's inventory in their store premises, with the requirement that all product sales are monitored through our centralized stock tracking system and accounted back to us. The stockists have the option of returning or exchanging any unsold inventory consigned to them.

We enable distributors to maximize their potential by providing a broad array of motivational, educational and support services. We motivate our distributors through our performance-based compensation plan, product-training seminars, workshops and participation in routine promotional activities.

We are committed to providing professionally designed educational training materials that our distributors can use to enhance recruitment and to maximize their sales. We conduct several training sessions per year to motivate our distributors. These training events teach our distributors not only how to develop invaluable business-building and leadership skills, but also how to differentiate our products with their consumers, including information sessions presented by in-house nutritional consultants.

Our corporate-sponsored training events provide a forum for distributors, who otherwise operate independently, to share ideas with us and each other. In addition we are also developing an e-marketing and e-trading platform allowing for marketing and trading of products to members, as well as online recruitment of new members and to provide direct sales to customers.

We are committed to providing our distributors with quality products to help them increase sales and recruit additional distributors. We leverage our team of in-house nutritional consultants with rich experience gained in the area of nutrition, in collaborating with our customers and clients to understand the health and wellness market via a process of consultative review. This review team is headed by the Head of Product Development. We then communicate our findings and proposals to third-party suppliers to improve formulations, to bring about new products for distributors and members who are ready to market to end-users.

We place a strong emphasis on the science of nutrition. We have obtained the appropriate authorizations from the Food Safety and Quality Division, and/or registered with the National Pharmaceutical Regulatory Agency (NPRA) of the Ministry of Health, Malaysia for our products. Whenever products are purchased for inventory replenishment, samples are randomly selected from every batch for testing at laboratories registered with the Ministry of Health Malaysia.

Our Customers

General

We provide health and wellness products and advisory services to health-conscious customers in the Malaysian market. Such customers are able to enjoy membership discounts across all our products by becoming members.

Our distributors enjoy further discounts on all of our products. Besides our three sales branches that are located in Kuala Lumpur, Johor Bahru and Ipoh, our products are also distributed to customers and members by our network of three stockists who are also independent distributors, whose store premises are located in two other locations in Malaysia.

We believe that our products are particularly well-suited for direct distribution because the sale of health and nutrition products are strengthened by ongoing personal contact between retail customers and distributors. We believe our continued commitment to sourcing quality science-based products will enhance our ability to attract new customer, as well as increase the productivity and retention of our distributors.

58

Structure of the membership program

Our customers are able to become lifetime members by paying a one-time membership fee with the purchase of specific products. Doing so allows the customer to enjoy membership discounts on all our products.

Members who accumulate a predetermined number of purchases are automatically promoted to become a distributor of the Company. Other than helping distributors achieve physical health and wellness through the use of our products, we offer our distributors, who are independent third parties, bonuses based on various performance factors. Distributors are required to maintain a predetermined number of purchases per year in order to maintain their distributor status.

Top performing distributors with their own physical stores may also become stockists of the Company, whereby they enjoy benefits such as maintaining a certain amount of the Company's inventory in their store premises. The stockists shall account to the Company for all products sales from their store premises as monitored through the Company's centralized stock tracking system. The stockists shall have the option to either return or exchange the Company's inventory consigned to them that are unsold.

The following table sets forth the number of members and distributors at the dates indicated:

    REGISTRATION NO. 333-239951

Distributors' and members' earnings

Distributors and members earn profits from the sales of our products to customers. Distributors enjoy additional discounts compared to members, allowing them to earn higher direct profits through the differences in pricing when selling products they bought at distributors' prices which are more favorable than member's prices to customers.

Members are encouraged to build their respective network group. Members are promoted to distributors if they manage to recruit the requisite number of members; and the network group is able to achieve set sales targets. Other than preferential distributor pricing for the purchase of the Company's products, distributors enjoy bonuses from the collective performance of their network group. There are several levels of distributors depending on the size and the collective sales performance of their respective network group. Each level affords bonus benefits in a different form in ascending order. A higher-level distributor will be compensated with higher returns in the form of bonus entitlements.

Distributors and members motivation and training

We believe that motivation, inspiration and training are key elements in the success of sales via network group marketing. Together with our distributors and members, we have established a consistent schedule of gatherings to support those needs. We conduct several training sessions per year to educate and motivate our distributors and members. The training sessions are typically presented by in-house staff with suitable background in nutrition, in order to provide key nutrition information about our products, as well as providing workshops to promote presentation skills to attending participants.

Our Suppliers

Currently, all of our products are acquired from unrelated third parties located in Australia, the United States, Germany and Malaysia, and rebranded by us. Due to the high costs associated with research and development of nutrition and health products, we do not maintain any facilities to produce our products. We have no expenditures or expenses relating to research and development of our product. We leverage our team of in-house nutritional consultants with rich experience gained in the area of nutritionist work, in collaborating with our customers and clients to understand the health and wellness market via a process of consultative review. We then communicate our findings and proposals to third-party suppliers to improve formulations and to bring about new products for distributors and members who are ready to market to end-users.

Up to the year ended December 31, 2020, we purchased from Agape S.E.A. Sdn Bhd, one of our largest suppliers, through the SEA Supply Agreement. For more information, please see "The SEA Supply Agreement" below. For the year ended December 31, 2022, we purchased from our three largest suppliers through purchase order forms which included customary terms including unit price, quantity, total price of the orders, and order lead times. We did not enter into any long-term supply agreements with our major suppliers for the six months ended June 30, 2023.

59

The SEA Supply Agreement

Agape S.E.A Sdn Bhd is a dietary supplement company founded in Malaysia. We originally entered into the SEA Supply Agreement with Agape S.E.A. Sdn Bhd, which was one of our largest suppliers at the time, in May 2018. Under the SEA Supply Agreement we purchased dietary supplement products and skincare products from Agape S.E.A.

However, the Company no longer relied on the VIE after the fiscal year ended December 31, 2020. For the six months ended June 30, 2023, and the years ended December 31, 2022 and 2021, we did not purchase any products from Agape S.E.A. Sdn Bhd.

The following summarizes the major terms of the SEA Supply Agreement:

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

60

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Quality Control

At present, our products are predominately sold in Malaysia. As the contents and combination of the main ingredients in our ATP Zeta Health Program and BEAUNIQUE series are categorized as health food rather than medicines or drugs, all of our products require authorization from the Food Safety and Quality Division of the Ministry of Health, Malaysia according to the Food Act 1983 (ACT 281) & Regulations in order to be sold in the country. Accordingly, we have obtained the appropriate authorizations from the Food Safety and Quality Division of the Ministry of Health, Malaysia for all products in our ATP Zeta Health Program and BEAUNIQUE series.

Our ENERGETIQUE series is regulated under the Control of Drugs and Cosmetics Regulations 1984, the Ministry of Health, Malaysia. We have also obtained the appropriate authorizations for distribution and sale of the products.

Inventory

The Company operates a central warehouse at its head office in Kuala Lumpur, Malaysia, which typically maintains an inventory reserve of up to 6 months per product. Inventory is transferred to the Company's sales branches via ordering through the Company's centralized stock tracking system. Stockists of the Company are required to have physical stores, and enjoys the benefit of being able to store certain amount of inventory in their stores for convenience. The stockists shall account to the Company for all products sales from their store premises as monitored through the Company's centralized stock tracking system. The stockists shall have the option to either return or exchange the Company's inventory consigned to them that are unsold.

Seasonality

The Company's business is generally not subject to any seasonality factors.

Warranty

Our products include a customer satisfaction guarantee. Under this guarantee, within 90 days of purchase, any customer who is not satisfied with our product for any reason may return it or any unused portion of it to the distributor from whom it was purchased for a full refund from the Company or credit toward the purchase of another product.

Historically, product returns have not been significant.

61

E-commerce system

In order to facilitate our continued growth and to support distributor activities, we continually invest and upgrade our platforms. In 2019, we invested in an initiative to establish e-commerce through the setup of e-trading of our products on an existing Malaysian e-commerce trading platform. Our e-trading initiative will be actively promoted for online recruitment of new members by existing distributors and to provide direct sales to customers. Once the E-trading platform has provided tangible results in the Malaysia market, we intend to expand the platform to other geographic markets in order to duplicate its success. We also intend to approach online social influencers as part of our marketing strategy to promote our products and our e-commerce platform.

Intellectual Property

We consider trademarks, patents and copyrights to protect our intellectual property rights critical to our success. We are the registered owner of five registered trademarks and with 1 trademark pending registration in Malaysia. We have one applied to register an additional one trademarks in Malaysia. We are also the registered owner of five domain names, namely "agapeatpgroup.com", "agapeatpcorporation.com", "atpsummit.com", "agapeatpgroup.my" and "agapeatpgroup.com.my."

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Employees

As at June 30, 2023 we had 30 employees (excluding our Directors). The following table sets forth the number of employees by function:

    REGISTRATION NO. 333-239951

Senior Management 1 Business Development Department 2 Finance Department 5 Human Resources Department 5 Operations Department 8 Product Development Department 3 Marketing Department 3 Corporate Affairs Department 3 Total 30

Properties

We currently lease 6 properties ranging from approximately 2,500 to 11,900 square feet in Kuala Lumpur, Johor Bahru and Ipoh which primarily carry out the functions of a staff accommodation, warehouse, office, service centers and sales branches in different regions of Malaysia.

Insurance

The Employees' Social Security Act, 1969, Malaysia mandates employers and employees to make a monthly contribution to the Social Security Organisation, Malaysia, ("SOCSO") for any employee who is employed for wages paid under a contract of service or apprenticeship with an employer for the purpose of providing social security protection to employees and their dependents against occupational injuries, including industrial accident, accident during emergency at the employers' premises, occupational diseases and commuting accidents. Depending on the monthly wages earned by the employee, employers shall cause to be deducted from the respective employee's wages, amounts that ranges between RM0.10 to RM19.75 for monthly wages between RM30 to RM4,000. The employers' contribution correspond to the said rates are between RM0.4 to RM69.05. Rates applicable to both the employee and employer are fixed at the maximum rate of RM19.75 and RM69.05 respectively. Employees who have attained 60 years of age are not required to contribute to the scheme. The employer's responsibility towards this group shall be at a reduced rate which ranges between MYR0.30 to RM49.40 for the said wage band.

Other than SOCSO, effective January 1, 2018, employees and employers in the private sector are mandated to contribute to an employment insurance system, ("EIS") under the Employment Insurance System Act, 2017. Both the employee and employer shall contribute at an equal rate at 0.2% of the employee's wages under the scheme, subject to a maximum monthly wage rate of RM4,000. No further contribution to the scheme is required from the employee or the employer for employees who have attained 60 years of age; and employees aged 57 and above who have no prior contributions are exempted.

We do not have any third-party liability insurance to cover claims in respect of personal injury or property or environmental damage arising from accidents on our property or relating to our operations. Such insurance is not mandatory according to the laws and regulations of Malaysia. We typically do not require our distributors to purchase insurance regarding their operations. We believe this practice is consistent with customary industry standards.

Legal Proceeding

We are not subjected to nor engaged in any litigation, arbitration or claim of material importance, and no litigation, arbitration or claim of material importance is known to us to be pending or threatened by or against our Company that would have a material adverse effect on our Company's results of operations or financial condition.

62

    REGISTRATION NO. 333-239951

This section sets forth a summary of the most significant rules and regulations that affect our business activities in Malaysia or the rights of our stockholders to receive dividends and other distributions from us.

Regulations Related to Health and Wellness

The Food Act 1983 (Act 281) and the Food Regulations 1985

The primary legislations governing the various aspects of food safety and quality control in Malaysia are (i) the Food Act 1983 (Act 281) ("the 1983 Act"); and (ii) the Food Regulations 1985 ("the 1985 Regulations"), both under the purview of the Food Safety and Quality Division (FSQD) of the Ministry of Health, Malaysia. The ministry also oversees the implementation and enforcement of the legislations. The objective of the 1983 Act is to ensure that the public is protected from health hazards and fraud in the preparation, sale and use of foods and for matters incidental thereto or connected therewith.

The 1983 Act and the 1985 Regulations are applicable to all foods sold in the country either locally produced or imported, covers a broad spectrum from compositional standards to food additives, nutrient supplements, contaminants, packages and containers, food labelling, procedure for taking samples, food irradiation, and penalty.

The 1983 Act strictly prohibits food adulteration, food containing substances injurious to health and food unfit for human consumption. The legislation also ensures that consumer gets the right information from product labels; and that claims on food labels are legitimate.

Food as defined under the 1983 Act, includes every article manufactured, sold or represented for use as food or drink for human consumption or which enters into or is used in the composition, preparation, preservation, of any food or drink and includes confectionery, chewing substances and any ingredient of such food, drink, confectionery or chewing substances. This includes food for special dietary use for persons with specific diseases, disorders or medical conditions, and food which contain quantities of added nutrients allowable under the 1983 Act and the 1985 Regulations.

The general requirements on product labelling for food on sale provided under the 1985 Regulations are as follows:

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

(iii) Important particulars required on product labels are:

    REGISTRATION NO. 333-239951

? Quantity of the food package.

63

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

? Marked with the expiry date or the date of minimum durability of that food.

    REGISTRATION NO. 333-239951

Further, based on the Guide to Nutrition Labelling and Claims, the nutritional information that must be declared on a product label are energy, protein, carbohydrate and fat. In addition, total sugars must also be declared for ready-to-drink beverages. Information on energy value is to be expressed as kcal (kilocalories) per 100 g or per 100 ml of the food or per package if the package contains only a single portion. In addition, the energy value should also be given for each serving of the food as quantified on the label. Besides kcal, energy value may also be expressed as kilojoule (kJ). The amount of protein, carbohydrate and fat should be expressed as g per 100 g or per 100 ml of the food or per package if the package contains only a single portion. In addition, the amount of these nutrients in the food should also be given for each serving of the food as quantified on the label.

Other than the mandatory nutrients, other nutrients may also be displayed on the nutrition label. These include vitamins and minerals, dietary fibre, sodium, cholesterol, fatty acids, amino acid, nucleotide and other food components.

Both ATP Zeta Health Program and BEAUNIQUE product series are regulated under the 1983 Act and the 1985 Regulation. ASL, the product owner of these product series are subject to 1983 Act and the 1985 Regulation.

Traditional and Complementary Medicine (T&CM) Act 2016 [Act 775]

The Traditional and Complementary Medicine (T&CM) Act 2016 [Act 775] (the "TCM Act") is an act to provide for the establishment of the T&CM Council to regulate the T&CM services in Malaysia and to provide for matters connected therewith. The TCM Act received Royal Assent on 2 March 2016 and was published in the Federal Government Gazette on 10 March 2016.

The enforcement of the TCM Act is implemented in phases. Phase 1 begun operation on August 1, 2016 with the establishment of the T&CM Council, identification of recognized practice areas, setting up the registration criteria for recognized practice areas, designation of practitioner body under section 42 of the TCM Act and enforcement of the various sections under Phase 1 in the TCM Act.

Phase 2 of the TCM Act begun operation on March 1, 2021 and include the registration of T&CM practitioners in recognized practice areas with the T&CM Council, the enforcement of various sections under the TCM Act and the operation of T&CM Regulations 2021. The transitional period of Phase 2 of the TCM Act began on March 1, 2021 and will last until February 29, 2024.

The business activities of DSY Wellness International Sdn Bhd, our complementary health therapies are regulated under TCM Act. DSY Wellness International Sdn Bhd complementary health therapies are subject to TCM Act.

Control of Drugs and Cosmetics Regulations 1984

The Malaysian government enacted the Control of Drugs and Cosmetics Regulations 1984 ("the 1984 Regulations") to regulate the manufacture, sell, supply, import, possess or administer of cosmetics. The authority that oversee the 1984 Regulations is the National Pharmaceutical Regulatory Agency ("NPRA") under the Ministry of Health, Malaysia. All cosmetics industry players who intend to manufacture or import any cosmetic, must apply the notification of cosmetics ("NOC") through NPRA.

Pursuant to Regulation 18A of the 1984 Regulations, cosmetics cannot be manufactured or sold if:

(i) The cosmetic has not been notified with the NPRA;

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

(iv) The notified cosmetic has been mixed with a registered product;

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

ENERGETIQUE product series are regulated under the 1984 regulation. ASL, the product owner of these product series is subject to the 1984 Regulations and relevant regulation.

64

Regulations Related to Consumer Protection

Consumer Protection Act 1999 (Act 599)

The principal law for consumer protection in Malaysia is the Consumer Protection Act 1999 (Act 599) ("the 1999 Act"). The 1999 Act establishes various consumer protection mechanisms in Malaysia, and bridge gaps that may occur in other major laws, which may be inadequate in protecting consumers. The government agency which is primarily responsible for policy-making and law enforcement on consumer protection in Malaysia is the Ministry of Domestic Trade and Consumer Affairs (MDTCA). The MDTCA is also responsible for receiving consumer complaints and acts as a secretariat to the National Consumer Advisory Council (NCAC) - an institution established by the Minister of Domestic Trade and Consumer Affairs to advise him on any relevant consumer issues and the implementation of the 1999 Act.

The 1999 Act has undergone several amendments since its enactment to cover various emerging issues relating to consumers, including the inclusion unfair contract terms, inclusion of credit sale agreements of goods and the most recent amendment on July 23, 2019 related to Tribunal for Consumer Claims Malaysia. Amendments to this Act are to increase the jurisdiction limit of claim hearing from RM25,000.00 to RM50,000.00 and the increase of maximum penalty for non-compliance with the Tribunal's award.

The 1999 Act covers almost every aspects of consumer protection; ranging from misleading and deceptive conducts, false representation and unfair practices; safety of goods and services; unfair contract terms; guarantees in respect of the supply of goods and services; and product liability; to the establishment, structure and functions of the National Consumer Advisory Council; the Committee on Advertisement; the Tribunals for Consumer Claims; and other matters related to enforcement, offences, remedies, and compensation.

All series products produced by us in Malaysia are subject to Consumer Protection Act 1999 (Act 599).

Direct Sales and Anti-Pyramid Scheme Act 1993 (Act 500) and Regulations.

In Malaysia, network marketing is regulated by the Direct Sales and Anti-Pyramid Scheme Act 1993 (Act 500) ("the 1993 Act) and Regulations. The 1993 Act provides for the licensing of persons carrying on direct sales business, for the regulation of direct selling, for prohibiting pyramid scheme or arrangement, chain distribution scheme or arrangement, or any similar scheme or arrangement, and for other matters connected therewith. The implementation and enforcement of the 1993 Act is governed by the Ministry of Domestic Trade and Consumer Affairs.

Under the 1993 Act, subject to section 14 and 42 no person shall carry on any direct sales business unless it is a company incorporated under the Companies Act 1965 and holds a valid licence granted under Section 6. The Controller may grant licence under Section 6 of the 1993 Act with conditions and licensee shall comply with the any conditions of the licence imposed by the Controller. By virtue of Section 8 of the 1983 Act, the Controller has the power to revoke a licence granted if he is satisfied that there are grounds on which his power to revoke a licence is exercisable under subsection 8(1). In lieu of revocation of licence, the Controller may restrict the licence by:

(a) Imposing limits on the duration of the licence;

    REGISTRATION NO. 333-239951

(c) Imposing both limits and conditions on the licence.

65

We have the responsibility to ensure that our marketing plan is in compliance with the Direct Sales (Scheme and Conduct) Regulations 2001, not promoting pyramid scheme and have the following characteristics:

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Regulations Related to Intellectual Property Rights

Intellectual property system in Malaysia is administered by the Intellectual Property Corporation of Malaysia (MyIPO), an agency under the Ministry of Domestic Trade and Consumer Affairs.

Trademarks Act 2019 (Act 815)

The Trademarks Act 2019 (Act 815) ("the 2019 Act") officially came into force in Malaysia on 27 December 2019. The Act repealed the Trade Marks Act 1976 and is seen as opportune in enabling Malaysia to adhere not only to commercial demands and sophistication of the current era, but also to international standards and procedures. The Trademarks Regulations 2019 is also now in force having been gazetted in the Government Gazette on 27 December 2019.

Malaysia is also a member of various trademark-related treating, including:

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

The 2019 Act provides that any person who claims to be the bona fide proprietor of a trademark may apply for the registration of the trademark if:

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

The 2019 Act has also expanded the types of trademark recognized for registration to be more than just word, logo, numbers, name. signature, letter and to include shape of goods or their packaging, colour, sound, scent, hologram, positioning marks and sequence of motion of any combination thereof; provided that they must be signs capable of being represented graphically.

In general, Malaysia provides for protection for both registered and unregistered trademarks. Unregistered trademarks are protected under common law rights, particularly in the tort of passing off. In fact even during the examination of trademark, the Registrar shall refuse, under relative grounds of Section 24(4) of the 2019 Act, to register it if the mark's use in Malaysia is prevented by virtue of any rule of law protecting an unregistered trademark or other sign used in the course of trade including the law of passing of.

The scope of trademark infringement and its exemptions has been substantially expanded by the 2019 Act. There could now be infringement even in the use of a similar mark on similar goods or services (as opposed to being identical). Liability will stick to secondary users who know or have reasons to believe that such use is without authorization of the trademark proprietor.

The 2019 Act and relevant regulation are applicable own our brand, word, logo, numbers, name. signature, letter and to include shape of goods or their packaging, color, sound, scent, hologram, positioning marks and/or sequence of motion of any combination.

Copyright Act 1987 (Act 332)

Copyright protection in Malaysia is governed by the Copyright Act 1987 (Act 332) ("the 1987 Act) which provides comprehensive protection for copyrightable works. The 1987 Act outlines the nature of works eligible for copyright (which includes computer software), the scope of protection, and the manner in which the protection is accorded. A unique feature of the 1987 Act is the inclusion of provisions for enforcing the Act, which include such powers to enter premises suspected of having infringing copies and to search and seize infringing copies and contrivances. Malaysia is a signatory of the Berne Convention. Foreign works of non-Berne member countries are also protected if they are made in Malaysia and are published in Malaysia within thirty days of their first publication in the country of origin.

66

Unlike trademarks, designs and patents (other intellectual property rights), there is no specific system of registration for copyright in Malaysia. Although copyright is a non-registrable right in Malaysia and enjoys automatic protection, ownership of copyright is difficult to establish. As such, proper documentation can be prepared to prove ownership. Copyright owners can claim ownership by way of a Statutory Declaration or by filing a Voluntary Notification at the MyIPO.

The definition of a literary work now includes table or compilations "whether or not expressed in words, figures or symbols and whether or not in a visible form". The owner of copyright in a work including a derivative work, will have the exclusive right to control "the transmission of a work through wire or wireless means to the public, including the making available of a work to the public in such a way that members of the public may access the work from a place and at a time individually chosen by them".

It is also an infringement of copyright to circumvent any effective technological measures aimed at restricting access to works, removal or alteration of any electronic rights management information without authority, or distribution, importation for distribution or communication to the public, without authority, works or copies of works in respect of which electronic rights management information has been removed or altered without authority.

The 1987 Act and the relevant regulations are benefited us which we are eligible to claim ownership by compiling proper documentation to prove ownership via a Statutory Declaration or by filing a Voluntary Notification at the MyIPO.

Regulations Related to Employment and Social Security

Employment Act 1955 (Act 265)

The Employment Act 1955 (Act 265) ("the 1955 Act) is the primary legislation on labour matters in Malaysia. The 1955 Act provides for minimum work requirements and benefits of employment, such as maximum working hours, overtime entitlement, leave entitlement, maternity protection and termination benefits. The 1955 Act applies only to employees earning a monthly wages of not more than RM2,000.00 or to employees, irrespective of their monthly wages, who are engaged in manual labour, including artisan or apprentice, or who are engaged in the operation of maintenance of mechanically propelled vehicles operated for the transport of passengers or goods or for commercial purposes, or who supervise or oversee other employees engaged in manual labour or who are engaged in any capacity in any vessel registered in Malaysia or who are engaged as domestic servant.

Children and Young Persons (Employment) Act 1966 (Act 350)

Children and Young Person (Employment) Act 1996 (Act 350) ("the 1996 Act") prohibits children from working near hazardous and poisonous material. The 1996 Act defines a "child" is a person who is under the age of fifteen years and a "young person" is a person who is fifteen or older, but below the age of eighteen years. The 1996 Act goes on to provide the minimum working hours for a child and young person. Further, under 1996 Act no child or young person shall be, or be required or permitted to be, engaged in any employment contrary to the provisions of the Factories and Machinery Act 1967 (Act 139), the Occupational Safety and Health Act 1994 (Act 514) or the Electricity Supply Act 1990 (Act 447) or in any employment requiring him to work underground. Any person contravening the provisions under the 1996 Act shall be guilty of an offense and shall be liable on conviction to imprisonment of not exceeding 2 years or to fine not exceeding RM50,000 or to both; and for repeat offenders, shall be liable on conviction to imprisonment of not exceeding 5 years or to fine not exceeding RM100,000 or to both.

Employees' Provident Fund Act 1991 (Act 452)

The Employees' Provident Fund Act 1991 (Act 452) ("the 1991 Act") imposes the statutory obligations on employers and employees to make contribution towards the Employees Provident Fund, which is essentially a fund established as a scheme of savings for employees' retirement and the management of savings for the retirement purposes. Under the 1991 Act, any employer who fails to pay the necessary contributions shall be liable to imprisonment for a term not exceeding three years or to a fine not exceeding ten thousand ringgit or to both.

67

Employee' Social Security Act 1969 (Act 4)

The Employee's Social Security Act 1969 (Act 4) ("the 1969 Act') was implemented to provide protection for employees and their families against economic and social distress in situations where the employees sustain injury or death. The schemes of social security under the 1969 Act are administered by Social Security Organization ("SOCSO") and are financed by compulsory contributions made by the employers and the employees. Under the 1969 Act, any person who fails to make contribution shall be all be punishable with imprisonment for a term which may extend to two years, or with fine not exceeding ten thousand ringgit, or with both.

Employment Insurance System Act 2017 (Act 800)

SOCSO reached a milestone when the Employment Insurance System Act 2017 (Act 800) was introduced and enforced from 28 December 2017 with the aim to provide protection and assist workers who have lost employment through two (2) main components namely, the Employment Insurance and Active Labour Market Policies. The Employment Insurance System (EIS) provides protection to workers who have lost their employment through income replacement, reskilling and upskilling training to enhance their employability as well as employment services so that they can secure other suitable jobs fast.

Our all employees which under definition of the Employment Act 1955 (Act 265) ("the 1955 Act) are subject to the provision of Employees' Provident Fund Act 1991 (Act 452), Employee' Social Security Act 1969 (Act 4), and Employment Insurance System Act 2017 (Act 800).

Regulation Related to Taxation

Income Tax Act 1967 (Act 53)

The Income Tax Act 1967 (Act 53) ("the 1967 Act") imposes a tax, known as income tax, for each year of assessment upon the income accruing in or derived from Malaysia, or received in Malaysia from other countries. A company is a tax resident in Malaysia if its management or control is exercised in Malaysia and generally, the place where directors' meetings are held concerning management and control of the company are considered in determining where the management and control of the company is exercised.

Under the 1967 Act, any person who makes an incorrect tax return by omitting or understating income or gives incorrect information affecting chargeability to tax otherwise than in good faith shall be guilty of an offence and shall upon conviction be liable to a fine not less than RM1,000.00 and not more than RM10,000.00 and shall pay a special penalty of double the amount of tax which had been undercharged.

The Company which is incorporated under Companies Act 2016 (Act 777) is subject to Income Tax Act The Company which is incorporated under Companies Act 2016 (Act 777) is subject to Income Tax Act.

Regulation Related to Foreign Exchange Control

Financial Services Act 2013 (Act 758)

The Financial Services Act 2013 (Act 758) provides regulation and supervision of financial institutions, payment systems and other relevant entities and the oversight of the money market and foreign exchange market to promote financial stability and for related, consequential or incidental matters.

Pursuant to the Foreign Exchange Administration Rules, a resident entity with domestic ringgit is only allowed to invest abroad up to RM50 million per calendar year ("the Maximum Foreign Investment"). For the avoidance of doubt, the limit of such Maximum Foreign Investment applies to the resident entities within the group of companies.

Notwithstanding the above, the Foreign Exchange Administration Rules allows non-residents to remit out divestment proceeds, profits, dividends or any income arising from investments in Malaysia. Repatriation, however, must be made in foreign currency.

As such, if our operating subsidiaries intend to invest exceeding the Maximum Foreign Investment, we are required to seek approval from the controller of Foreign Exchange, Central Bank of Malaysia

Regulation Related to Competition Law

Competition Act 2010 (Act 712)

In Malaysia, under the Competition Act 2010 (Act 712) ("the 2010 Act), such provisions may be considered to be anti-competitive if they are found to significantly prevent, restrict or distort competition in any market for goods or services. The 2010 Act is regulated by the Malaysia Competition Commission ("MyCC"), an independent body established under the Competition Commission Act 2010 (Act 713) to enforce the 2010 Act. The Competition Commission Act 2010 empowers MyCC to carry out functions such as implement and enforce the provisions of the 2010 Act, issue guidelines in relation to the implementation and enforcement of the competition laws, act as advocate for competition matters; carry out general studies in relation to issues connected with competition in the Malaysian economy or particular sectors of the Malaysian economy; inform and educate the public regarding the ways in which competition may benefit consumers in and the economy of Malaysia.

68

The 2010 Act prohibits horizontal or vertical agreements between enterprises that either the object or effect of significantly preventing, restricting or distorting competition in Malaysia. This is referred to as "Chapter One Prohibition". MyCC has indicated in its "Guidelines on Chapter 1 Prohibition" that in general, anti-competitive agreements will not be considered "significant" if:

    REGISTRATION NO. 333-239951

Further, the 2010 Act also prohibits enterprises from abusing their "dominant position" in a market. This is referred to as the "Chapter Two Prohibition". The term "dominant position "refers to one or more enterprises possessing such significant power in a market that they are able to adjust prices, outputs, or trading terms without effective constraint from competitors or potential competitors. There are no specific thresholds for abuse of a dominant position However, the following are the types of abuses prohibited under the 2010 Act; (i) predatory behaviour (for example, margin squeeze, and predatory pricing); (ii) refusal to supply; (iii) buying up scarce supply; and (iv) limiting output.

Pursuant to MyCC "Guidelines on Chapter 2 Prohibition", market share above 60% would be indicative that an enterprise is dominant. Nevertheless, market share shall not by itself be regarded as conclusive of dominance and other factors will be taken into account is assessing whether an enterprise is dominant.

In there is any infringement with the 2010 Act, MyCC may (i) require that the infringement be ceased immediately; (ii) specify steps which are required to be taken by the infringing enterprise(s) to bring the infringement to an end; (iii) impose financial penalties which could, for example, be 10% of the worldwide turnover of the relevant enterprise over the period during which an infringement occurred; or (iv) take any number of other actions, including imposing sanctions and penalties, as they deem appropriate.

We shall ensure there is any infringement with the 2010 Act, which we shall not:

(a) Be the parties to the agreement are competitors who are in the same market and their combined market share of the relevant market exceed 20%; or

(b) Be the parties to the agreement are not competitors and their individual market share in relevant market is more than 25%.

Regulation Related to Establishment, Operation and Management of Malaysia Subsidiaries

Companies Act 2016 (Act 777)

The Companies Act 2016 (Act 777) ("the 2016 Act") stipulates that a company must be registered with the Companies Commission Malaysia in order to engage in any business activity. Under the 2016 Act, a company shall have - (a) a name; (b) one or more members, having limited or unlimited liability for the obligations of the company; (c) in the case of a company limited by shares, one or more shares; and (d) one or more directors. With the liberalization in Malaysia equity policy, foreign companies/investors generally could hold 100% equity in majority industries except for strategic sectors of national interest such as water, telecommunications, ports, and energy. For every industry, there are specific sector regulations issued by the relevant governmental departments. These include regulations that could impose restrictions on the foreign ownership of equity of a company, require higher paid up capital requirements and also prior regulatory approval before the commencement of business operations. However, limits on foreign ownership do remain in place across many sectors such as telecommunications, oil & gas, tourism, wholesale and retail distributive trade, and financial services. A corporation is a "wholly-owned subsidiary" of another corporation if it has no members except- (a) that other corporation or its nominee; or (b) a wholly-owned subsidiary of that other corporation or its nominee. Private companies require a minimum of one director. A director shall ordinarily reside in Malaysia by having a principal place of residence in Malaysia.

Pursuant to the 2016 Act, appointment of an auditor is mandatory. However, the Registrar may exempt private companies from appointing an auditor where the Company is dormant, a zero-revenue company or a threshold-qualified company. Companies that elect to be exempted from audit must still lodge unaudited financial statements and the required statutory certificates with the Registrar of Companies. Since the coming into effect of the 2016 Act, private companies are no longer obligated to convene annual general meetings. However, stockholders have the right to request for the directors of the company to convene a general meeting. This right is however subject to the requirements in Section 311 of the 2016 Act.

For all companies incorporated in Malaysia (except in Labuan, Malaysia) are subject to the Companies Act 2016 (Act 777).

69

    REGISTRATION NO. 333-239951

Directors and Executive Officers

The following table sets forth information regarding our executive officers and directors as of the date of this prospectus:

Directors and Executive Officers (Last Name, First Name) Age Position/ Title How Kok Choong 59 Chief Executive Officer, President, Director, Chief Operating Officer, Chairman of the board of Directors and Secretary Lee Kam Fan Andrew 61 Chief Financial Officer Ramesh Ruben Louis 46 Independent Director Vong John Hing 70 Independent Director Chee Chin Aik 43 Independent Director

Dr. How Kok Choong is our founder and serves as our Chief Executive Officer, President, Director Chief Operating Officer, Chairman of the Board of Directors and Secretary since 2016. Dr. How is primarily responsible for overall development and business strategies, financial, administrative and human resources affairs of the Company. Dr. How has more than 20 years of experience in the senior management roles in the health and wellness industry. From 1987 to 2016, Dr. How was with the San Hin Group of Companies and his last position held was the group chief executive officer for the group. Since August 2003, Dr. How began to work for AGAPE Superior Living International Group as the global president and continues to hold this position. Further, since September 2009, Dr. How has worked for TH3 Holdings Sdn Bhd as president. Dr. How obtained a master's degree and a doctorate degree in Business Administrative from Newport University, USA in December 1997 and December 2000, respectively. In Malaysia, Dr. How Kok Choong was recognized by the Junior Chamber Malaysia (JCM) as an Outstanding Young Malaysian 2003, and was awarded the title of Justice of Peace of Malaysia since 2005. Dr. How Kok Choong received the Outstanding Asian Community Contribution Award in 2011, Malaysia Top Team 50 Enterprise Award in 2011 and 2016, The Contributor Award (Medical and Health Research) in 2012, "Man of The Year" in Worldwide Excellence Award in 2015, "Man of The Year" in McMillan Global Award in 2016, The Distinguished Asia Pacific Outstanding Entrepreneur Lifetime Achievement Award in 2019, World Outstanding Chinese Entrepreneur Lifetime Award in 2019 and Certified Professional Trainer of The International Professional Managers Association in 2019.

Mr. Lee Kam Fan, Andrew serves as our chief financial officer of the Company. Prior to joining the Company in January 2021, Mr. Lee has approximately 38 years of accounting and finance related experience. Since July 2014, Mr. Lee has been the proprietor of Andrew Lee & Company. Since June 2010, Mr. Lee served as an adjunct lecturer of the HKICPA Processional Examinations Preparatory Programme at HKU Space. From January 2011 to October 2015, Mr. Lee served as the managing director at ANSA CPA Limited. From September 2010 to October 2012, Mr. Lee served as an independent non-executive director at Sunrise (China) Technology Group Limited (currently referred to as KOALA Financial Group Limited (Hong Kong stock code: 08226)). From March 2006 to April 2017, Mr. Lee was in cooperation with Friedman LLP to oversee financial statements are prepared in accordance with U.S. GAAP. From October 2000 to December 2010, Mr. Lee served as an audit manager and subsequently a partner at Clodick & Company. From April 1998 to September 2000, Mr. Lee served as a director at Nitwell Business Services Limited. From August 1994 to April 1998, Mr. Lee was an assistant audit manager at Cheng, Kwok & Chang. From July 1990 to July 1994, Mr. Lee served as an accountant at K.C. Manufacturing Company. From April 1989 to July 1990, Mr. Lee served as an accountant at Haldane, Midgley & Booth. From January 1987 to April 1989, Mr. Lee served as an audit senior at RSM Nelson Wheeler. From October 1985 to December 1986, Mr. Lee served as an audit assistant at Andrew Ma & Company. From April 1983 to September 1985, Mr. Lee served as an audit Clerk at Anthony Y.T. Tse & Company. Mr. Lee is an associate member of the Institute of Chartered Accountants in England and Wales since April 2019, a certified public accountant (practicing) of the Hong Kong Institute of Certified Public Accountants since May 2010, a fellow member of the Association of International Accountants since December 2006, and an associate member and certified tax advisor of the Tax Institute of Hong Kong since July 2010. Mr. Lee received his bachelor's degree in business administration at the Open University of Hong Kong (currently referred to as Hong Kong Metropolitan University) in June 2004 and his master's degree in professional accounting from the Hong Kong Polytechnic University in November 2010.

Mr. Ramesh Ruben Louis, PhD is our independent director. Prior to joining the Company, Mr. Louis, PhD has approximately 25 years of accounting and finance related experience. Since January 2011, Mr. Louis, PhD has been an executive director and principal consultant of Assurance Threesixty Consulting. Since November 2009, Mr. Louis, PhD has been a professional freelance trainer and consultant at My Learning Training Resources, where he conducted various training courses including training for MIA, ACCA, CPA Australia ISCA Singapore. From May 2006 to October 2009, Mr. Louis, PhD was an executive director at Anuarul Azizan Chew Group, where he was involved in internal audit, risk management and review/assessment of internal controls assignments of various organisations including public listed companies in Malaysia. From 2000 to 2006, Mr. Louis, PhD worked in BDO Binder, where he worked in areas including corporate finance and assurance advisory, his last role being assistant audit manager. From 1997 to 1998, Mr. Louis, PhD was an audit assistant at Arthur Andersen & Co. Mr. Louis, PhD graduated with a bachelor of accounting from the National University of Malaysia in 2000, and graduated with a master of business administration from the University of Strathclyde, United Kingdom in 2012. Mr. Louis, PhD obtained a doctorate of philosophy from the University of Malaya in September, 2021. Mr. Louis, PhD became a member of CPA Malaysia in 2005, a member of the Institute of Internal Auditors Malaysia in 2010 and a member of the Association of Chartered Certified Accountants in 2011. Mr. Louis, PhD is also a director of Greenpro Capital Corp., Seatech Ventures Corp. and Fortune Valley Treasures, Inc.

Dr. Vong John Hing, PhD is our independent director. Prior to joining the Company, Dr. Vong, PhD has over 44 years of fintech and education experience. Dr. Vong, Phd is currently the lead of sustainable finance at ClimateWorks Australia since September 2021, a non-executive independent council member of Regional Bank since June 2013, and a senior technical specialist of the United Nations since May 2003. Dr. Vong, PhD has been a senior technical specialist at Asian Development Bank from January 2019 to February 2022, and a senior technical consultant at World Bank Group from September 2006 to June 2021. Dr. Vong, PhD has been a professor at the National University of Singapore from May 2015 to April 2017, foundation director of the Fintech Academy at the Singapore Management University from June 2013 to December 2014 and associate professor at James Cook University Singapore from February 2012 to June 2013. From October 2008 to October 2011, Dr. Vong, PhD was a deputy chief executive officer at Sacombank in Vietnam. In 2002 Dr. Vong, PhD was a senior consultant at PAGF- DFAT Australia in the Philippines. From February 1999 to February 2001, Dr. Vong, PhD was a team leader at Deloitte Australia. From 1994 to 1998 Dr. Vong, PhD was a regional director- lecturer of the Massachusetts Institute Technology and Nanyang Fellows Program at Nanyang Technological University. From May 1978 to August 1993, Dr. Vong, PhD was a senior executive at HSBC Holdings plc in various offices in Australia and Asia. Dr. Vong, PhD completed the public disputes program in advanced negotiation at MIT-Harvard University Consensus Building Institute in 2006. Dr. Vong, PhD graduated with a BA in economics at Birmingham City University, and a MBA in economics strategy and finance at University of Bradford. He received his PhD from the University of Bradford in MIS business intelligence. Dr. Vong, PhD is currently a member of CPA Australia.

Mr. Chee Chin Aik is our independent director. Prior to joining the Company, Mr. Chee has approximately 20 years of finance related experience. Mr. Chee is currently the head of South East Asia, cash and non-cash equity sales, global markets at HSBC Singapore. From October 2020 to May 2022, Mr. Chee was an executive director, head of Malaysia equity distribution and board member of JPMorgan Chase & Co. Mr. Chee has also worked at Credit Suisse for various periods, as director in institutional equity sales for Malaysia and Singapore from January 2019 to September 2020, as vice president in institutional equity sales in Singapore from January 2015 to December 2018, and associate in institutional equity sales in Singapore from April 2013 to December 2014. From January 2009 to August 2011, Mr. Chee worked as analyst and trader in equity derivatives and proprietary trading at Aminvestment Bank Berhad in Malaysia. From October 2007 to September 2008, Mr. Chee worked as equity research analyst at Credit Lyonnais Securities Asia Pacific Markets in Malaysia. From October 2006 to July 2007, Mr. Chee worked as associate in fixed income currencies and commodities at Goldman Sachs in USA. From July 2004 to October 2006, Mr. Chee worked as analyst for fixed income, corporate advisory division at Lehman Brothers Holdings Inc in USA. From Jun 2002 to July 2004, Mr. Chee worked as associate in financial regulatory and cycle examination group at National Association of Securities Dealers (FINRA) in USA. Mr. Chee graduated with a bachelor of arts from Franklin & Marshall College and MBA in finance from the University of Chicago Booth School of Business.

70

Employment Agreements

We have entered into employment agreements with all of our executive officers. Under these agreements, each of our executive officers is employed for a specified time period. We may terminate employment for cause, at any time, without advance notice or remuneration, for certain acts of the executive officer, such as conviction or plea of guilty to a felony or any crime involving moral turpitude, negligent or dishonest acts to our detriment, or misconduct or a failure to perform agreed duties. We may also terminate an executive officer's employment without cause upon advance written notice or payment in-lieu of notice. In such case of termination by us, we will provide severance payments to the executive officer as expressly required by applicable law of the jurisdiction where the executive officer is based. The executive officer may resign at any time upon advance written notice.

Each executive officer has agreed to hold, both during and after the termination or expiry of his or her employment agreement, in strict confidence and not to use, except as required in the performance of his or her duties in connection with the employment or pursuant to applicable law, any of our confidential information or trade secrets, any confidential information or trade secrets of our clients or prospective clients, or the confidential or proprietary information of any third party received by us and for which we have confidential obligations.

Terms of Directors and Officers

Our officers are elected by and serve at the discretion of the board of directors and the stockholders voting by ordinary resolution.

Compensation of Directors and Executive Officers

For the years ended December 31, 2022 and 2021, we paid an aggregate of approximately $289,957 and $275,210, respectively, in cash and benefits to our executive officers. We do not have a share incentive program to provide for grants of awards to our directors and executive officers. We have not set aside or accrued any amount to provide pension, retirement or other similar benefits to our executive officers and directors. We have no service contracts with any of our directors providing for benefits upon termination of employment.

Board of Directors and Committees

Our board of directors consists of four directors, including three independent directors. We established three committees under the board of directors immediately upon the effectiveness of our registration statement on Form S-1, of which this prospectus is a part: an audit committee, a compensation committee and a nominating and corporate governance committee. We intend to adopt and approve a charter for each of the three committees prior to consummation of this offering. Each of the committees of the board of directors shall have the composition and responsibilities described below.

Audit Committee

Mr. Louis, PhD, Dr. Vong, PhD, and Mr. Chee are the members of our Audit Committee where Mr. Louis, PhD is the chairman. All members of our Audit Committee satisfies the independence standards promulgated by the SEC and by NASDAQ as such standards apply specifically to members of audit committees.

71

We adopted and approved a charter for the Audit Committee prior to consummation of this offering. In accordance with our Audit Committee's Charter, our Audit Committee shall perform several functions, including:

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

It is determined that Mr. Louis, PhD possesses accounting or related financial management experience that qualifies him as an "audit committee financial expert" as defined by the rules and regulations of the SEC.

Compensation Committee

Mr. Louis, PhD, Dr. Vong, PhD and Mr. Chee are the members of our Compensation Committee where Dr. Vong, PhD is the chairman. All members of our Compensation Committee are qualified as independent under the current definition promulgated by NASDAQ. We adopted and approved a charter for the Compensation Committee prior to consummation of this offering. In accordance with the Compensation Committee's Charter, the Compensation Committee shall be responsible for overseeing and making recommendations to the board of directors regarding the salaries and other compensation of our executive officers and general employees and providing assistance and recommendations with respect to our compensation policies and practices.

Nominating and Governance Committee

Mr. Louis, PhD, Dr. Vong, PhD, and Mr. Chee are the members of our Nominating and Governance Committee where Mr. Chee is the chairman. All members of our Nominating and Governance Committee is qualified as independent under the current definition promulgated by NASDAQ. The board of directors adopted and approved a charter for the Nominating and Governance Committee prior to consummation of this offering. In accordance with the Nominating and Governance Committee's Charter, the Nominating and Corporate Governance Committee shall be responsible for identifying and proposing new potential director nominees to the board of directors for consideration and reviewing our corporate governance policies.

Director Independence

Our board of directors reviewed the materiality of any relationship that each of our proposed directors has with us, either directly or indirectly. Based on this review, it is determined that Mr. Louis, PhD, Dr. Vong, PhD and Mr. Chee are "independent directors" as defined by NASDAQ. In addition, as required by Nasdaq rules, our board of directors has made a subjective determination as to each independent director that no relationships exist, which, in the opinion of our board of directors, would interfere with the exercise of independent judgment in carrying out the responsibilities of a director. In making these determinations, our board of directors reviewed and discussed information provided by the directors and us with regard to each director's business and personal activities and relationships as they may relate to us and our management.

72

Family Relationships

There is no family relationship among any of our directors or executive officers.

Board Leadership Structure and Role in Risk Oversight

Our Board of Directors, or the Board, is primarily responsible for overseeing our risk management processes on behalf of our company. The Board receives and reviews periodic reports from management, auditors, legal counsel, and others, as considered appropriate regarding our company's assessment of risks. In addition, the Board focuses on the most significant risks facing our company and our company's general risk management strategy, and also ensures that risks undertaken by our company are consistent with the board's appetite for risk. While the Board oversees our company's risk management, management is responsible for day-to-day risk management processes. We believe this division of responsibilities is the most effective approach for addressing the risks facing our company and that our board leadership structure supports this approach.

Compensation Committee Interlocks and Insider Participation

None of our executive officers currently serves, or in the past year has served, as a member of the board of directors or compensation committee of any entity that has one or more executive officers on our board of directors or compensation committee.

Code of Ethical Business Conduct

We have a code of ethical business conduct that applies to all of our employees, including our principal executive officer, principal financial officer and principal accounting officer, and the Board. A copy of this code is available in our employee handbook and under the "About Us - Code of Conduct" section of our website at www.agapeatpgroup.com. In addition, we intend to post on our website all disclosures that are required by law or the listing standards of our applicable trading market concerning any amendments to, or waivers from, any provision of the code. The reference to our website address does not constitute incorporation by reference of the information contained at or available through our website, and you should not consider it to be a part of this prospectus.

73

Involvement in Certain Legal Proceedings

To our knowledge, our directors and executive officers have not been involved in any of the following events during the past ten years:

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

74

    REGISTRATION NO. 333-239951

Executive Officers' Compensation

The following table sets forth information concerning the annual and long-term compensation earned by or paid to our Chief Executive Officer and to other persons who served as executive officers as at fiscal years ended December 31, 2022 and 2021, or the named executive officers, for services as executive officers for the said fiscal year.

Summary Compensation Table

    REGISTRATION NO. 333-239951

Lee Kam Fan Andrew 2022 46,440 - - - - - 46,440 Chief Financial Officer 2021 46,988 - - - - - 46,988

75

Employment Agreements

How Kok Choong

Dr. How currently devotes approximately 90% per week of his time to manage the affairs of the Company. He has agreed to work with no remuneration nor drawn any (i) bonus; (ii) stock compensation; (iii) option awards; (iv) non-equity incentive plan compensation; (v) non-qualified deferred compensation earnings; and (vi) any other compensations until such time as the Company receives significant revenues necessary to provide management salaries. At this time, we cannot accurately estimate when significant revenues will occur to implement this compensation, or what the amount of the compensation will be.

Lee Kam Fan Andrew

On January 12, 2021, we entered into an Executive Employment Agreement with Mr. Lee Kan Fan Andrew, our Chief Financial Officer. Pursuant to the agreement, Mr. Lee is employed as our Chief Financial Officer. During the term of his employment, Mr. Lee will be entitled to a base salary at the annualized rate of $3,870. Pursuant to the agreement, Mr. Lee may be terminated for "cause" as defined in the agreement and Mr. Lee may resign upon the provision of a prior notice in writing not less than one (1) months to the Company or payment in lieu of notice at any time. In the event Mr. Lee is terminated without cause, we will be required to pay Mr. Lee all accrued salary, reimbursement for all business expenses. In the event Mr. Lee is terminated with cause, dies or is disabled, we will be required to pay Mr. Lee all accrued salary. Under the agreement Mr. Lee is subject to confidentiality restrictions.

Incentive Bonus

The Board may grant incentive bonuses to our executive officer and/or future executive officers in its sole discretion, if the Board of Directors believes such bonuses are in the Company's best interest, after analyzing our current business objectives and growth, if any, and the amount of revenue we are able to generate each month, which revenue is a direct result of the actions and ability of such executives.

Option Exercises and Stock Vested

We have not granted any stock options to our executive officers since our incorporation.

Long-term, Stock Based Compensation

In order to attract, retain and motivate executive talent necessary to support the Company's long-term business strategy we may award our executive and any future executives with long-term, stock-based compensation in the future, at the sole discretion of our Board of Directors, which we do not currently have any immediate plans to award. We have not granted any stock options to our executive officers since our incorporation.

No Pension Benefits

We do not maintain any plan that provide for payments or other benefits to our executive officers at, following or in connection with retirement and including, without limitation, any tax-qualified defined benefit plans or supplemental executive retirement plans.

76

No Nonqualified Deferred Compensation

We do not maintain any defined contribution or other plan that provides for the deferral of compensation on a basis that is not tax-qualified.

Director Compensation

    REGISTRATION NO. 333-239951

Mr. Ramesh Ruben Louis was appointed to the Board of Directors of our company to serve as independent director. On March 30, 2022, Mr. Louis, PhD entered into an agreement pursuant to which he will serve as an independent director of the Company upon SEC's declaration of effectiveness of our registration statement on Form S-1. During the term of the agreement, Mr. Louis will be entitled to director fees of US$21,600 per annum. Pursuant to the agreement, Mr. Louis may be terminated for "cause" as defined in the agreement and Mr. Louis may resign upon the provision of a prior notice in writing not less than 14 days to the Company.

Professor Dr. John Hing Vong was appointed to the Board of Directors of our company to serve as independent director. On September 12, 2022, Dr. Vong, PhD entered into an agreement pursuant to which he will serve as an independent director of the Company upon SEC's declaration of effectiveness of our registration statement on Form S-1. During the term of the agreement, Dr. Vong, PhD will be entitled to director fees of US$21,600 per annum. Pursuant to the agreement, Dr. Vong, PhD may be terminated for "cause" as defined in the agreement and Dr. Vong, PhD may resign upon the provision of a prior notice in writing not less than 14 days to the Company.

Chee Chin Aik was appointed to the Board of Directors of our company to serve as independent director. On November 30, 2022, Mr. Chee entered into an agreement pursuant to which he will serve as an independent director of the Company upon SEC's declaration of effectiveness of our registration statement on Form S-1. During the term of the agreement, Mr. Chee will be entitled to director fees of US$21,600 per annum. Pursuant to the agreement, Mr. Chee may be terminated for "cause" as defined in the agreement and Mr. Chee may resign upon the provision of a prior notice in writing not less than 14 days to the Company.

77

    REGISTRATION NO. 333-239951

SEC rules require us to disclose any transaction since the beginning of our last fiscal year or any currently proposed transaction in which we are a participant in which the amount involved exceeded or will exceed $120,000 and in which any related person has or will have a direct or indirect material interest. A related person is any executive officer, director, nominee for director, or holder of 5% or more of our common stock, or an immediate family member of any of those persons.

On May 8, 2020, the Company acquired approximately 99.99% of the issued share capital of Agape Superior Living Sdn Bhd from Dr. How Kok Choong. Dr. How received an aggregate consideration of $1,714,003, which was determined based on the net asset carrying value of ASL as at March 31, 2020. The aggregate consideration was satisfied by (i) the offset of the consideration whereby the Company has a loan receivable of $656,495 as of March 31, 2020 due from Dr. How; and (ii) the allotment and issue of the common stock of the Company. The Company allotted and issued 162,694 shares of the Company's common stock, each with a par value $0.0001, representing approximately 0.0432% of the total issued and outstanding shares in the Company after the issuance of the shares, which was valued at $1,057,508 based on the closing price of $6.50 of the Company as quoted on the OTC Market on March 31, 2020.

On July 1, 2020, the Company and Dr. How Kok Choong agreed to amend the Share Exchange agreement and enter into a supplemental agreement share exchange agreement (the "Supplemental Share Exchange Agreement"). In accordance with Supplemental Share Exchange Agreement, Dr. How received an aggregate consideration of $1,804,046, which was determined based on the net asset carrying value of ASL as at March 31, 2020. The aggregate consideration shall be satisfied by (i) the offset of the consideration whereby the Company has a loan receivable of $656,495 as of March 31, 2020 due from Dr. How; and (ii) the allotment and issuance of common stock of the Company. The Company allotted and issued 176,547 shares of the Company's common stock, par value $0.0001 (the "Shares"), representing approximately 0.0469% of the total issued and outstanding shares in the Company after the issuance of the Shares, which is valued at $1,147,551 based on the closing price of $6.50 of the Company as quoted on the OTC Market on March 31, 2020.

On February 1, 2021, Dr. How Kok Choong, our CEO and director, was appointed as the non-executive Chairman of Vettons. Vettons Sdn Bhd ("Vettons") is an e-commerce company through which ASL conducts some of its distribution activities to its members. As of December 31, 2020, the Company has accounts receivable of $172,757 from Vettons, representing 100% of our accounts receivable.

In December 2021, there were share forfeiture agreements (the "Share Forfeiture Agreements") between the Company and (i) HKC Talent Limited; (ii) various stockholders of the Company (the "Forfeiting Stockholders"), pursuant to which:

(i) HKC Talent Limited had agreed to forfeiture of 41,750,000 shares of common stock of the Company, and

(ii) the Forfeiting Stockholders had agreed to forfeiture, in aggregate, 44,242,000 shares of common stock of the Company. Included in (ii) is 11,242,000 shares forfeited from HKC Holdings Sdn. Bhd, a company in which Dr. How Kok Choong, is a stockholder. As a result, the outstanding shares was reduced by 85,992,000 shares of common stock.

On January 20, 2022, a share forfeiture agreement (the "Share Forfeiture Agreement") was entered between the Company and Dr. How Kok Choong, pursuant to which Dr. How agreed to forfeit 215,008,035 shares of common stock of the Company.

*HKC Holdings Sdn Bhd is owned and controlled by How Kok Choong who is our executive officer and director. As such, HKC Holdings Sdn Bhd. is regarded a related party.

With regards to all of the above transactions we claim an exemption from registration afforded by Section 4a(2) and/or Regulation S of the Securities Act of 1933, as amended ("Regulation S") due to the fact that the issuance of stock was made to non-U.S. persons (as defined under Rule 902 section (k)(2)(i) of Regulation S), pursuant an offshore transactions, and no directed selling efforts were made in the United States by the issuer, a distributor, any of their respective affiliates, or any person acting on behalf of any of the foregoing.

78

The Company's related party list and relationship are as follows:

Related parties Relationships

    REGISTRATION NO. 333-239951

DSY Wellness & Longevity Mr. Steve Yap, a director of DSY Wellness Center Sdn Bhd International Sdn Bhd, is also a director of DSY Wellness & Longevity Center Sdn Bhd.

CTA Nutriceuticals (Asia) The directors and shareholders of CTA are related Sdn Bhd parties to Mr. Steve Yap, a director of DSY International Wellness Sdn Bhd

SY Welltech Sdn Bhd The directors and shareholders of Welltech are ("Welltech") (formerly known related parties to Mr. Steve Yap, a director of as DSY Beauty Sdn Bhd) DSY Wellness International Sdn Bhd

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Related party balances as of June 30, 2023 and December 31, 2022 are as per table below:

Related party balances

Amount due from related parties

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Total $ 1,417 $ 10,534

Accounts payable - related parties

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

79

Other payable - related parties

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Related party transactions

Purchases

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

80

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Other Purchases

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

81

Other purchases

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Commission

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Commission

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

82

Other Income

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Other expenses

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

83

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Related party balances as of December 31, 2022 and 2021 are as per table below:

Amount due from related parties

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

84

Accounts payable - related parties

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Other payable - related parties

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

85

Related party transactions for years ended December 31, 2022 and 2021, are as per table below:

Purchases

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Other income

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Other purchases

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

86

Commission expense

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Other expenses

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

87

    REGISTRATION NO. 333-239951

Beneficial ownership is determined in accordance with the rules of the SEC and generally includes voting or investment power with respect to securities. In accordance with SEC rules, shares of our common stock which may be acquired upon exercise of stock options or warrants which are currently exercisable or which become exercisable within 60 days of the date of the applicable table below are deemed beneficially owned by the holders of such options and warrants and are deemed outstanding for the purpose of computing the percentage of ownership of such person, but are not treated as outstanding for the purpose of computing the percentage of ownership of any other person. Subject to community property laws, where applicable, the persons or entities named in the tables below have sole voting and investment power with respect to all shares of our common stock indicated as beneficially owned by them.

The following table sets forth certain information, as of the date of this prospectus, with respect to the beneficial ownership of the outstanding common stock by (i) any holder of more than five (5%) percent; (ii) each of our executive officers and directors; and (iii) our directors and executive officers as a group. Except as otherwise indicated, each of the stockholders listed below has sole voting and investment power over the shares beneficially owned.

    REGISTRATION NO. 333-239951

5% or more holders: HKC Talent Limited 8,245,000 10.93 % - - 10.93 %

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

88

    REGISTRATION NO. 333-239951

We have authorized capital stock consisting of 1,000,000,000 shares of common stock, par value $0.0001 per share, and 200,000,000 shares of preferred stock, par value $0.0001 per share. As of June 30, 2023, we had 75,452,012 shares of common stock issued and outstanding and no shares of preferred stock issued and outstanding.

Common Stock

All outstanding shares of common stock are of the same class and have equal rights and attributes. The holders of common stock are entitled to one vote per share on all matters submitted to a vote of stockholders of the company. All stockholders are entitled to share equally in dividends, if any, as may be declared from time to time by the Board of Directors out of funds legally available. In the event of liquidation, the holders of common stock are entitled to share ratably in all assets remaining after payment of all liabilities. The stockholders do not have cumulative or pre-emptive rights.

Preferred Stock

Our Certificate of Incorporation authorizes the issuance of up to 200,000,000 shares of preferred stock with designations, rights and preferences determined from time to time by our Board of Directors. Accordingly, our Board of Directors is empowered, without stockholder approval, to issue preferred stock with dividend, liquidation, conversion, voting, or other rights which could adversely affect the voting power or other rights of the holders of the common stock. In the event of issuance, the preferred stock could be utilized, under certain circumstances, as a method of discouraging, delaying or preventing a change in control of our company, which is sometimes referred to in corporate parlance as a "poison pill".

Options and Restricted Stock

As of June 30, 2023, other than the securities described above, we do not have any outstanding options or restricted stock.

Other Convertible Securities

As of June 30, 2023, other than the securities described above, we do not have any outstanding convertible securities.

Securities Authorized for Issuance under Equity Compensation Plans

We have not adopted any compensatory or benefit plans for future issuances of our securities.

Market for Common Equity and Related Stockholder Matters

We are a reporting company under Section 15(d) of the Securities Exchange Act of 1934, as amended. Our common stock currently is quoted on the OTC Markets - Pink Sheets, operated by OTC Markets Group, under the symbol "AATP." The last reported sale price of our common stock on the OTC Markets - Pink Sheets on September 21, 2023 was $8.00 per share. Our common stock have started trading on the NASDAQ Capital Market ("NASDAQ") under the symbol "ATPC" on October 11, 2023.

If our Common Stock is listed on the NASDAQ, we will be subject to continued listing requirements and corporate governance standards of NASDAQ. We expect the compliance with these new rules and regulations to significantly increase our legal, accounting and financial compliance costs.

As of the date of this prospectus, there are approximately 1,313 holders of record of our common stock.

Transfer Agent

The stock transfer agent for our securities is Vstock Transfer, LLC, 18 Lafayette Place, Woodmere, New York 11598 and telephone number is +1 (212) 828-8436.

89

    REGISTRATION NO. 333-239951

Immediately prior to this offering, there was little to no trading activity in our common stock. Future sales of substantial amounts of common stock in the public market, or the perception that such sales may occur, could adversely affect the market price of our common stock.

All shares sold in this offering will be freely tradable without restriction or further registration under the Securities Act, except for any shares purchased by our "affiliates," as that term is defined in Rule 144 under the Securities Act, whose sales would be subject to the Rule 144 resale restrictions described below, other than the holding period requirement.

Restricted securities are eligible for public sale only if they are registered under the Securities Act or if they qualify for an exemption from registration under Rules 144 or 701 under the Securities Act, described below. Restricted securities may also be sold outside of the United States to non-U.S. persons in accordance with Rule 904 of Regulation S.

Lock-Up

For further details on the lock-up agreements, see the section entitled "Underwriting - Lock-Up Agreements."

Rule 144

Some of our stockholders will be forced to hold their shares of our common stock for at least a six-month period before they are eligible to sell those shares, and even after that six-month period, sales may not be made under Rule 144 promulgated under the Securities Act unless we and such stockholders are in compliance with other requirements of Rule 144.

In general, Rule 144 provides that (i) any of our non-affiliates that has held restricted common stock for at least six months is thereafter entitled to sell its restricted stock freely and without restriction, provided that we remain compliant and current with our SEC reporting obligations, and (ii) any of our affiliates, which includes our directors, executive officers and other person in control of us, that has held restricted common stock for at least six months is thereafter entitled to sell its restricted stock subject to the following restrictions: (a) we are compliant and current with our SEC reporting obligations, (b) certain manner of sale provisions are satisfied, (c) a Form 144 is filed with the SEC, and (d) certain volume limitations are satisfied, which limit the sale of shares within any three-month period to a number of shares that does not exceed the greater of 1% of the total number of outstanding shares. A person who has ceased to be an affiliate at least three months immediately preceding the sale and who has owned such shares of common stock for at least one year is entitled to sell the shares under Rule 144 without regard to any of the limitations described above.

Rule 701

In general, Securities Act Rule 701 allows a stockholder who purchased shares of capital stock pursuant to a written compensatory plan or contract and who is not deemed to have been an affiliate of ours during the immediately preceding 90 days to sell those shares in reliance upon Securities Act Rule 144, but without being required to comply with the public information, holding period, volume limitation or notice provisions of Rule 144. All holders of Rule 701 shares, however, are required to wait until ninety (90) days after the date of this prospectus before selling shares pursuant to Rule 701.

Regulation S

Regulation S provides generally that sales made in offshore transactions are not subject to the registration or prospectus-delivery requirements of the Securities Act.

90

    REGISTRATION NO. 333-239951

Malaysia Taxation

The following discussion is a summary of the more relevant taxes that are applicable to our Malaysian subsidiaries with regards to transactions that they may enter into with a foreign holding company, i.e. AATP. It excludes specifically all Malaysian taxes that our Malaysian subsidiaries are subject to arising from their respective business activities in Malaysia such as income tax, various types of taxes imposable on transactions entered into in the course of conducting their business activities and taxes on capital gains. Generally, there is no taxes on capital gains in Malaysia except for real property gains tax ("RPGT") which is a tax on gains arising from the disposal of real property or shares in real property companies ("RPC"). Neither subject affects our Malaysian subsidiaries as none of them were engaged in activities in the said areas.

The type of transactions that Malaysian subsidiaries typically enter into with their foreign holding company (that is not attributable to a business carried on in Malaysia by the foreign holding company) are royalties, interest or service fees. With respect to such income, the tax liability of the foreign holding company, it being a non-resident will be settled by way of withholding tax ("WHT") deducted by the paying entity, i.e. the Malaysian subsidiary. The following are WHT rates that apply as per the double taxation agreement ("DTA") exists between the United States of America and Malaysia: (Royalty: 10%, Interest: 15%, Dividends: 0%, Income other than royalty and interest: 10%)

Payments of the above types of income to non-residents (except for dividends) are subject to WHT which is due and payable to the Inland Revenue Board (IRB) within one month after paying or crediting such payments. There is no WHT on dividends paid by Malaysian companies.

Tax administration

Transfer pricing

Transfer pricing (TP) legislation

The basis for determining proper compensation is, almost universally, the arm's length principle which has also been accepted by the Inland Revenue Board ("IRB").

The arm's length principle was incorporated into Section 140A of the Malaysian Income Tax Act 1967. It allows the Director General Inland Revenue ("DGIR") to adjust any transfer prices between related parties in Malaysia which, in the view of the DGIR, do not meet the arm's length standard.

What constitutes "arm's length" is not defined in the Income Tax Act 1967. Consequently, the IRB has issued the TP Rules 2012 and the revised TP Guidelines 2012 to give guidance on the arm's length standard that is acceptable to the IRB. The TP Rules and Guidelines seek to provide guidance on the application of the law on controlled transactions, the acceptable methodologies as provided in the rules and administrative requirements including the types of records and documentation expected from taxpayers involved in TP arrangements.

Advance pricing arrangements (APA)

Companies are allowed to apply for APAS from the DGIR. The objective of establishing APAS is to provide an avenue for taxpayers to obtain certainty upfront that their related party transactions meet the arm's length standard. The IRB has issued the APA Rules 2012 and APA Guidelines 2012 to give guidance on the matter.

Statute of limitation for TP adjustments

The statute of limitation is seven (7) years from the expiration of an assessment year ("YA") for raising an assessment or additional assessment for that YA in respect of TP adjustments for a transaction entered into between associated persons not at arm's length.

91

Country-by-Country Reporting

The Malaysian Country-by-Country Rules require a Malaysian multinational corporation ("MNC") group with total consolidated group revenue of RM3 billion and above in the financial year ("FY") preceding the reporting FY (i.e. FY commencing on or after 1 January 2017) to prepare and submit the Country-by-Country Report to the IRB no later than 12 months after the close of each FY.

Malaysian entities of foreign MNC groups will generally not be required to prepare and file Country-by-Country Reports as the obligation to file will be with the ultimate holding company in the jurisdiction it is tax resident in, However, a notification to the IRB may be required.

United States Federal Income Taxation

The following discussion is a summary of the material U.S. federal income tax consequences to Non-U.S. Holders (as defined below) of the purchase, ownership and disposition of our common stock issued pursuant to this prospectus, but does not purport to be a complete analysis of all potential tax effects. The effects of other U.S. federal tax laws, such as estate and gift tax laws, and any applicable state, local or non-U.S. tax laws are not discussed. This discussion is based on the U.S. Internal Revenue Code of 1986, as amended (the "Code"), Treasury Regulations promulgated thereunder, judicial decisions, and published rulings and administrative pronouncements of the U.S. Internal Revenue Service (the "IRS"), in each case in effect as of the date of this prospectus. These authorities may change or be subject to differing interpretations. Any such change or differing interpretation may be applied retroactively in a manner that could adversely affect a Non-U.S. Holder. We have not sought and will not seek any rulings from the IRS regarding the matters discussed below. There can be no assurance the IRS or a court will not take a contrary position to that discussed below regarding the tax consequences of the purchase, ownership and disposition of our common stock.

This discussion is limited to Non-U.S. Holders that hold our common stock as a "capital asset" within the meaning of Section 1221 of the Code (generally, property held for investment). This discussion does not address all U.S. federal income tax consequences relevant to a Non-U.S. Holder's particular circumstances, including the impact of the Medicare contribution tax on net investment income. In addition, it does not address consequences relevant to Non-U.S. Holders subject to special rules, including, without limitation:

    REGISTRATION NO. 333-239951

If an entity treated as a partnership for U.S. federal income tax purposes holds our common stock, the tax treatment of a partner in the partnership will depend on the status of the partner, the activities of the partnership and certain determinations made at the partner level. Accordingly, partnerships holding our common stock and the partners in such partnerships should consult their tax advisors regarding the U.S. federal income tax consequences to them.

92

INVESTORS SHOULD CONSULT THEIR TAX ADVISORS WITH RESPECT TO THE APPLICATION OF THE U.S. FEDERAL INCOME TAX LAWS TO THEIR PARTICULAR SITUATIONS AS WELL AS ANY TAX CONSEQUENCES OF THE PURCHASE, OWNERSHIP AND DISPOSITION OF OUR COMMON STOCK ARISING UNDER THE U.S. FEDERAL ESTATE OR GIFT TAX LAWS OR UNDER THE LAWS OF ANY STATE, LOCAL OR NON-U.S. TAXING JURISDICTION OR UNDER ANY APPLICABLE INCOME TAX TREATY.

Definition of a Non-U.S. Holder

For purposes of this discussion, a "Non-U.S. Holder" is any beneficial owner of our common stock that is neither a "U.S. person" nor an entity treated as a partnership for U.S. federal income tax purposes. A U.S. person is any person that, for U.S. federal income tax purposes, is or is treated as any of the following:

? an individual who is a citizen or resident of the United States; ? a corporation created or organized under the laws of the United States, any state thereof or the District of Columbia; ? an estate, the income of which is subject to U.S. federal income tax regardless of its source; or ? a trust that (1) is subject to the primary supervision of a U.S. court and all substantial decisions of which are subject to the control of one or more "United States persons" (within the meaning of Section 7701(a)(30) of the Code), or (2) has a valid election in effect to be treated as a United States person for U.S. federal income tax purposes.

Distributions

As described in the section entitled "Dividend Policy," we do not anticipate paying any cash dividends on our common stock in the foreseeable future. However, if we do make distributions of cash or property on our common stock, such distributions will constitute dividends for U.S. federal income tax purposes to the extent paid from our current or accumulated earnings and profits, as determined under U.S. federal income tax principles. Amounts not treated as dividends for U.S. federal income tax purposes will constitute a return of capital and first be applied against and reduce a Non-U.S. Holder's adjusted tax basis in its common stock, but not below zero. Any excess will be treated as capital gain and will be treated as described below under "-Sale or Other Taxable Disposition."

Subject to the discussion below on effectively connected income, dividends paid to a Non-U.S. Holder will be subject to U.S. federal withholding tax at a rate of 30% of the gross amount of the dividends (or such lower rate specified by an applicable income tax treaty, provided the Non-U.S. Holder furnishes a valid IRS Form W-8BEN or W-8BEN-E (or other applicable documentation) certifying qualification for the lower treaty rate). A Non-U.S. Holder that does not timely furnish the required documentation, but that qualifies for a reduced treaty rate, may obtain a refund of any excess amounts withheld by timely filing an appropriate claim for refund with the IRS. Non-U.S. Holders should consult their tax advisors regarding their entitlement to benefits under any applicable income tax treaty.

If dividends paid to a Non-U.S. Holder are effectively connected with the Non-U.S. Holder's conduct of a trade or business within the United States (and, if required by an applicable income tax treaty, the Non-U.S. Holder maintains a permanent establishment in the United States to which such dividends are attributable), the Non-U.S. Holder will be exempt from the U.S. federal withholding tax described above. To claim the exemption, the Non-U.S. Holder must furnish to the applicable withholding agent a valid IRS Form W-8ECI, certifying that the dividends are effectively connected with the Non-U.S. Holder's conduct of a trade or business within the United States.

Any such effectively connected dividends will be subject to U.S. federal income tax on a net income basis at the regular graduated rates. A Non-U.S. Holder that is a corporation also may be subject to a branch profits tax at a rate of 30% (or such lower rate specified by an applicable income tax treaty) on such effectively connected dividends, as adjusted for certain items. Non-U.S. Holders should consult their tax advisors regarding any applicable tax treaties that may provide for different rules.

93

Sale or Other Taxable Disposition

A Non-U.S. Holder will not be subject to U.S. federal income tax on any gain realized upon the sale or other taxable disposition of our common stock unless:

    REGISTRATION NO. 333-239951

Gain described in the first bullet point above generally will be subject to U.S. federal income tax on a net income basis at the regular graduated rates. A Non-U.S. Holder that is a corporation also may be subject to a branch profits tax at a rate of 30% (or such lower rate specified by an applicable income tax treaty) on such effectively connected gain, as adjusted for certain items.

Gain described in the second bullet point above will be subject to U.S. federal income tax at a rate of 30% (or such lower rate specified by an applicable income tax treaty), which may be offset by certain U.S. source capital losses of the Non-U.S. Holder (even though the individual is not considered a resident of the United States), provided the Non-U.S. Holder has timely filed U.S. federal income tax returns with respect to such losses.

With respect to the third bullet point above, we believe we currently are not, and do not anticipate becoming, a USRPHC. Because the determination of whether we are a USRPHC depends, however, on the fair market value of our USRPIs relative to the fair market value of our non-U.S. real property interests and our other business assets, there can be no assurance we currently are not a USRPHC or will not become one in the future. Even if we are or were to become a USRPHC, gain arising from the sale or other taxable disposition by a Non-U.S. Holder of our common stock will not be subject to U.S. federal income tax if our common stock is "regularly traded," as defined by applicable Treasury Regulations, on an established securities market, and such Non-U.S. Holder owned, actually and constructively, 5% or less of our common stock throughout the shorter of the five-year period ending on the date of the sale or other taxable disposition or the Non-U.S. Holder's holding period.

Non-U.S. Holders should consult their tax advisors regarding any applicable tax treaties that may provide for different rules.

Information Reporting and Backup Withholding

Payments of dividends on our common stock will not be subject to backup withholding, provided the applicable withholding agent does not have actual knowledge or reason to know the holder is a United States person and the holder either certifies its non-U.S. status, such as by furnishing a valid IRS Form W-8BEN, W-8BEN-E or W-8ECI, or otherwise establishes an exemption. However, information returns are required to be filed with the IRS in connection with any dividends on our common stock paid to the Non-U.S. Holder, regardless of whether any tax was actually withheld. In addition, proceeds of the sale or other taxable disposition of our common stock within the United States or conducted through certain U.S.-related brokers generally will not be subject to backup withholding or information reporting, if the applicable withholding agent receives the certification described above and does not have actual knowledge or reason to know that such holder is a United States person, or the holder otherwise establishes an exemption. Proceeds of a disposition of our common stock conducted through a non-U.S. office of a non-U.S. broker that does not have certain enumerated relationships with the United States generally will not be subject to backup withholding or information reporting.

94

Copies of information returns that are filed with the IRS may also be made available under the provisions of an applicable treaty or agreement to the tax authorities of the country in which the Non-U.S. Holder resides or is established.

Backup withholding is not an additional tax. Any amounts withheld under the backup withholding rules may be allowed as a refund or a credit against a Non-U.S. Holder's U.S. federal income tax liability, provided the required information is timely furnished to the IRS.

Additional Withholding Tax on Payments Made to Foreign Accounts

Withholding taxes may be imposed under Sections 1471 to 1474 of the Code (such Sections commonly referred to as the Foreign Account Tax Compliance Act, or "FATCA") on certain types of payments made to non-U.S. financial institutions and certain other non-U.S. entities. Specifically, a 30% withholding tax may be imposed on dividends on, or gross proceeds from the sale or other disposition of, our common stock paid to a "foreign financial institution" or a "non-financial foreign entity" (each as defined in the Code), unless (1) the foreign financial institution undertakes certain diligence and reporting obligations, (2) the non-financial foreign entity either certifies it does not have any "substantial United States owners" (as defined in the Code) or furnishes identifying information regarding each substantial United States owner, or (3) the foreign financial institution or non-financial foreign entity otherwise qualifies for an exemption from these rules. If the payee is a foreign financial institution and is subject to the diligence and reporting requirements in (1) above, it must enter into an agreement with the U.S. Department of the Treasury requiring, among other things, that it undertake to identify accounts held by certain "specified United States persons" or "United States-owned foreign entities" (each as defined in the Code), annually report certain information about such accounts, and withhold 30% on certain payments to non-compliant foreign financial institutions and certain other account holders. Foreign financial institutions located in jurisdictions that have an intergovernmental agreement with the United States governing FATCA may be subject to different rules.

Under the applicable Treasury Regulations and administrative guidance, withholding under FATCA generally applies to payments of dividends on our common stock, and will apply to payments of gross proceeds from the sale or other disposition of such stock on or after January 1, 2019.

Prospective investors should consult their tax advisors regarding the potential application of withholding under FATCA to their investment in our common stock.

95

    REGISTRATION NO. 333-239951

Under the terms and subject to the conditions of an underwriting agreement dated the date of this prospectus, Network 1 Financial Securities, Inc. has agreed to purchase, and we have agreed to sell to them, the number of shares of common stock at the initial public offering price, less the underwriting discount, as set forth on the cover page of this prospectus and as indicated below:

Underwriter Number of Shares Network 1 Financial Securities, Inc 1,650,000 Total 1,650,000

The Underwriter is offering the shares subject to acceptance of the shares from us and subject to prior sale. The underwriting agreement provides that the obligations of the Underwriter to pay for and accept delivery of the shares of common stock offered by this prospectus are subject to the approval of certain legal matters by its counsel and to other conditions. The Underwriter is obligated to take and pay for all of the shares of common stock offered by this prospectus if any such shares are taken. However, the Underwriter is not required to take or pay for the shares covered by the Underwriter's option to purchase additional shares described below.

We have granted to the Underwriter an option, exercisable for forty-five (45) days from the closing of this offering, to purchase up to 247,500 additional shares of common stock at the initial public offering price listed on the cover page of this prospectus, less underwriting discount. The Underwriter may exercise this option solely for the purpose of covering over-allotments, if any, made in connection with this offering. To the extent the option is exercised, the Underwriter will become obligated, subject to certain conditions, to purchase about the same percentage of the additional shares as the number listed next to the underwriter's name in the preceding table bears to the total number of shares listed next to the names of the Underwriter in the preceding table.

The Underwriter will offer the shares to the public at the initial public offering price set forth on the cover of this prospectus and to selected dealers at the initial public offering price less a selling concession not in excess of $0.32 per share. After this offering, the initial public offering price, concession and reallowance to dealers may be reduced by the Underwriter. No change in those terms will change the amount of proceeds to be received by us as set forth on the cover of this prospectus. The securities are offered by the Underwriter as stated herein, subject to receipt and acceptance by them and subject to their right to reject any order in whole or in part.

As of the date of this prospectus, Network 1 Financial Securities, Inc. and affiliates of Network 1 Financial Securities, Inc. beneficially own 2,000,000 shares of our Common Stock, which represent in the aggregate less than 10% of our issued and outstanding shares of Common Stock and therefore Network 1 Financial Securities, Inc. is not deemed to have a "conflict of interest" within the meaning of FINRA Rule 5121.

Discount and Expenses

If we complete this offering, then on the closing date, we will pay the Underwriter a discount of 8% of the value of the shares of common stock sold in this offering for the investors introduced by the Underwriter, and 6% of the aggregate gross proceeds of this offering of the common stock for the investors introduced by the Company. We have also agreed to pay the Underwriter an additional non-accountable expense allowance, equal to one percent (1%) of the gross proceed received by us from the sale of our shares of common stock.

The following table summarizes the compensation and estimated expenses we will pay in the offering. Such amounts are shown assuming both no exercise and full exercise of the Underwriter's over-allotment option.

    REGISTRATION NO. 333-239951

We have also agreed to reimburse the Underwriter for all of its reasonable out-of-pocket accountable expenses, including reasonable fees and expenses of its legal counsel, roadshow expenses, offering materials, background check fee, cost associated with closing volumes and commemorative mementos in an aggregate amount not to exceed $209,500 in connection with the offering. As of the date of this prospectus, the Company has advanced $50,000 to the Underwriter to cover its out-of-pocket expenses (the "Advance"); the Advance will be reimbursed to the Company to the extent not actually incurred in compliance with FINRA Rule 5110(g)(4)(A).

We expect our total expenses for this offering to be $768,834, exclusive of the above discount. If we complete this offering, then on the closing date, we will issue shares to investors.

We have agreed to indemnify the Underwriter against certain liabilities, including liabilities under the Securities Act, or to contribute to payments the Underwriter may be required to make in respect of those liabilities.

In connection with this offering, the Underwriter or certain of the securities dealers may distribute prospectuses electronically. No forms of prospectus other than printed prospectuses and electronically distributed prospectuses that are printable in Adobe PDF format will be used in connection with this offering.

96

Underwriter Warrant

We have also agreed to grant to the Underwriter a warrant covering a number shares of common stock equal to 7% of the common stock sold by the Underwriter in this public offering. The Underwriter Warrant will be exercisable from the date of issuance and will expire on the fifth year anniversary of the date of the commencement of sales in this offering. The Underwriter Warrant will be exercisable at a price equal to 110% of the initial public offering price. The Underwriter Warrant shall not be redeemable or cancellable. We will register the shares underlying the Underwriter Warrant and file all necessary undertakings in connection therewith. The Underwriter Warrant and the underlying securities may not be not be sold, transferred, assigned, pledged, or hypothecated, or be the subject of any hedging, short sale, derivative, put, or call transaction that would result in the effective economic disposition of the securities by any person for a period of 180 days beginning on the date of commencement of sales of this offering (in accordance with FINRA Rule 5110), except that they may be assigned, in whole or in part, to any officer or partner of the Underwriter, and to members of the syndicate or selling group and their respective officers or partners. The Underwriter Warrants may be exercised as to all or a lesser number of shares, will provide for cashless exercise and will contain provisions for one demand registration and unlimited "piggyback" registration rights at our expense with a duration of more than five years and seven years, respectively, from the commencement of sales of this offering. We have registered the Underwriter Warrant and the shares underlying the Underwriter Warrant in this offering.

Right of First Negotiation

In addition, we have agreed to grant to the Underwriter, upon the closing of this offering, a right of first negotiation to co-manage any public underwriting or private placement of debt or equity securities (excluding (i) shares issued under any compensation or stock option plan approved by the stockholders of the Company, (ii) shares issued in payment of the consideration for an acquisition or as part of strategic partnerships and transactions and (iii) conventional banking arrangements and commercial debt financing) of the Company or any subsidiary or successor of the Company, receiving the right to underwrite or place a number of the securities to be sold having an aggregate purchase price equal to a minimum of the aggregate purchase price of the shares being sold in this offering, until twelve (12) months after the effective date of the registration statement of which this prospectus forms a part.

Lock-Up Agreements

We and each of, our officers, directors, our affiliate shareholders and 10% or more stockholders, have agreed not to register, offer, sell, contract to sell or grant (except for private transfers and in such case only with the express requirement that such shares continue to be subject to the same lock-up) any of our shares of common stock or any securities convertible into or exercisable or exchangeable for our shares of common stock or any warrants to purchase our shares of common stock (including, without limitation, securities of our company which may be deemed to be beneficially owned by such individuals in accordance with the rules and regulations of the Securities and Exchange Commission and securities which may be issued upon the exercise of a stock option or warrant) for a period of 180 days after the closing date of this offering. Upon the expiration of these lock-up agreements, additional shares of common stock will be available for sale in the public market.

Market and Pricing Considerations

Prior to this offering, our common stock was quoted on the OTC Markets - Pink Sheets, and there was a limited public market for our common stock. The public offering price was determined based upon the price at which our common stock was quoted on the OTC Markets - Pink Sheets, as well as by negotiations between us and the Underwriter. Among the factors considered in determining the initial public offering price are the future prospects of our company and our industry in general, our sales, earnings and certain other financial and operating information in recent periods, and the price-earnings ratios, market prices of securities and certain financial and operating information of companies engaged in activities similar to those of our company.

An active trading market for our common stock may not develop. It is possible that after this offering the shares of common stock will not trade in the public market at or above the initial offering price.

97

Trading Market

Our common stock started trading on the NASDAQ Capital Market ("NASDAQ") under the symbol "ATPC" on October 11, 2023.

Price Stabilization, Short Positions and Penalty Bids

In order to facilitate the offering of our common stock, the Underwriter may engage in transactions that stabilize, maintain or otherwise affect the price of our common stock. These activities may raise or maintain the market price of our common stock above independent market levels or prevent or retard a decline in the market price of our common stock. The Underwriter is not required to engage in these activities, and may end any of these activities at any time. We and the Underwriter have agreed to indemnify each other against certain liabilities, including liabilities under the Securities Act.

Foreign Regulatory Restrictions on Purchase of our Shares

We have not taken any action to permit a public offering of our shares outside the United States or to permit the possession or distribution of this prospectus outside the United States. People outside the United States who come into possession of this prospectus must inform themselves about and observe any restrictions relating to this offering of our shares and the distribution of this prospectus outside the United States.

Notice to Prospective Investors in the European Economic Area

In relation to each member state of the European Economic Area, no offer of shares which are the subject of the offering has been, or will be made to the public in that Member State, other than under the following exemptions under the Prospectus Directive:

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

provided that no such offer of shares referred to in (a) to (c) above shall result in a requirement for the Company or any underwriter to publish a prospectus pursuant to Article 3 of the Prospectus Directive, or supplement a prospectus pursuant to Article 16 of the Prospectus Directive.

Each person located in a Member State to whom any offer of shares is made or who receives any communication in respect of an offer of shares, or who initially acquires any shares will be deemed to have represented, warranted, acknowledged and agreed to and with the Underwriter and the Company that (1) it is a "qualified investor" within the meaning of the law in that Member State implementing Article 2(1)(e) of the Prospectus Directive; and (2) in the case of any shares acquired by it as a financial intermediary as that term is used in Article 3(2) of the Prospectus Directive, the shares acquired by it in the offer have not been acquired on behalf of, nor have they been acquired with a view to their offer or resale to, persons in any Member State other than qualified investors, as that term is defined in the Prospectus Directive, or in circumstances in which the prior consent of the Underwriter has been given to the offer or resale; or where shares have been acquired by it on behalf of persons in any Member State other than qualified investors, the offer of those shares to it is not treated under the Prospectus Directive as having been made to such persons.

98

The Company, the Underwriter and their respective affiliates will rely upon the truth and accuracy of the foregoing representations, acknowledgments and agreements.

This prospectus has been prepared on the basis that any offer of shares in any Member State will be made pursuant to an exemption under the Prospectus Directive from the requirement to publish a prospectus for offers of shares. Accordingly any person making or intending to make an offer in that Member State of shares which are the subject of the offering contemplated in this prospectus may only do so in circumstances in which no obligation arises for the Company or the Underwriter to publish a prospectus pursuant to Article 3 of the Prospectus Directive in relation to such offer. Neither the Company nor the Underwriter have authorized, nor do they authorize, the making of any offer of shares in circumstances in which an obligation arises for the Company or the Underwriter to publish a prospectus for such offer.

For the purposes of this provision, the expression an "offer of shares to the public" in relation to any common stock in any Member State means the communication in any form and by any means of sufficient information on the terms of the offer and the common stock to be offered so as to enable an investor to decide to purchase or subscribe the common stock, as the same may be varied in that Member State by any measure implementing the Prospectus Directive in that Member State, the expression "Prospectus Directive" means Directive 2003/71/EC (as amended) and includes any relevant implementing measure in each Member State.

The above selling restriction is in addition to any other selling restrictions set out below.

Notice to Prospective Investors in Hong Kong

The securities have not been offered or sold and will not be offered or sold in Hong Kong, by means of any document, other than (a) to "professional investors" as defined in the Securities and Futures Ordinance (Cap. 571) of Hong Kong and any rules made under that Ordinance; or (b) in other circumstances which do not result in the document being a "prospectus" as defined in the Companies (Winding Up and Miscellaneous Provisions) Ordinance (Cap. 32) of Hong Kong or which do not constitute an offer to the public within the meaning of that Ordinance. No advertisement, invitation or document relating to the securities has been or may be issued or has been or may be in the possession of any person for the purposes of issue, whether in Hong Kong or elsewhere, which is directed at, or the contents of which are likely to be accessed or read by, the public of Hong Kong (except if permitted to do so under the securities laws of Hong Kong) other than with respect to securities which are or are intended to be disposed of only to persons outside Hong Kong or only to "professional investors" as defined in the Securities and Futures Ordinance and any rules made under that Ordinance.

Notice to Prospective Investors in Singapore

This prospectus has not been registered as a prospectus with the Monetary Authority of Singapore. Accordingly, this prospectus and any other document or material in connection with the offer or sale, or invitation for subscription or purchase, of Non-CIS Securities may not be circulated or distributed, nor may the Non-CIS Securities be offered or sold, or be made the subject of an invitation for subscription or purchase, whether directly or indirectly, to persons in Singapore other than (i) to an institutional investor under Section 274 of the Securities and Futures Act, Chapter 289 of Singapore (the "SFA"), (ii) to a relevant person pursuant to Section 275(1), or any person pursuant to Section 275(1A), and in accordance with the conditions specified in Section 275, of the SFA, or (iii) otherwise pursuant to, and in accordance with the conditions of, any other applicable provision of the SFA.

99

Where the Non-CIS Securities are subscribed or purchased under Section 275 of the SFA by a relevant person which is:

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

securities (as defined in Section 239(1) of the SFA) of that corporation or the beneficiaries' rights and interest (howsoever described) in that trust shall not be transferred within six months after that corporation or that trust has acquired the Non-CIS Securities pursuant to an offer made under Section 275 of the SFA except:

    REGISTRATION NO. 333-239951

(b) where no consideration is or will be given for the transfer;

(c) where the transfer is by operation of law;

(d) as specified in Section 276(7) of the SFA; or

    REGISTRATION NO. 333-239951

100

    REGISTRATION NO. 333-239951

Certain legal matters with respect to the validity of the shares of common stock offered hereby will be passed upon for us by Sherman & Howard L.L.C., Las Vegas, Nevada. Certain Legal matters related to U.S. federal securities law and the validity of certain securities offered hereby will be passed upon for us by Loeb & Loeb LLP, New York, New York. Legal matters as to Malaysia law will be passed upon for us by Lee & Poh Partnership. Loeb & Loeb, LLP may rely upon Lee & Poh Partnership. with respect to matters governed by Malaysian law. Hunter Taubman Fischer & Li LLC is acting as U.S. securities counsel for the Underwriter. Lee & Poh Partnership is acting as Malaysia counsel for the Company.

    REGISTRATION NO. 333-239951

The consolidated financial statements for the years ended December 31, 2022 and 2021, included in this Registration Statement have been so included in reliance on the reports of Marcum Asia CPAs LLP and Friedman LLP, independent registered public accounting firms, given on the authority of said firm in auditing and accounting. The office of Marcum Asia CPAs LLP is located at 7 Pennsylvania Plaza Suite 830, New York, NY 10001. The office of Friedman LLP is located at One Liberty Plaza, 165 Broadway 21st Floor, New York, NY 10006.

    REGISTRATION NO. 333-239951

We have filed with the SEC a registration statement on Form S-1 under the Securities Act with respect to the common stock offered by this prospectus. This prospectus, which is part of the registration statement, omits certain information, exhibits, schedules and undertakings set forth in the registration statement. For further information pertaining to us and our common stock, reference is made to the registration statement and the exhibits and schedules to the registration statement. Statements contained in this prospectus as to the contents or provisions of any documents referred to in this prospectus are not necessarily complete, and in each instance where a copy of the document has been filed as an exhibit to the registration statement, reference is made to the exhibit for a more complete description of the matters involved.

Registration statements and certain other filings made with the SEC electronically are publicly available through the SEC's web site at http://www.sec.gov. The registration statement, including all exhibits and amendments thereto, has been filed electronically with the SEC.

We are subject to the information and periodic reporting requirements of the Exchange Act and, accordingly, we file annual reports containing financial statements audited by an independent registered public accounting firm, quarterly reports containing unaudited financial data, current reports and other reports and information with the SEC. You may inspect and copy each of our periodic reports, proxy statements and other information at the SEC's public reference room, and at the web site of the SEC referred to above.

101

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Unaudited Condensed Consolidated Balance Sheets F-2 Unaudited Condensed Consolidated Statements of Operations and Comprehensive Loss F-3 Unaudited Condensed Consolidated Statements of Changes in Stockholders' Equity F-4 Unaudited Condensed Consolidated Statements of Cash Flows F-5 Notes to Unaudited Condensed Consolidated Financial Statements F-6

    REGISTRATION NO. 333-239951

Report of Independent Registered Public Accounting Firm (PCAOB ID: 5395) F-35 Report of Independent Registered Public Accounting Firm (PCAOB ID: 711) F-36 Consolidated Balance Sheets F-37 Consolidated Statements of Operations and Comprehensive Loss F-38 Consolidated Statements of Changes in Stockholders' Equity F-39 Consolidated Statements of Cash Flows F-40 Notes to Consolidated Financial Statements F-41

F-1

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

OTHER ASSETS Property and equipment, net 105,674 142,149 Intangible assets, net 19,728 24,044 Operating right-of-use assets 284,670 81,133 Investment in marketable securities 25,331 16,687 Investment in non-marketable securities - - Deferred offering costs 522,062 499,202 Deferred tax assets 6,382 - Total other assets 963,847 763,215

TOTAL ASSETS $ 1,905,283 $ 2,791,749

LIABILITIES AND STOCKHOLDERS' EQUITY CURRENT LIABILITIES Accounts payable $ 50,800 $ 28,833 Accounts payable - related parties 19,605 25,611 Customer deposits 312,189 363,018 Operating lease liabilities 98,688 82,708 Other payables and accrued liabilities ($1,028 and $1,090 are included in the consolidated VIE that are without recourse to the credit of Agape ATP Corporation as of June 30, 2023 and December 31, 2022, respectively.) 475,667 713,277 Other payable - related parties 1,030 4,880 Income tax payable 10,350 10,968 Total Current Liabilities 968,329 1,229,295

NON-CURRENT LIABILITIES Operating lease liabilities 186,300 - Deferred tax liabilities - - Total Non-current Liabilities 186,300 -

TOTAL LIABILITIES $ 1,154,629 $ 1,229,295

STOCKHOLDERS' EQUITY Preferred stock, $0.0001 par value; 200,000,000 shares authorized; None issued and outstanding - - Common Stock, par value $0.0001; 1,000,000,000 shares authorized, 75,452,012 shares issued and outstanding as of June 30, 2023 and December 31, 2022, respectively. 7,545 7,545 Additional paid in capital 6,470,716 6,470,716 Accumulated deficit (5,746,112) (4,945,586) Accumulated other comprehensive income 11,612 9,266 TOTAL AGAPE CORPORATION STOCKHOLDERS' EQUITY 743,761 1,541,941

NON-CONTROLLING INTERESTS 6,893 20,513

TOTAL EQUITY 750,654 1,562,454

TOTAL LIABILITIES AND STOCKHOLDERS' EQUITY $ 1,905,283 $ 2,791,749

    REGISTRATION NO. 333-239951

F-2

    REGISTRATION NO. 333-239951

CONDENSED CONSOLIDATED STATEMENTS OF OPERATIONS AND COMPREHENSIVE LOSS

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

REVENUE $ 303,935 $ 396,707 $ 684,703 $ 805,667

COST OF REVENUE (107,931) (109,383) (236,289) (182,814)

GROSS PROFIT 196,004 287,324 448,414 622,853

SELLING (64,126) (79,587) (140,224) (194,198) COMMISSION (21,942) (62,557) (55,884) (176,666) GENERAL AND ADMINISTRATIVE (469,469) (451,363) (1,065,723) (830,404) PROVISION FOR DOUBTFUL ACCOUNTS - - - - TOTAL OPERATING EXPENSES (555,537) (593,507) (1,261,831) (1,201,268)

LOSS FROM OPERATIONS (359,533) (306,183) (813,417) (578,415)

OTHER (EXPENSES) INCOME Other income, net 4,134 1,341 12,500 12,826 Interest income 1,634 3,526 4,817 8,251 Unrealized holding gain (loss) on marketable securities 3,790 (35,219) 8,710 (52,889) Dividend income from marketable securities - - - - Gain on disposal of property and equipment 1,787 - 1,787 - Exchange loss, net (33,700) (67,417) (34,576) (83,883) TOTAL OTHER EXPENSES, NET (22,355) (97,769) (6,762) (115,695)

LOSS BEFORE INCOME TAXES (381,888) (403,952) (820,179) (694,110)

BENEFIT OF (PROVISION FOR) INCOME TAXES 2,439 (392) 6,655 (8,680)

NET LOSS (379,449) (404,344) (813,524) (702,790)

LESS: NET (LOSS) INCOME ATTRIBUTABLE TO NON-CONTROLLING INTERESTS (4,763) 10,556 (12,998) 11,207

NET LOSS ATTRIBUTABLE TO AGAPE ATP CORPORATION $ (374,686) $ (414,900) $ (800,526) $ (713,997)

NET LOSS $ (379,449) $ (404,344) $ (813,524) $ (702,790)

OTHER COMPREHENSIVE INCOME (LOSS) Foreign currency translation adjustment 269 (61,156) 2,346 (73,179)

TOTAL COMPREHENSIVE LOSS (379,180) (465,500) (811,178) (775,969)

Less: Comprehensive loss attributable to non-controlling interests (5,401) (271) (13,619) (270)

COMPREHENSIVE LOSS ATTRIBUTABLE TO AGAPE ATP CORPORATION $ (373,779) $ (465,229) $ (797,559) $ (775,699)

LOSS PER SHARE Basic and diluted $ (0.00) $ (0.01) $ (0.01) $ (0.01)

WEIGHTED AVERAGE NUMBER OF COMMON SHARES OUTSTANDING Basic and diluted 75,452,012 75,452,012 75,452,012 100,397,696

    REGISTRATION NO. 333-239951

F-3

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

F-4

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

CASH FLOWS FROM OPERATING ACTIVITIES: Net loss $ (813,524) $ (702,790) Adjustments to reconcile net loss to net cash used in operating activities: Depreciation 36,177 36,661 Amortization 3,087 897 Amortization of operating right-of-use assets 78,333 75,241 Unrealized holding (gain) loss on marketable securities (8,710) 52,889 Dividend income from marketable securities - - Inventory write-down - - Provision for doubtful accounts - - Deferred tax (benefit) provision (6,655) - Changes in operating assets and liabilities: Accounts receivables (2,751) (214) Amount due from related parties (209) 2,201 Inventories (23,013) 28,790 Prepaid taxes 238,064 296,219 Prepayments and deposits 80,651 102,099 Accounts payable 24,608 7,804 Accounts payable -related parties (4,758) 14,407 Customer deposits (31,655) (175,936) Operating lease liabilities (79,551) (75,200) Other payables and accrued liabilities (228,812) (166,137) Other payable - related parties (3,457) 2,081 Income tax payable - 5,261 Net cash used in operating activities (742,175) (495,727)

CASH FLOWS FROM INVESTING ACTIVITIES: Purchase of equipment (6,499) (750) Purchase of intangible assets - - Net cash used in investing activities (6,499) (750)

CASH FLOWS FROM FINANCING ACTIVITIES: Deferred offering costs (22,861) (178,926) Advances to related parties - - Net cash used in financing activities (22,861) (178,926)

EFFECT OF EXCHANGE RATE ON CASH AND CASH EQUIVALENTS (13,141) (115,008)

DECREASE IN CASH AND CASH EQUIVALENTS (784,676) (790,411)

CASH AND CASH EQUIVALENTS, beginning of period 1,438,430 2,597,848

CASH AND CASH EQUIVALENTS, end of period $ 653,754 $ 1,807,437

SUPPLEMENTAL CASH FLOWS INFORMATION Income taxes paid $ 20,849 $ 77,117

SUPPLEMENTAL NON-CASH FLOWS INFORMATION Increase in right-of-use assets and lease liabilities due to lease renewal $ 283,220 $ -

    REGISTRATION NO. 333-239951

F-5

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

1. ORGANIZATION AND BUSINESS BACKGROUND

Agape ATP Corporation, a Nevada corporation ("the Company") was incorporated under the laws of the State of Nevada on June 1, 2016.

Agape ATP Corporation operates through its subsidiaries, namely, Agape ATP Corporation ("AATP LB"), a company incorporated in Labuan, Malaysia, and Agape Superior Living Sdn. Bhd. ("ASL"), a company incorporated in Malaysia.

Agape ATP Corporation, incorporated in Labuan, Malaysia, is an investment holding company with 100% equity interest in Agape ATP International Holding Limited ("AATP HK"), a company incorporated in Hong Kong.

On May 8, 2020, the Company entered into a Share Exchange Agreement with Mr. How Kok Choong, CEO and director of the Company to acquire 9,590,596 ordinary shares, no par value, equivalent to approximately 99.99% of the equity interest in Agape Superior Living Sdn. Bhd., a network marketing entity incorporated in Malaysia.

Agape Superior Living Sdn. Bhd. is a limited company incorporated on August 8, 2003, under the laws of Malaysia.

On September 11, 2020, the Company incorporated Wellness ATP International Holdings Sdn, Bhd. ("WATP"), a wholly owned subsidiary under the laws of Malaysia, to pursue the business of promoting wellness and wellbeing lifestyle of the community by providing services that includes online editorials, programs, events and campaigns on how to achieve positive wellness and lifestyle.

On November 11, 2021, Agape ATP Corporation (Labuan) formed a joint-venture entity, DSY Wellness International Sdn. Bhd. ("DSY Wellness") with an independent third party which Agape ATP Corporation (Labuan) owns 60% of the equity interest, to pursue the business of providing complementary health therapies.

The Company and its subsidiaries are principally engaged in the Health and Wellness Industry. The principal activity of the Company is to supply high-quality health and wellness products, including supplements to assist in cell metabolism, detoxification, blood circulation, anti-aging and products designed to improve the overall health system of the human body and various wellness programs.

The accompanying consolidated financial statements reflect the activities of the Company, AATP LB, AATP HK, WATP, ASL and its variable interest entity ("VIE"), Agape S.E.A. Sdn. Bhd. ("SEA") (See Note 3), and DSY Wellness.

Details of the Company's subsidiaries:

SCHEDULE OF SUBSIDIARIES AND ASSOCIATES

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

DSY Wellness Malaysia, 1,000 shares of Provision of International November 11, ordinary share complementary 6. Sdn Bhd. 2021 of RM1 each health therapies 60 %

F-6

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

1. ORGANIZATION AND BUSINESS BACKGROUND (Continued)

Business Overview

Agape ATP Corporation is a company that provides health and wellness products and health solution advisory services to our clients. The Company primarily focus its efforts on attracting customers in Malaysia. Its advisory services center on the "ATP Zeta Health Program", which is a health program designed to effectively prevent diseases caused by polluted environments, unhealthy dietary intake and unhealthy lifestyles, and promotion of health. The program aims to promote improved health and longevity in our clients through a combination of modern medicine, proper nutrition and advice from skilled nutritionists and/or dieticians.

In order to strengthen the Company's supply chain, on May 8, 2020, the Company has successfully acquired approximately 99.99% of ASL, with the goal of securing an established network marketing sales channel that has been established in Malaysia for the past 15 years. ASL has been offering the Company's ATP Zeta Health Program as part of its product lineup. As such, the acquisition creates synergy in the Company's operation by boosting the Company's retail and marketing capabilities. The newly acquired subsidiary allows the Company to fulfill its mission of "helping people to create health and wealth" by providing a financially rewarding business opportunity to distributors and quality products to distributors and customers who seek a healthy lifestyle.

Via ASL, the Company offers three series of programs which consist of different services and products: ATP Zeta Health Program, ENERGETIQUE and BEAUNIQUE.

The ATP Zeta Health Program is a health program designed to promote health and general wellbeing designed to prevent health diseases caused by polluted environments, unhealthy dietary intake and unhealthy lifestyles. The program aims to promote improved health and longevity through a combination of modern health supplements, proper nutrition and advice from skilled dieticians as well as trained members and distributors.

The ENERGETIQUE series aims to provide a total dermal solution for a healthy skin beginning from the cellular level. The series is comprised of the Energy Mask series, Hyaluronic Acid Serum and Mousse Facial Cleanser.

The BEAUNIQUE product series focuses on the research of our diet's impact on modifying gene expressions in order to address genetic variations and deliver a nutrigenomic solution for every individual.

The Company deems creating public awareness on wellness and wellbeing lifestyle as essential to enhance the provision of its health solution advisory services; and therefore, incorporated WATP. Upon its establishment, WATP started collaborating with ASL to carry out various wellness programs.

To further its reach in the Health and Wellness Industry, on November 11, 2021, Agape ATP Corporation (Labuan) formed a joint-venture entity, DSY Wellness International Sdn. Bhd. ("DSY Wellness") with an independent third party which Agape ATP Corporation (Labuan) owns 60% of the equity interest, to pursue the business of providing complementary health therapies.

F-7

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

2. GOING CONCERN

In assessing the Company's liquidity, the Company monitors and analyzes its cash on-hand and its operating and capital expenditure commitments. The Company's liquidity needs are to meet its working capital requirements, operating expenses and capital expenditure obligations. Equity financing is used to supplement working capital requirements of the Company.

The Company's management has considered whether there is substantial doubt about its ability to continue as a going concern due to (1) the net loss of $379,449 and $813,524 for the three and six months ended June 30, 2023; (2) accumulated deficit of $5,746,112 as of June 30, 2023; (3) working capital deficit of $26,892 as of June 30, 2023; and (4) the unexpectedly long turnaround time that the Company's distributors and members are taking to revert to pre-pandemic mode to generate sales.

Management has determined there is substantial doubt about its ability to continue as a going concern. If the Company is unable to generate significant revenue, the Company may be required to curtail or cease its operations. Management is trying to alleviate the going concern risk through the following sources:

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Based on the above measures, management is of the opinion that the Company will probably not have sufficient funds to meet its working capital requirements and debt obligations as they become due one year from the filing date of these unaudited condensed consolidated financial statements.

There is no assurance that the Company will be successful in implementing the foregoing plans or that additional financing will be available to the Company on commercially reasonable terms, or at all. There are a number of factors that could potentially arise that could undermine the Company's plans, such as (i) undue delay in the Company's current pursuit in seeking second listing on NASDAQ, (ii) the slow rate in which the Company's distributors and members re-ignite their sales activities, (iii) changes in the demand for the Company's products and services due to the diminishing effect on the purchasing power of the public in general, as a result of the COVID-19 pandemic, and (iv) if the Company's new business in the provision of complementary health therapies fail to grow in the manner and at the rate as planned. The Company's inability to secure needed financing when required could require material changes to the Company's business plans and could have a material adverse effect on the Company's viability and results of operations.

3. SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES

Basis of presentation

The accompanying interim unaudited condensed consolidated financial statements of the Company have been prepared in accordance with accounting principles generally accepted in the United States of America ("U.S. GAAP").

The interim unaudited financial information as of June 30, 2023 and for the three and six months ended June 30, 2023 and 2022 have been prepared without audit, pursuant to the rules and regulations of the SEC and pursuant to Regulation S-X. Certain information and footnote disclosures, which are normally included in annual consolidated financial statements prepared in accordance with U. S. GAAP, have been omitted pursuant to those rules and regulations. The interim unaudited financial information should be read in conjunction with the audited consolidated financial statements and the notes thereto, included in the Form 10-K for the fiscal year ended December 31, 2022, which was filed with the SEC on March 31, 2023.

In the opinion of management, all adjustments (including normal recurring adjustments) necessary to present a fair statement of the Company's unaudited financial position as of June 30, 2023, its unaudited results of operations for the three and six months ended June 30, 2023 and 2022, and its unaudited cash flows for the six months ended June 30, 2023 and 2022, as applicable, have been made. The unaudited interim results of operations are not necessarily indicative of the operating results for the full fiscal year or any future periods.

The unaudited condensed consolidated financial statements include the financial statements of the Company, its subsidiaries and its variable interest entity ("VIE") over which the Company exercises control and, where applicable, entities for which the Company has a controlling financial interest or is the primary beneficiary. All transactions and balances among the Company, its subsidiaries and its VIE have been eliminated upon consolidation.

Principles of consolidation

Subsidiaries are those entities in which the Company, directly or indirectly, controls more than one half of the voting power; or has the power to govern the financial and operating policies, to appoint or remove the majority of the members of the board of directors, or to cast a majority of votes at the meeting of directors.

A VIE is an entity that has either a total equity investment that is insufficient to permit the entity to finance its activities without additional subordinated financial support, or whose equity investors lack the characteristics of a controlling financial interest, such as through voting rights, right to receive the expected residual returns of the entity or obligation to absorb the expected losses of the entity. The variable interest holder, if any, that has a controlling financial interest in a VIE is deemed to be the primary beneficiary and must consolidate the VIE. As of and for the three and six months ended June 30, 2023, SEA, the only VIE of the Company has no significant operations.

Use of estimates

The preparation of unaudited condensed consolidated financial statements in conformity with U.S. GAAP requires management to make estimates and assumptions that affect the reported amounts of assets and liabilities and disclosures of contingent assets and liabilities as of the date of the unaudited condensed consolidated financial statements and the reported amounts of revenues and expenses during the periods presented. Significant accounting estimates reflected in the Company's unaudited condensed consolidated financial statements include allowance for inventories obsolescence, impairment of long-lived assets and allowance for deferred tax assets. Actual results could differ from these estimates.

Cash and cash equivalents

Cash and cash equivalents represent cash on hand, time deposits placed with banks or other financial institutions and all highly liquid investments with an original maturity of three months or less.

F-8

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

3. SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES (Continued)

Accounts receivable

Accounts receivable are recorded at the invoiced amount less an allowance for any uncollectible accounts and do not bear interest, which are due on credit term. Management reviews the adequacy of the allowance for doubtful accounts on an ongoing basis, using historical collection trends and aging of receivables. Management also periodically evaluates individual customer's financial condition, credit history, and the current economic conditions to make adjustments in the allowance when it is considered necessary. Account balances are charged off against the allowance after all means of collection have been exhausted and the potential for recovery is considered remote. The Company's management continues to evaluate the reasonableness of the valuation allowance policy and update it if necessary. As of June 30, 2023 and December 31, 2022, no allowance of doubtful accounts was recorded.

Inventories

Inventories consist of finished goods and are stated at the lower of cost or net realizable value using the first-in first-out method. Management reviews inventory on hand for estimated obsolescence or unmarketable items, as compared to future demand requirements and the shelf life of the various products. Based on the review, the Company records inventory write-downs, when necessary, when costs exceed expected net realizable value. For the three and six months ended June 30, 2023 and 2022, the Company did not recognize any inventory write-downs nor write-off.

Prepaid taxes

Prepaid taxes include prepaid income taxes that will either be refunded or utilized to offset future income tax.

Prepayments and deposits

Prepayments and deposits are mainly cash deposited or advanced to suppliers for future inventory purchases or service providers for future services. This amount is refundable and bears no interest. For any prepayments and deposits determined by management that such advances will not be in receipts of inventories, services, or refundable, the Company will recognize an allowance account to reserve such balances. Management reviews its prepayments and deposits on a regular basis to determine if the allowance is adequate, and adjusts the allowance when necessary. Delinquent account balances are written-off against allowance for doubtful accounts after management has determined that the likelihood of collection is not probable. The Company's management continues to evaluate the reasonableness of the allowance policy and update it if necessary. There was no allowance for doubtful accounts recorded nor doubtful accounts written-off during the three and six months ended June 30, 2023 and 2022. There was no allowance for doubtful accounts balances as of June 30, 2023 and December 31, 2022.

Property and equipment, net

Property and equipment are stated at cost less accumulated depreciation. Depreciation is computed using the straight-line method over the estimated useful lives of the assets with no residual value. The estimated useful lives are as follows:

F-9

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

3. SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES (Continued)

SCHEDULE OF ESTIMATED USEFUL LIVES OF PROPERTY AND EQUIPMENT

    REGISTRATION NO. 333-239951

The cost and related accumulated depreciation of assets sold or otherwise retired are eliminated from the accounts and any gain or loss is included in the unaudited condensed consolidated statements of operations and comprehensive loss. Expenditures for maintenance and repairs are charged to earnings as incurred, while additions, renewals and betterments, which are expected to extend the useful life of assets, are capitalized. The Company also re-evaluates the periods of depreciation to determine whether subsequent events and circumstances warrant revised estimates of useful lives.

Intangible assets, net

Intangible assets, net, are stated at cost, less accumulated amortization. Amortization expense is recognized on the straight-line basis over the estimated useful lives of the assets as follows:

SCHEDULE OF ESTIMATED USEFUL LIVES OF INTANGIBLE ASSETS, NET

Classification Useful Life

Computer software 5 years

Impairment for long-lived assets

Long-lived assets, including property and equipment, and intangible assets with finite lives are reviewed for impairment whenever events or changes in circumstances (such as a significant adverse change to market conditions that will impact the future use of the assets) indicate that the carrying value of an asset may not be recoverable. The Company assesses the recoverability of the assets based on the undiscounted future cash flows the assets are expected to generate and recognize an impairment loss when estimated undiscounted future cash flows expected to result from the use of the asset plus net proceeds expected from disposition of the asset, if any, are less than the carrying value of the asset. If an impairment is identified, the Company would reduce the carrying amount of the asset to its estimated fair value based on a discounted cash flows approach or, when available and appropriate, to comparable market values. As of June 30, 2023 and December 31, 2022, no impairment of long-lived assets was recognized.

Deferred offering costs

Deferred offering costs represents costs associated with the Company's current offering which will be netted against the proceeds from the Company's proposed offering for uplisting.

Investment in marketable equity securities

The Company follows the provisions of ASU 2016-01, Financial Instruments - Overall (Subtopic 825-10): Recognition and Measurement of Financial Assets and Financial Liabilities. Investments in marketable equity securities (non-current) are reported at fair value with changes in fair value recognized in the Company's unaudited condensed consolidated statements of operations and comprehensive loss in the caption of "unrealized holding gain (loss) on marketable securities" in each reporting period.

F-10

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

3. SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES (Continued)

Investment in non-marketable equity securities

The Company follows the provisions of ASU 2016-01, Financial Instruments - Overall (Subtopic 825-10): Recognition and Measurement of Financial Assets and Financial Liabilities. Due to the Company's non-marketable equity securities (non-current) does not qualify for the practical expedient to estimate fair value in accordance with ASC 820-10-35-59, the Company has selected to record its investments in non-marketable equity securities (non-current) at cost minus impairment, if any, plus or minus changes resulting from observable price changes in orderly transactions for the identical or a similar investment of the same issue.

At each reporting period, the Company will make a qualitative assessment considering impairment indicators to evaluate whether the investment is impaired. The qualitative assessment indicators include, but are not limited to: (1) A significant deterioration in the earnings performance, credit rating, asset quality, or business prospects of the investee; (ii) A significant adverse change in the regulatory, economic, or technological environment of the investee; (iii) A significant adverse change in the general market condition of either the geographical area or the industry in which the investee operates; (iv) A bona fide offer to purchase, an offer by the investee to sell, or a completed auction process for the same or similar investment for an amount less than the carrying amount of that investment; and (v) Factors that raise significant concerns about the investee's ability to continue as a going concern, such as negative cash flows from operations, working capital deficiencies, or noncompliance with statutory capital requirements or debt covenants. If the qualitative assessment indicators indicated that the non-marketable equity securities (non-current) is deemed to be impaired, the Company would recognize the impairment loss equal to the difference between the fair value of the investment and its carrying amount.

Customer deposits

Customer deposits represent amounts advanced by customers on product orders and unapplied unexpired coupons. Customer deposits are reduced when the related sale is recognized in accordance with the Company's revenue recognition policy.

Revenue recognition

The Company adopted Accounting Standards Update ("ASU") 2014-09, Revenue from Contracts with Customers (ASC Topic 606). The core principle underlying the revenue recognition of this ASU allows the Company to recognize - revenue that represents the transfer of goods and services to customers in an amount that reflects the consideration to which the Company expects to be entitled in such exchange. This will require the Company to identify contractual performance obligations and determine whether revenue should be recognized at a point in time or over time, based on when control of goods and services transfers to a customer. The Company's revenue streams are recognized at a point in time for the Company's sale of health and wellness products.

The ASU requires the use of a new five-step model to recognize revenue from customer contracts. The five-step model requires that the Company (i) identify the contract with the customer, (ii) identify the performance obligations in the contract, (iii) determine the transaction price, including variable consideration to the extent that it is probable that a significant future reversal will not occur, (iv) allocate the transaction price to the respective performance obligations in the contract, and (v) recognize revenue when (or as) the Company satisfies the performance obligation.

The Company accounts for a contract with a customer when the contract is committed in writing, the rights of the parties, including payment terms, are identified, the contract has commercial substance and consideration is probable of substantially collection.

F-11

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

3. SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES (Continued)

Sales of Health and Wellness products

- Performance obligations satisfied at a point in time

The Company derives its revenues from sales contracts with its customers with revenues being recognized when control of the health and wellness products are transferred to its customer at the Company's office or shipment of the goods. The revenue is recorded net of estimated discounts and return allowances. Products are given 60 days for returns or exchanges from the date of purchase. Historically, there were insignificant sales returns.

Under the Company's network marketing business, the Company issues product coupons to members and distributors when these customers made purchases above certain thresholds set by the Company. Depending on the type of product coupons issued, the coupons carry varying values and can be used by the customers for reduction in the transaction price of product purchases within the coupon validity period. The value of the product coupons issued is recorded as a reduction of the Company's revenue account upon issuance; the corresponding amount credited to the customer deposits account. Amounts in customer deposits will be reversed when the coupons are used. The Company's coupons have a validity period of between six and twelve months. If the Company's customers did not utilize the coupons after the validity period, the Company would recognize the forfeiture of the originated sales value of the coupons as net revenues.

For the three months ended June 30, 2023 and 2022, the Company recognized $6,422 and $4,824, as forfeited coupon income, respectively. For the six months ended June 30, 2023 and 2022, the Company recognized $28,872 and $5,777, as forfeited coupon income, respectively.

The Company had contracts for the sales of health and wellness products amounting to $7,790 which it is expected to fulfill within 12 months from June 30, 2023.

Sales of products for the provision of complementary health therapies

Products for the provision of complementary health therapies are predominantly Chinese herbs in different forms, processed or otherwise, for prescriptions for treating non-communicable diseases.

Provision of Health and Wellness services

- Performance obligations satisfied at a point in time

The Company carries out its Wellness program, where the Company's products are bundled with health screening test and a health camp program. The health screening test and the health camp programs are considered as separate performance obligations. The promises to deliver the health screening test report and the attendance at the health camp are separately identifiable, which are evidenced by the fact that the Company provides separate services of delivering the health screening test report and allowing admission of the customers to attend the health camp. The Company derives its revenues from sales contracts with its customers with revenues being recognized when the test reports are completed and delivered to its customers during the consultation session in person.

The Company also separately derives its revenues from sales contracts with its customers with revenues being recognized when the health camp program was completed in the final day of the health camp. For the three months ended June 30, 2023 and 2022, revenues from health and wellness services were $58,862 and $30,072 respectively. For the six months ended June 30, 2023 and 2022, revenues from health and wellness services were $124,214 and $31,139 respectively.

F-12

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

3. SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES (Continued)

Disaggregated information of revenues by products are as follows:

SCHEDULE OF DIS-AGGREGATED INFORMATION OF REVENUES

    REGISTRATION NO. 333-239951

Cost of revenue

Cost of revenue comprised freight-in, the purchase cost of manufactured goods for sale to customers and products for the provision of complementary health therapies. For the three and six months ended June 30, 2023, cost of revenue were $107,931 and $236,289, respectively. For the three and six months ended June 30, 2022, cost of revenue were $109,383 and $182,814, respectively.

Shipping and handling

Shipping and handling charges amounted to $1,131 and $4,272 for the three months ended June 30, 2023 and 2022, respectively. Shipping and handling charges amounted to $2,656 and $7,179 for the six months ended June 30, 2023 and 2022, respectively. Shipping and handling charges are expensed as incurred and included in selling expenses.

Advertising costs

There were no advertising costs incurred for the three and six months ended June 30, 2023. Advertising costs amounted to $4,765 and $4,765 for the three and six months ended June 30, 2022. Advertising costs are expensed as incurred and included in selling expenses.

F-13

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

3. SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES (Continued)

Commission expenses

Commission expenses are the Company's most significant expenses. As with all companies in the network marketing industry, the Company's sales channel is external to the Company. The Company's "external sales force" is stratified into two levels based on priority recruitment. First, there are sales distributors. Second, all members recruited by a sales distributor, directly or indirectly, are referred to as "sales network members". The Company pays commission to every sales distributor based on purchases made by its sales network members which includes the independent direct sales members. Top performing distributors with their own physical stores may also become stockists of the Company, whereby they enjoy benefits such as maintaining a certain amount of the Company's inventory on their store premises. The stockists shall account to the Company for all products sales from their store premises as monitored through the Company's centralized stock tracking system. The Company pays a separate commission to stockists based on revenue generated from the stockists' physical stores. Commission expenses amounted to $21,942 and $62,557 for the three months ended June 30, 2023 and 2022, respectively. Commission expenses amounted to $55,884 and $176,666 for the six months ended June 30, 2023 and 2022, respectively.

Defined contribution plan

The full-time employees of the Company are entitled to the government mandated defined contribution plan. The Company is required to accrue and pay for these benefits based on certain percentages of the employees' respective salaries, subject to certain ceilings, in accordance with the relevant government regulations, and make cash contributions to the government mandated defined contribution plan. Total expenses for the plans were $35,759 and $35,936 for the three months ended June 30, 2023 and 2022, respectively. Total expenses for the plans were $79,472 and $63,408 for the six months ended June 30, 2023 and 2022, respectively.

The related contribution plans include:

    REGISTRATION NO. 333-239951

Income taxes

The Company accounts for income taxes in accordance with U.S. GAAP for income taxes. The charge for taxation is based on the results for the fiscal year as adjusted for items, which are non-assessable or disallowed. It is calculated using tax rates that have been enacted or substantively enacted by the balance sheet date.

Deferred taxes is accounted for using the asset and liability method in respect of temporary differences arising from differences between the carrying amount of assets and liabilities in the consolidated financial statements and the corresponding tax basis used in the computation of assessable tax profit. In principle, deferred tax liabilities are recognized for all taxable temporary differences. Deferred tax assets are recognized to the extent that it is probable that taxable profit will be available against which deductible temporary differences can be utilized. Deferred tax is calculated using tax rates that are expected to apply to the period when the asset is realized or the liability is settled.

F-14

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

3. SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES (Continued)

Deferred tax is charged or credited in the income statement, except when it is related to items credited or charged directly to equity, in which case the deferred tax is also dealt with in equity. Deferred tax assets are reduced by a valuation allowance when, in the opinion of management, it is more likely than not that some portion or all of the deferred tax assets will not be realized. Current income taxes are provided for in accordance with the laws of the relevant taxing authorities.

An uncertain tax position is recognized as a benefit only if it is "more likely than not" that the tax position would be sustained in a tax examination, with a tax examination being presumed to occur. The amount recognized is the largest amount of tax benefit that is greater than 50% likely of being realized on examination. For tax positions not meeting the "more likely than not" test, no tax benefit is recorded. No penalties and interest incurred related to underpayment of income taxes for the three and six months ended June 30, 2023 and 2022.

The Company conducts much of its business activities in Hong Kong and Malaysia and is subject to tax in each of these jurisdictions. As a result of its business activities, the Company will file separate tax returns that are subject to examination by the foreign tax authorities.

Comprehensive income (loss)

Comprehensive income (loss) consists of two components, net income (loss) and other comprehensive income (loss). Net income (loss) refers to revenue, expenses, gains and losses that under GAAP are recorded as an element of stockholders' equity but are excluded from net income. Other comprehensive income (loss) consists of a foreign currency translation adjustment resulting from the Company not using the U.S. dollar as its functional currencies.

Non-controlling interest

Non-controlling interest consists of 40% of the equity interests of DSY Wellness held by an individual and approximately 0.01% (2 ordinary shares out of 9,590,598 shares) of the equity interests of ASL held by two individuals. The non-controlling interests are presented in the consolidated balance sheets, separately from equity attributable to the shareholders of the Company. Non-controlling interests in the results of the Company are presented on the face of the consolidated statements of operations as an allocation of the total income or loss for the periods between non-controlling interest holders and the shareholders of the Company.

Earnings (loss) per share

The Company computes earnings (loss) per share ("EPS") in accordance with ASC 260, "Earnings per Share". ASC 260 requires companies to present basic and diluted EPS. Basic EPS is measured as net income (loss) divided by the weighted average ordinary share outstanding for the period. Diluted EPS presents the dilutive effect on a per share basis of the potential common stocks (e.g., convertible securities, options and warrants) as if they had been converted at the beginning of the periods presented, or issuance date, if later. Potential common stocks that have an anti-dilutive effect (i.e., those that increase income per share or decrease loss per share) are excluded from the calculation of diluted EPS. For the three and six months ended June 30, 2023 and 2022, there were no dilutive shares.

F-15

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

3. SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES (Continued)

Foreign currencies translation and transaction

Transactions denominated in currencies other than the functional currency are translated into the functional currency at the exchange rates prevailing at the dates of the transaction. Monetary assets and liabilities denominated in currencies other than the functional currency are translated into the functional currency using the applicable exchange rates at the balance sheet dates. The resulting exchange differences are recorded in the consolidated statements of operations and comprehensive loss.

The reporting currency of the Company is United States Dollars ("US$") and the accompanying financial statements have been expressed in US$. The Company's subsidiary in Labuan maintains its books and record in United States Dollars ("US$") albeit its functional currency being the primary currency of the economic environment in which the entity operates, which is the Malaysian Ringgit ("MYR" or "RM"). The Company's subsidiary in Hong Kong maintains its books and record in Hong Kong Dollars ("HK$"), similar to its functional currency. The Company's subsidiary and VIE in Malaysia conducts its businesses and maintains its books and record in the local currency, Malaysian Ringgit ("MYR" or "RM"), as its functional currency.

In general, for consolidation purposes, assets and liabilities of its subsidiaries whose functional currency is not US$ are translated into US$, in accordance with ASC Topic 830-30, "Translation of Financial Statement", using the exchange rate on the balance sheet date. Revenues and expenses are translated at average rates prevailing during the period. The gains and losses resulting from translation of financial statements of foreign subsidiary are recorded as a separate component of accumulated other comprehensive income within the statements of stockholders' equity. Cash flows are also translated at average translation rates for the periods, therefore, amounts reported on the statement of cash flows will not necessarily agree with changes in the corresponding balances on the consolidated balance sheets.

Translation of foreign currencies into US$1 have been made at the following exchange rates for the respective periods:

SCHEDULE OF FOREIGN CURRENCIES TRANSLATION EXCHANGE RATES

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

F-16

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

3. SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES (Continued)

Related parties

Parties, which can be a corporation or individual, are considered to be related if the Company has the ability, directly or indirectly, to control the other party or exercise significant influence over the other party in making financial and operating decisions. Companies are also considered to be related if they are subject to common control or common significant influence.

Fair value of financial instruments

The accounting standard regarding fair value of financial instruments and related fair value measurements defines financial instruments and requires disclosure of the fair value of financial instruments held by the Company.

The accounting standards define fair value, establish a three-level valuation hierarchy for disclosures of fair value measurement and enhance disclosure requirements for fair value measures. The three levels are defined as follow:

    REGISTRATION NO. 333-239951

Financial instruments included in current assets and current liabilities are reported in the consolidated balance sheets at face value or cost, which approximate fair value because of the short period of time between the origination of such instruments and their expected realization and their current market rates of interest.

Leases

The Company adopted ASU 2016-02, "Leases" (Topic 842), and elected the practical expedients that does not require the Company to reassess: (1) whether any expired or existing contracts are, or contain, leases, (2) lease classification for any expired or existing leases and (3) initial direct costs for any expired or existing leases. For lease terms of twelve months or fewer, a lessee is permitted to make an accounting policy election not to recognize lease assets and liabilities. The Company also adopts the practical expedient that allows lessees to treat the lease and non-lease components of a lease as a single lease component. Some of the Company's leases include one or more options to renew, which is typically at the Company's sole discretion. The Company regularly evaluates the renewal options, and, when it is reasonably certain of exercise, it will include the renewal period in its lease term. New lease modifications result in re-measurement of the right of use ("ROU") assets and lease liabilities. Operating ROU assets and lease liabilities are recognized at the commencement date, based on the present value of lease payments over the lease term. Since the implicit rate for the Company's leases is not readily determinable, the Company use its incremental borrowing rate based on the information available at the commencement date in determining the present value of lease payments. The incremental borrowing rate is the rate of interest that the Company would have to pay to borrow, on a collateralized basis, an amount equal to the lease payments, in a similar economic environment and over a similar term.

F-17

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

3. SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES (Continued)

Lease terms used to calculate the present value of lease payments generally do not include any options to extend, renew, or terminate the lease, as the Company does not have reasonable certainty at lease inception that these options will be exercised. The Company generally considers the economic life of its operating lease ROU assets to be comparable to the useful life of similar owned assets. The Company has elected the short-term lease exception, therefore operating lease ROU assets and liabilities do not include leases with a lease term of twelve months or less. Its leases generally do not provide a residual guarantee. The operating lease ROU asset also excludes lease incentives. Lease expense is recognized on a straight-line basis over the lease term.

The Company reviews the impairment of its ROU assets consistent with the approach applied for its other long-lived assets. The Company reviews the recoverability of its long-lived assets when events or changes in circumstances occur that indicate that the carrying value of the asset may not be recoverable. The assessment of possible impairment is based on its ability to recover the carrying value of the asset from the expected undiscounted future pre-tax cash flows of the related operations. The Company has elected to include the carrying amount of operating lease liabilities in any tested asset group and includes the associated operating lease payments in the undiscounted future pre-tax cash flows.

Recent accounting pronouncements

The Company has reviewed all recently issued, but not yet effective, considers the applicability and impact of all accounting standards updates ("ASUs"). Management periodically reviews new accounting standards that are issued.

In March 2023, the FASB issued ASU No. 2023-01, "Leases (Topic 842) Common Control Arrangements". This ASU provides guidance in ASC Topic 842 that leasehold improvements associated with common control leases should be (i) amortized by the lessee over the useful life of the leasehold improvements to the common control group, regardless of the lease term, as long as the lessee controls the use of the underlying asset through a lease, and (ii) accounted for as a transfer between entities under common control through an adjustment to equity if and when the lessee no longer controls the use of the underlying asset. The ASU 2023-01 is effective for reporting periods beginning after December 15, 2023. Early adoption is permitted for both interim and annual financial statements that have not yet been issued. When adopted in an interim period, it must be adopted from the beginning of the year that includes that interim period. The Company is currently evaluating the impact of this ASU may have on its unaudited condensed consolidated financial statements.

Except for the above-mentioned pronouncements, there are no other new recent issued accounting standards that will have a material impact on the consolidated financial position, statements of operations and cash flows.

Recently adopted Accounting Pronouncements

In November 2019, the FASB issued ASU No. 2019-10, which to update the effective date of ASU No. 2016-13 for private companies, not-for-profit organizations and certain smaller reporting companies applying for credit losses, leases, and hedging standard. The new effective date for these preparers is for fiscal years beginning after December 15, 2022. ASU 2019-05 is effective for the Company for annual and interim reporting periods beginning January 1, 2023 as the Company is qualified as a smaller reporting company. The Company has accordingly adopted ASUs 2016-13 and 2019-05 in the preparation of its unaudited condensed consolidated financial statements. The adoption of the accounting standards has no material impact on the unaudited condensed consolidated financial statements for the three and six months ended June 30, 2023.

4. VARIABLE INTEREST ENTITY ("VIE")

SEA is a trading company incorporated on March 4, 2004, under the laws of Malaysia. SEA provided majority of ASL's purchases. Its equity at risk was insufficient to finance its activities and 100% of its business is transacted with ASL. Therefore, it was considered to be a VIE and ASL is the primary beneficiary since it has both of the following characteristics:

    REGISTRATION NO. 333-239951

Accordingly, the accounts of SEA is consolidated in the accompanying financial statements.

F-18

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

4. VARIABLE INTEREST ENTITY ("VIE") (Continued)

The carrying amount of the VIE's assets and liabilities were as follows:

SCHEDULE OF VARIABLE INTEREST ENTITY

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Current liabilities: Accounts payable - intercompany $ 40,029 $ 42,422 Other payables and accrued liabilities 1,028 1,090 Total current liabilities $ 41,057 $ 43,512 Net deficit $ (38,240) $ (40,162)

The summarized operating results of the VIE's are as follows:

    REGISTRATION NO. 333-239951

Operating revenues $ - $ - $ - $ - Gross profit $ - $ - $ - $ - Profit (Loss) from operations $ (81) $ 1,723 $ (359) $ (3,219) Net loss $ (81) $ 1,723 $ (359) $ (3,219)

F-19

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

5. CASH AND CASH EQUIVALENTS

As of June 30, 2023 and December 31, 2022 the Company has $653,754 and $1,438,430, respectively, of cash and cash equivalents, which consists of $332,431 and $523,619, respectively, of cash and cash in banks and $321,323 and $914,811, respectively, of time deposits placed with banks or other financial institutions and are all highly liquid investments with an original maturity of three months or less. The effective interest rate for the time deposits ranged between 1.22% to 1.88% per annum for the three and six months ended June 30, 2023. The effective interest rate ranged between 1.10% to 1.17% per annum for the three and six months ended June 30, 2022. As of June 30, 2023 and December 31, 2022, $397,809 and $231,187 of these balances are not covered by deposit insurance, respectively.

6. ACCOUNTS RECEIVABLE

    REGISTRATION NO. 333-239951

Accounts receivable $ 5,303 $ 2,826 Allowance for doubtful accounts - - Total accounts receivable $ 5,303 $ 2,826

7. INVENTORIES

Inventories consist of the following:

SCHEDULE OF INVENTORIES

    REGISTRATION NO. 333-239951

Finished goods $ 66,056 $ 46,277

There were no inventory write-downs nor write-off for the three and six months ended June 30, 2023 and 2022, respectively.

8. PREPAYMENTS AND DEPOSITS

SCHEDULE OF PREPAID EXPENSES AND DEPOSITS

    REGISTRATION NO. 333-239951

Receivables from sales distributors $ 28,219 $ 43,596 Deposits to suppliers 94,719 147,504 Subtotal 122,938 191,100 Less: Allowance for doubtful accounts - - Total $ 122,938 $ 191,100

F-20

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

8. PREPAYMENTS AND DEPOSITS (Continued)

Movements of allowance for doubtful accounts are as follows:

SCHEDULE OF CHANGES IN ALLOWANCE FOR DOUBTFUL ACCOUNTS

    REGISTRATION NO. 333-239951

Beginning balance $ - $ 121,095 Addition - - Write off - (120,372) Exchange rate effect - (723) Ending balance $ - $ -

9. PROPERTY AND EQUIPMENT, NET

Property and equipment, net consist of the following:

SCHEDULE OF PROPERTY AND EQUIPMENT, NET

    REGISTRATION NO. 333-239951

Computer and office equipment $ 88,641 $ 87,428 Furniture & fixtures 109,342 115,789 Leasehold improvements 181,136 191,965 Vehicle 88,259 93,535 Subtotal 467,378 488,717 Less: accumulated depreciation (361,704) (346,568) Total $ 105,674 $ 142,149

Depreciation expense for the three months ended June 30, 2023 and 2022 amounted to $18,124 and $17,954, respectively. Depreciation expense for the six months ended June 30, 2023 and 2022 amounted to $36,177 and $36,661, respectively.

10. INTANGIBLE ASSETS, NET

Intangible assets, net, consist of the following:

SCHEDULE OF INTANGIBLE ASSETS, NET

    REGISTRATION NO. 333-239951

Computer software $ 52,225 $ 55,348 Less: accumulated amortization (32,497) (31,304) Total $ 19,728 $ 24,044

Amortization expense for the three months ended June 30, 2023 and 2022 amounted to $1,506 and $439, respectively. Amortization expense for the six months ended June 30, 2023 and 2022 amounted to $3,087 and $897, respectively.

F-21

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

11. INVESTMENT IN MARKETABLE SECURITIES

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

12. INVESTMENT IN NON-MARKETABLE SECURITIES

On April 3, 2019, the Company purchased a 5% of stock or 15,000,000 shares of common stock in Phoenix Plus Corp. for $1,500 at purchase price of $0.0001 per share. Phoenix Plus Corp. attained its effective date with the Securities Exchange Commission for listing on OTC (Pink Sheet), U.S. on March 12, 2021, and obtained approval for Depository trust Company ("DTC") eligibility on April 26, 2022. Accordingly, stocks of Phoenix Plus Corp. can be traded on OTC. As such the investment in Phoenix Plus Corp. was transferred to marketable securities.

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

F-22

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

13. CUSTOMER DEPOSITS

SCHEDULE OF CUSTOMER DEPOSITS

    REGISTRATION NO. 333-239951

Customer deposits $ 265,300 $ 289,487 Unexpired product coupons 46,889 73,531 Total $ 312,189 $ 363,018

Customer deposits represent amounts advanced by customers on product orders and unexpired product coupons issued to the Company's members and distributors of its network marketing business.

14. OTHER PAYABLES AND ACCRUED LIABILITIES

SCHEDULE OF OTHER PAYABLES AND ACCRUED LIABILITIES

    REGISTRATION NO. 333-239951

Professional fees $ 140,672 $ 324,629 Promotion expenses 38,583 38,583 Payroll 17,944 21,164 Amounts held in eWallets (a) 195,000 216,049 Tax penalty 75,000 75,000 Others 8,468 37,852 Total $ 475,667 $ 713,277

    REGISTRATION NO. 333-239951

15. RELATED PARTY BALANCES AND TRANSACTIONS

Related party balances

Amount due from related parties

SCHEDULE OF RELATED PARTIES

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Total $ 1,417 $ 10,534

Accounts payable - related parties

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

F-23

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

15. RELATED PARTY BALANCES AND TRANSACTIONS (Continued)

Related party balances

Other payable - related parties

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Related party transactions

Purchases

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

F-24

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

15. RELATED PARTY BALANCES AND TRANSACTIONS (Continued)

Related party transactions

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Other Purchases

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

F-25

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

15. RELATED PARTY BALANCES AND TRANSACTIONS (Continued)

Related party transactions

Other purchases

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Commission

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

F-26

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

15. RELATED PARTY BALANCES AND TRANSACTIONS (Continued)

Related party transactions

Commission

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Other Income

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

F-27

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

15. RELATED PARTY BALANCES AND TRANSACTIONS (Continued)

Related party transactions

Other expenses

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

16. STOCKHOLDERS' EQUITY

Preferred stock

As of June 30, 2023 and December 31, 2022, there were 200,000,000 preferred stocks authorized but none were issued and outstanding.

Common stock

As of June 30, 2023 and December 31, 2022, there were 1,000,000,000 common stocks authorized; and 75,452,012 shares issued and outstanding.

A share forfeiture agreement (the "Share Forfeiture Agreement") dated January 20, 2022, between the Company and Mr. How Kok Choong, the CEO and director of the Company, pursuant to which Mr. How Kok Choong agreed to forfeit 215,008,035 shares of common stock of the Company. As a result, the outstanding shares was reduced by 215,008,035 shares of common stock.

There were no stock options, warrants or other potentially dilutive securities outstanding as of June 30, 2023 and December 31, 2022.

F-28

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

17. NON-CONTROLLING INTEREST

The Company's non-controlling interest consists of the following:

SCHEDULE OF NON CONTROLLING INTEREST

    REGISTRATION NO. 333-239951

18. INCOME TAXES

The United States and foreign components of income (loss) before income taxes were comprised of the following:

SCHEDULE OF COMPONENTS OF INCOME/(LOSS) BEFORE INCOME TAX

    REGISTRATION NO. 333-239951

Tax jurisdictions from: Local - United States $ (142,912) $ (187,379) $ (310,697) $ (293,804) Foreign - Malaysia (241,867) (189,395) (516,152) (354,459) Foreign - Hong Kong 2,891 (27,178) 6,670 (45,847) Foreign, Tax Jurisdictions 2,891 (27,178) 6,670 (45,847)

Loss before income tax $ (381,888) $ (403,952) $ (820,179) $ (694,110)

The benefit of (provision for) income taxes consisted of the following:

SCHEDULE OF PROVISION FOR INCOME TAX

    REGISTRATION NO. 333-239951

Current: - Local $ - $ - $ - $ - - Foreign - (392) - (8,680)

Deferred: - Local - - - - - Foreign 2,439 - 6,655 - Benefit of (Provision for) income tax $ 2,439 $ (392) $ 6,655 $ (8,680)

The effective tax rate in the periods presented is the result of the mix of income earned in various tax jurisdictions that apply a broad range of income tax rates. The Company and its subsidiary that operate in various countries: United States, Malaysia (including Labuan) and Hong Kong that are subject to taxes in the jurisdictions in which they operate, as follows:

F-29

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

18. INCOME TAXES (Continued)

United States of America

Agape ATP Corporation was incorporated in the State of Nevada and is subject to the tax laws of the United States of America with a corporate tax rate of 21% on its taxable income. Agape ATP Corporation also subject to controlled foreign corporations Subpart F income ("Subpart F") tax, which is a tax primarily on passive income from controlled foreign corporations with a tax rate of 35%. In addition, the Tax Cuts and Jobs Act imposed a global intangible low-taxed income ("GILTI") tax, which is a tax on certain off-shore earnings at an effective rate of 10.5% for tax years (50% deduction of the current enacted tax rate of 21%) with a partial offset for 80% foreign tax credits. If the foreign tax rate is 13.125% or higher, there will be no U.S. corporate tax after the 80% foreign tax credits are applied.

For the three and six months ended June 30, 2023 and 2022, the Company's foreign subsidiaries did not generate any income that are subject to Subpart F tax and GILTI tax.

As of June 30, 2023 and December 31, 2022, the operations in the United States of America incurred approximately $1,668,000 and $1,357,000, respectively, of cumulative net operating losses ("NOL") which can be carried forward to offset future taxable income or Subpart F and GILTI taxes. These balances can be carried forward indefinitely. The deferred tax valuation allowance as of June 30, 2023 and December 31, 2022 were approximately $350,000 and $285,000, respectively.

Malaysia

Agape ATP Corporation, Agape Superior Living Sdn Bhd, Agape S.E.A Sdn Bhd., Wellness ATP International Holdings Sdn Bhd. and DSY Wellness International Sdn. Bhd. are governed by the income taxes laws of Malaysia and the income taxes provision in respect of operations in Malaysia is calculated at the applicable tax rates on the taxable income for the periods based on existing legislation, interpretations and practices in respect thereof. Under the Income Tax Act of Malaysia, enterprises that incorporated in Malaysia are usually subject to a unified 24% enterprise income taxes rate while preferential tax rates, tax holidays and even tax exemption may be granted on case-by-case basis. The tax rate for small and medium sized companies (generally companies incorporated in Malaysia with paid-in capital of RM 2,500,000 or less) is 17% for the first RM 600,000 (or approximately $150,000) for the three and six months ended June 30, 2023 and 2022, with the remaining balance being taxed at the 24% rate.

As of June 30, 2023 and December 31, 2022, the operations in Malaysia incurred approximately $2,149,000 and $1,723,000, respectively, of cumulative net operating losses ("NOL") which can be carried forward to offset future taxable income. Approximately $35,000, $778,000, $858,000 and $478,000 of the net operating loss carry forwards will expire in 2030, 2031, 2032 and 2033, respectively, if unutilized. The deferred tax valuation allowance as of June 30, 2023 and December 31, 2022 were approximately $501,000 and $408,000, respectively.

Hong Kong

Agape ATP International Holding (HK) Limited is subject to Hong Kong Profits Tax, which is charged at the statutory income rate of 16.5% on its assessable income derived from Hong Kong. Business income derived or business expenses incurred outside the Special Administrative Region is not subject to Hong Kong Profits Tax or deduction.

F-30

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

18. INCOME TAXES (Continued)

The following table sets forth the significant components of the aggregate deferred tax assets of the Company:

SCHEDULE OF DEFERRED TAX ASSETS

    REGISTRATION NO. 333-239951

Less: valuation allowance (851,545) (693,185) Deferred tax assets, net $ 6,382 $ -

Uncertain tax positions

The Company evaluates each uncertain tax position (including the potential application of interest and penalties) based on the technical merits, and measure the unrecognized benefits associated with the tax positions. As of June 30, 2023 and December 31, 2022, the Company did not have any significant unrecognized uncertain tax positions. The Company did not incur any interest and penalties tax for the three and six months ended June 30, 2023 and 2022.

19. CONCENTRATIONS OF RISKS

(a) Major customers

For the three months ended June 30, 2023 and 2022, no customer accounted for 10% or more of the Company's total revenues. For the six months ended June 30, 2023 and 2022, no customer accounted for 10% or more of the Company's total revenues.

As of June 30, 2023, two individual customers accounted for approximately 19.9% and 18.7% of the Company's balance of accounts receivable, respectively. As of December 31, 2022, five individual customers accounted for approximately 72.0% of the Company's balance of accounts receivable.

(b) Major vendors

For the three months ended June 30, 2023, three vendors accounted for approximately 43.1%, 27.5% and 26.0% of the Company's total purchases. For the three months ended June 30, 2022, three vendors accounted for approximately 70.0%, 17.0% and 11% of the Company's total purchases, respectively.

For the six months ended June 30, 2023, the same three vendors accounted for approximately 47.2%, 26.5% and 13.6% of the Company's total purchases. For the six months ended June 30, 2022, two vendors accounted for approximately 46.0% and 43.0% of the Company's total purchases.

As of June 30, 2023, two vendors accounted for approximately 62.3% and 27.8% of the Company's total balance of accounts payable, respectively. As of December 31, 2022, three vendors accounted for approximately 46.6%, 25.8% and 23.9% of the Company's total balance of accounts payable, respectively.

CTA Nutriceuticals (Asia) Sdn Bhd, a related company, accounted for approximately 27.8% and 46.6% of the Company's total balance of accounts payable as of June 30, 2023 and December 31, 2022, respectively.

F-31

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

19. CONCENTRATIONS OF RISKS (Continued)

(c) Commission Expenses to Sales Distributors and Stockists

One sales distributor accounted for 10% or more of the Company's commission expense for the three months ended June 30, 2023 and 2022.

For the six months ended June 30, 2023, one sales distributor accounted for 10% or more of the Company's commission expense. For the six months ended June 30, 2022, no sales distributor accounted for 10% or more of the Company's commission expense.

(d) Credit risk

Financial instruments that potentially subject the Company to significant concentrations of credit risk consist primarily of cash. As of June 30, 2023 and December 31, 2022, $630,285 and $1,427,963 were deposited with financial institutions, respectively, $397,809 and $231,187 of these balances are not covered by deposit insurance, respectively. While management believes that these financial institutions are of high credit quality, it also continually monitors their credit worthiness.

Financial instruments that are potentially subject to credit risk consist principally of accounts receivable. The Company believes the concentration of credit risk in its account receivable is substantially mitigated by its ongoing credit evaluation process and relatively short collection terms. The Company does not generally require collateral from customers. The Company evaluates the need for an allowance for doubtful accounts based upon factors surrounding the credit risk of specific customers, historical trends and other information. Historically, the Company did not have any bad debt on its account receivable.

(e) Exchange rate risk

The Company cannot guarantee that the current exchange rate will remain steady; therefore, there is a possibility that the Company could post the same amount of profit for two comparable periods and because of the fluctuating exchange rate actually post higher or lower profit depending on exchange rate of RM and HK$ converted to US$ on that date. The exchange rate could fluctuate depending on changes in political and economic environments without notice.

20. COMMITMENTS AND CONTINGENCIES

Lease commitments

On April 1, 2020, the Company adopted ASC 842 for ASL's office space lease and sales and training center as the lease commencement date upon the acquisition of ASL. The Company recognized lease liabilities of approximately $490,000, with a corresponding right-of-use ("ROU") asset in the same amount based on the present value of the future minimum rental payments of the lease, using an effective interest rate of 5.5%, which was determined using the Company's estimated incremental borrowing rate.

On May 31, 2021, the Company entered into two separate two-year leases extension with the modified lease expiring May 31, 2023 for its office space and expiring August 31, 2023 for its training center. The lease modification required the Company to re-measure the ROU assets and lease liabilities based on the modified leases. The Company recognized a reduction of $3,250 in ROU assets and lease liabilities upon lease modifications based on the present value of the future minimum rental payments of the lease, using an effective interest rate of 5.5%, which was determined using the Company's estimated incremental borrowing rate. On June 1, 2023, upon the expiry of the two-years lease for its office space, the Company entered into a new three-years lease with the same landlord. The Company recognized lease liabilities of approximately $283,220, with a corresponding right-of-use ("ROU") asset in the same amount based on the present value of the future minimum rental payments of the lease, using an effective interest rate of 5.5%, which was determined using the Company's estimated incremental borrowing rate.

On October 1, 2021, the Company entered into a two-years lease for an apartment to serve as staff accommodation. The Company recognized lease liabilities of approximately $9,777, with a corresponding right-of-use ("ROU") asset in the same amount based on the present value of the future minimum rental payments of the lease, using an effective interest rate of 5.5%, which was determined using the Company's estimated incremental borrowing rate.

On November 1, 2021, the Company entered into a two-years lease for a branch office and operating centre. The Company recognized lease liabilities of approximately $10,864, with a corresponding right-of-use ("ROU") asset in the same amount based on the present value of the future minimum rental payments of the lease, using an effective interest rate of 5.5%, which was determined using the Company's estimated incremental borrowing rate.

Amortization of operating right-of-use assets for the three months ended June 30, 2023 and 2022 were $38,683 and $36,162 respectively. Amortization of operating right-of-use assets for the six months ended June 30, 2023 and 2022 were $78,333 and $75,241 respectively.

As of June 30, 2023, the weighted remaining term of the lease is approximately 2.81 years.

F-32

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

20. COMMITMENTS AND CONTINGENCIES (Continued)

The five-year maturity of the Company's operating lease liabilities is as follow:

SCHEDULE OF LEASE COMMITMENTS

Twelve Months Ending June 30, Operating lease liabilities

2024 $ 111,362 2025 102,501 2026 93,959 Thereafter - Total lease payments 307,822 Less: interest (22,834) Present value of lease liabilities $ 284,988

The Company also leases one office and operation center, and one shophouse with an expiring term of twelve months or less, which were classified as operation leases. Since the lease terms for these leases were twelve months or less, a lessee is permitted to elect not to recognize lease assets and liabilities. The Company has elected not to recognize lease assets and liabilities on these leases. As of June 30, 2023, the Company's commitment for minimum lease payment under these operating leases within the next twelve months were $16,020.

Rent expense for the three months ended June 30, 2023 and 2022 was $48,727 and $54,237, respectively. Rent expense for the six months ended June 30, 2023 and 2022 was $99,434 and $98,312, respectively.

Contingencies

Legal

From time to time, the Company is party to certain legal proceedings, as well as certain asserted and un-asserted claims. Amounts accrued, as well as the total amount of reasonably possible losses with respect to such matters, individually and in the aggregate, are not deemed to be material to the consolidated financial statements.

F-33

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

20. COMMITMENTS AND CONTINGENCIES (Continued)

COVID-19

Malaysia, where the operations of the Company predominantly reside, officially transitioned to the endemic phase of COVID-19 effective April 1, 2022. Restrictions on businesses and people are minimal. Meanwhile, the government continues to encourage inoculation for those between the ages of 5 and 11 years and its adolescent group which comprised those between the ages 12 and 17. Adults who have been fully vaccinated, i.e. received two doses of the COVID-19 vaccine are encouraged to take booster shots.

Substantially all of our revenues are concentrated in Malaysia. Consequently, our results of operations will likely be adversely, and may be materially, affected, to the extent that the COVID-19 or any other epidemic harms the Malaysia and global economy in general. Any potential impact to our results will depend on, to a large extent, future developments and new information that may emerge regarding the duration and severity of the COVID-19 and the actions taken by government authorities and other entities to contain the COVID-19 or treat its impact, almost all of which are beyond our control. Potential impacts include, but are not limited to, the following:

    REGISTRATION NO. 333-239951

Because of the uncertainty surrounding the COVID-19 outbreak, the financial impact related to the outbreak of and response to the COVID-19 cannot be reasonably estimated at this time. There is no guarantee that the Company's total revenues will grow or remain at similar levels year over year in 2023 and beyond.

21. SUBSEQUENT EVENTS

The Company has evaluated subsequent events through the date of issuance of this unaudited condensed consolidated financial statements, and does not identify any events with material financial impact on the Company's unaudited condensed consolidated financial statements.

F-34

    REGISTRATION NO. 333-239951

To the Board of Directors and

Stockholders of Agape ATP Corporation

Opinion on the Financial Statements

We have audited the accompanying consolidated balance sheet of Agape ATP Corporation (the "Company") as of December 31, 2022, the related consolidated statement of operation, comprehensive loss, stockholders' equity and cash flows for the year then ended, and the related notes (collectively referred to as the "financial statements"). In our opinion, the financial statements present fairly, in all material respects, the financial position of the Company as of December 31, 2022, and the results of its operations and its cash flows for the year then ended, in conformity with accounting principles generally accepted in the United States of America.

Basis for Opinion

These financial statements are the responsibility of the Company's management. Our responsibility is to express an opinion on the Company's financial statements based on our audit. We are a public accounting firm registered with the Public Company Accounting Oversight Board (United States) ("PCAOB") and are required to be independent with respect to the Company in accordance with the U.S. federal securities laws and the applicable rules and regulations of the Securities and Exchange Commission and the PCAOB.

We conducted our audit in accordance with the standards of the PCAOB. Those standards require that we plan and perform the audit to obtain reasonable assurance about whether the financial statements are free of material misstatement, whether due to error or fraud. The Company is not required to have, nor were we engaged to perform, an audit of its internal control over financial reporting. As part of our audit we are required to obtain an understanding of internal control over financial reporting but not for the purpose of expressing an opinion on the effectiveness of the Company's internal control over financial reporting. Accordingly, we express no such opinion.

Our audit included performing procedures to assess the risks of material misstatement of the financial statements, whether due to error or fraud, and performing procedures that respond to those risks. Such procedures included examining, on a test basis, evidence regarding the amounts and disclosures in the financial statements. Our audit also included evaluating the accounting principles used and significant estimates made by management, as well as evaluating the overall presentation of the financial statements. We believe that our audit provides a reasonable basis for our opinion.

Critical Audit Matters

Critical audit matters are matters arising from the current period audit of the financial statements that were communicated or required to be communicated to the audit committee and that: (1) relate to accounts or disclosures that are material to the financial statements and (2) involved our especially challenging, subjective, or complex judgments. We determined that there are no critical audit matters.

/s/ Marcum Asia CPAs LLP

Marcum Asia CPAs LLP

We have served as the Company's auditor since 2019 (such date takes into account the acquisition of certain assets of Friedman LLP by Marcum Asia CPAs LLP effective September 1, 2022)

New York, New York March 31, 2023

F-35

[[Image Removed]]

    REGISTRATION NO. 333-239951

To the Board of Directors and

Stockholders of Agape ATP Corporation

Opinion on the Consolidated Financial Statements

We have audited the accompanying consolidated balance sheet of Agape ATP Corporation (the "Company") as of December 31, 2021, and the related consolidated statement of operations and comprehensive loss, changes in stockholders' equity and cash flow for the year ended December 31, 2021, and the related notes (collectively referred to as the consolidated financial statements). In our opinion, the consolidated financial statements present fairly, in all material respects, the financial position of the Company as of December 31, 2021, and the result of its operations and its cash flow for the year ended December 31, 2021, in conformity with accounting principles generally accepted in the United States of America.

Basis for Opinion

These consolidated financial statements are the responsibility of the Company's management. Our responsibility is to express an opinion on the Company's consolidated financial statements based on our audit. We are a public accounting firm registered with the Public Company Accounting Oversight Board (United States) ("PCAOB") and are required to be independent with respect to the Company in accordance with the U.S. federal securities laws and the applicable rules and regulations of the Securities and Exchange Commission and the PCAOB.

We conducted our audit in accordance with the standards of the PCAOB. Those standards require that we plan and perform the audit to obtain reasonable assurance about whether the consolidated financial statements are free of material misstatement, whether due to error or fraud. The Company is not required to have, nor were we engaged to perform, an audit of its internal control over financial reporting. As part of our audit, we are required to obtain an understanding of internal control over financial reporting, but not for the purpose of expressing an opinion on the effectiveness of the Company's internal control over financial reporting. Accordingly, we express no such opinion.

Our audit included performing procedures to assess the risks of material misstatement of the consolidated financial statements, whether due to error or fraud, and performing procedures that respond to those risks. Such procedures included examining, on a test basis, evidence regarding the amounts and disclosures in the consolidated financial statements. Our audit also included evaluating the accounting principles used and significant estimates made by management, as well as evaluating the overall presentation of the consolidated financial statements. We believe that our audit provide a reasonable basis for our opinion.

/s/ Friedman LLP

We have served as the Company's auditor since 2019 through 2022

New York, New York

March 28, 2022

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

OTHER ASSETS Property and equipment, net 142,149 215,799 Intangible assets, net 24,044 3,660 Operating right-of-use assets 81,133 237,718 Investment in marketable securities 16,687 89,001 Investment in non-marketable securities - 1,500 Deferred offering costs 499,202 264,735 Total other assets 763,215 812,413

TOTAL ASSETS $ 2,791,749 $ 4,724,535

LIABILITIES AND STOCKHOLDERS' EQUITY CURRENT LIABILITIES Accounts payable $ 28,833 $ 13,715 Accounts payable - related parties 25,611 - Customer deposits 363,018 279,689 Operating lease liabilities 82,708 157,094 Other payables and accrued liabilities ($1,090 and $1,548 are included in the consolidated VIE that are without recourse to the credit of Agape ATP Corporation as of December 31, 2022 and 2021, respectively.) 713,277 858,355 Other payable - related parties 4,880 - Income tax payable 10,968 3,988 Total Current Liabilities 1,229,295 1,312,841

NON-CURRENT LIABILITIES Operating lease liabilities $ - $ 83,484 Deferred tax liabilities - 15,574 Total Non-current Liabilities - 99,058

TOTAL LIABILITIES $ 1,229,295 $ 1,411,899

STOCKHOLDERS' EQUITY Preferred stock, $0.0001 par value; 200,000,000 shares authorized; None issued and outstanding - - Common Stock, par value $0.0001; 1,000,000,000 shares authorized, 75,452,012 and 290,460,047 shares issued and outstanding as of December 31, 2022 and 2021, respectively. 7,545 29,046 Additional paid in capital 6,470,716 6,449,215 Accumulated deficit (4,945,586) (3,258,687) Accumulated other comprehensive income 9,266 93,398 TOTAL AGAPE CORPORATION STOCKHOLDERS' EQUITY 1,541,941 3,312,972

NON-CONTROLLING INTERESTS 20,513 (336)

TOTAL EQUITY 1,562,454 3,312,636

TOTAL LIABILITIES AND STOCKHOLDERS' EQUITY $ 2,791,749 $ 4,724,535

    REGISTRATION NO. 333-239951

F-37

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

REVENUE $ 1,856,564 $ 1,016,962

COST OF REVENUE (666,042) (297,333)

GROSS PROFIT 1,190,522 719,629

SELLING (361,414) (394,682) COMMISSION (405,351) (316,267) GENERAL AND ADMINISTRATIVE (1,957,023) (1,745,734) PROVISION FOR DOUBTFUL ACCOUNTS - (121,514) TOTAL OPERATING EXPENSES (2,723,788) (2,578,197)

LOSS FROM OPERATIONS (1,533,266) (1,858,568)

OTHER INCOME (EXPENSES) Other expenses, net (79,539) (68,323) Interest income 16,190 25,570 Unrealized holding loss on marketable securities (73,519) (505,231) Dividend income from marketable securities - 18,939 TOTAL OTHER EXPENSES, NET (136,868) (529,045)

LOSS BEFORE INCOME TAXES (1,670,134) (2,387,613)

BENEFIT OF (PROVISION FOR) INCOME TAXES 4,055 (137,067)

NET LOSS (1,666,079) (2,524,680)

NET (INCOME) LOSS ATTRIBUTABLE TO NON-CONTROLLING INTERESTS (20,820) 436

NET LOSS ATTRIBUTABLE TO AGAPE ATP CORPORATION $ (1,686,899) $ (2,524,244)

NET LOSS $ (1,666,079) $ (2,524,680)

OTHER COMPREHENSIVE LOSS Foreign currency translation adjustment (84,132) (87,615)

TOTAL COMPREHENSIVE LOSS (1,750,211) (2,612,295)

Less: Comprehensive income (loss) attributable to non-controlling interests 20,849 (433)

COMPREHENSIVE LOSS ATTRIBUTABLE TO AGAPE ATP CORPORATION $ (1,771,060) $ (2,611,862)

LOSS PER SHARE Basic and diluted $ (0.02) $ (0.01)

WEIGHTED AVERAGE NUMBER OF COMMON SHARES OUTSTANDING Basic and diluted 87,822,337 376,216,452

    REGISTRATION NO. 333-239951

F-38

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Foreign currency translation adjustment - - - - (84,132) 29 (84,103) Balance as of December 31, 2022 75,452,012 $ 7,545 $ 6,470,716 $ (4,945,586) $ 9,266 $ 20,513 $ 1,562,454 Balance 75,452,012 $ 7,545 $ 6,470,716 $ (4,945,586) $ 9,266 $ 20,513 $ 1,562,454

    REGISTRATION NO. 333-239951

F-39

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

CASH FLOWS FROM OPERATING ACTIVITIES: Net loss $ (1,666,079) $ (2,524,680) Adjustments to reconcile net loss to net cash used in operating activities: Depreciation 71,754 75,797 Amortization 2,122 1,961 Amortization of operating right-of-use assets 144,064 139,451 Unrealized holding loss on marketable securities 73,519 505,231 Dividend income from marketable securities - (18,939) Deferred tax (benefit) expense (14,751) 10,127 Inventory write-down 5,307 36,241 Provision for doubtful accounts - 121,514 Changes in operating assets and liabilities: Accounts receivables (2,824) 167,566 Amount due from related parties (3,786) - Inventories 343,483 192,713 Prepaid taxes 263,404 430,062 Prepayments and deposits 89,113 (128,363) Accounts payable 15,825 - Accounts payable - related parties 25,597 - Customer deposits 94,877 52,981 Operating lease liabilities (145,197) (138,143) Other payables and accrued liabilities (119,963) 226,651 Other payables - related parties 4,878 - Income tax payables 6,974 3,988 Net cash used in operating activities (811,683) (845,842)

CASH FLOWS FROM INVESTING ACTIVITIES: Purchase of equipment (9,433) (3,959) Purchase of intangible assets (22,686) - Net cash used in investing activities (32,119) (3,959)

CASH FLOWS FROM FINANCING ACTIVITIES: Deferred offering costs (234,466) (15,210) Advances to related parties - (3,851) Net cash used in financing activities (234,466) (19,061)

EFFECT OF EXCHANGE RATE ON CASH AND CASH EQUIVALENTS (81,150) (50,890)

DECREASE IN CASH AND CASH EQUIVALENTS (1,159,418) (919,752)

CASH AND CASH EQUIVALENTS, beginning of year 2,597,848 3,517,600

CASH AND CASH EQUIVALENTS, end of year $ 1,438,430 $ 2,597,848

SUPPLEMENTAL CASH FLOWS INFORMATION Income taxes paid $ 78,511 $ 326,838

SUPPLEMENTAL NON-CASH FLOWS INFORMATION Changes in right-of-use assets and lease liabilities due to lease modifications $ - $ 3,250

    REGISTRATION NO. 333-239951

F-40

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

1. ORGANIZATION AND BUSINESS BACKGROUND

Agape ATP Corporation, a Nevada corporation ("the Company") was incorporated under the laws of the State of Nevada on June 1, 2016.

Agape ATP Corporation operates through its subsidiaries, namely, Agape ATP Corporation ("AATP LB"), a company incorporated in Labuan, Malaysia, and Agape Superior Living Sdn. Bhd. ("ASL"), a company incorporated in Malaysia.

Agape ATP Corporation, incorporated in Labuan, Malaysia, is an investment holding company with 100% equity interest in Agape ATP International Holding Limited ("AATP HK"), a company incorporated in Hong Kong.

On May 8, 2020, the Company entered into a Share Exchange Agreement with Mr. How Kok Choong, CEO and director of the Company to acquire 9,590,596 ordinary shares, no par value, equivalent to approximately 99.99% of the equity interest in Agape Superior Living Sdn. Bhd., a network marketing entity incorporated in Malaysia.

Agape Superior Living Sdn. Bhd. is a limited company incorporated on August 8, 2003, under the laws of Malaysia.

On September 11, 2020, the Company incorporated Wellness ATP International Holdings Sdn, Bhd. ("WATP"), a wholly owned subsidiary under the laws of Malaysia, to pursue the business of promoting wellness and wellbeing lifestyle of the community by providing services that includes online editorials, programs, events and campaigns on how to achieve positive wellness and lifestyle.

On November 11, 2021, Agape ATP Corporation (Labuan) formed a joint-venture entity, DSY Wellness International Sdn. Bhd. ("DSY Wellness") with an independent third party which Agape ATP Corporation (Labuan) owns 60% of the equity interest, to pursue the business of providing complementary health therapies.

The Company and its subsidiaries are principally engaged in the Health and Wellness Industry. The principal activity of the Company is to supply high-quality health and wellness products, including supplements to assist in cell metabolism, detoxification, blood circulation, anti-aging and products designed to improve the overall health system of the human body and various wellness programs.

The accompanying consolidated financial statements reflect the activities of the Company, AATP LB, AATP HK, WATP, ASL and the variable interest entity ("VIE"), Agape S.E.A. Sdn. Bhd. ("SEA") (See Note 3), and DSY Wellness.

Details of the Company's subsidiaries:

SCHEDULE OF SUBSIDIARIES AND ASSOCIATES

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

F-41

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

1. ORGANIZATION AND BUSINESS BACKGROUND (CONT'D)

Business Overview

Agape ATP Corporation is a company that provides health and wellness products and health solution advisory services to our clients. The Company primarily focus its efforts on attracting customers in Malaysia. Its advisory services center on the "ATP Zeta Health Program", which is a health program designed to effectively prevent diseases caused by polluted environments, unhealthy dietary intake and unhealthy lifestyles, and promotion of health. The program aims to promote improved health and longevity in our clients through a combination of modern medicine, proper nutrition and advice from skilled nutritionists and/or dieticians.

In order to strengthen the Company's supply chain, on May 8, 2020, the Company successfully acquired approximately 99.99% of ASL, with the goal of securing an established network marketing sales channel that has been established in Malaysia for the past 15 years. ASL has been offering the Company's ATP Zeta Health Program as part of its product lineup. As such, the acquisition creates synergy in the Company's operation by boosting the Company's retail and marketing capabilities. The newly acquired subsidiary allows the Company to fulfill its mission of "helping people to create health and wealth" by providing a financially rewarding business opportunity to distributors and quality products to distributors and customers who seek a healthy lifestyle.

Via ASL, the Company offers three series of programs which consist of different services and products: ATP Zeta Health Program, ENERGETIQUE and BEAUNIQUE.

The ATP Zeta Health Program is a health program designed to promote health and general wellbeing designed to prevent health diseases caused by polluted environments, unhealthy dietary intake and unhealthy lifestyles. The program aims to promote improved health and longevity through a combination of modern health supplements, proper nutrition and advice from skilled dieticians as well as trained members and distributors.

The ENERGETIQUE series aims to provide a total dermal solution for a healthy skin beginning from the cellular level. The series is comprised of the Energy Mask series, Hyaluronic Acid Serum and Mousse Facial Cleanser.

The BEAUNIQUE product series focuses on the research of our diet's impact on modifying gene expressions in order to address genetic variations and deliver a nutrigenomic solution for every individual.

The Company deems creating public awareness on wellness and wellbeing lifestyle as essential to enhance the provision of its health solution advisory services; and therefore, incorporated WATP. Upon its establishment, WATP started collaborating with ASL to carry out various wellness programs.

To further its reach in the Health and Wellness Industry, on November 11, 2021, Agape ATP Corporation (Labuan) formed a joint-venture entity, DSY Wellness International Sdn. Bhd. ("DSY Wellness") with an independent third party which Agape ATP Corporation (Labuan) owns 60% of the equity interest, to pursue the business of providing complementary health therapies.

2. SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES

Basis of presentation

The accompanying consolidated financial statements have been prepared in accordance with accounting principles generally accepted in the United States of America ("U.S. GAAP") for information pursuant to the rules and regulations of the Securities Exchange Commission ("SEC").

The consolidated financial statements include the financial statements of the Company, its subsidiaries and the VIE over which the Company exercises control and, where applicable, entities for which the Company has a controlling financial interest or is the primary beneficiary. All transactions and balances among the Company, its subsidiaries and the VIE have been eliminated upon consolidation.

F-42

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

2. SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES (CONT'D)

Principles of consolidation

Subsidiaries are those entities in which the Company, directly or indirectly, controls more than one half of the voting power; or has the power to govern the financial and operating policies, to appoint or remove the majority of the members of the board of directors, or to cast a majority of votes at the meeting of directors.

A VIE is an entity that has either a total equity investment that is insufficient to permit the entity to finance its activities without additional subordinated financial support, or whose equity investors lack the characteristics of a controlling financial interest, such as through voting rights, right to receive the expected residual returns of the entity or obligation to absorb the expected losses of the entity. The variable interest holder, if any, that has a controlling financial interest in a VIE is deemed to be the primary beneficiary and must consolidate the VIE. As of and for the year ended December 31, 2022, SEA, the only VIE of the Company has no significant operations.

Use of estimates

The preparation of consolidated financial statements in conformity with U.S. GAAP requires management to make estimates and assumptions that affect the reported amounts of assets and liabilities and disclosures of contingent assets and liabilities as of the date of the consolidated financial statements and the reported amounts of revenues and expenses during the periods presented. Significant accounting estimates reflected in the Company's consolidated financial statements include allowance for inventories obsolescence, impairment of long-lived assets, allowance for deferred tax assets. Actual results could differ from these estimates.

Cash and cash equivalents

Cash and cash equivalents represent cash on hand, time deposits placed with banks or other financial institutions and all highly liquid investments with an original maturity of three months or less.

Accounts receivable

Accounts receivable are recorded at the invoiced amount less an allowance for any uncollectible accounts and do not bear interest, which are due on credit term. Management reviews the adequacy of the allowance for doubtful accounts on an ongoing basis, using historical collection trends and aging of receivables. Management also periodically evaluates individual customer's financial condition, credit history, and the current economic conditions to make adjustments in the allowance when it is considered necessary. Account balances are charged off against the allowance after all means of collection have been exhausted and the potential for recovery is considered remote. The Company's management continues to evaluate the reasonableness of the valuation allowance policy and update it if necessary. As of December 31, 2022 and 2021, no allowance of doubtful accounts was recorded.

F-43

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

2. SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES (CONT'D)

Inventories

Inventories consist of finished goods and are stated at the lower of cost or net realizable value using the first-in first-out method. Management reviews inventory on hand for estimated obsolescence or unmarketable items, as compared to future demand requirements and the shelf life of the various products. Based on the review, the Company records inventory write-downs, when necessary, when costs exceed expected net realizable value.

For the years ended December 31, 2022 and 2021, the Company recognized $5,307 and $36,241 inventory write-down; and $142,466 and $0 inventory write-off, respectively.

Prepaid taxes

Prepaid taxes include prepaid income taxes that will either be refunded or utilized to offset future income tax.

Prepayments and deposits

Prepayments and deposits are mainly cash deposited or advanced to suppliers for future inventory purchases or service providers for future services. This amount is refundable and bears no interest. For any prepayments and deposits determined by management that such advances will not be in receipts of inventories, services, or refundable, the Company will recognize an allowance account to reserve such balances. Management reviews its prepayments and deposits on a regular basis to determine if the allowance is adequate, and adjusts the allowance when necessary. Delinquent account balances are written-off against allowance for doubtful accounts after management has determined that the likelihood of collection is not probable. The Company's management continues to evaluate the reasonableness of the allowance policy and update it if necessary. For the years ended December 31, 2022 and 2021, the Company wrote-off allowance for doubtful accounts of $120,372 and $0, respectively. As of December 31, 2022 and 2021, there was $0 and $121,514 allowance for the doubtful accounts recorded.

Property and equipment, net

Property and equipment are stated at cost less accumulated depreciation. Depreciation is computed using the straight-line method over the estimated useful lives of the assets with no residual value. The estimated useful lives are as follows:

SCHEDULE OF ESTIMATED USEFUL LIVES OF PROPERTY AND EQUIPMENT

    REGISTRATION NO. 333-239951

Computer and office equipment 5-7 years Furniture & fixtures 6-7 years Leasehold improvements Lease Term Vehicle 5 years

The cost and related accumulated depreciation of assets sold or otherwise retired are eliminated from the accounts and any gain or loss is included in the consolidated statements of income and comprehensive income. Expenditures for maintenance and repairs are charged to earnings as incurred, while additions, renewals and betterments, which are expected to extend the useful life of assets, are capitalized. The Company also re-evaluates the periods of depreciation to determine whether subsequent events and circumstances warrant revised estimates of useful lives.

F-44

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

2. SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES (CONT'D)

Intangible assets, net

Intangible assets, net, are stated at cost, less accumulated amortization. Amortization expense is recognized on the straight-line basis over the estimated useful lives of the assets as follows:

SCHEDULE OF ESTIMATED USEFUL LIVES OF INTANGIBLE ASSETS, NET

Classification Useful Life

Computer software 5 years

Impairment for long-lived assets

Long-lived assets, including property and equipment, and intangible assets with finite lives are reviewed for impairment whenever events or changes in circumstances (such as a significant adverse change to market conditions that will impact the future use of the assets) indicate that the carrying value of an asset may not be recoverable. The Company assesses the recoverability of the assets based on the undiscounted future cash flows the assets are expected to generate and recognize an impairment loss when estimated undiscounted future cash flows expected to result from the use of the asset plus net proceeds expected from disposition of the asset, if any, are less than the carrying value of the asset. If an impairment is identified, the Company would reduce the carrying amount of the asset to its estimated fair value based on a discounted cash flows approach or, when available and appropriate, to comparable market values. As of December 31, 2022 and 2021, no impairment of long-lived assets was recognized.

Deferred offering costs

Deferred offering costs represents costs associated with the Company's current offering which will be netted against the proceeds from the Company's current offering.

Investment in marketable equity securities

The Company follows the provisions of ASU 2016-01, Financial Instruments - Overall (Subtopic 825-10): Recognition and Measurement of Financial Assets and Financial Liabilities. Investments in marketable equity securities (non-current) are reported at fair value with changes in fair value recognized in the Company's consolidated statements of operations and comprehensive income (loss) in the caption of "unrealized holding gain loss on marketable securities" in each reporting period.

Investment in non-marketable equity securities

The Company follows the provisions of ASU 2016-01, Financial Instruments - Overall (Subtopic 825-10): Recognition and Measurement of Financial Assets and Financial Liabilities. Due to the Company's non-marketable equity securities (non-current) does not qualify for the practical expedient to estimate fair value in accordance with ASC 820-10-35-59, the Company has selected to record its investments in non-marketable equity securities (non-current) at cost minus impairment, if any, plus or minus changes resulting from observable price changes in orderly transactions for the identical or a similar investment of the same issue.

At each reporting period, the Company will make a qualitative assessment considering impairment indicators to evaluate whether the investment is impaired. The qualitative assessment indicators include, but are not limited to: (1) A significant deterioration in the earnings performance, credit rating, asset quality, or business prospects of the investee; (ii) A significant adverse change in the regulatory, economic, or technological environment of the investee; (iii) A significant adverse change in the general market condition of either the geographical area or the industry in which the investee operates; (iv) A bona fide offer to purchase, an offer by the investee to sell, or a completed auction process for the same or similar investment for an amount less than the carrying amount of that investment; and (v) Factors that raise significant concerns about the investee's ability to continue as a going concern, such as negative cash flows from operations, working capital deficiencies, or noncompliance with statutory capital requirements or debt covenants. If the qualitative assessment indicators indicated that the non-marketable equity securities (non-current) is deemed to be impaired, the Company would recognize the impairment loss equal to the difference between the fair value of the investment and its carrying amount.

F-45

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

2. SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES (CONT'D)

Customer deposits

Customer deposits represent amounts advanced by customers on product orders and unapplied unexpired coupons. Customer deposits are reduced when the related sale is recognized in accordance with the Company's revenue recognition policy.

Revenue recognition

The Company adopted Accounting Standards Update ("ASU") 2014-09, Revenue from Contracts with Customers (ASC Topic 606). The core principle underlying the revenue recognition of this ASU allows the Company to recognize - revenue that represents the transfer of goods and services to customers in an amount that reflects the consideration to which the Company expects to be entitled in such exchange. This will require the Company to identify contractual performance obligations and determine whether revenue should be recognized at a point in time or over time, based on when control of goods and services transfers to a customer. The Company's revenue streams are recognized at a point in time for the Company's sale of health and wellness products.

The ASU requires the use of a new five-step model to recognize revenue from customer contracts. The five-step model requires that the Company (i) identify the contract with the customer, (ii) identify the performance obligations in the contract, (iii) determine the transaction price, including variable consideration to the extent that it is probable that a significant future reversal will not occur, (iv) allocate the transaction price to the respective performance obligations in the contract, and (v) recognize revenue when (or as) the Company satisfies the performance obligation.

The Company accounts for a contract with a customer when the contract is committed in writing, the rights of the parties, including payment terms, are identified, the contract has commercial substance and consideration is probable of substantially collection.

Sales of Health and Wellness products

- Performance obligations satisfied at a point in time

The Company derives its revenues from sales contracts with its customers with revenues being recognized when control of the health and wellness products are transferred to its customer at the Company's office or shipment of the goods. The revenue is recorded net of estimated discounts and return allowances. Products are given 60 days for returns or exchanges from the date of purchase. Historically, there were insignificant sales returns.

Under the Company's network marketing business, the Company issues product coupons to members and distributors when these customers made purchases above certain thresholds set by the Company. Depending on the type of product coupons issued, the coupons carry varying values and can be used by the customers for reduction in the transaction price of product purchases within the coupon validity period. The value of the product coupons issued is recorded as a reduction of the Company's revenue account upon issuance; the corresponding amount credited to the customer deposits account. Amounts in customer deposits will be reversed when the coupons are used. The Company's coupons have a validity period of between six and twelve months. If the Company's customers did not utilize the coupons after the validity period, the Company would recognize the forfeiture of the originated sales value of the coupons as net revenues. For the years ended December 31, 2022 and 2021, the Company recognized $7,543 and $15,209 as forfeited coupon income, respectively.

As of December 31, 2022, the Company had contracts for the sales of health and wellness products amounting to $17,912 which it is expected to fulfill within 12 months from December 31, 2022.

Sales of products for the provision of complementary health therapies

Products for the provision of complementary health therapies are predominantly Chinese herbs in different forms, processed or otherwise, for prescriptions for treating non-communicable diseases.

F-46

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

2. SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES (CONT'D)

Provision of Health and Wellness services

- Performance obligations satisfied at a point in time

The Company carries out its Wellness program, where the Company's products are bundled with health screening test and a health camp program. The health screening test and the health camp programs are considered as separate performance obligations. The promises to deliver the health screening test report and the attendance at the health camp are separately identifiable, which are evidenced by the fact that the Company provides separate services of delivering the health screening test report and allowing admission of the customers to attend the health camp. The Company derives its revenues from sales contracts with its customers with revenues being recognized when the test reports are completed and delivered to its customers during the consultation section in person.

The Company also separately derives its revenues from sales contracts with its customers with revenues being recognized when the health camp program is completed in the final day of the health camp. For the years ended December 31, 2022 and 2021, revenues from providing health and wellness services are $145,510 and $7,543, respectively.

Disaggregated information of revenues by products and services are as follows:

SCHEDULE OF DIS-AGGREGATED INFORMATION OF REVENUES

    REGISTRATION NO. 333-239951

Survivor Select $ 122,470 $ 83,904 Energized Mineral Concentrate - 52,047 Ionized Cal-Mag 148,219 39,527 Omega Blend 272,332 222,718 BetaMaxx 137,447 208,043 Vege Fruit Fiber - 65,757 Iron 16,697 28,114 Young Formula 31,403 52,425 Organic Youth Care Cleansing Bar - 5,137 ATPR Mito+ 271,493 183,800 Lipomask - 15,331 Energetique 49,089 25,574 Trim+ 88,613 27,042 Others - Products for the provision of complementary health therapies 569,823 - Others 3,468 - Total revenues - products 1,711,054 1,009,419 Health and Wellness services 145,510 7,543 Total revenues - products and services $ 1,856,564 $ 1,016,962

F-47

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

2. SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES (CONT'D)

Cost of revenue

Cost of revenue comprised freight-in, the purchase cost of manufactured goods for sale to customers and products for the provision of complementary health therapies. Cost of revenue amounted to $666,042 (including inventory write-downs of $5,307 and inventory written-off of $142,466) and $297,333 (including inventory write-downs of $36,241) for the years ended December 31, 2022 and 2021, respectively.

Shipping and handling

Shipping and handling charges amounted to $16,585 and $11,054 for the years ended December 31, 2022 and 2021, respectively. Shipping and handling charges are expensed as incurred and included in selling expenses.

Advertising costs

Advertising costs amounted to $4,688 and $20,218 for the years ended December 31, 2022 and 2021, respectively. Advertising costs are expensed as incurred and included in selling expenses.

Commission expenses

Commission expenses are the Company's most significant expenses. As with all companies in the network marketing industry, the Company's sales channel is external to the Company. The Company's "external sales force" is stratified into two levels based on priority recruitment. First, there are sales distributors. Second, all members recruited by a sales distributor, directly or indirectly, are referred to as "sales network members". The Company pays commission to every sales distributor based on purchases made by its sales network members which includes the independent direct sales members. Top performing distributors with their own physical stores may also become stockists of the Company, whereby they enjoy benefits such as maintaining a certain amount of the Company's inventory on their store premises. The stockists shall account to the Company for all products sales from their store premises as monitored through the Company's centralized stock tracking system. The Company pays a separate commission to stockists based on revenue generated from the stockists' physical stores. Commission expenses amounted to $405,351 and $316,267 for the years ended December 31, 2022 and 2021, respectively.

Defined contribution plan

The full-time employees of the Company are entitled to the government mandated defined contribution plan. The Company is required to accrue and pay for these benefits based on certain percentages of the employees' respective salaries, subject to certain ceilings, in accordance with the relevant government regulations, and make cash contributions to the government mandated defined contribution plan. Total expenses for the plans were $133,489 and $99,488 for the years ended December 31, 2022 and 2021, respectively.

The related contribution plans include:

    REGISTRATION NO. 333-239951

F-48

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

2. SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES (CONT'D)

Income taxes

The Company accounts for income taxes in accordance with U.S. GAAP for income taxes. The charge for taxation is based on the results for the fiscal year as adjusted for items, which are non-assessable or disallowed. It is calculated using tax rates that have been enacted or substantively enacted by the balance sheet date.

Deferred taxes is accounted for using the asset and liability method in respect of temporary differences arising from differences between the carrying amount of assets and liabilities in the consolidated financial statements and the corresponding tax basis used in the computation of assessable tax profit. In principle, deferred tax liabilities are recognized for all taxable temporary differences. Deferred tax assets are recognized to the extent that it is probable that taxable profit will be available against which deductible temporary differences can be utilized. Deferred tax is calculated using tax rates that are expected to apply to the period when the asset is realized or the liability is settled. Deferred tax is charged or credited in the income statement, except when it is related to items credited or charged directly to equity, in which case the deferred tax is also dealt with in equity. Deferred tax assets are reduced by a valuation allowance when, in the opinion of management, it is more likely than not that some portion or all of the deferred tax assets will not be realized. Current income taxes are provided for in accordance with the laws of the relevant taxing authorities.

An uncertain tax position is recognized as a benefit only if it is "more likely than not" that the tax position would be sustained in a tax examination, with a tax examination being presumed to occur. The amount recognized is the largest amount of tax benefit that is greater than 50% likely of being realized on examination. For tax positions not meeting the "more likely than not" test, no tax benefit is recorded. $0 and $395 penalties and interest incurred related to underpayment of income tax for the years ended December 31, 2022 and 2021, respectively.

The Company conducts much of its business activities in Hong Kong and Malaysia and is subject to tax in each of their jurisdictions. As a result of its business activities, the Company will file separate tax returns that are subject to examination by the foreign tax authorities.

Comprehensive income (loss)

Comprehensive income (loss) consists of two components, net income (loss) and other comprehensive income (loss). Net income (loss) refers to revenue, expenses, gains and losses that under GAAP are recorded as an element of stockholders' equity but are excluded from net income. Other comprehensive income (loss) consists of a foreign currency translation adjustment resulting from the Company not using the U.S. dollar as its functional currencies.

Non-controlling interest

Non-controlling interest consists of 40% of the equity interests of DSY Wellness held by an individual and approximately 0.01% (2 ordinary shares out of 9,590,598 shares) of the equity interests of ASL held by two individuals. The non-controlling interests are presented in the consolidated balance sheets, separately from equity attributable to the shareholders of the Company. Non-controlling interests in the results of the Company are presented on the face of the consolidated statements of operations as an allocation of the total income or loss for the periods between non-controlling interest holders and the shareholders of the Company.

F-49

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

2. SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES (CONT'D)

Earnings (loss) per share

The Company computes earnings (loss) per share ("EPS") in accordance with ASC 260, "Earnings per Share". ASC 260 requires companies to present basic and diluted EPS. Basic EPS is measured as net income divided by the weighted average shares of common stock outstanding for the period. Diluted EPS presents the dilutive effect on a per share basis of the potential shares (e.g., convertible securities, options and warrants) as if they had been converted at the beginning of the periods presented, or issuance date, if later. Potential shares that have an anti-dilutive effect (i.e., those that increase income per share or decrease loss per share) are excluded from the calculation of diluted EPS. For the years ended December 31, 2022 and 2021, there were no dilutive shares.

Foreign currencies translation and transaction

Transactions denominated in currencies other than the functional currency are translated into the functional currency at the exchange rates prevailing at the dates of the transaction. Monetary assets and liabilities denominated in currencies other than the functional currency are translated into the functional currency using the applicable exchange rates at the balance sheet dates. The resulting exchange differences are recorded in the consolidated statements of operations and comprehensive income (loss).

The reporting currency of the Company is United States Dollars ("US$") and the accompanying financial statements have been expressed in US$. The Company's subsidiary in Labuan maintains its books and record in United States Dollars ("US$") albeit its functional currency being the primary currency of the economic environment in which the entity operates, which is the Malaysian Ringgit ("MYR" or "RM"). The Company's subsidiary in Hong Kong maintains its books and record in Hong Kong Dollars ("HK$"), similar to its functional currency. The Company's subsidiary and VIE in Malaysia conducts its businesses and maintains its books and record in the local currency, Malaysian Ringgit ("MYR" or "RM"), as its functional currency.

In general, for consolidation purposes, assets and liabilities of its subsidiaries whose functional currency is not US$ are translated into US$, in accordance with ASC Topic 830-30, "Translation of Financial Statement", using the exchange rate on the balance sheet date. Revenues and expenses are translated at average rates prevailing during the period. The gains and losses resulting from translation of financial statements of foreign subsidiary are recorded as a separate component of accumulated other comprehensive income within the statements of stockholders' equity. Cash flows are also translated at average translation rates for the periods, therefore, amounts reported on the statement of cash flows will not necessarily agree with changes in the corresponding balances on the consolidated balance sheets.

Translation of foreign currencies into US$1 have been made at the following exchange rates for the respective periods:

SCHEDULE OF FOREIGN CURRENCIES TRANSLATION EXCHANGE RATES

    REGISTRATION NO. 333-239951

Period-end MYR : US$1 exchange rate 4.41 4.18 Period-end HKD : US$1 exchange rate 7.80 7.80 Foreign currency exchange rate, translation 7.80 7.80

    REGISTRATION NO. 333-239951

Period-average MYR : US$1 exchange rate 4.41 4.14 Period-average HKD : US$1 exchange rate 7.83 7.77 Foreign currency exchange rate period average 7.83 7.77

F-50

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

2. SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES (CONT'D)

Related parties

Parties, which can be a corporation or individual, are considered to be related if the Company has the ability, directly or indirectly, to control the other party or exercise significant influence over the other party in making financial and operating decisions. Companies are also considered to be related if they are subject to common control or common significant influence.

Fair value of financial instruments

The accounting standard regarding fair value of financial instruments and related fair value measurements defines financial instruments and requires disclosure of the fair value of financial instruments held by the Company.

The accounting standards define fair value, establish a three-level valuation hierarchy for disclosures of fair value measurement and enhance disclosure requirements for fair value measures. The three levels are defined as follow:

    REGISTRATION NO. 333-239951

Financial instruments included in current assets and current liabilities are reported in the consolidated balance sheets at face value or cost, which approximate fair value because of the short period of time between the origination of such instruments and their expected realization and their current market rates of interest.

Leases

The Company adopted ASU 2016-02, "Leases" (Topic 842), and elected the practical expedients that does not require the Company to reassess: (1) whether any expired or existing contracts are, or contain, leases, (2) lease classification for any expired or existing leases and (3) initial direct costs for any expired or existing leases. For lease terms of twelve months or fewer, a lessee is permitted to make an accounting policy election not to recognize lease assets and liabilities. The Company also adopts the practical expedient that allows lessees to treat the lease and non-lease components of a lease as a single lease component. Some of the Company's leases include one or more options to renew, which is typically at the Company's sole discretion. The Company regularly evaluates the renewal options, and, when it is reasonably certain of exercise, it will include the renewal period in its lease term. New lease modifications result in re-measurement of the right of use ("ROU") assets and lease liabilities. Operating ROU assets and lease liabilities are recognized at the commencement date, based on the present value of lease payments over the lease term. Since the implicit rate for the Company's leases is not readily determinable, the Company use its incremental borrowing rate based on the information available at the commencement date in determining the present value of lease payments. The incremental borrowing rate is the rate of interest that the Company would have to pay to borrow, on a collateralized basis, an amount equal to the lease payments, in a similar economic environment and over a similar term.

F-51

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

2. SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES (CONT'D)

Lease terms used to calculate the present value of lease payments generally do not include any options to extend, renew, or terminate the lease, as the Company does not have reasonable certainty at lease inception that these options will be exercised. The Company generally considers the economic life of its operating lease ROU assets to be comparable to the useful life of similar owned assets. The Company has elected the short-term lease exception, therefore operating lease ROU assets and liabilities do not include leases with a lease term of twelve months or less. Its leases generally do not provide a residual guarantee. The operating lease ROU asset also excludes lease incentives. Lease expense is recognized on a straight-line basis over the lease term.

The Company reviews the impairment of its ROU assets consistent with the approach applied for its other long-lived assets. The Company reviews the recoverability of its long-lived assets when events or changes in circumstances occur that indicate that the carrying value of the asset may not be recoverable. The assessment of possible impairment is based on its ability to recover the carrying value of the asset from the expected undiscounted future pre-tax cash flows of the related operations. The Company has elected to include the carrying amount of operating lease liabilities in any tested asset group and includes the associated operating lease payments in the undiscounted future pre-tax cash flows.

Recent accounting pronouncements

The Company has reviewed all recently issued, but not yet effective, considers the applicability and impact of all accounting standards updates ("ASUs"). Management periodically reviews new accounting standards that are issued.

In November 2019, the FASB issued ASU No. 2019-10, which to update the effective date of ASU No. 2016-13 for private companies, not-for-profit organizations and certain smaller reporting companies applying for credit losses, leases, and hedging standard. The new effective date for these preparers is for fiscal years beginning after December 15, 2022. ASU 2019-05 is effective for the Company for annual and interim reporting periods beginning January 1, 2023 as the Company is qualified as a smaller reporting company. The Company is currently evaluating the impact ASUs 2016-13 and 2019-05 may have on its consolidated financial statements.

Except for the above-mentioned pronouncements, there are no new recent issued accounting standards that will have a material impact on the consolidated financial position, statements of operations and cash flows.

3. VARIABLE INTEREST ENTITY ("VIE")

SEA is a trading company incorporated on March 4, 2004, under the laws of Malaysia. SEA provided majority of ASL's purchases. Its equity at risk was insufficient to finance its activities and 100% of its business is transacted with ASL. Therefore, it was considered to be a VIE and ASL is the primary beneficiary since it has both of the following characteristics:

    REGISTRATION NO. 333-239951

Accordingly, the accounts of SEA is consolidated in the accompanying financial statements.

F-52

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

3. VARIABLE INTEREST ENTITY ("VIE") (CONT'D)

The carrying amount of the VIE's assets and liabilities were as follows:

SCHEDULE OF VARIABLE INTEREST ENTITY

    REGISTRATION NO. 333-239951

Current assets $ 3,350 $ 18,850 Current liabilities (43,512) (51,272) Net deficit $ (40,162) $ (32,422)

    REGISTRATION NO. 333-239951

Current assets: Cash $ 1,609 $ 17,493 Prepaid taxes 1,741 1,357 Total current assets $ 3,350 $ 18,850

Current liabilities: Accounts payable - intercompany $ 42,422 $ 49,724 Other payables and accrued liabilities 1,090 1,548 Total current liabilities $ 43,512 $ 51,272

Net deficit $ (40,162) $ (32,422)

The summarized operating results of the VIE's are as follows:

    REGISTRATION NO. 333-239951

Operating revenues $ - $ - Gross profit $ - $ - Loss from operations $ (9,432) $ (21,966) Net loss $ (9,432) $ (27,966)

4. CASH AND CASH EQUIVALENTS

As of December 31, 2022 and 2021 the Company had $1,438,430 and $2,597,848, respectively, of cash and cash equivalents, which consisted of $513,152 and $554,864, respectively, of cash in banks and $914,811 and $1,975,347, respectively, of time deposits placed with banks or other financial institutions and are all highly liquid investments with an original maturity of three months or less. The effective interest rate for the time deposits ranges between 1.10% to 1.88% per annum. As of December 31, 2022 and 2021, $231,187 and $295,761 of these balances are not covered by deposit insurance, respectively.

F-53

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

5. ACCOUNTS RECEIVABLE

SCHEDULE OF ACCOUNTS RECEIVABLES - RELATED PARTY

    REGISTRATION NO. 333-239951

6. INVENTORIES

Inventories consist of the following:

SCHEDULE OF INVENTORIES

    REGISTRATION NO. 333-239951

For the years ended December 31, 2022 and 2021, the Company recognized $5,307 and $36,241 inventory write-down; and $142,466 and $0 inventory write-off, respectively.

7. PREPAYMENTS AND DEPOSITS

SCHEDULE OF PREPAID EXPENSES AND DEPOSITS

    REGISTRATION NO. 333-239951

Movements of allowance for doubtful accounts are as follows:

SCHEDULE OF CHANGES IN ALLOWANCE FOR DOUBTFUL ACCOUNTS

    REGISTRATION NO. 333-239951

F-54

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

8. PROPERTY AND EQUIPMENT, NET

Property and equipment, net consist of the following:

SCHEDULE OF PROPERTY AND EQUIPMENT, NET

    REGISTRATION NO. 333-239951

Depreciation expense for the years ended December 31, 2022 and 2021 amounted to $71,754 and $75,797, respectively.

9. INTANGIBLE ASSETS, NET

Intangible assets, net, consist of the following:

SCHEDULE OF INTANGIBLE ASSETS, NET

    REGISTRATION NO. 333-239951

Amortization expense for the years ended December 31, 2022 and 2021 amounted to $2,122 and $1,961, respectively.

10. INVESTMENT IN MARKETABLE SECURITIES

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

F-55

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

10. INVESTMENT IN MARKETABLE SECURITIES (CONT'D)

SCHEDULE OF INVESTMENT IN MARKETABLE SECURITIES

    REGISTRATION NO. 333-239951

11. INVESTMENT IN NON-MARKETABLE SECURITIES

On April 3, 2019, the Company purchased a 5% of stock or 15,000,000 shares of common stock in Phoenix Plus Corp. for $1,500 at purchase price of $0.0001 per share. Phoenix Plus Corp. attained its effective date with the Securities Exchange Commission for listing on OTC (Pink Sheet), U.S. on March 12, 2021, and obtained approval for Depository trust Company ("DTC") eligibility on April 26, 2022. Accordingly, stocks of Phoenix Plus Corp. can be traded on OTC. As such the investment in Phoenix Plus Corp. was transferred to marketable securities.

SCHEDULE OF INVESTMENT IN NON MARKETABLE SECURITIES

    REGISTRATION NO. 333-239951

12. CUSTOMER DEPOSITS

SCHEDULE OF CUSTOMER DEPOSITS

    REGISTRATION NO. 333-239951

Customer deposits represent amounts advanced by customers on product orders and unexpired product coupons issued to the Company's members and distributors of its network marketing business.

13. OTHER PAYABLES AND ACCRUED LIABILITIES

SCHEDULE OF OTHER PAYABLES AND ACCRUED LIABILITIES

    REGISTRATION NO. 333-239951

Total $ 713,277 $ 858,355

The Company requires all members and distributors of its network marketing business to maintain an electronic wallet (eWallet) account with the Company. The eWallet is primarily for the crediting of any commission payment that falls below RM100 (or $22.70). Commission payment exceeding the RM100 threshold shall only be credited into the member's or distributor's eWallet upon request. The eWallet functionality allows the members to place new product orders utilizing eWallet available balance and/or request commission payout via multiple payment methods provided that each of the withdrawal amount exceeds RM100. Amounts held in eWallets are reflected on the balance sheet as a current liability.

F-56

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

14. RELATED PARTY BALANCES AND TRANSACTIONS

Related party balances

Amount due from related parties

SCHEDULE OF RELATED PARTIES

    REGISTRATION NO. 333-239951

TH3 Technology Mr. How Kok Prepayment Sdn Bhd ("TH3") Choong, the CEO of IT and director of expenses the Company is also a director of TH3 $ 1,273 $ - DSY Beauty Sdn The directors and Deposits for Bhd ("DSY shareholders of products Beauty") DSY Beauty are purchases related parties to Mr. Yap Foo Ching (Steve Yap), a director of DSY Wellness International Sdn Bhd 9,261 - Agape ATP (Asia) Mr. How Kok Expenses Limited ("AATP Choong, the CEO paid for Asia") and director of AATP Asia the Company is also the sole shareholder and director of AATP Asia - 2,214 Hostastay Sdn. Mr. How Kok Sublease Bhd. Choong, the CEO rent due "Hostastay" and director of from the Company is Hostastay also the director of Hostastay. Mr. How Kok Choong ceased to be the director of Hostastay as of April 21, 2021 - 4,790 Total $ 10,534 $ 7,004

Accounts payable - related parties

    REGISTRATION NO. 333-239951

CTA The directors and Purchases of Nutriceuticals shareholders of products for (Asia) Sdn Bhd CTA are related the provision ("CTA") parties to Mr. of Yap Foo Ching complementary (Steve Yap), a health director of DSY therapies International Wellness Sdn Bhd $ 25,387 $ - DSY Beauty Sdn The directors and Purchases of Bhd ("DSY shareholders of beauty Beauty") DSY Beauty are products related parties to Mr. Yap Foo Ching (Steve Yap), a director of DSY Wellness International Sdn Bhd 224 - Total $ 25,611 $ -

F-57

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

14. RELATED PARTY BALANCES AND TRANSACTIONS (CONT'D)

Related party balances

Other payable - related parties

    REGISTRATION NO. 333-239951

CTA The directors and Purchase of Nutriceuticals shareholders of products for (Asia) Sdn Bhd CTA are related general use ("CTA") parties to Mr. Yap Foo Ching (Steve Yap), a director of DSY International Wellness Sdn Bhd $ 2,149 $ - DSY Beauty Sdn The directors and Purchase of Bhd ("DSY shareholders of products for Beauty") DSY Beauty are general use related parties to Mr. Yap Foo Ching (Steve Yap), a director of DSY Wellness International Sdn Bhd 2,147 - Mr. How Kok Mr. How Kok Commission Choong Choong, the CEO expense and director of the Company 584 - Total $ 4,880 $ -

Related party transactions

Purchases

    REGISTRATION NO. 333-239951

CTA The directors and Purchases of Nutriceuticals shareholders of products for (Asia) Sdn Bhd CTA are related the provision ("CTA") parties to Mr. of Yap Foo Ching complementary (Steve Yap), a health director of DSY therapies International Wellness Sdn Bhd $ 198,376 $ - DSY Beauty Sdn The directors and Purchases of Bhd ("DSY shareholders of beauty Beauty") DSY Beauty are products related parties to Mr. Yap Foo Ching (Steve Yap), a director of DSY Wellness International Sdn Bhd 3,975 718 DSY Wellness & Mr. Yap Foo Ching Purchases of Longevity Center (Steve Yap), a products for Sdn Bhd director of DSY the provision ("DSYWLC") Wellness of International Sdn complementary Bhd is also a health director of therapies DSYWLC. 124 - Total $ 202,475 $ 718

F-58

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

14. RELATED PARTY BALANCES AND TRANSACTIONS (CONT'D)

Related party transactions

Other income

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Other purchases

    REGISTRATION NO. 333-239951

CTA The directors and Purchases of Nutriceuticals shareholders of products for (Asia) Sdn Bhd CTA are related the provision ("CTA") parties to Mr. of Yap Foo Ching complementary (Steve Yap), a health director of DSY therapies International Wellness Sdn Bhd $ 5,431 $ - DSY Beauty Sdn The directors and Purchases of Bhd ("DSY shareholders of beauty Beauty") DSY Beauty are products related parties to Mr. Yap Foo Ching (Steve Yap), a director of DSY Wellness International Sdn Bhd 6,888 - DSY Wellness & Mr. Yap Foo Ching Purchases of Longevity Center (Steve Yap), a products for Sdn Bhd director of DSY the provision ("DSYWLC") Wellness of International Sdn complementary Bhd is also a health director of therapies DSYWLC. 4 - Total $ 12,323 $ -

F-59

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

14. RELATED PARTY BALANCES AND TRANSACTIONS (CONT'D)

Related party transactions

Commission expense

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

Other expenses

    REGISTRATION NO. 333-239951

TH3 Technology Mr. How Kok IT support Sdn Bhd ("TH3") Choong, the CEO services fee and director of the Company is also a director of TH3 $ 56,450 $ - Redboy Picture Mr. How Kok Sponsorship Sdn Bhd Choong, the CEO fee ("Redboy") and director of the Company is also the director of Redboy 22,686 718 DSY Wellness & Mr. Yap Foo Ching Office Longevity Center (Steve Yap), a rental Sdn Bhd director of DSY expenses ("DSYWLC") Wellness International Sdn Bhd is also a director of DSYWLC. 21,779 - Total $ 100,915 $ 718

F-60

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

15. STOCKHOLDERS' EQUITY

Preferred stock

As of December 31, 2022 and 2021, there were 200,000,000 preferred stocks authorized but none were issued and outstanding.

Common stock

As of December 31, 2022 and 2021, there were 1,000,000,000 common stocks authorized, 75,452,012 and 290,460,047 shares issued and outstanding, respectively.

In December 2021, there were share forfeiture agreements (the "Share Forfeiture Agreements") between the Company and (i) HKC Talent Limited; (ii) various shareholders of the Company (the "Forfeiting Shareholders"), pursuant to which: (i) HKC Talent Limited had agreed to forfeiture of 41,750,000 shares of common stock of the Company, and (ii) the Forfeiting Shareholders had agreed to forfeiture, in aggregate, 44,242,000 shares of common stock of the Company. Included in (ii) is 11,242,000 shares forfeited from HKC Holdings Sdn. Bhd, a company in which Mr. How Kok Choong, the CEO and director of the Company, is a shareholder. As a result, the outstanding shares was reduced by 85,992,000 shares of common stock.

A share forfeiture agreement (the "Share Forfeiture Agreement") dated January 20, 2022, between the Company and Mr. How Kok Choong, the CEO and director of the Company, pursuant to which Mr. How Kok Choong agreed to forfeit 215,008,035 shares of common stock of the Company. As a result, the outstanding shares was reduced by 215,008,035 shares of common stock.

There were no stock options, warrants or other potentially dilutive securities outstanding as of December 31, 2022 and 2021.

16. NON-CONTROLLING INTEREST

The Company's non-controlling interest consists of the following:

SCHEDULE OF NON CONTROLLING INTEREST

    REGISTRATION NO. 333-239951

F-61

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

17. INCOME TAXES

The United States and foreign components of loss before income taxes were comprised of the following:

SCHEDULE OF COMPONENTS OF INCOME/(LOSS) BEFORE INCOME TAX

    REGISTRATION NO. 333-239951

Loss before income tax $ (1,670,134) $ (2,387,613)

The benefit of (provision for) income taxes consisted of the following:

SCHEDULE OF PROVISION FOR INCOME TAX

    REGISTRATION NO. 333-239951

Deferred: - Local - - - Foreign 15,017 (10,127)

Benefit of (Provision for) income taxes $ 4,055 $ (137,067)

The effective tax rate in the periods presented is the result of the mix of income earned in various tax jurisdictions that apply a broad range of income tax rates. The Company and its subsidiary that operate in various countries: United States, Malaysia (including Labuan) and Hong Kong that are subject to taxes in the jurisdictions in which they operate, are as follows:

United States of America

Agape ATP Corporation was incorporated in the State of Nevada and is subject to the tax laws of the United States of America with a corporate tax rate of 21% on its taxable income. Agape ATP Corporation also subject to controlled foreign corporations Subpart F income ("Subpart F") tax, which is a tax primarily on passive income from controlled foreign corporations with a tax rate of 35%. In addition, the Tax Cuts and Jobs Act imposed a global intangible low-taxed income ("GILTI") tax, which is a tax on certain off-shore earnings at an effective rate of 10.5% for tax years (50% deduction of the current enacted tax rate of 21%) with a partial offset for 80% foreign tax credits. If the foreign tax rate is 13.125% or higher, there will be no U.S. corporate tax after the 80% foreign tax credits are applied.

For the year ended December 31, 2022 and 2021, the Company's foreign subsidiaries did not generate any income that were subject to Subpart F tax and GILTI tax.

F-62

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

17. INCOME TAXES (CONT'D)

As of December 31, 2022 and 2021, the operations in the United States of America incurred approximately $1,357,000 and $620,000, respectively, of cumulative net operating losses ("NOL") which can be carried forward to offset future taxable income or Subpart F and GILTI taxes. These balances can be carried forward indefinitely. The deferred tax valuation allowance as of December 31, 2022 and 2021 were approximately $285,000 and $130,000, respectively.

For the year ended December 31, 2021, the Company re-visited its fiscal 2020 U.S. income taxes and determined its stock dividend from Greenpro Capital Corp as a result of its Spin-off of DSwiss Inc.'s shares in 2020 were subject to Subpart F and GILTI taxes. As a result, the Company incurred additional income taxes expenses of $22,205, including interest and penalty of $395, for the year ended December 31, 2021, after utilizing its estimated cumulative net operating losses ("NOL") of $312,608 as of December 31, 2020. As a result, the Company's deferred tax assets of estimated NOL of $65,648 were fully utilized and reduced to $0.

Malaysia

Changes to the Labuan Business Activity Tax Act (LBATA) 1990 which was gazetted and came into operation on January 1, 2019 mandate companies incorporated in Labuan to satisfy the "substantial activity requirements" to qualify for the preferential tax rate of 3% on net audited profit. Subsequently, on April 29, 2020, a circular setting out revisions to the "substantial activity requirements" was issued. As Agape ATP Corporation did not maintain a permanent establishment in Labuan, and therefore did not satisfy the said requirements, the company was subjected to tax at 24% on its net audited profit. On June 11, 2021, Agape ATP Corporation made an irrevocable election to be taxed under the Malaysian Income Tax Act 1967 as the elected tax regime is more tax efficient to the entity compare to LBATA.

Agape Superior Living Sdn Bhd, Agape S.E.A Sdn Bhd and Wellness ATP International Holdings Sdn Bhd. are governed by the income taxes laws of Malaysia and the income taxes provision in respect of operations in Malaysia is calculated at the applicable tax rates on the taxable income for the periods based on existing legislation, interpretations and practices in respect thereof. Under the Income Tax Act of Malaysia, enterprises that incorporated in Malaysia are usually subject to a unified 24% enterprise income taxes rate while preferential tax rates, tax holidays and even tax exemption may be granted on case-by-case basis. The tax rate for small and medium sized companies (generally companies incorporated in Malaysia with paid-in capital of RM 2,500,000 or less) is 17% for the first RM 800,000 (or approximately $150,000) for the year ended December 31, 2022 and 2021, with the remaining balance being taxed at the 24% rate.

As of December 31, 2022 and 2021, the operations in the Malaysia incurred approximately $1,723,000 and $946,000, respectively, of cumulative net operating losses ("NOL") which can be carried forward to offset future taxable income. Approximately $790,000, $897,000 and $36,000 of the net operating loss carry forwards will expire in 2028, 2029 and 2030, respectively, if unutilized. The deferred tax valuation allowance as of December 31, 2022 and 2021 were approximately $408,000 and $217,000, respectively.

Hong Kong

Agape ATP International Holding (HK) Limited is subject to Hong Kong Profits Tax, which is charged at the statutory income rate of 16.5% on its assessable income derived from Hong Kong. Business income derived or business expenses incurred outside the Special Administrative Region is not subject to Hong Kong Profits Tax or deduction.

F-63

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

17. INCOME TAXES (CONT'D)

The following table reconciles the local (United States) statutory rates to the Company's effective tax rate for the periods indicated below:

SCHEDULE OF EFFECTIVE INCOME TAX RATE

    REGISTRATION NO. 333-239951

(1) The amount comprised: (1) The amount comprised: (1.0)% being expenses incurred in AATP LB, ASL, SEA and WATP that are not deductible in the Malaysia tax return. - 1.2% being expenses incurred in AATP LB, ASL, SEA and WATP that are not deductible in the Malaysia tax return.

(2) The amount comprised: (2) The amount comprised: 6.2% being income derived in AATP HK that were not taxable in the Malaysia tax returns; and 6.7% being expenses incurred in AATP LB, ASL, SEA, WATP, and DSY Wellness that are not deductible in the Malaysia tax return. - 6.2% being income derived in AATP HK that were not taxable in the Malaysia tax returns; and - 6.5% being expenses incurred in AATP LB, ASL, SEA, WATP, and DSY Wellness that are not deductible in the Malaysia tax return.

The following table sets forth the significant components of the aggregate deferred tax assets of the Company as of:

SCHEDULE OF DEFERRED TAX ASSETS

    REGISTRATION NO. 333-239951

Uncertain tax positions

The Company evaluates each uncertain tax position (including the potential application of interest and penalties) based on the technical merits, and measure the unrecognized benefits associated with the tax positions. As of December 31, 2022 and 2021, the Company did not have any significant unrecognized uncertain tax positions. The Company did not incur interest and penalties tax for the years ended December 31, 2022 and 2021.

F-64

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

18. CONCENTRATIONS OF RISKS

(a) Major customers

For the years ended December 31, 2022 and 2021, no customer accounted for 10.0% or more of the Company's total revenues.

As of December 31, 2022, five individual customers accounted for approximately 72.0% of the Company's balance of accounts receivable. There was no accounts receivable balance as of December 31, 2021.

(b) Major vendors

For the year ended December 31, 2022, three vendors accounted for approximately 53.3%, 22.1% and 21.3% of the Company's total purchases. For the year ended December 31, 2021, two vendors accounted for approximately 47.3% and 45.2% of the Company's total purchases.

Via a dividend distribution, the Company acquired 23,330 shares of common stock of DSwiss, Inc., represents approximately 0.01% ownership, that the Company accounted for as investment in marketable securities (See Note 11). DSwiss, Inc.'s wholly owned subsidiary is the vendor that accounted for the Company's total purchases of approximately 22.1% and 47.3% for the years ended December 31, 2022 and 2021, respectively.

As of December 31, 2022, three vendors accounted for approximately 46.6%, 25.8% and 23.9% of the Company's total balance of accounts payable, respectively. CTA Nutriceuticals (Asia) Sdn Bhd, a related company, accounted for approximately 47% of the Company's total balance of accounts payable. As of December 31, 2021, one vendor accounted for 100% of the total balance of accounts payable.

(c) Commission Expenses to Sales Distributors and Stockists

For the year ended December 31, 2022, one sales distributor accounted for approximately 10.3% of the Company's total commission expense. For the year ended December 2021, one sales distributor accounted for approximately 17.9% of the Company's total commission expense.

(d) Credit risk

Financial instruments that potentially subject the Company to significant concentrations of credit risk consist primarily of cash. As of December 31, 2022 and 2021, $513,152 and $554,864 were deposited with financial institutions, respectively, $231,187 and $295,761 of these balances are not covered by deposit insurance. While management believes that these financial institutions are of high credit quality, it also continually monitors their credit worthiness.

Financial instruments that are potentially subject to credit risk consist principally of accounts receivable. The Company believes the concentration of credit risk in its account receivable is substantially mitigated by its ongoing credit evaluation process and relatively short collection terms. The Company does not generally require collateral from customers. The Company evaluates the need for an allowance for doubtful accounts based upon factors surrounding the credit risk of specific customers, historical trends and other information. Historically, the Company did not have any bad debt on its account receivable.

(e) Exchange rate risk

The Company cannot guarantee that the current exchange rate will remain steady; therefore, there is a possibility that the Company could post the same amount of profit for two comparable periods and because of the fluctuating exchange rate actually post higher or lower profit depending on exchange rate of RM and HK$ converted to US$ on that date. The exchange rate could fluctuate depending on changes in political and economic environments without notice.

F-65

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

19. COMMITMENTS AND CONTINGENCIES

Lease commitments

On April 1, 2020, the Company adopted ASC 842 for ASL's office space lease and sales and training center as the lease commencement date upon the acquisition of ASL. The Company recognized lease liabilities of approximately $490,000, with a corresponding right-of-use ("ROU") asset in the same amount based on the present value of the future minimum rental payments of the lease, using an effective interest rate of 5.5%, which was determined using the Company's estimated incremental borrowing rate.

On May 31, 2021, the Company entered into two separate two-year leases extension with the modified lease expiring May 31, 2023 for its office space and expiring August 31, 2023 for its training center. The lease modification required the Company to re-measure the ROU assets and lease liabilities based on the modified leases. The Company recognized a reduction of $3,250 in ROU assets and lease liabilities upon lease modifications based on the present value of the future minimum rental payments of the lease, using an effective interest rate of 5.5%, which was determined using the Company's estimated incremental borrowing rate.

On October 1, 2021, the Company entered into a two-years lease for an apartment to serve as staff accommodation. The Company recognized lease liabilities of approximately $9,777, with a corresponding right-of-use ("ROU") asset in the same amount based on the present value of the future minimum rental payments of the lease, using an effective interest rate of 5.5%, which was determined using the Company's estimated incremental borrowing rate.

On November 1, 2021, the Company entered into a two-years lease for a branch office and operating centre. The Company recognized lease liabilities of approximately $10,864, with a corresponding right-of-use ("ROU") asset in the same amount based on the present value of the future minimum rental payments of the lease, using an effective interest rate of 5.5%, which was determined using the Company's estimated incremental borrowing rate.

As of December 31, 2022, the weighted remaining term of the lease is approximately 0.54 years.

The five-year maturity of the Company's operating lease liabilities is as follow:

SCHEDULE OF LEASE COMMITMENTS

Twelve Months Ending December 31, Operating lease liabilities

2023 $ 84,146 Thereafter - Total lease payments 84,146 Less: interest (1,439) Present value of lease liabilities $ 82,707

The Company also leased one office and operation center, and one shophouse with an expiring term of twelve months or less, which were classified as operation leases. Since the lease terms for these leases were twelve months or less, a lessee is permitted to elect not to recognize lease assets and liabilities. The Company has elected not to recognize lease assets and liabilities on these leases. As of December 31, 2022, the Company's commitment for minimum lease payment under these operating leases within the next twelve months were $567.

Rent expense for the years ended December 31, 2022 and 2021 was $190,547 and $179,562, respectively.

Contingencies

Legal

From time to time, the Company is party to certain legal proceedings, as well as certain asserted and un-asserted claims. Amounts accrued, as well as the total amount of reasonably possible losses with respect to such matters, individually and in the aggregate, are not deemed to be material to the consolidated financial statements.

COVID-19

Malaysia, where the operations of the Company predominantly reside, officially transitioned to the endemic phase of COVID-19 effective April 1, 2022. Restrictions on businesses and people are minimal. Meanwhile, the government continues to encourage inoculation for those between the ages of 5 and 11 years and its adolescent group which comprised those between the ages 12 and 17. Adults who have been fully vaccinated, i.e. received two doses of the COVID-19 vaccine are encouraged to take booster shots.

Substantially all of our revenues are concentrated in Malaysia. Consequently, our results of operations will likely be adversely, and may be materially, affected, to the extent that the COVID-19 or any other epidemic harms the Malaysia and global economy in general. Any potential impact to our results will depend on, to a large extent, future developments and new information that may emerge regarding the duration and severity of the COVID-19 and the actions taken by government authorities and other entities to contain the COVID-19 or treat its impact, almost all of which are beyond our control. Potential impacts include, but are not limited to, the following:

    REGISTRATION NO. 333-239951

Because of the uncertainty surrounding the COVID-19 outbreak, the financial impact related to the outbreak of and response to the COVID-19 cannot be reasonably estimated at this time. There is no guarantee that the Company's total revenues will grow or remain at similar levels year over year in 2023 and beyond.

20. SUBSEQUENT EVENTS

The Company has evaluated subsequent events through the date of issuance of this consolidated financial statements, and does not identify any events with material financial impact on the Company's consolidated financial statements.

F-66

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

    REGISTRATION NO. 333-239951

You should rely only on the information contained in this prospectus. No dealer, salesperson or other person is authorized to give information that is not contained in this prospectus. This prospectus is not an offer to sell nor is it seeking an offer to buy these securities in any jurisdiction where the offer or sale is not permitted. The information contained in this prospectus is correct only as of the date of this prospectus, regardless of the time of the delivery of this prospectus or the sale of these securities.

Until and including November 4, 2023 (twenty-five (25) days after the date of this prospectus), all dealers that effect transactions in these securities, whether or not participating in this offering, may be required to deliver a prospectus. This is in addition to the dealers' obligation to deliver a prospectus when acting as underwriter with respect to their unsold subscriptions.

    REGISTRATION NO. 333-239951

COMTEX_441824596/2255/2023-10-13T00:51:59

(c) 1995-2023 Cybernet Data Systems, Inc. All Rights Reserved

EDGAR Online-8-K Glimpse
Tuesday, December 13, 2022 19830 mots, p. NA

8-K: Magenta Therapeutics, Inc.

(EDGAR Online via COMTEX) -- --12-31 0001690585 false 0001690585 2022-12-09 2022-12-09

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

    FORM 8-K

    CURRENT REPORT
     Pursuant to Section 13 or 15(d)
     of the Securities Exchange Act of 1934

Date of Report (Date of earliest event reported): December 9, 2022

    MAGENTA THERAPEUTICS, INC.
     (Exact name of registrant as specified in its charter)

    Delaware 001-38541 81-0724163
    (State or other jurisdiction (Commission (I.R.S. Employer
     of incorporation) File Number) Identification No.)

100 Technology Square Cambridge, Massachusetts 02139 (Address of principal executive offices) (Zip Code)

Registrant's telephone number, including area code: (857) 242-0170

Check the appropriate box below if the Form 8-K filing is intended to simultaneously satisfy the filing obligation of the registrant under any of the following provisions:

    ? Written communications pursuant to Rule 425 under the Securities Act (17 CFR
     230.425)

    ? Soliciting material pursuant to Rule 14a-12 under the Exchange Act (17 CFR
     240.14a-12)

    ? Pre-commencement communications pursuant to Rule 14d-2(b) under the Exchange
     Act (17 CFR 240.14d-2(b))

    ? Pre-commencement communications pursuant to Rule 13e-4(c) under the Exchange
     Act (17 CFR 240.13e-4(c))

Securities registered pursuant to Section 12(b) of the Act:

    Trading Name of each exchange
     Title of each class Symbol(s) on which registered
    Common Stock, $0.001 Par Value MGTA The Nasdaq Global Market

Indicate by check mark whether the registrant is an emerging growth company as defined in Rule 405 of the Securities Act of 1933 (230.405 of this chapter) or Rule 12b-2 of the Securities Exchange Act of 1934 (240.12b-2 of this chapter).

Emerging growth company ?

If an emerging growth company, indicate by check mark if the registrant has elected not to use the extended transition period for complying with any new or revised financial accounting standards provided pursuant to Section 13(a) of the Exchange Act. ?

    --------------------------------------------------------------------------------
    Item 5.03 Amendments to Articles of Incorporation or Bylaws; Change in Fiscal
     Year.

On December 9, 2022, the Board of Directors (the "Board") of Magenta Therapeutics, Inc., a Delaware corporation (the "Company"), approved the amendment and restatement of the By-laws of the Company (the "Second Amended and Restated By-laws"). The Second Amended and Restated By-laws are effective as of December 9, 2022.

The principal revision in the Second Amended and Restated By-laws is to designate the federal district courts of the United States as the exclusive forum for the resolution of any complaint asserting a cause of action arising under the Securities Act of 1933, as amended. The previous provision had designated the United States District Court for the District of Massachusetts as the exclusive forum for the resolution of any such complaint.

The foregoing summary does not purport to be complete and is qualified in its entirety by the text of the Second Amended and Restated By-laws, a copy of which is filed herewith as Exhibit 3.1 to this Current Report on Form 8-K and is incorporated by reference into this Item 5.03.

Item 7.01 Regulation FD Disclosure.

On December 12, 2022, the Company issued a press release regarding certain clinical updates to the Company's MGTA-117 Phase 1/2 clinical trial presented at the American Society of Hematology (ASH) 2022 Annual Meeting and other program updates. A copy of the press release is furnished as Exhibit 99.1 to this Current Report on Form 8-K and is incorporated herein by reference.

The Company will host a call and webcast on December 13, 2022 at 8:30 a.m. Eastern Time regarding the foregoing updates. Call details are contained in the press release referenced above. Accompanying slides may be accessed through the "Investors & Media" section of the Company's website at https://investor.magentatx.com. A copy of these slides is furnished as Exhibit 99.2 to this Current Report on Form 8-K and is incorporated herein by reference.

The information in Item 7.01 of this Current Report on Form 8-K (including Exhibit 99.1 and 99.2) shall not be deemed "filed" for purposes of Section 18 of the Securities Exchange Act of 1934, as amended (the "Exchange Act"), or otherwise subject to the liabilities of that section, nor shall it be deemed incorporated by reference in any filing under the Securities Act of 1933, as amended, or the Exchange Act, except as expressly set forth by specific reference in such filing.

Item 8.01 Other Events.

On December 12, 2022, the Company presented preliminary clinical data for its MGTA-117 Phase 1/2 clinical trial in patients with relapsed/refractory acute myeloid leukemia (AML) and myelodysplastic syndrome (MDS) patients.

As of December 1, 2022, a total of 15 participants have been dosed with MGTA-117 in Cohorts 1, 2 and 3. All dosed participants contributed data in whole or in part to the preliminary data set depending on an individual's availability for collecting assessments. Eleven of the 15 dosed participants completed the dose-limiting toxicity safety observation period of 21 days. None of the four participant discontinuations were deemed to be related to MGTA-117.

MGTA-117 bound to CD117-expressing target cells within 15 minutes after dosing in all participants as measured by a receptor occupancy (RO) assay. RO increased with higher dose levels of MGTA-117. The percentage of occupied CD117 receptors was greater, and the receptor occupancy was more durable at the higher dose levels of Cohorts 2 and 3 as compared to Cohort 1.

MGTA-117 showed greater depletion of target cancer blast cells in the blood of participants in Cohorts 2 and 3 compared to Cohort 1. In addition, three out of the four participants in Cohort 3 for whom paired bone marrow samples were collected at baseline and post-dosing had depletion of cancer blast cells in both blood and bone marrow.

Participants entering the clinical trial were considered ineligible for stem cell transplant and had active and persistent AML/MDS after receiving one or more anti-leukemic therapies. One relapsed/refractory MDS participant in Cohort 3 had a reduction of bone marrow cancer blast cells to a level that enabled the participant to become eligible for transplant. This is the trial's second participant who became eligible for transplant after a single dose of MGTA-117. The first participant, from Cohort 1, had an approximate 83% reduction of blasts in the bone marrow at day 14 post-dosing (from 6% to 1%) and also progressed to transplant.

MGTA-117 was shown to be rapidly cleared from the body. No MGTA-117 was detectable in the blood 48 hours after dosing in Cohorts 1 and 2, and over 95% of MGTA-117 was cleared in the blood 48 hours after dosing at the higher dose level of Cohort 3. In addition, the MGTA-117 ADC was shown to be stable in blood over time in all participants, and no free payload was detectable in the blood of any participants at any time point.

MGTA-117 was well-tolerated in all participants. No serious adverse events were deemed to be related to MGTA-117, and no dose-limiting toxicities were observed. Treatment-related adverse events deemed to be related to MGTA-117 were low-grade liver enzyme elevations, low-grade fever, and grade 3 and grade 4 leukopenia in two participants who had baseline grade 2 and grade 3 leukopenia, respectively. All instances of observed liver enzyme elevations were low-grade, transient and resolved without intervention. The Phase 1/2 clinical trial is currently enrolling in Cohort 4 (0.13 mg/kg).

    2

    --------------------------------------------------------------------------------
    Item 9.01 Financial Statements and Exhibits.

(d) Exhibits:

3.1* Second Amended and Restated By-laws of the Registrant.

99.1** Press Release dated December 12, 2021.

99.2** Company Presentation dated December 13, 2022.

104* Cover Page Interactive Data File (embedded within the Inline XBRL document).

* Filed herewith.

** Furnished herewith.

    3

    --------------------------------------------------------------------------------
     SIGNATURES

Pursuant to the requirements of the Securities Exchange Act of 1934, the registrant has duly caused this report to be signed on its behalf by the undersigned hereunto duly authorized.

MAGENTA THERAPEUTICS, INC.

    Date: December 13, 2022

    By: /s/ Stephen Mahoney
     Stephen Mahoney
    Title: Chief Financial and Operating Officer

    4

    Exhibit 3.1

    SECOND AMENDED AND RESTATED

    BY-LAWS

    OF

    MAGENTA THERAPEUTICS, INC.

    (the "Corporation")

    ARTICLE I

    Stockholders

SECTION 1. Annual Meeting. The annual meeting of stockholders (any such meeting being referred to in these By-laws as an "Annual Meeting") shall be held at the hour, date and place within or without the United States which is fixed by the Board of Directors, which time, date and place may subsequently be changed at any time by vote of the Board of Directors. If no Annual Meeting has been held for a period of thirteen (13) months after the Corporation's last Annual Meeting, a special meeting in lieu thereof may be held, and such special meeting shall have, for the purposes of these By-laws or otherwise, all the force and effect of an Annual Meeting. Any and all references hereafter in these By-laws to an Annual Meeting or Annual Meetings also shall be deemed to refer to any special meeting(s) in lieu thereof.

SECTION 2. Notice of Stockholder Business and Nominations.

(a) Annual Meetings of Stockholders.

(1) Nominations of persons for election to the Board of Directors of the Corporation and the proposal of other business to be considered by the stockholders may be brought before an Annual Meeting (i) by or at the direction of the Board of Directors or (ii) by any stockholder of the Corporation who was a stockholder of record at the time of giving of notice provided for in this By-law, who is entitled to vote at the meeting, who is present (in person or by proxy) at the meeting and who complies with the notice procedures set forth in this By-law as to such nomination or business. For the avoidance of doubt, the foregoing clause (ii) shall be the exclusive means for a stockholder to bring nominations or business properly before an Annual Meeting (other than matters properly brought under Rule 14a-8 (or any successor rule) under the Securities Exchange Act of 1934, as amended (the "Exchange Act")), and such stockholder must comply with the notice and other procedures set forth in Article I, Section 2(a)(2) and (3) of this By-law to bring such nominations or business properly before an Annual Meeting. In addition to the other requirements set forth in this By-law, for any proposal of business to be considered at an Annual Meeting, it must be a proper subject for action by stockholders of the Corporation under Delaware law.

    --------------------------------------------------------------------------------
    (2) For nominations or other business to be properly brought before an Annual
    Meeting by a stockholder pursuant to clause (ii) of Article I, Section 2(a)(1)
    of this By-law, the stockholder must (i) have given Timely Notice (as defined
    below) thereof in writing to the Secretary of the Corporation, (ii) have
    provided any updates or supplements to such notice at the times and in the forms
    required by this By-law and (iii) together with the beneficial owner(s), if any,
    on whose behalf the nomination or business proposal is made, have acted in
    accordance with the representations set forth in the Solicitation Statement (as
    defined below) required by this By-law. To be timely, a stockholder's written
    notice shall be received by the Secretary at the principal executive offices of
    the Corporation not later than the close of business on the ninetieth (90th) day
    nor earlier than the close of business on the one hundred twentieth (120th) day
    prior to the one-year anniversary of the preceding year's Annual Meeting;
    provided, however, that in the event the Annual Meeting is first convened more
    than thirty (30) days before or more than sixty (60) days after such anniversary
    date, or if no Annual Meeting were held in the preceding year, notice by the
    stockholder to be timely must be received by the Secretary of the Corporation
    not later than the close of business on the later of the ninetieth (90th) day
    prior to the scheduled date of such Annual Meeting or the tenth (10th) day
    following the day on which public announcement of the date of such meeting is
    first made (such notice within such time periods shall be referred to as "Timely
    Notice"). Notwithstanding anything to the contrary provided herein, for the
    first Annual Meeting following the initial public offering of common stock of
    the Corporation, a stockholder's notice shall be timely if received by the
    Secretary at the principal executive offices of the Corporation not later than
    the close of business on the later of the ninetieth (90th) day prior to the
    scheduled date of such Annual Meeting or the tenth (10th) day following the day
    on which public announcement of the date of such Annual Meeting is first made or
    sent by the Corporation. Such stockholder's Timely Notice shall set forth:

(A) as to each person whom the stockholder proposes to nominate for election or reelection as a director, (i) the name, age, business address and residence address of the nominee, (ii) the principal occupation or employment of the nominee, (iii) the class and number of shares of the corporation that are held of record or are beneficially owned by the nominee and any derivative positions held or beneficially held by the nominee, (iv) whether and the extent to which any hedging or other transaction or series of transactions has been entered into by or on behalf of the nominee with respect to any securities of the corporation, and a description of any other agreement, arrangement or understanding (including any short position or any borrowing or lending of shares), the effect or intent of which is to mitigate loss to, or to manage the risk or benefit of share price changes for, or to increase or decrease the voting power of the nominee, (v) a description of all arrangements or understandings between or among the stockholder and each nominee and any other person or persons (naming such person or persons) pursuant to which the nominations are to be made by the stockholder or concerning the nominee's potential service on the Board of Directors, (vi) a written statement executed by the nominee acknowledging that as a director of the corporation, the nominee will owe fiduciary duties under Delaware law with respect to the corporation and its stockholders, and (vii) all information relating to such person that is required to be disclosed in solicitations of proxies for election of directors in an election contest, or is otherwise required, in each case pursuant to Regulation 14A under the Exchange Act (including such person's written consent to being named in the proxy statement as a nominee and to serving as a director if elected);

    2

    --------------------------------------------------------------------------------
    (B) as to any other business that the stockholder proposes to bring before the
    meeting, a brief description of the business desired to be brought before the
    meeting, the reasons for conducting such business at the meeting, the text, if
    any, of any resolutions or By-law amendment proposed for adoption, and any
    material interest in such business of each Proposing Person (as defined below);

(C) (i) the name and address of the stockholder giving the notice, as they appear on the Corporation's books, and the names and addresses of the other Proposing Persons (if any) and (ii) as to each Proposing Person, the following information: (a) the class or series and number of all shares of capital stock of the Corporation which are, directly or indirectly, owned beneficially or of record by such Proposing Person or any of its affiliates or associates (as such terms are defined in Rule 12b-2 promulgated under the Exchange Act), including any shares of any class or series of capital stock of the Corporation as to which such Proposing Person or any of its affiliates or associates has a right to acquire beneficial ownership at any time in the future, (b) all Synthetic Equity Interests (as defined below) in which such Proposing Person or any of its affiliates or associates, directly or indirectly, holds an interest including a description of the material terms of each such Synthetic Equity Interest, including without limitation, identification of the counterparty to each such Synthetic Equity Interest and disclosure, for each such Synthetic Equity Interest, as to (x) whether or not such Synthetic Equity Interest conveys any voting rights, directly or indirectly, in such shares to such Proposing Person, (y) whether or not such Synthetic Equity Interest is required to be, or is capable of being, settled through delivery of such shares and (z) whether or not such Proposing Person and/or, to the extent known, the counterparty to such Synthetic Equity Interest has entered into other transactions that hedge or mitigate the economic effect of such Synthetic Equity Interest, (c) any proxy (other than a revocable proxy given in response to a public proxy solicitation made pursuant to, and in accordance with, the Exchange Act), agreement, arrangement, understanding or relationship pursuant to which such Proposing Person has or shares a right to, directly or indirectly, vote any shares of any class or series of capital stock of the Corporation, (d) any rights to dividends or other distributions on the shares of any class or series of capital stock of the Corporation, directly or indirectly, owned beneficially by such Proposing Person that are separated or separable from the underlying shares of the Corporation, and (e) any performance-related fees (other than an asset based fee) that such Proposing Person, directly or indirectly, is entitled to based on any increase or decrease in the value of shares of any class or series of capital stock of the Corporation or any Synthetic Equity Interests (the disclosures to be made pursuant to the foregoing clauses (a) through (e) are referred to, collectively, as "Material Ownership Interests") and (iii) a description of the material terms of all agreements, arrangements or understandings (whether or not in writing) entered into by any Proposing Person or any of its affiliates or associates with any other person for the purpose of acquiring, holding, disposing or voting of any shares of any class or series of capital stock of the Corporation;

    3

    --------------------------------------------------------------------------------
    (D) (i) a description of all agreements, arrangements or understandings by and
    among any of the Proposing Persons, or by and among any Proposing Persons and
    any other person (including with any proposed nominee(s)) pertaining to the
    nomination(s) or other business proposed to be brought before the meeting of
    stockholders (which description shall identify the name of each other person who
    is party to such an agreement, arrangement or understanding), and
    (ii) identification of the names and addresses of other stockholders (including
    beneficial owners) known by any of the Proposing Persons to support such
    nominations or other business proposal(s), and to the extent known the class and
    number of all shares of the Corporation's capital stock owned beneficially or of
    record by such other stockholder(s) or other beneficial owner(s); and

(E) a statement whether or not the stockholder giving the notice and/or the other Proposing Person(s), if any, will deliver a proxy statement and form of proxy to holders of, in the case of a business proposal, at least the percentage of voting power of all of the shares of capital stock of the Corporation required under applicable law to approve the proposal or, in the case of a nomination or nominations, at least the percentage of voting power of all of the shares of capital stock of the Corporation reasonably believed by such Proposing Person to be sufficient to elect the nominee or nominees proposed to be nominated by such stockholder (such statement, the "Solicitation Statement").

For purposes of this Article I of these By-laws, the term "Proposing Person" shall mean the following persons: (i) the stockholder of record providing the notice of nominations or business proposed to be brought before a stockholders' meeting, and (ii) the beneficial owner(s), if different, on whose behalf the nominations or business proposed to be brought before a stockholders' meeting is made. For purposes of this Section 2 of Article I of these By-laws, the term "Synthetic Equity Interest" shall mean any transaction, agreement or arrangement (or series of transactions, agreements or arrangements), including, without limitation, any derivative, swap, hedge, repurchase or so-called"stock borrowing" agreement or arrangement, the purpose or effect of which is to, directly or indirectly: (a) give a person or entity economic benefit and/or risk similar to ownership of shares of any class or series of capital stock of the Corporation, in whole or in part, including due to the fact that such transaction, agreement or arrangement provides, directly or indirectly, the opportunity to profit or avoid a loss from any increase or decrease in the value of any shares of any class or series of capital stock of the Corporation, (b) mitigate loss to, reduce the economic risk of or manage the risk of share price changes for, any person or entity with respect to any shares of any class or series of capital stock of the Corporation, (c) otherwise provide in any manner the opportunity to profit or avoid a loss from any decrease in the value of any shares of any class or series of capital stock of the Corporation, or (d) increase or decrease the voting power of any person or entity with respect to any shares of any class or series of capital stock of the Corporation.

    4

    --------------------------------------------------------------------------------
    (3) A stockholder providing Timely Notice of nominations or business proposed to
    be brought before an Annual Meeting shall further update and supplement such
    notice, if necessary, so that the information (including, without limitation,
    the Material Ownership Interests information) provided or required to be
    provided in such notice pursuant to this By-law shall be true and correct as of
    the record date for the meeting and as of the date that is ten (10) business
    days prior to such Annual Meeting, and such update and supplement shall be
    received by the Secretary at the principal executive offices of the Corporation
    not later than the close of business on the fifth (5th) business day after the
    record date for the Annual Meeting (in the case of the update and supplement
    required to be made as of the record date), and not later than the close of
    business on the eighth (8th) business day prior to the date of the Annual
    Meeting (in the case of the update and supplement required to be made as of ten
    (10) business days prior to the meeting).

(4) Notwithstanding anything in the second sentence of Article I, Section 2(a)(2) of this By-law to the contrary, in the event that the number of directors to be elected to the Board of Directors of the Corporation is increased and there is no public announcement naming all of the nominees for director or specifying the size of the increased Board of Directors made by the Corporation at least ten (10) days before the last day a stockholder may deliver a notice of nomination in accordance with the second sentence of Article I, Section 2(a)(2), a stockholder's notice required by this By-law shall also be considered timely, but only with respect to nominees for any new positions created by such increase, if it shall be received by the Secretary of the Corporation not later than the close of business on the tenth (10th) day following the day on which such public announcement is first made by the Corporation.

(b) General.

(1) Only such persons who are nominated in accordance with the provisions of this By-law shall be eligible for election and to serve as directors and only such business shall be conducted at an Annual Meeting as shall have been brought before the meeting in accordance with the provisions of this By-law or in accordance with Rule 14a-8 under the Exchange Act. The Board of Directors or a designated committee thereof shall have the power to determine whether a nomination or any business proposed to be brought before the meeting was made in accordance with the provisions of this By-law. If neither the Board of Directors nor such designated committee makes a determination as to whether any stockholder proposal or nomination was made in accordance with the provisions of this By-law, the presiding officer of the Annual Meeting shall have the power and duty to determine whether the stockholder proposal or nomination was made in accordance with the provisions of this By-law. If the Board of Directors or a designated committee thereof or the presiding officer, as applicable, determines that any stockholder proposal or nomination was not made in accordance with the provisions of this By-law, such proposal or nomination shall be disregarded and shall not be presented for action at the Annual Meeting.

(2) Except as otherwise required by law, nothing in this Article I, Section 2 shall obligate the Corporation or the Board of Directors to include in any proxy statement or other stockholder communication distributed on behalf of the Corporation or the Board of Directors information with respect to any nominee for director or any other matter of business submitted by a stockholder.

    5

    --------------------------------------------------------------------------------
    (3) Notwithstanding the foregoing provisions of this Article I, Section 2, if
    the nominating or proposing stockholder (or a qualified representative of the
    stockholder) does not appear at the Annual Meeting to present a nomination or
    any business, such nomination or business shall be disregarded, notwithstanding
    that proxies in respect of such vote may have been received by the Corporation.
    For purposes of this Article I, Section 2, to be considered a qualified
    representative of the proposing stockholder, a person must be authorized by a
    written instrument executed by such stockholder or an electronic transmission
    delivered by such stockholder to act for such stockholder as proxy at the
    meeting of stockholders and such person must produce such written instrument or
    electronic transmission, or a reliable reproduction of the written instrument or
    electronic transmission, to the presiding officer at the meeting of
    stockholders.

(4) For purposes of this By-law, "public announcement" shall mean disclosure in a press release reported by the Dow Jones News Service, Associated Press or comparable national news service or in a document publicly filed by the Corporation with the Securities and Exchange Commission pursuant to Section 13, 14 or 15(d) of the Exchange Act.

(5) Notwithstanding the foregoing provisions of this By-law,a stockholder shall also comply with all applicable requirements of the Exchange Act and the rules and regulations thereunder with respect to the matters set forth in this By-law. Nothing in this By-law shall be deemed to affect any rights of (i) stockholders to have proposals included in the Corporation's proxy statement pursuant to Rule 14a-8 (or any successor rule), as applicable, under the Exchange Act and, to the extent required by such rule, have such proposals considered and voted on at an Annual Meeting or (ii) the holders of any series of Undesignated Preferred Stock to elect directors under specified circumstances.

SECTION 3. Special Meetings. Except as otherwise required by statute and subject to the rights, if any, of the holders of any series of Undesignated Preferred Stock, special meetings of the stockholders of the Corporation may be called only by the Board of Directors acting pursuant to a resolution approved by the affirmative vote of a majority of the Directors then in office. The Board of Directors may postpone or reschedule any previously scheduled special meeting of stockholders. Only those matters set forth in the notice of the special meeting may be considered or acted upon at a special meeting of stockholders of the Corporation. Nominations of persons for election to the Board of Directors of the Corporation and stockholder proposals of other business shall not be brought before a special meeting of stockholders to be considered by the stockholders unless such special meeting is held in lieu of an annual meeting of stockholders in accordance with Article I, Section 1 of these By-laws, in which case such special meeting in lieu thereof shall be deemed an Annual Meeting for purposes of these By-laws and the provisions of Article I, Section 2 of these By-laws shall govern such special meeting.

    6

    --------------------------------------------------------------------------------
    SECTION 4. Notice of Meetings; Adjournments.

(a) A notice of each Annual Meeting stating the hour, date and place, if any, of such Annual Meeting and the means of remote communication, if any, by which stockholders and proxyholders may be deemed to be present in person and vote at such meeting, shall be given not less than ten (10) days nor more than sixty (60) days before the Annual Meeting, to each stockholder entitled to vote thereat by delivering such notice to such stockholder or by mailing it, postage prepaid, addressed to such stockholder at the address of such stockholder as it appears on the Corporation's stock transfer books. Without limiting the manner by which notice may otherwise be given to stockholders, any notice to stockholders may be given by electronic transmission in the manner provided in Section 232 of the Delaware General Corporation Law ("DGCL").

(b) Unless otherwise required by the DGCL, notice of all special meetings of stockholders shall be given in the same manner as provided for Annual Meetings, except that the notice of all special meetings shall state the purpose or purposes for which the meeting has been called.

(c) Notice of an Annual Meeting or special meeting of stockholders need not be given to a stockholder if a waiver of notice is executed, or waiver of notice by electronic transmission is provided, before or after such meeting by such stockholder or if such stockholder attends such meeting, unless such attendance is for the express purpose of objecting at the beginning of the meeting to the transaction of any business because the meeting was not lawfully called or convened.

(d) The Board of Directors may postpone and reschedule any previously scheduled Annual Meeting or special meeting of stockholders and any record date with respect thereto, regardless of whether any notice or public disclosure with respect to any such meeting has been sent or made pursuant to Section 2 of this Article I of these By-laws or otherwise. In no event shall the public announcement of an adjournment, postponement or rescheduling of any previously scheduled meeting of stockholders commence a new time period for the giving of a stockholder's notice under this Article I of these By-laws.

(e) When any meeting is convened, the presiding officer may adjourn the meeting if (i) no quorum is present for the transaction of business, (ii) the Board of Directors determines that adjournment is necessary or appropriate to enable the stockholders to consider fully information which the Board of Directors determines has not been made sufficiently or timely available to stockholders, or (iii) the Board of Directors determines that adjournment is otherwise in the best interests of the Corporation. When any Annual Meeting or special meeting of stockholders is adjourned to another hour, date or place, notice need not be given of the adjourned meeting other than an announcement at the meeting at which the adjournment is taken of the hour, date and place, if any, to which the meeting is adjourned and the means of remote communications, if any, by which stockholders and proxyholders may be deemed to be present in person and vote at such adjourned meeting; provided, however, that if the adjournment is for more than thirty (30) days from the meeting date, or if after the adjournment a new record date is fixed for the adjourned meeting, notice of the adjourned meeting and the means of remote communications, if any, by which stockholders and proxyholders may be deemed to be present in person and vote at such adjourned meeting shall be given to each stockholder of record entitled to vote thereat and each stockholder who, by law or under the Certificate of Incorporation of the Corporation (as the same may hereafter be amended and/or restated, the "Certificate") or these By-laws, is entitled to such notice.

    7

    --------------------------------------------------------------------------------
    SECTION 5. Quorum. A majority of the shares entitled to vote, present in person
    or represented by proxy, shall constitute a quorum at any meeting of
    stockholders. If less than a quorum is present at a meeting, the holders of
    voting stock representing a majority of the voting power present at the meeting
    or the presiding officer may adjourn the meeting from time to time, and the
    meeting may be held as adjourned without further notice, except as provided in
    Section 4 of this Article I. At such adjourned meeting at which a quorum is
    present, any business may be transacted which might have been transacted at the
    meeting as originally noticed. The stockholders present at a duly constituted
    meeting may continue to transact business until adjournment, notwithstanding the
    withdrawal of enough stockholders to leave less than a quorum.

SECTION 6. Voting and Proxies. Stockholders shall have one vote for each share of stock entitled to vote owned by them of record according to the stock ledger of the Corporation as of the record date, unless otherwise provided by law or by the Certificate. Stockholders may vote either (i) in person, (ii) by written proxy or (iii) by a transmission permitted by Section 212(c) of the DGCL. Any copy, facsimile telecommunication or other reliable reproduction of the writing or transmission permitted by Section 212(c) of the DGCL may be substituted for or used in lieu of the original writing or transmission for any and all purposes for which the original writing or transmission could be used, provided that such copy, facsimile telecommunication or other reproduction shall be a complete reproduction of the entire original writing or transmission. Proxies shall be filed in accordance with the procedures established for the meeting of stockholders. Except as otherwise limited therein or as otherwise provided by law, proxies authorizing a person to vote at a specific meeting shall entitle the persons authorized thereby to vote at any adjournment of such meeting, but they shall not be valid after final adjournment of such meeting. A proxy with respect to stock held in the name of two or more persons shall be valid if executed by or on behalf of any one of them unless at or prior to the exercise of the proxy the Corporation receives a specific written notice to the contrary from any one of them.

SECTION 7. Action at Meeting. When a quorum is present at any meeting of stockholders, any matter before any such meeting (other than an election of a director or directors) shall be decided by a majority of the votes properly cast for and against such matter, except where a larger vote is required by law, by the Certificate or by these By-laws. Any election of directors by stockholders shall be determined by a plurality of the votes properly cast on the election of directors.

SECTION 8. Stockholder Lists. The Secretary or an Assistant Secretary (or the Corporation's transfer agent or other person authorized by these By-laws or by law) shall prepare and make, at least ten (10) days before every Annual Meeting or special meeting of stockholders, a complete list of the stockholders entitled to vote at the meeting, arranged in alphabetical order, and showing the address of each stockholder and the number of shares registered in the name of each stockholder. Such list shall be open to the examination of any stockholder, for a period of at least ten (10) days prior to the meeting in the manner provided by law. The list shall also be open to the examination of any stockholder during the whole time of the meeting as provided by law.

    8

    --------------------------------------------------------------------------------
    SECTION 9. Presiding Officer. The Board of Directors shall designate a
    representative to preside over all Annual Meetings or special meetings of
    stockholders, provided that if the Board of Directors does not so designate such
    a presiding officer, then the Chairman of the Board, if one is elected, shall
    preside over such meetings. If the Board of Directors does not so designate such
    a presiding officer and there is no Chairman of the Board or the Chairman of the
    Board is unable to so preside or is absent, then the Chief Executive Officer, if
    one is elected, shall preside over such meetings, provided further that if there
    is no Chief Executive Officer or the Chief Executive Officer is unable to so
    preside or is absent, then the President shall preside over such meetings. The
    presiding officer at any Annual Meeting or special meeting of stockholders shall
    have the power, among other things, to adjourn such meeting at any time and from
    time to time, subject to Sections 4 and 5 of this Article I. The order of
    business and all other matters of procedure at any meeting of the stockholders
    shall be determined by the presiding officer.

SECTION 10. Inspectors of Elections. The Corporation shall, in advance of any meeting of stockholders, appoint one or more inspectors to act at the meeting and make a written report thereof. The Corporation may designate one or more persons as alternate inspectors to replace any inspector who fails to act. If no inspector or alternate is able to act at a meeting of stockholders, the presiding officer shall appoint one or more inspectors to act at the meeting. Any inspector may, but need not, be an officer, employee or agent of the Corporation. Each inspector, before entering upon the discharge of his or her duties, shall take and sign an oath faithfully to execute the duties of inspector with strict impartiality and according to the best of his or her ability. The inspectors shall perform such duties as are required by the DGCL, including the counting of all votes and ballots. The inspectors may appoint or retain other persons or entities to assist the inspectors in the performance of the duties of the inspectors. The presiding officer may review all determinations made by the inspectors, and in so doing the presiding officer shall be entitled to exercise his or her sole judgment and discretion and he or she shall not be bound by any determinations made by the inspectors. All determinations by the inspectors and, if applicable, the presiding officer, shall be subject to further review by any court of competent jurisdiction.

    ARTICLE II

    Directors

SECTION 1. Powers. The business and affairs of the Corporation shall be managed by or under the direction of the Board of Directors except as otherwise provided by the Certificate or required by law.

    9

    --------------------------------------------------------------------------------
    SECTION 2. Number and Terms. The number of directors of the Corporation shall be
    fixed solely and exclusively by resolution duly adopted from time to time by the
    Board of Directors. The directors shall hold office in the manner provided in
    the Certificate.

SECTION 3. Qualification. No director need be a stockholder of the Corporation.

SECTION 4. Vacancies. Vacancies in the Board of Directors shall be filled in the manner provided in the Certificate.

SECTION 5. Removal. Directors may be removed from office only in the manner provided in the Certificate.

SECTION 6. Resignation. A director may resign at any time by electronic transmission or by giving written notice to the Chairman of the Board, if one is elected, the President or the Secretary. A resignation shall be effective upon receipt, unless the resignation otherwise provides.

SECTION 7. Regular Meetings. The regular annual meeting of the Board of Directors shall be held, without notice other than this Section 7, on the same date and at the same place as the Annual Meeting following the close of such meeting of stockholders. Other regular meetings of the Board of Directors may be held at such hour, date and place as the Board of Directors may by resolution from time to time determine and publicize by means of reasonable notice given to any director who is not present at the meeting at which such resolution is adopted.

SECTION 8. Special Meetings. Special meetings of the Board of Directors may be called, orally or in writing, by or at the request of a majority of the directors, the Chairman of the Board, if one is elected, or the President. The person calling any such special meeting of the Board of Directors may fix the hour, date and place thereof.

SECTION 9. Notice of Meetings. Notice of the hour, date and place of all special meetings of the Board of Directors shall be given to each director by the Secretary or an Assistant Secretary, or in case of the death, absence, incapacity or refusal of such persons, by the Chairman of the Board, if one is elected, or the President or such other officer designated by the Chairman of the Board, if one is elected, or the President. Notice of any special meeting of the Board of Directors shall be given to each director in person, by telephone, or by facsimile, electronic mail or other form of electronic communication, sent to his or her business or home address, at least twenty-four (24) hours in advance of the meeting, or by written notice mailed to his or her business or home address, at least forty-eight (48) hours in advance of the meeting. Such notice shall be deemed to be delivered when hand-delivered to such address, read to such director by telephone, deposited in the mail so addressed, with postage thereon prepaid if mailed, dispatched or transmitted if sent by facsimile transmission or by electronic mail or other form of electronic communications. A written waiver of notice signed or electronically transmitted before or after a meeting by a director and filed with the records of the meeting shall be deemed to be equivalent to notice of the meeting. The attendance of a director at a meeting shall

    10

    --------------------------------------------------------------------------------
    constitute a waiver of notice of such meeting, except where a director attends a
    meeting for the express purpose of objecting at the beginning of the meeting to
    the transaction of any business because such meeting is not lawfully called or
    convened. Except as otherwise required by law, by the Certificate or by these
    By-laws, neither the business to be transacted at, nor the purpose of, any
    meeting of the Board of Directors need be specified in the notice or waiver of
    notice of such meeting.

SECTION 10. Quorum. At any meeting of the Board of Directors, a majority of the total number of directors shall constitute a quorum for the transaction of business, but if less than a quorum is present at a meeting, a majority of the directors present may adjourn the meeting from time to time, and the meeting may be held as adjourned without further notice. Any business which might have been transacted at the meeting as originally noticed may be transacted at such adjourned meeting at which a quorum is present. For purposes of this section, the total number of directors includes any unfilled vacancies on the Board of Directors.

SECTION 11. Action at Meeting. At any meeting of the Board of Directors at which a quorum is present, the vote of a majority of the directors present shall constitute action by the Board of Directors, unless otherwise required by law, by the Certificate or by these By-laws.

SECTION 12. Action by Consent. Any action required or permitted to be taken at any meeting of the Board of Directors may be taken without a meeting if all members of the Board of Directors consent thereto in writing or by electronic transmission and the writing or writings or electronic transmission or transmissions are filed with the records of the meetings of the Board of Directors. Such filing shall be in paper form if the minutes are maintained in paper form and shall be in electronic form if the minutes are maintained in electronic form. Such consent shall be treated as a resolution of the Board of Directors for all purposes.

SECTION 13. Manner of Participation. Directors may participate in meetings of the Board of Directors by means of conference telephone or other communications equipment by means of which all directors participating in the meeting can hear each other, and participation in a meeting in accordance herewith shall constitute presence in person at such meeting for purposes of these By-laws.

SECTION 14. Presiding Director. The Board of Directors shall designate a representative to preside over all meetings of the Board of Directors, provided that if the Board of Directors does not so designate such a presiding director or such designated presiding director is unable to so preside or is absent, then the Chairman of the Board, if one is elected, shall preside over all meetings of the Board of Directors. If both the designated presiding director, if one is so designated, and the Chairman of the Board, if one is elected, are unable to preside or are absent, the Board of Directors shall designate an alternate representative to preside over a meeting of the Board of Directors.

    11

    --------------------------------------------------------------------------------
    SECTION 15. Committees. The Board of Directors, by vote of a majority of the
    directors then in office, may elect one or more committees, including, without
    limitation, a Compensation Committee, a Nominating & Corporate Governance
    Committee and an Audit Committee, and may delegate thereto some or all of its
    powers except those which by law, by the Certificate or by these By-laws may not
    be delegated. Except as the Board of Directors may otherwise determine, any such
    committee may make rules for the conduct of its business, but unless otherwise
    provided by the Board of Directors or in such rules, its business shall be
    conducted so far as possible in the same manner as is provided by these By-laws
    for the Board of Directors. All members of such committees shall hold such
    offices at the pleasure of the Board of Directors. The Board of Directors may
    abolish any such committee at any time. Any committee to which the Board of
    Directors delegates any of its powers or duties shall keep records of its
    meetings and shall report its action to the Board of Directors.

SECTION 16. Compensation of Directors. Directors shall receive such compensation for their services as shall be determined by a majority of the Board of Directors, or a designated committee thereof, provided that directors who are serving the Corporation as employees and who receive compensation for their services as such, shall not receive any salary or other compensation for their services as directors of the Corporation.

    ARTICLE III

    Officers

SECTION 1. Enumeration. The officers of the Corporation shall consist of a President, a Treasurer, a Secretary and such other officers, including, without limitation, a Chairman of the Board of Directors, a Chief Executive Officer and one or more Vice Presidents (including Executive Vice Presidents or Senior Vice Presidents), Assistant Vice Presidents, Assistant Treasurers and Assistant Secretaries, as the Board of Directors may determine.

SECTION 2. Election. At the regular annual meeting of the Board of Directors following the Annual Meeting, the Board of Directors shall elect the President, the Treasurer and the Secretary. Other officers may be elected by the Board of Directors at such regular annual meeting of the Board of Directors or at any other regular or special meeting.

SECTION 3. Qualification. No officer need be a stockholder or a director. Any person may occupy more than one office of the Corporation at any time.

SECTION 4. Tenure. Except as otherwise provided by the Certificate or by these By-laws, each of the officers of the Corporation shall hold office until the regular annual meeting of the Board of Directors following the next Annual Meeting and until his or her successor is elected and qualified or until his or her earlier resignation or removal.

SECTION 5. Resignation. Any officer may resign by delivering his or her written or electronically transmitted resignation to the Corporation addressed to the President or the Secretary, and such resignation shall be effective upon receipt, unless the resignation otherwise provides.

    12

    --------------------------------------------------------------------------------
    SECTION 6. Removal. Except as otherwise provided by law or by resolution of the
    Board of Directors, the Board of Directors may remove any officer with or
    without cause by the affirmative vote of a majority of the directors then in
    office.

SECTION 7. Absence or Disability. In the event of the absence or disability of any officer, the Board of Directors may designate another officer to act temporarily in place of such absent or disabled officer.

SECTION 8. Vacancies. Any vacancy in any office may be filled for the unexpired portion of the term by the Board of Directors.

SECTION 9. President. The President shall, subject to the direction of the Board of Directors, have such powers and shall perform such duties as the Board of Directors may from time to time designate.

SECTION 10. Chairman of the Board. The Chairman of the Board, if one is elected, shall have such powers and shall perform such duties as the Board of Directors may from time to time designate.

SECTION 11. Chief Executive Officer. The Chief Executive Officer, if one is elected, shall have such powers and shall perform such duties as the Board of Directors may from time to time designate.

SECTION 12. Vice Presidents and Assistant Vice Presidents. Any Vice President (including any Executive Vice President or Senior Vice President) and any Assistant Vice President shall have such powers and shall perform such duties as the Board of Directors or the Chief Executive Officer may from time to time designate.

SECTION 13. Treasurer and Assistant Treasurers. The Treasurer shall, subject to the direction of the Board of Directors and except as the Board of Directors or the Chief Executive Officer may otherwise provide, have general charge of the financial affairs of the Corporation and shall cause to be kept accurate books of account. The Treasurer shall have custody of all funds, securities, and valuable documents of the Corporation. He or she shall have such other duties and powers as may be designated from time to time by the Board of Directors or the Chief Executive Officer. Any Assistant Treasurer shall have such powers and perform such duties as the Board of Directors or the Chief Executive Officer may from time to time designate.

SECTION 14. Secretary and Assistant Secretaries. The Secretary shall record all the proceedings of the meetings of the stockholders and the Board of Directors (including committees of the Board of Directors) in books kept for that purpose. In his or her absence from any such meeting, a temporary secretary chosen at the meeting shall record the proceedings thereof. The Secretary shall have charge of the stock ledger (which may, however, be kept by any transfer or other agent of the Corporation). The Secretary shall have custody of the seal of the Corporation, and the Secretary, or an Assistant Secretary shall have authority to affix it to

    13

    --------------------------------------------------------------------------------
    any instrument requiring it, and, when so affixed, the seal may be attested by
    his or her signature or that of an Assistant Secretary. The Secretary shall have
    such other duties and powers as may be designated from time to time by the Board
    of Directors or the Chief Executive Officer. In the absence of the Secretary,
    any Assistant Secretary may perform his or her duties and responsibilities. Any
    Assistant Secretary shall have such powers and perform such duties as the Board
    of Directors or the Chief Executive Officer may from time to time designate.

SECTION 15. Other Powers and Duties. Subject to these By-laws and to such limitations as the Board of Directors may from time to time prescribe, the officers of the Corporation shall each have such powers and duties as generally pertain to their respective offices, as well as such powers and duties as from time to time may be conferred by the Board of Directors or the Chief Executive Officer.

    ARTICLE IV

    Capital Stock

SECTION 1. Certificates of Stock. Each stockholder shall be entitled to a certificate of the capital stock of the Corporation in such form as may from time to time be prescribed by the Board of Directors. Such certificate shall be signed by any two authorized officers of the Corporation. The Corporation seal and the signatures by the Corporation's officers, the transfer agent or the registrar may be facsimiles. In case any officer, transfer agent or registrar who has signed or whose facsimile signature has been placed on such certificate shall have ceased to be such officer, transfer agent or registrar before such certificate is issued, it may be issued by the Corporation with the same effect as if he or she were such officer, transfer agent or registrar at the time of its issue. Every certificate for shares of stock which are subject to any restriction on transfer and every certificate issued when the Corporation is authorized to issue more than one class or series of stock shall contain such legend with respect thereto as is required by law. Notwithstanding anything to the contrary provided in these Bylaws, the Board of Directors of the Corporation may provide by resolution or resolutions that some or all of any or all classes or series of its stock shall be uncertificated shares (except that the foregoing shall not apply to shares represented by a certificate until such certificate is surrendered to the Corporation), and by the approval and adoption of these Bylaws the Board of Directors has determined that all classes or series of the Corporation's stock may be uncertificated, whether upon original issuance, re-issuance, or subsequent transfer.

SECTION 2. Transfers. Subject to any restrictions on transfer and unless otherwise provided by the Board of Directors, shares of stock that are represented by a certificate may be transferred on the books of the Corporation by the surrender to the Corporation or its transfer agent of the certificate theretofore properly endorsed or accompanied by a written assignment or power of attorney properly executed, with transfer stamps (if necessary) affixed, and with such proof of the authenticity of signature as the Corporation or its transfer agent may reasonably require. Shares of stock that are not represented by a certificate may be transferred on the books of the Corporation by submitting to the Corporation or its transfer agent such evidence of transfer and following such other procedures as the Corporation or its transfer agent may require.

    14

    --------------------------------------------------------------------------------
    SECTION 3. Record Holders. Except as may otherwise be required by law, by the
    Certificate or by these By-laws, the Corporation shall be entitled to treat the
    record holder of stock as shown on its books as the owner of such stock for all
    purposes, including the payment of dividends and the right to vote with respect
    thereto, regardless of any transfer, pledge or other disposition of such stock,
    until the shares have been transferred on the books of the Corporation in
    accordance with the requirements of these By-laws.

SECTION 4. Record Date. In order that the Corporation may determine the stockholders entitled to notice of or to vote at any meeting of stockholders or any adjournment thereof or entitled to receive payment of any dividend or other distribution or allotment of any rights, or entitled to exercise any rights in respect of any change, conversion or exchange of stock or for the purpose of any other lawful action, the Board of Directors may fix a record date, which record date shall not precede the date upon which the resolution fixing the record date is adopted by the Board of Directors, and which record date: (a) in the case of determination of stockholders entitled to vote at any meeting of stockholders, shall, unless otherwise required by law, not be more than sixty (60) nor less than ten (10) days before the date of such meeting and (b) in the case of any other action, shall not be more than sixty (60) days prior to such other action. If no record date is fixed: (i) the record date for determining stockholders entitled to notice of or to vote at a meeting of stockholders shall be at the close of business on the day next preceding the day on which notice is given, or, if notice is waived, at the close of business on the day next preceding the day on which the meeting is held; and (ii) the record date for determining stockholders for any other purpose shall be at the close of business on the day on which the Board of Directors adopts the resolution relating thereto.

SECTION 5. Replacement of Certificates. In case of the alleged loss, destruction or mutilation of a certificate of stock of the Corporation, a duplicate certificate may be issued in place thereof, upon such terms as the Board of Directors may prescribe.

    ARTICLE V

    Indemnification

SECTION 1. Definitions. For purposes of this Article:

(a) "Corporate Status" describes the status of a person who is serving or has served (i) as a Director of the Corporation, (ii) as an Officer of the Corporation, (iii) as a Non-Officer Employee of the Corporation, or (iv) as a director, partner, trustee, officer, employee or agent of any other corporation, partnership, limited liability company, joint venture, trust, employee benefit plan, foundation, association, organization or other legal entity which such person is or was serving at the request of the Corporation. For purposes of this Section 1(a), a Director, Officer or Non-Officer Employee of the Corporation who is serving or has served as a director, partner, trustee, officer, employee or agent of a Subsidiary shall be deemed to be serving at the request of the Corporation. Notwithstanding the foregoing, "Corporate Status" shall not include the status of a person who is serving or has served as a director, officer, employee or agent of a constituent corporation absorbed in a merger or consolidation transaction with the Corporation with respect to such person's activities prior to said transaction, unless specifically authorized by the Board of Directors or the stockholders of the Corporation;

    15

    --------------------------------------------------------------------------------
    (b) "Director" means any person who serves or has served the Corporation as a
    director on the Board of Directors of the Corporation;

(c) "Disinterested Director" means, with respect to each Proceeding in respect of which indemnification is sought hereunder, a Director of the Corporation who is not and was not a party to such Proceeding;

(d) "Expenses" means all attorneys' fees, retainers, court costs, transcript costs, fees of expert witnesses, private investigators and professional advisors (including, without limitation, accountants and investment bankers), travel expenses, duplicating costs, printing and binding costs, costs of preparation of demonstrative evidence and other courtroom presentation aids and devices, costs incurred in connection with document review, organization, imaging and computerization, telephone charges, postage, delivery service fees, and all other disbursements, costs or expenses of the type customarily incurred in connection with prosecuting, defending, preparing to prosecute or defend, investigating, being or preparing to be a witness in, settling or otherwise participating in, a Proceeding;

(e) "Liabilities" means judgments, damages, liabilities, losses, penalties, excise taxes, fines and amounts paid in settlement;

(f) "Non-Officer Employee" means any person who serves or has served as an employee or agent of the Corporation, but who is not or was not a Director or Officer;

(g) "Officer" means any person who serves or has served the Corporation as an officer of the Corporation appointed by the Board of Directors of the Corporation;

(h) "Proceeding" means any threatened, pending or completed action, suit, arbitration, alternate dispute resolution mechanism, inquiry, investigation, administrative hearing or other proceeding, whether civil, criminal, administrative, arbitrative or investigative; and

(i) "Subsidiary" shall mean any corporation, partnership, limited liability company, joint venture, trust or other entity of which the Corporation owns (either directly or through or together with another Subsidiary of the Corporation) either (i) a general partner, managing member or other similar interest or (ii) (A) fifty percent (50%) or more of the voting power of the voting capital equity interests of such corporation, partnership, limited liability company, joint venture or other entity, or (B) fifty percent (50%) or more of the outstanding voting capital stock or other voting equity interests of such corporation, partnership, limited liability company, joint venture or other entity.

SECTION 2. Indemnification of Directors and Officers.

(a) Subject to the operation of Section 4 of this Article V of these By-laws, each Director and Officer shall be indemnified and held harmless by the Corporation to the fullest extent authorized by the DGCL, as the same exists or may hereafter be amended (but, in the case of any such amendment, only to the extent that such amendment permits the Corporation to provide broader indemnification rights than such law permitted the Corporation to provide prior to such amendment), and to the extent authorized in this Section 2.

    16

    --------------------------------------------------------------------------------
    (1) Actions, Suits and Proceedings Other than By or In the Right of the
    Corporation. Each Director and Officer shall be indemnified and held harmless by
    the Corporation against any and all Expenses and Liabilities that are incurred
    or paid by such Director or Officer or on such Director's or Officer's behalf in
    connection with any Proceeding or any claim, issue or matter therein (other than
    an action by or in the right of the Corporation), which such Director or Officer
    is, or is threatened to be made, a party to or participant in by reason of such
    Director's or Officer's Corporate Status, if such Director or Officer acted in
    good faith and in a manner such Director or Officer reasonably believed to be in
    or not opposed to the best interests of the Corporation and, with respect to any
    criminal proceeding, had no reasonable cause to believe his or her conduct was
    unlawful.

(2) Actions, Suits and Proceedings By or In the Right of the Corporation. Each Director and Officer shall be indemnified and held harmless by the Corporation against any and all Expenses that are incurred by such Director or Officer or on such Director's or Officer's behalf in connection with any Proceeding or any claim, issue or matter therein by or in the right of the Corporation, which such Director or Officer is, or is threatened to be made, a party to or participant in by reason of such Director's or Officer's Corporate Status, if such Director or Officer acted in good faith and in a manner such Director or Officer reasonably believed to be in or not opposed to the best interests of the Corporation; provided, however, that no indemnification shall be made under this Section 2(a)(2) in respect of any claim, issue or matter as to which such Director or Officer shall have been finally adjudged by a court of competent jurisdiction to be liable to the Corporation, unless, and only to the extent that, the Court of Chancery or another court in which such Proceeding was brought shall determine upon application that, despite adjudication of liability, but in view of all the circumstances of the case, such Director or Officer is fairly and reasonably entitled to indemnification for such Expenses that such court deems proper.

(3) Survival of Rights. The rights of indemnification provided by this Section 2 shall continue as to a Director or Officer after he or she has ceased to be a Director or Officer and shall inure to the benefit of his or her heirs, executors, administrators and personal representatives.

(4) Actions by Directors or Officers. Notwithstanding the foregoing, the Corporation shall indemnify any Director or Officer seeking indemnification in connection with a Proceeding initiated by such Director or Officer only if such Proceeding (including any parts of such Proceeding not initiated by such Director or Officer) was authorized in advance by the Board of Directors of the Corporation, unless such Proceeding was brought to enforce such Officer's or Director's rights to indemnification or, in the case of Directors, advancement of Expenses under these By-laws in accordance with the provisions set forth herein.

    17

    --------------------------------------------------------------------------------
    SECTION 3. Indemnification of Non-OfficerEmployees. Subject to the operation of
    Section 4 of this Article V of these By-laws, each Non-Officer Employee may, in
    the discretion of the Board of Directors of the Corporation, be indemnified by
    the Corporation to the fullest extent authorized by the DGCL, as the same exists
    or may hereafter be amended, against any or all Expenses and Liabilities that
    are incurred by such Non-Officer Employee or on such Non-Officer Employee's
    behalf in connection with any threatened, pending or completed Proceeding, or
    any claim, issue or matter therein, which such Non-Officer Employee is, or is
    threatened to be made, a party to or participant in by reason of such
    Non-Officer Employee's Corporate Status, if such Non-Officer Employee acted in
    good faith and in a manner such Non-Officer Employee reasonably believed to be
    in or not opposed to the best interests of the Corporation and, with respect to
    any criminal proceeding, had no reasonable cause to believe his or her conduct
    was unlawful. The rights of indemnification provided by this Section 3 shall
    exist as to a Non-Officer Employee after he or she has ceased to be a
    Non-Officer Employee and shall inure to the benefit of his or her heirs,
    personal representatives, executors and administrators. Notwithstanding the
    foregoing, the Corporation may indemnify any Non-Officer Employee seeking
    indemnification in connection with a Proceeding initiated by such Non-Officer
    Employee only if such Proceeding was authorized in advance by the Board of
    Directors of the Corporation.

SECTION 4. Determination. Unless ordered by a court, no indemnification shall be provided pursuant to this Article V to a Director, to an Officer or to a Non-Officer Employee unless a determination shall have been made that such person acted in good faith and in a manner such person reasonably believed to be in or not opposed to the best interests of the Corporation and, with respect to any criminal Proceeding, such person had no reasonable cause to believe his or her conduct was unlawful. Such determination shall be made by (a) a majority vote of the Disinterested Directors, even though less than a quorum of the Board of Directors, (b) a committee comprised of Disinterested Directors, such committee having been designated by a majority vote of the Disinterested Directors (even though less than a quorum), (c) if there are no such Disinterested Directors, or if a majority of Disinterested Directors so directs, by independent legal counsel in a written opinion, or (d) by the stockholders of the Corporation.

SECTION 5. Advancement of Expenses to Directors Prior to Final Disposition.

(a) The Corporation shall advance all Expenses incurred by or on behalf of any Director in connection with any Proceeding in which such Director is involved by reason of such Director's Corporate Status within thirty (30) days after the receipt by the Corporation of a written statement from such Director requesting such advance or advances from time to time, whether prior to or after final disposition of such Proceeding. Such statement or statements shall reasonably evidence the Expenses incurred by such Director and shall be preceded or accompanied by an undertaking by or on behalf of such Director to repay any Expenses so advanced if it shall ultimately be determined that such Director is not entitled to be indemnified against such Expenses. Notwithstanding the foregoing, the Corporation shall advance all Expenses incurred by or on behalf of any Director seeking advancement of expenses hereunder in connection with a Proceeding initiated by such Director only if such Proceeding (including any parts of such Proceeding not initiated by such Director) was (i) authorized by the Board of Directors of the Corporation, or (ii) brought to enforce such Director's rights to indemnification or advancement of Expenses under these By-laws.

    18

    --------------------------------------------------------------------------------
    (b) If a claim for advancement of Expenses hereunder by a Director is not paid
    in full by the Corporation within thirty (30) days after receipt by the
    Corporation of documentation of Expenses and the required undertaking, such
    Director may at any time thereafter bring suit against the Corporation to
    recover the unpaid amount of the claim and if successful in whole or in part,
    such Director shall also be entitled to be paid the expenses of prosecuting such
    claim. The failure of the Corporation (including its Board of Directors or any
    committee thereof, independent legal counsel, or stockholders) to make a
    determination concerning the permissibility of such advancement of Expenses
    under this Article V shall not be a defense to an action brought by a Director
    for recovery of the unpaid amount of an advancement claim and shall not create a
    presumption that such advancement is not permissible. The burden of proving that
    a Director is not entitled to an advancement of expenses shall be on the
    Corporation.

(c) In any suit brought by the Corporation to recover an advancement of expenses pursuant to the terms of an undertaking, the Corporation shall be entitled to recover such expenses upon a final adjudication that the Director has not met any applicable standard for indemnification set forth in the DGCL.

SECTION 6. Advancement of Expenses to Officers and Non-Officer Employees Prior to Final Disposition.

(a) The Corporation may, at the discretion of the Board of Directors of the Corporation, advance any or all Expenses incurred by or on behalf of any Officer or any Non-Officer Employee in connection with any Proceeding in which such person is involved by reason of his or her Corporate Status as an Officer or Non-Officer Employee upon the receipt by the Corporation of a statement or statements from such Officer or Non-Officer Employee requesting such advance or advances from time to time, whether prior to or after final disposition of such Proceeding. Such statement or statements shall reasonably evidence the Expenses incurred by such Officer or Non-Officer Employee and shall be preceded or accompanied by an undertaking by or on behalf of such person to repay any Expenses so advanced if it shall ultimately be determined that such Officer or Non-Officer Employee is not entitled to be indemnified against such Expenses.

(b) In any suit brought by the Corporation to recover an advancement of expenses pursuant to the terms of an undertaking, the Corporation shall be entitled to recover such expenses upon a final adjudication that the Officer or Non-Officer Employee has not met any applicable standard for indemnification set forth in the DGCL.

SECTION 7. Contractual Nature of Rights.

(a) The provisions of this Article V shall be deemed to be a contract between the Corporation and each Director and Officer entitled to the benefits hereof at any time while this Article V is in effect, in consideration of such person's past or current and any future performance of services for the Corporation. Neither amendment, repeal or modification of any provision of this Article V nor the adoption of any provision of the Certificate of Incorporation

    19

    --------------------------------------------------------------------------------
    inconsistent with this Article V shall eliminate or reduce any right conferred
    by this Article V in respect of any act or omission occurring, or any cause of
    action or claim that accrues or arises or any state of facts existing, at the
    time of or before such amendment, repeal, modification or adoption of an
    inconsistent provision (even in the case of a proceeding based on such a state
    of facts that is commenced after such time), and all rights to indemnification
    and advancement of Expenses granted herein or arising out of any act or omission
    shall vest at the time of the act or omission in question, regardless of when or
    if any proceeding with respect to such act or omission is commenced. The rights
    to indemnification and to advancement of expenses provided by, or granted
    pursuant to, this Article V shall continue notwithstanding that the person has
    ceased to be a director or officer of the Corporation and shall inure to the
    benefit of the estate, heirs, executors, administrators, legatees and
    distributes of such person.

(b) If a claim for indemnification hereunder by a Director or Officer is not paid in full by the Corporation within sixty (60) days after receipt by the Corporation of a written claim for indemnification, such Director or Officer may at any time thereafter bring suit against the Corporation to recover the unpaid amount of the claim, and if successful in whole or in part, such Director or Officer shall also be entitled to be paid the expenses of prosecuting such claim. The failure of the Corporation (including its Board of Directors or any committee thereof, independent legal counsel, or stockholders) to make a determination concerning the permissibility of such indemnification under this Article V shall not be a defense to an action brought by a Director or Officer for recovery of the unpaid amount of an indemnification claim and shall not create a presumption that such indemnification is not permissible. The burden of proving that a Director or Officer is not entitled to indemnification shall be on the Corporation.

(c) In any suit brought by a Director or Officer to enforce a right to indemnification hereunder, it shall be a defense that such Director or Officer has not met any applicable standard for indemnification set forth in the DGCL.

SECTION 8. Non-Exclusivity of Rights. The rights to indemnification and to advancement of Expenses set forth in this Article V shall not be exclusive of any other right which any Director, Officer, or Non-Officer Employee may have or hereafter acquire under any statute, provision of the Certificate or these By-laws, agreement, vote of stockholders or Disinterested Directors or otherwise.

SECTION 9. Insurance. The Corporation may maintain insurance, at its expense, to protect itself and any Director, Officer or Non-Officer Employee against any liability of any character asserted against or incurred by the Corporation or any such Director, Officer or Non-OfficerEmployee, or arising out of any such person's Corporate Status, whether or not the Corporation would have the power to indemnify such person against such liability under the DGCL or the provisions of this Article V.

SECTION 10. Other Indemnification. The Corporation's obligation, if any, to indemnify or provide advancement of Expenses to any person under this Article V as a result of such person serving, at the request of the Corporation, as a director, partner, trustee, officer, employee or agent of another corporation, partnership, joint venture, trust, employee benefit plan or other enterprise shall be reduced by any amount such person may collect as indemnification or

    20

    --------------------------------------------------------------------------------
    advancement of Expenses from such other corporation, partnership, joint venture,
    trust, employee benefit plan or enterprise (the "Primary Indemnitor"). Any
    indemnification or advancement of Expenses under this Article V owed by the
    Corporation as a result of a person serving, at the request of the Corporation,
    as a director, partner, trustee, officer, employee or agent of another
    corporation, partnership, joint venture, trust, employee benefit plan or other
    enterprise shall only be in excess of, and shall be secondary to, the
    indemnification or advancement of Expenses available from the applicable Primary
    Indemnitor(s) and any applicable insurance policies.

    ARTICLE VI

    Miscellaneous Provisions

SECTION 1. Fiscal Year. The fiscal year of the Corporation shall be determined by the Board of Directors.

SECTION 2. Seal. The Board of Directors shall have power to adopt and alter the seal of the Corporation.

SECTION 3. Execution of Instruments. All deeds, leases, transfers, contracts, bonds, notes and other obligations to be entered into by the Corporation in the ordinary course of its business without director action may be executed on behalf of the Corporation by the Chairman of the Board, if one is elected, the President or the Treasurer or any other officer, employee or agent of the Corporation as the Board of Directors or the executive committee of the Board may authorize.

SECTION 4. Voting of Securities. Unless the Board of Directors otherwise provides, the Chairman of the Board, if one is elected, the President or the Treasurer may waive notice of and act on behalf of the Corporation, or appoint another person or persons to act as proxy or attorney in fact for the Corporation with or without discretionary power and/or power of substitution, at any meeting of stockholders or shareholders of any other corporation or organization, any of whose securities are held by the Corporation.

SECTION 5. Resident Agent. The Board of Directors may appoint a resident agent upon whom legal process may be served in any action or proceeding against the Corporation.

SECTION 6. Corporate Records. The original or attested copies of the Certificate, By-laws and records of all meetings of the incorporators, stockholders and the Board of Directors and the stock transfer books, which shall contain the names of all stockholders, their record addresses and the amount of stock held by each, may be kept outside the State of Delaware and shall be kept at the principal office of the Corporation, at an office of its counsel, at an office of its transfer agent or at such other place or places as may be designated from time to time by the Board of Directors.

    21

    --------------------------------------------------------------------------------
    SECTION 7. Certificate. All references in these By-laws to the Certificate shall
    be deemed to refer to the Amended and Restated Certificate of Incorporation of
    the Corporation, as amended and/or restated and in effect from time to time.

SECTION 8. Exclusive Jurisdiction of Delaware Courts and the United States Federal District Courts for Certain Claims. Unless the Corporation consents in writing to the selection of an alternative forum, the Court of Chancery of the State of Delaware shall be the sole and exclusive forum for (i) any derivative action or proceeding brought on behalf of the Corporation, (ii) any action asserting a claim of breach of or based on a fiduciary duty owed by any current or former director, officer or other employee of the Corporation to the Corporation or the Corporation's stockholders, (iii) any action asserting a claim against the Corporation or any current or former director, officer or other employee or stockholder of the Corporation arising pursuant to any provision of the Delaware General Corporation Law or the Certificate or By-laws, or (iv) any action asserting a claim against the Corporation or any current or former director or officer or other employee of the Corporation governed by the internal affairs doctrine. Unless the Corporation consents in writing to the selection of an alternative forum, the federal district courts of the United States shall be the exclusive forum for the resolution of any complaint asserting a cause of action arising under the Securities Act of 1933, as amended. Any person or entity purchasing or otherwise acquiring any interest in shares of capital stock of the Corporation shall be deemed to have notice of and consented to the provisions of this Section 8.

SECTION 9. Amendment of By-laws.

(a) Amendment by Directors. Except as provided otherwise by law, these By-laws may be amended or repealed by the Board of Directors by the affirmative vote of a majority of the directors then in office.

(b) Amendment by Stockholders. These By-laws may be amended or repealed at any Annual Meeting, or special meeting of stockholders called for such purpose in accordance with these By-Laws, by the affirmative vote of not less than two thirds (2/3) of the outstanding shares entitled to vote on such amendment or repeal, voting together as a single class; provided, however, that if the Board of Directors recommends that stockholders approve such amendment or repeal at such meeting of stockholders, such amendment or repeal shall only require the affirmative vote of the majority of the outstanding shares entitled to vote on such amendment or repeal, voting together as a single class. Notwithstanding the foregoing, stockholder approval shall not be required unless mandated by the Certificate, these By-laws, or other applicable law.

SECTION 10. Notices. If mailed, notice to stockholders shall be deemed given when deposited in the mail, postage prepaid, directed to the stockholder at such stockholder's address as it appears on the records of the Corporation. Without limiting the manner by which notice otherwise may be given to stockholders, any notice to stockholders may be given by electronic transmission in the manner provided in Section 232 of the DGCL.

    22

    --------------------------------------------------------------------------------
    SECTION 11. Waivers. A written waiver of any notice, signed by a stockholder or
    director, or waiver by electronic transmission by such person, whether given
    before or after the time of the event for which notice is to be given, shall be
    deemed equivalent to the notice required to be given to such person. Neither the
    business to be transacted at, nor the purpose of, any meeting need be specified
    in such a waiver.

Updated effective as of December 9, 2022

    23

    Exhibit 99.1

[[Image Removed: LOGO]]

    Magenta Therapeutics Presents Positive MGTA-117 Clinical Data at the American
     Society of Hematology (ASH) Annual Meeting and Provides Program Updates

- MGTA-117 preliminary clinical results from 15 patients across three dose-escalation cohorts of the ongoing Phase 1/2 clinical trial shows single-agent activity with no dose-limiting toxicities; transition to patients with transplant-eligible AML/MDS expected in H1 2023 pending regulatory alignment -

- CD45 antibody-drug conjugate (CD45-ADC) IND-enabling studies are advancing -

    - MGTA-145 clinical trial for stem cell mobilization in sickle cell disease
     patients is progressing with data now expected to be shared H1 2023 -

    - Conference call and webcast scheduled for 8:30am ET / 7:30am CT on
     December 13, 2022 -

Cambridge, MA - December 12, 2022 - Magenta Therapeutics (Nasdaq: MGTA), a clinical-stage biotechnology company developing novel medicines designed to bring the curative power of stem cell transplant to more patients, highlights updated clinical data from the ongoing MGTA-117 Phase 1/2 dose-escalation clinical trial made in an oral presentation today at the American Society of Hematology 2022 Annual (ASH) Meeting in New Orleans and provides program updates across the portfolio.

"We have shown that a single dose of MGTA-117 binds target cells, depletes target cells, clears the body quickly as designed, and does so with a favorable tolerability profile in our ongoing Phase 1/2 clinical trial. We believe that these positive clinical data establishes proof-of-mechanism, and that we have reached an active dose. Target cell depletion is a critical measurement of success for MGTA-117, and we are encouraged by the levels of depletion we have observed in both the blood and the bone marrow of relapsed/refractory acute myeloid leukemia (AML) and myelodysplastic syndrome (MDS) patients. We are excited about our planned next steps to take MGTA-117 into transplant-eligible AML and MDS patients as well as into patients who are receiving gene therapy. We are thankful to all of the patients and families who have participated in our trial to date as well as our investigators and the clinical site staff, all of whom have contributed greatly to the advancement of MGTA-117 for patients," said Jason Gardner, President and Chief Executive Officer of Magenta Therapeutics. "Together with the progress we are making on CD45-ADC and MGTA-145, we are pleased with the momentum across our portfolio and the multiple anticipated inflection points for Magenta in the coming year."

    --------------------------------------------------------------------------------
    MGTA-117 Clinical Data and Continued Development

MGTA-117 is Magenta's most advanced targeted conditioning product candidate designed to deplete CD117-expressing target cells in the blood and/or bone marrow prior to a patient undergoing stem cell transplant or receiving an ex vivo gene therapy product. MGTA-117 is an anti-CD117 antibody conjugated to an amanitin payload. CD117, also known as c-Kit receptor, is highly expressed on hematopoietic stem cells, progenitor cells and cancer blast cells.

Current Phase 1/2 Patient Population and Potential Significance for Clinical Development

The ongoing Phase 1/2 clinical trial is in relapsed/refractory (R/R) AML and MDS. These patients are deemed ineligible for transplant due to active disease characterized by high numbers of cancer blast cells present in the bone marrow and in the bloodstream. Over 80% of patients with AML and MDS express the CD117 receptor on the surface of their cancer cells. In these patients, CD117+ target cells are a combination of cancer blast cells in the blood and bone marrow and non-malignant stem and progenitor cells in the bone marrow. MGTA-117 is designed to target all of these cells, and clinical evidence of depletion in this patient population provides valuable support that MGTA-117 will robustly deplete target cells in the proposed next phase of development in (i) transplant-eligible AML and MDS patients who have significantly lower numbers of cancer blast cells and (ii) gene therapy patients who have no cancer blast cells. Therefore, Magenta expects MGTA-117 to bind and deplete target cells in the bone marrow in these patient populations, and potentially achieve greater levels of depletion, at the same dose levels studied in R/R AML and MDS patients.

MGTA-117 Proof-of-Mechanism and Potential Active Dose

    - Participants Dosed & Available Data. As of December 1, 2022, a total of
     15 participants have been dosed with MGTA-117 in Cohorts 1, 2 and 3. All
     dosed participants contributed data in whole or in part to the
     preliminary data set depending on an individual's availability for
     collecting assessments. Eleven of the 15 dosed participants completed the
     dose-limiting toxicity safety observation period of 21 days. None of the
     four participant discontinuations were deemed to be related to MGTA-117.

    - Target Cell Binding. MGTA-117 bound to CD117-expressing target cells
     within 15 minutes after dosing in all participants as measured by a
     receptor occupancy (RO) assay. RO increased with higher dose levels of
     MGTA-117. The percentage of occupied CD117 receptors was greater, and the
     receptor occupancy was more durable at the higher dose levels of Cohorts
     2 and 3 as compared to Cohort 1 as expected.

    --------------------------------------------------------------------------------
     - Target Cell Depletion.

    - Depletion in Blood and Bone Marrow. MGTA-117 showed greater
     depletion of target cancer blast cells in the blood of
     participants in Cohorts 2 and 3 compared to Cohort 1. In addition,
     three out of the four participants in Cohort 3 for whom paired
     bone marrow samples were collected at baseline and post-dosing had
     depletion of cancer blast cells in both blood and bone marrow.
     This matched depletion response in the blood and bone marrow
     provides evidence of an active dose and dose-dependent depletion
     of CD117-expressing cells.

    - Two Transplant-Ineligible Participants Became Transplant-Eligible.
     Participants entering the clinical trial were considered
     ineligible for stem cell transplant and had active and persistent
     AML/MDS after receiving one or more anti-leukemic therapies. One
     relapsed/refractory MDS participant in Cohort 3 had a reduction of
     bone marrow cancer blast cells to a level that enabled the
     participant to become eligible for transplant. This is the trial's
     second participant who became eligible for transplant after a
     single dose of MGTA-117. The first participant, from Cohort 1, had
     relapsed/refractory AML and was previously disclosed.

    - Clearance. MGTA-117 was shown to be rapidly cleared from the body as
     expected. No MGTA-117 was detectable in the blood 48 hours after dosing
     in Cohorts 1 and 2, and over 95% of MGTA-117 was cleared in the blood 48
     hours after dosing at the higher dose level of Cohort 3. Rapid clearance
     of MGTA-117 was engineered into the molecule to ensure avoidance of
     depleting newly transplanted donor cells in allogeneic transplant or, in
     the case of gene therapy, of autologous gene-modified cells. In addition,
     the MGTA-117 ADC was shown to be stable in blood over time in all
     participants, and no free payload was detectable in the blood of any
     participants at any time point.

    - Tolerability. MGTA-117 was well-tolerated in all participants. No serious
     adverse events were deemed to be related to MGTA-117, and no
     dose-limiting toxicities were observed. Treatment-related adverse events
     deemed to be related to MGTA-117 were low-grade liver enzyme elevations,
     low-grade fever, and grade 3 and grade 4 leukopenia in two participants
     who had baseline grade 2 and grade 3 leukopenia, respectively. All
     instances of observed liver enzyme elevations were low-grade, transient
     and resolved without intervention, as expected.

    - Continued Trial Progress and Data Expectations. The Phase 1/2 clinical
     trial is currently enrolling in Cohort 4 (0.13 mg/kg) and Magenta
     anticipates presenting aggregate clinical data from the clinical trial,
     including Cohort 4, at a scientific conference in Q1 2023.

MGTA-117 Regulatory Engagement and Clinical Development Next Steps in Transplant-Eligible AML/MDS and Autologous Gene Therapy

As previously disclosed, Magenta has initiated formal engagements with regulatory agencies to transition MGTA-117 into a transplant-eligible AML and MDS patient population. Magenta also plans to engage regulators in H1 2023 for the purposes of initiating a MGTA-117 clinical trial in autologous ex vivo gene therapy.

    --------------------------------------------------------------------------------
     - Transplant-Eligible AML and MDS. Magenta anticipates that MGTA-117's
     pharmacokinetics (PK), pharmacodynamics (PD) and tolerability in Cohorts
     1-3 will support alignment with regulatory authorities to study MGTA-117
     in AML and MDS transplant-eligible patients. Importantly, the proposed
     study design in the transplant setting will allow for the measurement of
     depletion of CD117-expressing cells in the bone marrow after a single
     dose of MGTA-117 prior to reduced-intensity conditioning (RIC) and the
     ensuing allogeneic transplant. By depleting residual cancer blast cells
     prior to a standard RIC regimen, MGTA-117 has the potential to boost
     disease control prior to transplant and improve disease outcomes
     post-transplant. These potential positive outcomes could address the
     current significant unmet need associated with RIC-conditioning where AML
     and MDS patients relapse at a rate of 40%-50% within six months
     post-transplant1. Pending regulatory alignment, Magenta plans to share
     additional details of the proposed transplant-eligible MGTA-117 study
     design in Q1 2023.

    - Gene Therapy. Magenta expects to use the clinical data package from the
     ongoing Phase 1/2 trial, together with supporting insights from PK/PD
     modeling, to engage with regulators on a potential MGTA-117 clinical
     trial in autologous ex vivo gene therapy. In a gene therapy clinical
     trial, Magenta anticipates dosing patients with MGTA-117 to deplete stem
     and progenitor cells before the patient receives an infusion of
     gene-modified stem cells, with a goal of replacing the current
     standard-of-care conditioning that relies on high doses of
     chemotherapeutic agents such as busulfan, which is known to be
     carcinogenic. Magenta anticipates sharing more details in 2023 as
     development plans progress in collaboration with gene therapy partners.
     Magenta has existing clinical collaborations with gene therapy companies
     and anticipates entering into additional collaborations as MGTA-117
     development advances.

CD45-ADC IND-Enabling Plans

Magenta's CD45-ADC is a second targeted conditioning ADC, designed to selectively target and deplete both stem cells and immune cells, and is intended to replace the use of chemotherapy-based conditioning prior to stem cell transplant in patients with blood cancers and autoimmune diseases.

    - As previously disclosed, Good Manufacturing Practice (GMP) manufacturing
     and other investigative new drug application (IND)-enabling activities
     are ongoing for the CD45-ADC program. A Good Laboratory Practice (GLP)
     toxicology study is expected to be completed in H2 2023.

    - Magenta anticipates regulatory interactions prior to filing an IND and
     anticipates providing further details on the CD45-ADC program in 2023,
     including molecule design, key preclinical data, and timelines to IND.

    --------------------------------------------------------------------------------
    MGTA-145 Phase 2 Progress

Magenta is developing MGTA-145, in combination with plerixafor, to improve the process by which stem cells are released out of the bone marrow and into the bloodstream, known as stem cell mobilization. The mobilized cells are then collected and available for transplant. This is the first step for patients and is required for the majority of transplants and stem cell gene therapies.

    - Magenta, in partnership with bluebird bio, is enrolling patients in a
     Phase 2 clinical trial evaluating the ability of MGTA-145 in combination
     with plerixafor to mobilize stem cells for collection in patients with
     sickle cell disease.

    - Due to enrollment delays at the clinical sites that are unrelated to
     MGTA-145, Magenta anticipates disclosing clinical data in H1 2023.

Conference Call Information:

Magenta will host a conference call and webcast at 8:30 a.m. Eastern Time / 7:30 a.m. Central Time tomorrow, Tuesday, December 13, 2022 to review the MGTA-117 data presented at the 2022 ASH Annual Meeting.

To access the conference call, please register online at https://register.vevent.com/register/BI872661cff05d4191a7bb100830aae147. Upon registering, each participant will be provided with call details and a conference ID. The live webcast of the call and slide deck may be accessed at https://edge.media-server.com/mmc/p/hk2eojv2, or by visiting the Investors & Media section of the company's website at https://investor.magentatx.com. A replay of the webcast will be available shortly after the conclusion of the call and will be archived on the Events & Presentations page.

    1 Scott, Journal of Clinical Oncology 2017.
     https://pubmed-ncbi-nlm-nih-gov.univ-eiffel.idm.oclc.org/28380315/

About Magenta Therapeutics

Magenta Therapeutics is a clinical-stage biotechnology company developing medicines designed to bring the curative power of stem cell transplant to more patients with blood cancers, genetic diseases and autoimmune diseases. Magenta is combining leadership in stem cell biology and biotherapeutics development with clinical and regulatory expertise to revolutionize blood and immune reset to allow more patients to take advantage of the curative potential of stem cell transplant and potentially improve eligibility for future gene therapies.

Magenta is based in Cambridge, Mass. For more information, please visit www.magentatx.com.

    --------------------------------------------------------------------------------
    Follow Magenta on Twitter: @magentatx

Forward-Looking Statements

This press release contains forward-looking statements within the meaning of The Private Securities Litigation Reform Act of 1995, as amended. These statements include, without limitation, implied and express statements relating to: Magenta's future business expectations, plans and prospects; the potential of, and expectations for, Magenta's product candidate pipeline; proposed study designs; potential collaborations with other companies; the potential benefits and expected performance of Magenta's product candidates and programs; the development of product candidates and advancement of preclinical and clinical programs, including, without limitation, patient enrollment; expectations, plans and timing for preclinical activities, clinical trials and related results involving Magenta's product candidates; expectations, plans and timing for the generation, receipt and disclosure of preclinical and clinical trial data, toxicology results, and other results involving Magenta's product candidates; timing for the disclosure of developmental timelines, developmental plans and program updates regarding Magenta's product candidates; the completion of dose-limiting toxicity observation periods; regulatory interactions and alignment with regulators; the use of clinical data and supporting insights from PK/PD modeling in regulatory engagement and advancement into transplant eligible AML and MDS patients and gene therapy patients; that MGTA-117's pharmacokinetics (PK), pharmacodynamics (PD) and tolerability in Cohorts 1-3 will support alignment with regulatory authorities to study MGTA-117 in AML and MDS transplant-eligible patients; that clinical evidence of depletion in the AML and MDS patient population provides valuable support that MGTA-117 will robustly deplete target cells in the proposed next phase of development in (i) transplant-eligible AML and MDS patients who have significantly lower numbers of cancer blast cells and (ii) gene therapy patients who have no cancer blast cells, and Magenta's expectation that MGTA-117 will bind and deplete target cells in the bone marrow in these patient populations at the same or lower dose levels studied in R/R AML and MDS patients; the planned transition of the MGTA-117 Phase 1/2 clinical trial into transplant-eligible AML and MDS patients, as well as into patients who are receiving gene therapy; and the predictive value of Magenta's MGTA-117 preclinical modeling.

Words such as "anticipate," "believe," "continue," "could," "designed," "endeavor," "estimate," "expect," "intend," "may," "might," "plan," "potential," "predict," "project," "seek," "should," "target," "preliminary," "will," "would" and similar expressions are intended to identify forward-looking statements. The express or implied forward-looking statements included in this press release are only predictions and are subject to a number of risks, uncertainties and assumptions, including, without limitation: uncertainties inherent in preclinical and clinical trials and in the availability and timing of data from ongoing and planned clinical and

    --------------------------------------------------------------------------------
    preclinical trials; the ability to initiate, enroll, conduct or complete ongoing
    and planned preclinical and clinical trials; vulnerability and/or fragility of,
    and the presence of underlying disorders in, the patient population for the
    clinical trials of Magenta's product candidates, including the MGTA-117 Phase
    1/2 clinical trial in patients with relapsed/refractory AML and MDS; that
    preliminary data from Magenta's clinical trials may change materially following
    a more comprehensive review of the data; the delay of any current or planned
    preclinical or clinical trials, or the delay in development of Magenta's product
    candidates; whether results from preclinical or earlier clinical trials will be
    predictive of the results of future trials; interactions with regulatory
    agencies such as the U.S. Food and Drug Administration; the expected timing of
    submissions for regulatory approval to conduct or continue trials or to market
    products; Magenta's ability to successfully demonstrate the safety and efficacy
    of its product candidates; whether Magenta's cash resources will be sufficient
    to fund Magenta's foreseeable and unforeseeable operating expenses and capital
    expenditure requirements; and risks, uncertainties and assumptions regarding the
    impact of the continuing COVID-19 pandemic on Magenta's business, operations,
    preclinical activities, clinical trials, strategy, goals and anticipated
    timelines. These and other risks are described in additional detail in Magenta's
    Quarterly Report on Form 10-Q for the quarter ended September 30, 2022 and its
    other filings made with the Securities and Exchange Commission from time to
    time. Any forward-looking statements contained in this press release represent
    Magenta's views only as of today and should not be relied upon as representing
    its views as of any subsequent date. Magenta explicitly disclaims any obligation
    to update any forward-looking statements, except to the extent required by law.

Contact:

Jill Bertotti, Real Chemistry (advisor to Magenta) 714-225-6726 [email protected]

    Exhibit 99.2

    [[Image Removed: LOGO]]

Exhibit 99.2 MGTA-117 Clinical Data Update ASH Annual Meeting December 13, 2022 (NASDAQ: MGTA)

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

Agenda & Introductions Introduction Review of MGTA-117 Phase 1/2 Clinical Results - Cohorts 1-3 Next Steps Q&A Session Jason Gardner, D.Phil. CEO, President and Co-founder Lisa Olson, Ph.D. Chief Scientific Officer Shawn Rose, M.D., Ph.D. Senior Vice President, Clinical Development Steve Mahoney, J.D., M.B.A. Chief Financial and Operating Officer 2

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

Forward-Looking Statements This presentation contains forward-looking statements within the meaning of The Private Securities Litigation Reform Act of 1995, as amended. These statements include, without limitation, implied and express statements relating to: Magenta's future business expectations, plans and prospects; the potential of, and expectations for, Magenta's product candidate pipeline; the goals, potential benefits and expected performance of Magenta's product candidates and programs; the potential of Magenta's product candidates and programs to drive expansion of patient eligibility across stem cell transplant and gene therapies; the potential of stem cell transplant as a platform for advancing cell and gene therapies; the eligibility of future patient populations with improved conditioning; MGTA-117's potential to improve upon current conditioning approaches, including the potential to reduce or eliminate the need for chemo- or radiation-based conditioning; the development of product candidates and advancement of preclinical and clinical programs, including, without limitation, patient enrollment; expectations, plans and timing for preclinical activities and clinical trials involving Magenta's product candidates; expectations, plans and timing for the generation, receipt and disclosure of preclinical and clinical data and other results involving Magenta's product candidates; timelines and expectations for patient dosing, dosing regimens and administration; regulatory engagement, interactions and alignment with regulators; the expected transition of MGTA-117 into transplant-eligible patients and gene therapy patients; that MGTA-117's evidence of depletion in the Relapsed / Refractory AML and MDS patient population provides an important readthrough for the next phase of development; that MGTA-117 is expected to more efficiently target CD117+ blast and/or stem cells in the bone marrow of transplant-eligible AML and MDS patients and gene therapy patients due to lower number or absence of blasts in those patient populations; potential study designs and partners for use of MGTA-117 in transplant eligible patients and gene therapy; and plans to develop in gene therapy and collaborations with Magenta's partners. Words such as "anticipate," "believe," "continue," "could," "designed," "endeavor," "estimate," "expect," "goal," "intend," "may," "might," "plan," "potential," "predict," "project," "seek," "should," "target," "will," "would" and similar expressions are intended to identify forward-looking statements. The express or implied forward-looking statements included in this presentation are only predictions and are subject to a number of risks, uncertainties and assumptions, including, without limitation: uncertainties inherent in preclinical and clinical trials and in the availability and timing of data from ongoing and planned clinical and preclinical trials; the ability to initiate, enroll, conduct or complete ongoing and planned preclinical and clinical trials; vulnerability and/or fragility of, and the presence of underlying disorders in, the patient population for the clinical trials of Magenta's product candidates, including the MGTA-117Phase 1/2 clinical trial in patients with relapsed/refractory AML and MDS; that preliminary data from Magenta's clinical trials may change materially following a more comprehensive review of the data; the delay of any current or planned preclinical or clinical trials, or the delay in development of Magenta's product candidates; whether results from preclinical or earlier clinical trials will be predictive of the results of future trials; interactions with regulatory agencies such as the U.S. Food and Drug Administration; the expected timing of submissions for regulatory approval to conduct or continue trials or to market products; Magenta's ability to successfully demonstrate the safety and efficacy of its product candidates; whether Magenta's cash resources will be sufficient to fund Magenta's foreseeable and unforeseeable operating expenses and capital expenditure requirements; and risks, uncertainties and assumptions regarding the impact of the continuing COVID-19 pandemic on Magenta's business, operations, preclinical activities, clinical trials, strategy, goals and anticipated timelines. These and other risks are described in additional detail in Magenta's Quarterly Report on Form 10-Q for the quarter ended September 30, 2022 and its other filings made with the Securities and Exchange Commission from time to time. Any forward-looking statements contained in this presentation represent Magenta's views only as of the date of this presentation and should not be relied upon as representing its views as of any subsequent date. Magenta explicitly disclaims any obligation to update any forward-looking statements, except to the extent required by law. 3

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

Improve Outcomes and Expand Use of Stem Cell Transplant & Gene Therapy Transplant could be a path to a cure Barriers to transplant Opening the door to a cure 90,000 stem cell transplants/year globally1 Blood Cancers (AML, MDS) Gene Therapy (Sickle Cell Disease) Autoimmune (Multiple Sclerosis) ~60% of eligible patients receive transplant3 <1% of eligible patients receive transplant3 Significant Limitations of Current Conditioning Options: Many patients need high intensity chemotherapy conditioning to prepare for transplant ~20% Mortality associated with chemotherapy conditioning regimens2 Magenta addresses key factors keeping patients from accessing HSCT and better outcomes 4 HSCT: Hematopoietic Stem Cell Transplant Source: 1 CIBMTR, EBMT, and APBMT Transplant Registry Data (2018), 2 Scott, BL. Biol Blood Marrow Transplant. 2020, 26 (3): S11; 3 Magenta Market Research, Data on File (2020) 4

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

Differentiated Pipeline with Potentially First-in-ClassADC Targeted Conditioning Disease Area Preclinical IND-Enabling Phase 1 Phase 2 Clinical Trial Partners Product Rights MGTA-117 Targeted Conditioning: MGTA-145 Stem Cell Mobilization and Collection: CD45-ADC Targeted Conditioning: Research Platform: Blood Cancers Lysosomal Disorders Hemoglobinopathies Sickle Cell Disease Heme Malignancies Autoimmune Disease Novel Conditioning & Translational Stem Cell Sciences AML/MDS1 Gene Therapy Gene Therapy Gene Therapy 1 AML/MDS: Acute Myeloid Leukemia or Myelodysplastic Syndromes Confidential 5

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

TARGETED CONDITIONING MGTA-117

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

MGTA-117: Antibody-Drug Conjugate Designed to Selectively Deplete Target Cells TARGETED BLOCKING Selective binding to CD117+ target cells Blocks Stem Cell Factor (SCF) binding Short half-life to rapidly clear the ADC from the body Short half-life to rapidly clear the ADC from the body Amanitin Payload: Direct depletion of target cells POTENT RAPIDLY CLEARED Target CD117 Target Cells - Stem cells Cancer blast cells Dual Mechanism Depletion ADC-mediated cytotoxicity Blocking of stem cell factor1 Disease Applications Blood cancers Gene therapy Source: 1 Bertelsen et al. ASH 2022 Abstract 7

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

Multiple CD117+ Target Cells in Bone Marrow and Blood Across Diseases Relapsed / Refractory AML & MDS Patients High numbers of cancer blast cells in blood and bone marrow Transplant-Eligible AML & MDS Patients Limited cancer blast cells in bone marrow Gene Therapy Patients No cancer blast cells in blood or bone marrow BLOOD BONE MARROW CD117+ Cancer blast cells CD117+ Stem cells CD117+ Erythroid progenitor cells Red blood cells Sources: Kent et al. Clin Cancer Res (2008) 14 (7): 1926-1930, Wells et al. Am J Clin Pathol (1996) 106(2):192-5, Treatment of relapsed or refractory acute myeloid leukemia - UpToDate Confidential 8

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

Current Data Set & Dosing Regimen Expected to Support Move to Transplant and Gene Therapy Studies Dec 2022 AML / MDS Cohorts 1-3 Data at ASH Data submitted to regulatory agencies Enables Additional AML Cohort Data at a scientific conference in Q1 '23 Regulatory alignment on AML / MDS transplant study expected in Q1 '23 Regulatory engagement expected to align on developing MGTA-117 for gene therapy in H1 '231 1 Assuming partner and alignment on regulatory feedback 9

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

American Society of Hematology Helping hematologists conquer blood diseases worldwide MGTA-117,an Anti-CD117 Antibody-Drug Conjugated With Amanitin, in Participants With Relapsed/Refractory Adult Acute Myeloid Leukemia (AML) and Myelodysplasia With Excess Blasts (MDS-EB): Safety, Pharmacokinetics and Pharmacodynamics Initial Findings From a Phase 1/2 Study Peter Westervelt, MD, PhD1; Partow Kebriaei, MD2; Mark Juckett, MD3; Andrew S. Artz, MD4; Onyee Chan, MD5; Philip L. McCarthy, MD6; Sherif Farag, MD, PhD7; Anurag K. Singh, MD8; Eytan Stein, MD9; Ji Hyun Lee, MD, MPH10; Alison Occhiuti, MS10; Jeanie Tang, BS10; David Santos, BS10; Kirk Bertelsen, PhD10; Balaji Mahender, BPharm, MS10; Nicole Henry, BSN, RN10; Shawn Rose, MD, PhD10 1Washington University, St. Louis, MO, USA; 2The University of Texas MD Anderson Cancer Center, Houston, TX, USA; 3University of Minnesota, Minneapolis, MN, USA; 4City of Hope, Duarte, CA, USA; 5H. Lee Moffitt Cancer Center and Research Institute, Tampa, FL, USA; 6Roswell Park Comprehensive Cancer Center, Buffalo, NY, USA; 7IU Simon Cancer Center, Indianapolis, IN, USA; 8University of Kansas Medical Center, Kansas City, KS; 9Memorial Sloan Kettering Cancer Center, New York, NY, USA; 10Magenta Therapeutics, Cambridge, MA, USA

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

MGTA-117: Phase 1/2 Clinical Trial Design Phase 1/2 Study in CD117+ Relapsed / Refractory AML and MDS-EB Key Inclusion / Exclusion Criteria CD117+ R/R AML or MDS-EB Age 18-75 with identified HSCT donor ECOG performance status ?2 No significant organ dysfunction No systemic infections No APL, active CNS leukemia or chloroma Washouts for prior anti-leukemic therapies a Up to 8 cohorts, up to 42 participants may be enrolled. Doses: 0.02-0.40 mg/kg. PD, pharmacodynamics; PK, pharmacokinetics; RO, receptor occupancy; R/R, relapsed refractory; AML, acute myeloid leukemia; MDS-EB, Myeloid dysplastic syndrome with excess blasts, HSCT: hematopoietic stem cell transplant, ECOG: Eastern Cooperative Oncology Group, APL, acute promyelocytic leukemia; CNS, central nervous system Cohort 5* Complete 0.02 mg/kg 0.04 mg/kg 0.08 mg/kg 0.13 mg/kg 0.19 mg/kg Cohort 4 Cohort 3 Cohort 2 Cohort 1 Study Design Multi-center, U.S. Study Open Label Single Ascending Dose(s) 3+3 Cohort Design Modified Fibonacci Sequence for Dosing Key Objectives Target Engagement (RO) Robust Cell Depletion (PD) Rapid Clearance (PK) Tolerability/Safety 11

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

MGTA-117 Phase 1/2 Schedule of Assessments Baseline Blood Baseline Bone Marrow Screening Peripheral Blood for RO, PK Peripheral Blood (Flow analysis) Peripheral Blood (Flow analysis) Peripheral Blood (Flow analysis) MGTA-117 Dose (IV) Bone Marrow Collection Bone Marrow Collection (Optional) End of DLT Observation Period Note: Protocol amendment implemented to change bone marrow biopsy collection from 14 days (Cohort 1) to 7 days (Cohort 2 onwards) after dosing; samples not always collected depending on the health of the participant 12

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

Participant Disposition Through the DLT Observation Period *Interim data through Cohort 3 is subject to further verification and analysis Cohort 3 MGTA-117 0.076 mg/kg N=5 Cohort 2 MGTA-117 0.04 mg/kg N=6 Cohort 1 MGTA-117 0.02 mg/kg N=4 Participant discontinuations from the study were all considered unrelated to MGTA-117 a Data from discontinued participants contributed to study outcome assessments (safety, PK, RO, PD) DLT, Dose Limited Toxicity Completed DLT Observation Period (N=5) Under Evaluation for DLT (N=0") Discontinued (N=0) Completed DLT Observation Period (N=3) Discontinued (N=3") Completed DLT Observation Period (N=3) Discontinued (N=1") 13

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

Baseline Participant Demographics and Disease Characteristics R/R AML study population has a poor prognosis with a high burden of disease and multiple previous lines of therapy Characteristics Age, Years, Median (range) Sex, Male/Female Total (N=15) 65 (26-74) Diagnosis, n, AML/MDS ELN Risk Classification for AML Adverse Intermediate Unknown Months Since Diagnosis, Median (range) Bone Marrow Blast % at Baseline, Median (range) Prior Lines of Therapy, Median (range) 6/9 13/2 553 3 9 (3-38) 24 (5-60)2.5 (1-8) ELN: European LeukemiaNet 14

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

MGTA-117 Rapidly Bound to CD117+ Cancer Blast Cells in Blood %Receptor Occupancy Receptor Occupancy (N=15) 125- 100- 75- 50- 25- A Cohort 3 (n=5) Cohort 2 (n=6) a' Cohort 1 (n=4) 0 0 8 16 24 32 40 48 mean + standard deviation Time (hours) Key Results Binding of CD117+ cells observed in all participants at 15-minute initial measurement after dosing RO decline observed in all dosed participants indicating internalization of MGTA-117 Higher receptor occupancy was observed in Cohorts 2 and 3 relative to Cohort 1 Longer duration of receptor occupancy was observed in Cohorts 2 and 3 relative to Cohort 1 RO, receptor occupancy. 15

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

MGTA-117 Depleted CD117+ Cancer Blast Cells in Peripheral Blood Depletion in Blood (N=14) %Change in CD117+ Blasts Relative to Baseline 100 -80 -60 -40 -20 0 3000 Cohort 3 (n=5) Cohort 2 (n=5) Cohort 1 (n=4) Key Results Depletion of CD117+ cancer blast cells was observed in the blood in Cohorts 2 and 3 Higher depletion in Cohorts 2 and 3 compared to Cohort 1 observed, consistent with higher and longer receptor occupancy in the blood Analysis by flow cytometry; percent change is the maximum change at any time point up to Day 21 relative to baseline Cancer blast cells defined as CD45+CD34brightCD33+CD117+ 16

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

MGTA-117 Depleted Cancer Blast Cells in the Bone Marrow Cohort 1 Cohort 2 Cohort 3 Absolute % change from baseline Key Results Greater depletion was observed in the bone marrow in Cohort 3 participants compared to previous cohorts MGTA-117 depleted cancer blast cells in blood AND bone marrow in 3 participants (#11, 13, 14) in Cohort 3 Two participants became transplant eligible after receiving a single dose of MGTA-117 (circled participants) Analysis by bone marrow morphology. Timeframe of biopsy: at baseline, Day 14 (Cohort 1), Days 7 (Cohort 2 and beyond) 17

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

A Single Dose of MGTA-117 in Participants with Relapsed/Refractory AML/MDS Resulted in Two Participants Becoming Transplant Eligible Case Study: 58-year-old male with FLT3 mutation and treatment refractory AML (Cohort 1) Diagnosis Disease and Treatment Course Transplant 37% BM cancer blast cells 18% BM blasts (Partial Remission) BM & blood blasts persist 6% BM blasts at Trial Screening Day 14 1% BM blasts Day 28 BM CRi w/ MRD+ Engraftment Day 30 Engraftment Day 100 Treatment 1 Treatment 2 MGTA-117 Dose (Day 1) Myeloablative Conditioning HSCT MRD+ Relapse Day 137 Case Study: 73-year-old female with ASXL1, BCOR, U2AF1 mutations and treatment refractory MDS (Cohort 3) Diagnosis 17% BM blasts Disease and Treatment Course BM & blood blasts persist 10% BM blasts at Trial Screening Day 7 3% BM blasts (Marrow CR) Transplant Pending (as of 12/06/2022) Treatment 1 MGTA-117 Dose (Day 1) AML: Acute Myeloid Leukemia; BM: Bone Marrow; CRi: Complete Remission with incomplete hematologic recovery; HSCT: Hematopoietic Stem Cell Transplantation; MAC: Myeloablative Conditioning; MDS: Myelodysplastic Syndrome 18

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

MGTA-117 Was Well-Tolerated in Cohorts 1-3 Cohort 1 Cohort 2 Cohort 3 Category (N=4) (N=6) (N=5) n (%) n (%) n (%) Participants with Treatment-Emergent Adverse Events (TEAEs) TEAEs classified as dose-limiting toxicities Serious AEs (all unrelated) Grade 3 or higher TEAEs TEAEs resulting in death (all unrelated) AML disease progression, N=2; sepsis, N=1 TEAEs in >20% of Participants Regardless of Causality Nausea (27%), constipation (27%), hypokalaemia (27%), hypomagnesaemia (20%) disease progression (20%), liver enzyme elevation (20%), headache (20%) Leukopenia (20%) Participants with MGTA-117 Related TEAEs Grade 2 (fever) Grade 3 (leukopenia) Grade 4 (leukopenia) Grade 5 Total 1 One participant (Cohort 2) had a Grade 2 liver enzyme elevation not reflected in table; pending site data entry 2 Participant had severe neutropenia with Grade 2 leukopenia at baseline 3 Participant had severe neutropenia with Grade 3 leukopenia at baseline TEAEs observations are from independent participants TEAEs: Treatment- Emergent Adverse Events; AEs: Adverse Events. Safety and Tolerability Treatment-emergent AEs considered consistent with underlying disease No unexpected AEs, treatment-related serious AEs, treatment-related deaths, or dose-limiting toxicities (DLTs) were observed No treatment-related infusion reactions were observed No MGTA-117 related TEAEs led to discontinuation Liver enzyme elevations were expected, transient, low-grade, and resolved without any intervention 19

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

Summary of Phase 1/2 Trial Results - Cohorts 1-3 Goals Clinical Observations Target Engagement: Measurable MGTA-117 binding to CD117+ target cells in Engage the blood of all participants Deplete Cell Depletion: MGTA-117 depletes target cells in the blood and bone marrow Clear Pharmacokinetics: MGTA-117 rapidly clears from the blood; no detectable payload indicates the ADC is stable in the blood Well Tolerated Tolerability: No unexpected or serious treatment-related adverse events were reported; no dose-limiting toxicities (DLTs) Source: 15 participants dosed with MGTA-117, 11 participants completed the safety evaluation period; preliminary data, subject to further verification and analysis 20

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

MGTA-117 Depletion in the R/R Patient Population Provides an Important Readthrough for the Next Phase of Development Relapsed MDS / Refractory Patients AML & blast High numbers cells of cancer in blood and bone marrow BLOOD BONE MARROW DEPLETION in blood and bone marrow BLOOD BONE MARROW CD117+ Cancer blast cells CD117+ Stem cells CD117+ Erythroid progenitor cells Confidential Red blood cells 21

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

Potential for Robust Bone Marrow Depletion in Transplant-Eligible AML/MDS and Gene Therapy Patients MGTA-117 expected to more efficiently target CD117+ blast and/or stem cells in bone marrow due to lower number or absence of blasts MGTA-117 targets CD117+ cells for DEPLETION in bone marrow Transplant MDS- Eligible Patients AML & Limited cancer blast cells in bone marrow Gene Therapy Patients No cancer blast cells in blood or bone marrow Only stem cells and progenitor cells BLOOD BLOOD BONE MARROW BONE MARROW CD117+ Cancer blast cells CD117+ Stem cells CD117+ Erythroid progenitor cells Confidential Red blood cells 22

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

Anticipated Further Development in Transplant-Eligible and Gene Therapy Patients Current Study Relapsed/Refractory Acute Myeloid Leukemia (R/R AML) or (MDS-EB) Enrolling Complete Complete Complete Cohort 5* Cohort Expected Alignment with regulators on path to transplant Anticipated Next Steps: Studies in Transplant-Eligible Patients & Gene Therapy Conditioning Transition to Transplant-Eligible AML and MDS patients Transition to Gene Therapy Clinical Studies 23

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

Potential to Address Sub-Optimal Outcomes in AML/MDS and Gene Therapy Potential Outcomes Potential Impact of MGTA-117 MG stered as a single agent, single dose AML & MDS Gene Therapy Reduce disease burden prior to Reduced Intensity Conditioning (RIC) by depletion of target cancer blast cells and stem cells Deplete stem and progenitor cells in the bone marrow without busulfan Improve relapse and outcomes post-transplant Better outcomes vs. SOC conditioning with expanded patient eligibility Confidential 24

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

MGTA-117 NEXT STEPS Confidential

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

MGTA-117 Summary of Cohorts 1-3 and Next Steps Single Agent Depletion Activity Transition to Transplant-Eligible AML & MDS Advance into Gene Therapy MGTA-117 has shown target cell depletion in the blood and bone marrow, providing evidence of an active dose MGTA-117 is the first targeted ADC in the clinic as a single agent prior to transplant and has been well tolerated Plan to transition an active dose to patients with transplant-eligible AML/MDS prior to receiving a RIC allogeneic transplant Regulatory feedback expected in Q1 2023 Transplant-eligible study design and data expectations to be shared in Q1 2023 Plan to develop with gene therapy partners Anticipate engaging regulatory agencies with the same data package (Cohorts 1-3)in H1 2023 Confidential 26

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

Acknowledgements Thank you to our trial participants and their loved ones Thank you to the 117-HEM-101 trial investigators and their site staff MGT CD117 Receptor Stem Cell Factor (SCF) STEM CELL 27

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

Q&A

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

APPENDIX Confidential

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

MGTA-117 Rapidly Cleared From the Blood Without ADC Degradation Pharmacokinetics (n=15) 0 500 1000 1500 MGTA-117 Concentration (ng/ml) Cohort 1 (n=4) Cohort 2 (n=6) Cohort 3 (n=5) T1/2 ?10 hours 0 8 16 24 32 40 48 Time (hours) mean + standard deviation Key Results - Maximum concentrations of MGTA-117 were reached within an average of 2 hours after dosing (n=15) - MGTA-117 showed rapid clearance - >95% clearance 48 hours after dosing - Confirmed in vivo stability of ADC: no free payload detectable at any timepoint after dosing (n=15) 30 Confidential

    --------------------------------------------------------------------------------
     [[Image Removed: LOGO]]

Availability of Data Across Phase 1/2 Cohorts 1-3 Participant discontinuations from the study were all deemed unrelated to MGTA-117 PARTICIPANTS DOSED (N=15 for RO, Tolerability; N=12 for PK) Participants completing DLT observation period (n=11 of 15) Cohort 3 MGTA-117 0.08 mg/kg N=5 Cohort 2 MGTA-117 0.04 mg/kg N=6 Cohort 1 MGTA-117 0.02 mg/kg N=4 5 participants dosed All participants completed the DLT observation period 6 participants dosed 3 participants completed the DLT observation period 3 participants discontinued, all deemed unrelated to MGTA-117 - 2 due to AML disease progression (1 death), 1 due to sepsis (1 death) 4 participants dosed 3 participants completed the DLT observation period 1 patient discontinued due to AML disease progression (1 death), deemed unrelated to MGTA-117 PB n=5; BM n=4 PB n=3; BM n=3 PB n=3; BM n=2 Total (includes all available data) PB n=14; BM n=9 RO: receptor occupancy; DLT: dose-limiting toxicity PK: pharmacokinetics Source: Magenta clinical data on file as of 11/21/2022 Available Depletion Data: Peripheral Blood (PB) Confidential Bone Marrow (BM) 31

Dec 09, 2022

<img alt="comtex tracking" height="1" src="https://prt.comtex.com/prt.php?ContentID=420705375&SourceID=2254&EndPointID=2566&DateTime=2022-12-13T12:00:07&Headline=8-K:%2520Magenta%2520Therapeutics,%2520Inc." width="865"/>

COMTEX_420705375/2254/2022-12-13T12:00:07

(c) 1995-2022 Cybernet Data Systems, Inc. All Rights Reserved

EDGAR Online-Prospectus and Proxies
Thursday, November 2, 2023 80061 mots, p. NA

S-1/A: Tidal Commodities Trust I.

(EDGAR Online via COMTEX) -- As filed with the Securities and Exchange Commission on November 2, 2023

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

Approximate date of commencement of proposed sale to the public: As soon as practicable after the effective date of this Registration Statement.

If any of the securities being registered on this Form are to be offered on a delayed or continuous basis pursuant to Rule 415 under the Securities Act of 1933, check the following box. ?

If this Form is filed to register additional securities for an offering pursuant to Rule 462(b) under the Securities Act, check the following box and list the Securities Act registration statement number of the earlier effective registration statement for the same offering. ?

If this Form is a post-effective amendment filed pursuant to Rule 462(c) under the Securities Act, check the following box and list the Securities Act registration statement number of the earlier effective registration statement for the same offering. ?

If this Form is a post-effective amendment filed pursuant to Rule 462(d) under the Securities Act, check the following box and list the Securities Act registration statement number of the earlier effective registration statement for the same offering. ?

Indicate by check mark whether the registrant is a large accelerated filer, an accelerated filer, a non-accelerated filer, smaller reporting company, or an emerging growth company. See the definitions of "large accelerated filer," "accelerated filer," "smaller reporting company," and "emerging growth company" in Rule 12b-2 of the Exchange Act.

Large accelerated filer ? Accelerated filer ? Non-accelerated filer ? Smaller reporting company ? Emerging growth company ?

If an emerging growth company, indicate by check mark if the registrant has elected not to use the extended transition period for complying with any new or revised financial accounting standards provided pursuant to Section 7(a)(2)(B) of the Securities Act. ?

The Registrant hereby amends this Registration Statement on such date or dates as may be necessary to delay its effective date until the Registrant shall file a further amendment which specifically states that this Registration Statement shall thereafter become effective in accordance with Section 8(a) of the Securities Act or until this Registration Statement shall become effective on such date as the Commission, acting pursuant to said Section 8(a), may determine.

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

Hashdex Bitcoin Futures ETF (the "Fund" or "DEFI") is designed to provide investors with a means to gain price exposure to the bitcoin market. The Fund issues shares ("Shares") that trade on NYSE Arca stock exchange ("NYSE Arca") under the symbol "DEFI." Shares can be purchased and sold by investors through their broker-dealer. Under its current investment objective, the Fund will not hold, purchase, or otherwise own any bitcoin. Purchasing Shares of the Fund is subject to the risks of bitcoin as well as the additional risks of investing in the Fund.

The Fund's investment objective is for changes in the Shares' net asset value ("NAV") to reflect the daily changes of the price of the Hashdex U.S. Bitcoin Futures Fund Benchmark (the "Benchmark"), less expenses from the Fund's operations. The Benchmark is currently the average of the closing settlement prices for the first to expire and second to expire bitcoin futures contracts ("Bitcoin Futures Contracts") listed on the Chicago Mercantile Exchange Inc. ("CME"). The Bitcoin Futures Contracts that at any given time make up the Benchmark are referred to hereinafter as the "Benchmark Component Futures Contracts." Under normal market conditions, the Fund invests in Benchmark Component Futures Contracts and cash and cash equivalents. Because the Fund's investment objective is to track the price of the Benchmark by investing in Benchmark Futures Contracts rather than bitcoin, changes in the price of the Shares will vary from changes in the spot price of bitcoin.

An investment in the Fund is subject to the risks of an investment in futures contracts, which are complex instruments that are often subject to a high degree of price variability. Because the price of Bitcoin Futures Contracts is linked to the price of bitcoin, an investment in the Fund may be riskier than other exchange-traded products that do not hold financial instruments related to bitcoin and may not be suitable for all investors. In addition, Bitcoin Futures Contracts may experience pronounced and swift price changes. Accordingly, there is a potential for movement in the price of Shares between the time an investor places an order to purchase or sell with its broker-dealer and the time of the actual purchase or sale resulting from the price volatility of Bitcoin Futures Contracts.

Investing in the Fund involves significant risks. See "What Are the Risk Factors Involved with an Investment in the Fund?" beginning on page 11. The Fund is not a mutual fund registered under the Investment Company Act of 1940, and Fund Shareholders will not be afforded the protections associated with ownership of shares in a registered investment company. See "The Fund is not a registered investment company, so you do not have the protections of the Investment Company Act of 1940" on page 18.

THE COMMODITY FUTURES TRADING COMMISSION HAS NOT PASSED UPON THE MERITS OF PARTICIPATING IN THIS POOL NOR HAS THE COMMISSION PASSED ON THE ADEQUACY OR ACCURACY OF THIS DISCLOSURE DOCUMENT.

NEITHER THE SECURITIES AND EXCHANGE COMMISSION ("SEC") NOR ANY STATE SECURITIES COMMISSION HAS APPROVED OR DISAPPROVED OF THE SECURITIES OFFERED IN THIS PROSPECTUS OR DETERMINED IF THIS PROSPECTUS IS TRUTHFUL OR COMPLETE. ANY REPRESENTATION TO THE CONTRARY IS A CRIMINAL OFFENSE.

The Fund is a series of the Tidal Commodities Trust I (the "Trust"). Shareholders have no voting rights with respect to the Trust or the Fund except as expressly provided in the Trust's First Amended and Restated Declaration of Trust and Trust Agreement (the "Trust Agreement"). The sponsor of the Fund is Tidal Investments LLC (f/k/a Toroso Investments, LLC, hereinafter the "Sponsor"), which receives a management fee. The principal office address and telephone number of both the Fund and the Sponsor is 234 West Florida Street, Suite 203, Milwaukee, Wisconsin 53204 and (844)-986-7700. Tidal ETF Services LLC ("Tidal" or the "Administrator") provides administrative services to the Fund and has also engaged the Fund's Sub-Administrator (as defined below). Tidal assists the Fund and the Sponsor with certain functions and duties relating to marketing, which include the following: marketing, sales strategy, and related services. Hashdex Asset Management Ltd. ("Hashdex") will serve as the Fund's Digital Asset Adviser and will assist the Sponsor and Administrator with research and investment analysis regarding bitcoin and bitcoin markets for use in the marketing of the Fund. Hashdex will also provide the Fund with branding, marketing services including, but not limited to, the issuance of press releases, preparation of website data content, holding promotional webinars and engaging in promotional activities through social media outlets. Hashdex has no role in maintaining, calculating or publishing the Benchmark. Hashdex also has no responsibility for the investment or management of the Fund's investment portfolio or for the overall performance or operation of the Fund.

The Sponsor, Administrator, Digital Asset Adviser, and Teucrium Trading, LLC ("Prior Sponsor") have entered into an agreement, as amended (the "Support Agreement") that sets forth the terms and conditions applicable to the launch, marketing, promotion, development, and ongoing operation of the Fund, as well the respective rights in profits and obligations for expenses. Specifically, Hashdex and the Sponsor have experience in the digital asset and exchange-traded fund industry, and seek to offer a bitcoin futures based fund as part of their long-term business goals. Additionally, the parties to the Support Agreement ("Parties") agreed that, in furtherance of their long-term business goals, the Fund will be the successor and surviving entity from the merger (the "Merger") into the Fund of Hashdex Bitcoin Futures ETF (the "Predecessor Fund") that is a series of the Teucrium Commodity Trust (the "Predecessor Trust") sponsored by Prior Sponsor. The Merger did not materially modify the rights of Fund shareholders. The Fund and the Predecessor Fund have filed current reports on Form 8-K including a press release notifying shareholders that the Merger has been consummated.

While investors will purchase and sell Shares through their broker-dealer, the Fund continuously offers creation baskets consisting of 10,000 Shares ("Creation Baskets") at their NAV to certain parties who have entered into an agreement with the Sponsor ("Authorized Purchasers"). The initial Shares will be offered and sold, in creation basket aggregation at an offering price of $ per Share, which is the same per Share price used in the Merger closing. Thereafter, Shares will be sold at the next determined NAV per Share. Authorized Purchasers, in turn, may sell such Shares, which are listed on NYSE Arca, to the public at per-Share offering prices that are expected to reflect, among other factors, the trading price of the Shares on NYSE Arca, the NAV of the Fund at the time the Authorized Purchaser purchased the Creation Baskets and the NAV at the time of the offer of the Shares to the public, the supply of and demand for Shares at the time of sale, and the liquidity of the markets for Bitcoin Futures Contracts in which the Fund invests. A list of the Fund's Authorized Purchasers as of the date of this Prospectus can be found under "Plan of Distribution - Marketing Agent and Authorized Purchasers," on page 42. The prices of Shares offered by Authorized Purchasers are expected to fall between the Fund's NAV and the trading price of the Shares on NYSE Arca at the time of sale. The Fund's Shares may trade in the secondary market on NYSE Arca at prices that are lower or higher than their NAV per Share.

This is a best efforts offering; the Marketing Agent, Foreside Fund Services, LLC, a wholly-owned subsidiary of Foreside Financial Group, LLC (d/b/a ACA Group) (the "Marketing Agent") is not required to sell any specific number or dollar amount of Shares but will use its best efforts to sell Shares. The Merger closed on January 3, 2024. The share price used for the delivery of shares of the Predecessor Fund was the net asset value per share of the Predecessor Fund determined after the close of business of NYSE Arca on January 2, 2024. Consequently, the Merger resulted in a one for one exchange of shares between the Predecessor Fund and the Fund. Prior to the Merger, the Fund had no operations, received $100 in cash from the Sponsor for four Shares to complete the pre-operational formation of the Fund and had no liabilities. This is intended to be a continuous offering that will terminate on January 1, 2027 unless suspended or terminated at any earlier time for certain reasons specified in this prospectus or unless extended as permitted under the rules of the Securities Act of 1933. See "Prospectus Summary - The Shares" and "Creation and Redemption of Shares - Rejection of Purchase Orders" below.

The Fund is a commodity pool and the Sponsor is a commodity pool operator subject to regulation by the Commodity Futures Trading Commission and the National Futures Association under the Commodity Exchange Act ("CEA").

This prospectus is in two parts: a disclosure document and a statement of additional information. These parts are bound together, and both contain important information.

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

YOU SHOULD CAREFULLY CONSIDER WHETHER YOUR FINANCIAL CONDITION PERMITS YOU TO PARTICIPATE IN A COMMODITY POOL. IN SO DOING, YOU SHOULD BE AWARE THAT COMMODITY INTEREST TRADING CAN QUICKLY LEAD TO LARGE LOSSES AS WELL AS GAINS. SUCH TRADING LOSSES CAN SHARPLY REDUCE THE NET ASSET VALUE OF THE POOL AND CONSEQUENTLY THE VALUE OF YOUR INTEREST IN THE POOL. IN ADDITION, RESTRICTIONS ON REDEMPTIONS MAY AFFECT YOUR ABILITY TO WITHDRAW YOUR PARTICIPATION IN THE POOL.

FURTHER, COMMODITY POOLS MAY BE SUBJECT TO SUBSTANTIAL CHARGES FOR MANAGEMENT, AND ADVISORY AND BROKERAGE FEES. IT MAY BE NECESSARY FOR THOSE POOLS THAT ARE SUBJECT TO THESE CHARGES TO MAKE SUBSTANTIAL TRADING PROFITS TO AVOID DEPLETION OR EXHAUSTION OF THEIR ASSETS. THIS DISCLOSURE DOCUMENT CONTAINS A COMPLETE DESCRIPTION OF EACH EXPENSE TO BE CHARGED THIS POOL AT PAGE 41 AND A STATEMENT OF THE PERCENTAGE RETURN NECESSARY TO BREAK EVEN, THAT IS, TO RECOVER THE AMOUNT OF YOUR INITIAL INVESTMENT, AT PAGE 7.

THIS BRIEF STATEMENT CANNOT DISCLOSE ALL THE RISKS AND OTHER FACTORS NECESSARY TO EVALUATE YOUR PARTICIPATION IN THIS COMMODITY POOL. THEREFORE, BEFORE YOU DECIDE TO PARTICIPATE IN THIS COMMODITY POOL, YOU SHOULD CAREFULLY STUDY THIS DISCLOSURE DOCUMENT, INCLUDING A DESCRIPTION OF THE PRINCIPAL RISK FACTORS OF THIS INVESTMENT, AT PAGE 5 AND THE "RISK FACTORS" SECTION BEGINNING ON PAGE 11.

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

This is only a summary of the prospectus and, while it contains material information about the Fund and its Shares, it does not contain or summarize all of the information about the Fund and the Shares contained in this prospectus that is material and/or which may be important to you. You should read this entire prospectus, including "What Are the Risk Factors Involved with an Investment in the Fund?" beginning on page 11, before making an investment decision about the Shares. In addition, this prospectus includes a statement of additional information that follows and is bound together with the primary disclosure document. Both the primary disclosure document and the statement of additional information contain important information.

Principal Offices of the Fund and the Sponsor

The Fund is a series of the Trust. The principal offices of the Sponsor, the Trust and the Fund are located at 234 West Florida Street, Suite 203, Milwaukee, Wisconsin 53204. The telephone number is (844)-986-7700.

Breakeven Point

The amount of trading income required for the redemption value of a Share at the end of one year to equal the selling price of the Share, assuming an initial price of $30.04, is $0.27 or 0.90% of the selling price. For more information, see "Breakeven Analysis" below.

Fund's Current Net Assets and Year to Date Performance

As of August 23, 2023, the Fund's total net assets were $1,608,534. As of August 22, 2023, the Fund's year-to-date net asset value ("NAV") per share of the Fund's performance from January 1, 2023 through August 22, 2023 was 52.66%. For a further discussion of the Fund's performance, see "OFFERING - Market Price of Shares and Prior Performance of Shares" below.

The Fund's Investment Objective

The Fund is a commodity pool that issues Shares that may be purchased and sold on NYSE Arca. The Fund's investment objective is for changes in the Shares' NAV to reflect the daily changes of the price of the Benchmark, less expenses from the Fund's operations. Under normal market conditions, the Fund invests in Benchmark Component Futures Contracts and cash and cash equivalents. Because the Fund's investment objective is to track the price of the Benchmark by investing in Benchmark Futures Contracts rather than bitcoin, changes in the price of the Shares will vary from changes in the spot price of bitcoin. NYSE Arca rule under which the Shares will be listed and traded prevents the Fund from utilizing leverage. ICE Data Indices, LLC calculates an approximate net asset value every 15 seconds throughout each day that the Fund's Shares are traded on NYSE Arca for as long as the CME's main pricing mechanism is open.

Bitcoin is a digital asset or cryptocurrency that is a unit of account on the "Bitcoin Network," an open source, decentralized peer-to-peer computer network. The ownership and operation of bitcoin is determined by purchasers in the Bitcoin Network. The Bitcoin Network connects computers that run publicly accessible, or open source, software that follows the rules and procedures governing the Bitcoin Network. This is commonly referred to as the Bitcoin Protocol. Bitcoin may be held, may be used to purchase goods and services or may be exchanged for fiat currency. No single entity owns or operates the Bitcoin Network, and the value of bitcoin is not backed by any government, corporation or other entity. Instead the value of bitcoin is determined in part by the supply and demand in markets created to facilitate the trading of bitcoin. Public key cryptography protects the ownership and transaction records for bitcoin. Because the source code for the Bitcoin Network is open source, anyone can contribute to its development. At this time, the ultimate supply of bitcoin is finite and limited to 21 million "coins" with the number of bitcoin available increasing gradually as new bitcoin supplies are mined until the 21 million current protocol cap is reached. The following factors, among others, may affect the price and market for bitcoin: The Fund does not invest directly in bitcoin.

? How widely bitcoin is adopted, including the use of bitcoin as a payment.

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

? Scalability as the use of bitcoin expands to a greater number of users.

The Fund is organized as a series of the Trust, a Delaware statutory trust organized on February 10, 2023. The Trust and the Fund operate pursuant to the Trust Agreement, dated February 10, 2023. The Trust Agreement may be found on the SEC's EDGAR filing database at https://www.sec.gov/Archives/edgar/data/1985840/000138713123008542/ex3-1.htm. The Fund was formed and is managed and controlled by the Sponsor, a limited liability company formed in Delaware on March 14, 2012. The Sponsor is registered as a commodity pool operator ("CPO") with the Commodity Futures Trading Commission ("CFTC") and is a member of the National Futures Association ("NFA"). The Fund intends to be treated as a partnership for U.S. federal income tax purposes.

The Benchmark currently is the average of the closing settlement prices for the first to expire and second to expire bitcoin futures contracts ("Bitcoin Futures Contracts") listed on the CME. These futures contracts are the Benchmark Component Futures Contracts. The CME currently offers two Bitcoin Futures Contracts, one contract representing 5 bitcoin ("BTC Contracts") and another contract representing 0.10 bitcoin ("MBT Contracts"). The Fund will invest in BTC Contracts and MBT Contracts to the extent necessary to achieve maximum exposure to the bitcoin futures market. Because the Fund's investment objective is to track the price of the Benchmark by investing in Benchmark Futures Contracts rather than bitcoin, changes in the price of the Shares will vary from changes in the spot price of bitcoin. The Fund will purchase MBT Contracts only if the Fund has proceeds remaining from the sale of a Creation Basket that are less than the price of a BTC contract. BTC and MBT will count toward an aggregate position limit.

BTC Contracts began trading on the CME Globex trading platform on December 15, 2017 under the CME ClearPort ticker symbol "BTC" and are cash settled in U.S. dollars. MBT Contracts began trading on the CME Globex trading platform on May 3, 2021 under the CME ClearPort ticker symbol "MBT" and are also cash settled in U.S. dollars. The daily settlement prices for MBT Contracts are derived directly from the settlements in the BTC Contracts. BTC Contracts and MBT Contracts each trade six consecutive monthly contracts plus two additional December contract months (if the 6 consecutive months include December, only one additional December contract month is listed).

Because BTC Contracts and MBT Contracts are exchange-listed, they allow investors to gain price exposure to bitcoin without having to hold the underlying cryptocurrency. Like a futures contract on a commodity or stock index, BTC Contracts and MBT Contracts provide a means for investors to hedge investment positions or speculate on the future price of the bitcoin market.

CME Bitcoin Futures Contracts are cash-settled and based on the CME CF Bitcoin Reference Rate (BRR) and CME CF Bitcoin Real-Time Index (BRTI). The BRR is a daily reference rate of the U.S. dollar price of one bitcoin calculated daily as of 4:00 p.m. London time. It is calculated based on the bitcoin trading activity on specified constituent bitcoin exchanges during a calculation window between 3:00 p.m. and 4:00 p.m. London time, which currently include Bitstamp, Coinbase, Gemini, itBit Kraken and LMAX Digital. BRTI is a real time index of the U.S. dollar price of one bitcoin, published once per second, 24 hours per day, 7 days per week, and 365 days per year. The CME launched the BRR and BRTI on November 14, 2016.

The CME selects constituent exchanges for the BRR on the basis of the following criteria, which each exchange must demonstrate that it continues to fulfill on an ongoing basis:

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

Should the average daily contribution of a constituent exchange fall below 3%, then the continued inclusion of the venue as a constituent exchange is assessed.

Qualifying transactions from the constituent exchanges that take place during the one-hour calculation window are added to a list, with the trade price and size for each transaction recorded. The one-hour calculation is partitioned into twelve intervals of five minutes each, and for each partition, the volume-weighted median trade price is calculated from the trade prices and sizes of relevant transactions. (A volume-weighted median differs from a standard median in that a weighting factor, in this case trade size, is factored into the calculation.) The BRR is the equally-weighted average of the volume-weighted medians of all twelve partitions.

    Registration No. 333-273364

The Fund's Investment Strategies

The Fund seeks to achieve its investment objective by investing in Benchmark Component Futures Contracts. Under normal market conditions, the Fund expects that the Fund's assets will be invested in Benchmark Component Futures Contracts and in cash and cash equivalents, such as short-term Treasury bills, money market funds, and demand deposit accounts. The term "normal market conditions" includes, but is not limited to, the absence of: trading halts in the applicable financial markets generally; operational issues (e.g., systems failure) causing dissemination of inaccurate market information; or force majeure type events such as natural or man-made disaster, act of God, armed conflict, act of terrorism, riot or labor disruption or any similar intervening circumstance.

The Sponsor owns and maintains the Benchmark and ICE Data Indices, LLC will publish the Benchmark. ICE Data Indices, LLC disseminates the intraday indicative value (also referred to in this prospectus as "approximate net asset value") of the Fund's Shares through the facilities of Consolidated Tape Association's Consolidated Quotation High Speed Lines (also known as the "CTA/QC High Speed Lines"). ICE Data Indices, LLC will make the Benchmark information available through online information services, such as Yahoo Finance, Bloomberg and Reuters. The Benchmark will only include BTC Contracts.

The Fund's futures contract positions will be rolled on a monthly basis by closing out the first to expire contracts prior to their final settlement date and then entering into the third to expire contracts which will become the new second to expire - maintaining an equal weight of 50% first to expire and 50% second to expire. A first to expire contract is the contract with the nearest expiration date. A second to expire contract follows the first - it is the contract that will expire second in line after the first contract has expired. For example, when a first to expire contract expires, the second to expire contract becomes the first to expire contract.

Futures contract rolling will take place on the market business day preceding the last trading day of the first to expire contract. The last trading day of the first to expire contact is currently defined as the last business Friday of each month. By way of example, as of the date of this prospectus the Fund's futures contract positions will be entered and exited according to the roll schedule below. For example, on April 27, 2023, if the fund held 100 futures contracts, 50 would be expiring in April 2023 and 50 contracts would be expiring in May 2023.

Hashdex Bitcoin Futures ETF (DEFI) - Roll Schedule Jan 2023 - Dec 2023

    Registration No. 333-273364

One factor determining the total return from investing in futures contracts is the price relationship between soon to expire contracts and later to expire contracts. The design of the Fund's Benchmark is such that the Benchmark Component Futures Contracts will change on a monthly basis, with the contracts with the shortest maturity being replaced with contracts with a longer maturity. Sometimes the Fund will have to pay more for longer maturity contracts to replace existing shorter maturity contracts about to expire. This situation is known as "contango" in the futures markets. In the event of a prolonged period of contango, and absent the impact of rising or falling bitcoin prices, this could have a negative impact on the Fund's NAV and total return, which in turn may have a negative impact on your investment in the Fund. By way of example, during the period from 6/30/2020 to 6/30/2023, the market for Bitcoin Component Futures Contracts were in contango approximately 87% of the time, which resulted in an average annual negative roll yield of approximately 4.5%. If the futures market is in a state of backwardation (i.e., when the price of bitcoin in the future is to be less than the current price), the Fund will buy later to expire contracts for a lower price than the soon to expire contracts that it sells.

Consistent with applicable provisions of the Trust Agreement and Delaware law, the Fund has broad authority to make changes to the Fund's operations. The Fund may change its investment objective, Benchmark, or investment strategies and Shareholders of the Fund will not have any rights with respect to these changes. The Fund has no current intention to make any such change, and any change is subject to applicable regulatory requirements, including, but not limited to, any requirement to amend applicable listing rules of NYSE Arca.

    Registration No. 333-273364

The reasons for and circumstances that may trigger any such changes may vary widely and cannot be predicted. However, by way of example, the Fund may change the term structure or underlying components of the Benchmark in furtherance of the Fund's investment objective of tracking the price of the Benchmark Component Futures Contracts if, due to market conditions, a potential or actual imposition of position limits by the CFTC or futures exchange rules, or the imposition of risk mitigation measures by a futures commission merchant, restricts the ability of the Fund to invest in the current Benchmark Component Futures Contracts. The Fund would, among other things, file a current report on Form 8-K and a prospectus supplement to describe any such change and the effective date of the change. Shareholders may modify their holdings of the Fund's Shares in response to any change by purchasing or selling Fund Shares through their broker-dealer.

The Fund invests in Benchmark Component Futures Contracts to the fullest extent possible without being leveraged or unable to satisfy its expected current or potential margin or collateral obligations with respect to its investments in Benchmark Component Futures Contracts. After fulfilling such margin and collateral requirements, the Fund invests the remainder of its proceeds from the sale of baskets in short term financial instruments of the type commonly known as "cash and cash equivalents."

The Sponsor employs a "neutral" investment strategy intended to track the changes in the Benchmark regardless of whether the Benchmark goes up or goes down. The Fund's "neutral" investment strategy is designed to permit investors generally to purchase and sell the Fund's Shares for the purpose of investing indirectly in the bitcoin market in a cost-effective manner. The Sponsor endeavors to place the Fund's trades in Benchmark Component Futures Contracts and otherwise manage the Fund's investments so that the Fund's average daily tracking error against the Benchmark will be less than 10 percent over any period of 30 trading days. However, the Fund incurs certain expenses in connection with its operations, which cause imperfect correlation between changes in the Fund's NAV and changes in the Benchmark because the Benchmark does not reflect expenses or income. As a result, investors may incur a partial or complete loss of their investment even when the performance of the Benchmark is positive.

Investors may purchase and sell Shares through their broker-dealers. However, the Fund creates and redeems Shares only in blocks called Creation Baskets and Redemption Baskets, respectively, and only Authorized Purchasers may purchase or redeem Creation Baskets or Redemption Baskets. An Authorized Purchaser is under no obligation to create or redeem baskets, and an Authorized Purchaser is under no obligation to offer to the public Shares of any baskets it does create. Baskets are generally created when there is a demand for Shares, including, but not limited to, when the market price per Share is at (or perceived to be at) a premium to the NAV per Share. Similarly, baskets are generally redeemed when the market price per Share is at (or perceived to be at) a discount to the NAV per Share. Retail investors seeking to purchase or sell Shares on any day are expected to affect such transactions in the secondary market, on NYSE Arca, at the market price per Share, rather than in connection with the creation or redemption of baskets.

The Sponsor believes that by investing in Benchmark Component Futures Contracts, the Fund's NAV will closely track the Benchmark. The Sponsor also believes that because of market arbitrage opportunities, the market price at which investors will purchase and sell Shares through their broker-dealer will closely track the Fund's NAV. The Sponsor believes that the net effect of these relationships is that the Fund's market price on NYSE Arca at which investors purchase and sell Shares will closely track the bitcoin market, as measured by the Benchmark.

The CFTC and U.S. designated contract markets, such as the CME, have established position limits and accountability levels on the maximum net long or net short Bitcoin Futures Contracts that the Fund may hold, own or control. The current CME established position limit level for investments in BTC Contracts for the spot month is 4,000 contracts. A position accountability level of 5,000 contracts will be applied to positions in single months outside the spot month and in all months combined. The MBT Contracts have a spot month limit of 200,000 contracts and a position accountability level of 250,000 contracts. Open positions in MBT Contracts will count as 1/50 of a BTC Contract for the purposes of determining the aggregate position limit. Accountability levels are not fixed ceilings but rather thresholds above which the exchange may exercise greater scrutiny and control over an investor, including limiting the Fund to holding no more Bitcoin Futures Contracts than the amount established by the accountability levels. The potential for the Fund to reach position or accountability limits will depend on if and how quickly the Fund's net assets increase.

In addition to position limits and accountability limits, the CME and other exchanges have set dynamic price fluctuation limits on Bitcoin Futures Contracts. The dynamic price limit functionality under the special price fluctuation limits mechanism assigns a price limit variant which equals a percentage of the prior trading day's settlement price, or a price deemed appropriate. During the trading day, the dynamic variant is utilized in continuous rolling 60-minute look-back periods to establish dynamic upper and lower price fluctuation limits. Once the dynamic price fluctuation limit has been reached in a particular Bitcoin Futures Contract, no trades may be made at a price beyond that limit. The CME has adopted daily dynamic price fluctuation limit functionality effective March 11, 2019, specifically, Rule 589 which is found in the following link: https://www.cmegroup.com/content/dam/cmegroup/notices/ser/2019/03/SER-8351.pdf. When a Bitcoin Futures Contract has closed at its daily price fluctuation limit, that limit price will be the daily settlement price that the CME publishes. The Fund will use the published settlement price to price its Shares on that day. If the CME halted trading in Bitcoin Futures Contracts for other reasons, including if trading were halted for an entire trading day or several trading days, the Fund would value its Bitcoin Futures Contracts by using the settlement price that the CME publishes.

Position limits, accountability limits and dynamic price fluctuation limits may limit the Fund's ability to invest the proceeds of Creation Baskets in Bitcoin Futures Contracts. As a result, when the Fund offers to sell Creation Baskets it may be limited in its ability to invest in Bitcoin Futures Contracts, including the Benchmark Component Futures Contracts. The Fund may hold larger amounts of cash and cash equivalents, which will impair the Fund's ability to meet its investment objective of tracking the Benchmark.

    Registration No. 333-273364

There is a minimum number of baskets and associated Shares specified for the Fund. If the Fund experiences redemptions that cause the number of Shares outstanding to decrease to the minimum level of Shares required to be outstanding, until the minimum number of Shares is again exceeded through the purchase of a new Creation Basket, there can be no more redemptions by an Authorized Purchaser. In such case, market makers may be less willing to purchase Shares from investors in the secondary market, which may in turn limit the ability of Shareholders of the Fund to sell their Shares in the secondary market. These minimum levels for the Fund are 50,000 Shares, representing five baskets. The minimum level of Shares specified for the Fund is subject to change.

The Sponsor maintains a public website on behalf of the Fund, http://hashdex-etfs.com/, which contains information about the Trust, the Fund, and the Shares.

Note to Secondary Market Investors: Except when aggregated in Redemption Baskets, Shares are not individually redeemable. Shares can be directly purchased from the Fund only in Creation Baskets, and only by Authorized Purchasers. Each Creation Basket consists of 10,000 Shares and therefore requires a significant financial commitment to purchase. The initial Shares will be offered and sold, in creation basket aggregation at an offering price of $ per Share, which is the same per Share price used in the Merger closing. Thereafter, Shares will be sold at the next determined NAV per Share. Accordingly, investors who do not have such resources or who are not Authorized Purchasers should be aware that some of the information contained in this prospectus, including information about purchases and redemptions of Shares directly with the Fund, is only relevant to Authorized Purchasers. There is no guarantee that Shares will trade at prices that are at or near the per-Share NAV. When buying or selling Shares on the secondary market through a broker, most investors incur customary brokerage commissions and charges.

As noted, the Fund invests in Bitcoin Futures Contracts traded on the CME. The Fund expressly disclaims any association with the CME or endorsement of the Fund by such exchange and acknowledges that "CME" is a registered trademark of such exchange.

Voting Rights

As interests in separate series of a Delaware statutory trust, the Shares do not involve the rights normally associated with the ownership of shares of a corporation (including, for example, the right to bring shareholder oppression and derivative actions). In addition, the Shares have limited voting and distribution rights (for example, shareholders do not have the right to elect directors, as the Trust does not have a board of directors, and generally will not receive regular distributions of the net income and capital gains earned by the Fund).

Shareholders have no voting rights with respect to the Trust or the Fund except as expressly provided in the Trust Agreement. The Trust Agreement provides that Shareholders representing at least a majority (over 50%) of the outstanding Shares of the Trust, voting together as a single class (excluding Shares acquired by the Sponsor in connection with its initial capital contribution to any Trust series), may vote to (i) continue the Trust by electing a successor Sponsor as described above, and (ii) approve amendments to the Trust Agreement that impair the right to surrender Redemption Baskets for redemption. In addition, Fund shareholders holding Shares representing seventy-five percent (75%) of the outstanding Shares of the Trust, voting together as a single class (excluding Shares acquired by the Sponsor in connection with its initial capital contribution to any Trust series) may vote to dissolve the Trust upon not less than ninety (90) days' notice to the Sponsor.

Principal Investment Risks of an Investment in the Fund

An investment in the Fund involves a degree of risk and you could incur a partial or total loss of your investment in the Fund. Some of the risks you may face are summarized below. A more extensive discussion of these risks appears in the "What Are the Risk Factors Involved with an Investment in the Fund?" section, beginning on page 11.

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

For additional risks, see "What Are the Risk Factors Involved with an Investment in the Fund?"

Determination of NAV

The Fund's NAV is determined as of the earlier of the close of trading on NYSE Arca or 4:00 p.m. (ET) on each day that NYSE Arca is open for trading.

Defined Terms

For a glossary of defined terms, see Appendix A.

Breakeven Analysis

The breakeven analysis set forth below is a hypothetical illustration of the approximate dollar returns and percentage returns for the redemption value of a single Share to equal the amount invested twelve months after the investment is made. For purposes of this breakeven analysis, an initial selling price of $25.00 per Share, is assumed. The breakeven analysis is an approximation only and assumes a constant month-end Net Asset Value. In order for a hypothetical investment in Shares to breakeven over the next 12 months, assuming a selling price of $25.00 per Share, the investment would have to generate a 0.92% or $0.23 return. The numbers in the chart below have been rounded to the nearest 0.01.

    Registration No. 333-273364

Assumed initial selling price per Share (1) 30.04 Management Fee (0.94%) (2) $0.28 Estimated Brokerage Commissions and Fees (3) $0.37 Other Fund Fees and Expenses (4) $0.00 Interest and Other Income (2.50%) (5) $(0.38) Amount of trading income (loss) required for the redemption value at the end of one year to equal the selling price of the Share $0.27 Percentage of initial selling price per Share (6) 0.90%

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

NYSE Arca Symbol "DEFI"

Creation Authorized Purchasers pay a $300 fee per order to create Creation and Baskets, and a $300 fee per order for Redemption Baskets, which is Redemption paid to the Custodian. Authorized Purchasers are not required to sell any specific number or dollar amount of Shares. The per Share price of Shares offered in Creation Baskets is the total NAV of the Fund calculated as of the close of NYSE Arca on that day divided by the number of issued and outstanding Shares.

Inter-Series While the Fund will be a separate single series of the Trust, Limitation additional series may be created in the future. The Trust has been on Liability formed and will be operated with the goal that the Fund and any other series of the Trust will be liable only for obligations of such series, and a series will not be responsible for or affected by any liabilities or losses of or claims against any other series. If any creditor or shareholder in any particular series (such as the Fund) were to successfully assert against a series a claim with respect to its indebtedness or shares, the creditor or shareholder could recover only from that particular series and its assets. Accordingly, the debts and other obligations incurred, contracted for or otherwise existing solely with respect to a particular series would be enforceable only against the assets of that series, and not against any other series or the Trust generally or any of their respective assets. The assets of the Fund and any other series will include only those funds and other assets that are paid to, held by or distributed to the series on account of and for the benefit of that series, including, without limitation, amounts delivered to the Trust for the purchase of shares in a series.

Registration Individual certificates are not issued for the Shares. Instead, Clearance Shares will be represented by one or more global certificates, which and are deposited by the transfer agent with the Depository Trust Company Settlement ("DTC") and registered in the name of Cede & Co., as nominee for DTC. The global certificates evidence all of the Shares outstanding at any time. Beneficial interests in Shares are held through DTC's book-entry system, which means that Shareholders are limited to: (1) purchasers in DTC such as banks, brokers, dealers and trust companies, (2) those who maintain, either directly or indirectly, a custodial relationship with a DTC purchaser, and (3) those who hold interests in the Shares through DTC purchasers or indirect purchasers, in each case who satisfy the requirements for transfers of Shares. DTC purchasers acting on behalf of investors holding Shares through such DTC purchasers' accounts in DTC will follow the delivery practice applicable to securities eligible for DTC's Same-Day Funds Settlement System. Shares are credited to DTC purchasers' securities accounts following confirmation of receipt of payment.

    Registration No. 333-273364

    Registration No. 333-273364

Fund The Fund pays the Sponsor a Management Fee, monthly in arrears, in an Expenses amount equal to 0.94% per annum of the daily NAV of the Fund. The Management Fee is paid in consideration of the Sponsor's services related to the management of the Fund's business and affairs, including the provision of commodity futures trading advisory services. The Fund pays all of its respective brokerage commissions, including applicable exchange fees, NFA fees and give-up fees, and other transaction related fees and expenses charged in connection with trading activities for the Fund's investments in CFTC regulated investments. The Fund bears other transaction costs related to the FCM capital requirements on a monthly basis. The Sponsor pays all of the routine operational, administrative and other ordinary expenses of the Fund, generally as determined by the Sponsor, including but not limited to, fees and expenses of the Administrator, Sub-Administrator, Custodian, Marketing Agent Transfer Agent, licensors, accounting and audit fees and expenses, tax preparation expenses, legal fees, ongoing SEC registration fees, individual Schedule K-1 preparation and mailing fees, and report preparation and mailing expenses. The Fund pays all of its non-recurring and unusual fees and expenses, if any, as determined by the Sponsor. Non-recurring and unusual fees and expenses are unexpected or unusual in nature, such as legal claims and liabilities and litigation costs or indemnification or other unanticipated expenses. Extraordinary fees and expenses also include material expenses which are not currently anticipated obligations of the Fund. Routine operational, administrative and other ordinary expenses are not deemed extraordinary expenses. The estimated amount of fees and expenses that are anticipated to be incurred in a single Share during the first twelve (12) months of ownership is $0.27 or 0.90% of the selling price. The total estimated fees and expenses are expressed as a percentage of an estimated $1,500,000 million in assets.

    Registration No. 333-273364

    Registration No. 333-273364

Termination The Trust and the Fund shall continue in existence from the date of Events their formation in perpetuity, unless the Trust or the Fund, as the case may be, is sooner terminated upon the occurrence of certain events specified in the Trust Agreement, including the following: (1) the filing of a certificate of dissolution or cancellation of the Sponsor or revocation of the Sponsor's charter or the withdrawal of the Sponsor, unless Shareholders holding a majority of the outstanding Shares of the Trust, voting together as a single class, elect within ninety (90) days after such event to continue the business of the Trust and appoint a successor Sponsor; (2) the occurrence of any event which would make the existence of the Trust or the Fund unlawful; (3) the suspension, revocation, or termination of the Sponsor's registration as a CPO with the CFTC or membership with the NFA; (4) the insolvency or bankruptcy of the Trust or the Fund; (5) a vote by the Shareholders holding at least seventy-five percent (75%) of the outstanding Shares of the Trust, voting together as a single class, to dissolve the Trust subject to certain conditions; (6) the determination by the Sponsor to dissolve the Trust or the Fund, subject to certain conditions; (7) the Trust is required to be registered as an investment company under the Investment Company Act of 1940; and (8) DTC is unable or unwilling to continue to perform its functions and a comparable replacement is unavailable. Upon termination of the Fund, the affairs of the Fund shall be wound up and all of its debts and liabilities discharged or otherwise provided for in the order of priority as provided by law. The fair market value of the remaining assets of the Fund shall then be determined by the Sponsor. Thereupon, the assets of the Fund shall be distributed pro rata to the Shareholders in accordance with their Shares.

Authorized A list of the Fund's Authorized Purchasers as of the date of this Purchasers prospectus can be found under "Plan of Distribution - Marketing Agent and Authorized Purchasers," on page 42. Authorized Purchasers must be (1) registered broker-dealers or other securities market purchasers, such as banks and other financial institutions, which are not required to register as broker-dealers to engage in securities transactions, and (2) DTC purchasers. To become an Authorized Purchaser, a person must enter into an Authorized Purchaser Agreement with the Sponsor.

Conflicts There are present and potential future conflicts of interest related of to the Trust's structure and operation that you should consider Interest before you purchase Shares. These include, among others, conflicts related to the Sponsor serving as the sponsor to the other funds and to commodity pools other than the Fund in the future. A description of such conflicts of interest can be found under "The Sponsor Has Conflicts of Interest" on page 49.

    Registration No. 333-273364

WHAT ARE THE RISK FACTORS INVOLVED WITH AN INVESTMENT IN THE FUND?

You should consider carefully the risks described below before making an investment decision. You should also refer to the other information included in this prospectus, and the Fund's and the Trust's financial statements and the related notes incorporated by reference herein. See "Incorporation by Reference of Certain Information."

Risks Associated with Investing in Bitcoin

Further development and acceptance of Bitcoin and the Bitcoin Network is uncertain.

The further development and acceptance of the Bitcoin Network, which is part of a new and rapidly changing industry, is subject to a variety of factors that are difficult to evaluate. The slowing, stopping or reversing of the development or acceptance of the Bitcoin Network may adversely affect the price of bitcoin and therefore cause the Fund to suffer losses. Regulatory changes or actions may alter the nature of an investment in bitcoin or restrict the use of bitcoin or the operations of the Bitcoin Network or venues on which bitcoin trades in a manner that adversely affects the price of bitcoin and, therefore, the Fund's Bitcoin Futures Contracts. Bitcoin generally operates without central authority (such as a bank) and is not backed by any government. Bitcoin is not legal tender and federal, state and/or foreign governments may restrict the use and exchange of bitcoin, and regulation in the United States is still developing. For example, it may become difficult or illegal to acquire, hold, sell or use bitcoin in one or more countries, which could adversely impact the price of bitcoin, and therefore the value of the Fund's Bitcoin Futures Contracts.

"Forks" in Bitcoin Network could have adverse effects.

From time to time, developers of the bitcoin network suggest changes to the bitcoin software. If a sufficient number of users and miners elect not to adopt the changes, a new digital asset, operating on the earlier version of the bitcoin software, may be created. This is often referred to as a "fork."

In August 2017, bitcoin "forked" into bitcoin and a new digital asset, bitcoin cash, as a result of a several-year dispute over how to increase the rate of transactions that the Bitcoin network can process. Since then, bitcoin has been forked numerous times to launch new digital assets, such as bitcoin gold, bitcoin silver and bitcoin diamond. Additional hard forks of the Bitcoin blockchain could adversely affect the market for Bitcoin Futures in which the Fund invests and, therefore, an investment in the Fund. A substantial giveaway of bitcoin (sometimes referred to as an "air drop") may also result in significant and unexpected declines in the value of bitcoin, Bitcoin Futures Contracts, and the Fund.

Rewards for mining Bitcoin are designed to decline over time, which may lessen the incentive for miners to process and confirm transactions on the Bitcoin Network.

Transactions in bitcoin are processed by miners who are primarily compensated by receiving newly issued bitcoin as a reward for successfully solving cryptological puzzles according to a payment schedule that declines over time (in some instances, miners are also compensated through voluntary fees paid by Bitcoin Network participants). If this compensation is not sufficient to incentivize miners to process transactions, the confirmation process for transactions, which acts as security for the Bitcoin Network, may become slower and the Bitcoin Network may become more vulnerable. These and similar events may have a significant adverse effect on the price and liquidity of bitcoin and the value of an investment in the Fund.

The Bitcoin Network may face scalability challenges as it expands to a greater number of users.

As with other digital asset networks, the Bitcoin Network faces significant scaling challenges because public blockchains generally face a tradeoff between security and scalability. A decentralized network is less susceptible to manipulation or capture if more participants, or "nodes," are involved in the processing and maintenance of such network. However, a greater number of nodes decreases the network's efficiency in processing transactions and may result in increased settlement times. Increased settlement times could discourage certain uses for bitcoin (for example, micropayments), and could reduce demand for and price of bitcoin, which could adversely impact the value of an investment in the Fund.

Bitcoin Markets are susceptible to extreme price fluctuations, theft, loss and destruction.

The market price of bitcoin has been subject to extreme fluctuations. If bitcoin markets continue to be subject to sharp fluctuations, the Fund's Shareholders may experience losses. Similar to fiat currencies (i.e., a currency that is backed by a central bank or a national, supra-national or quasi-national organization), bitcoin is susceptible to theft, loss and destruction. Accordingly, the Fund's Bitcoin Futures are also susceptible to these risks. Cybersecurity risks of the Bitcoin Protocol and of entities that custody or facilitate the transfers or trading of bitcoin could result in a loss of public confidence in bitcoin, a decline in the value of bitcoin and, as a result, adversely impact the Fund's Bitcoin Futures Contracts.

    Registration No. 333-273364

Bitcoin ownership is concentrated in a small number of holders referred to as 'Whales.'

A significant portion of bitcoin is held by a small number of holders who have the ability to affect the price of bitcoin and who are sometimes referred to as "whales." Because bitcoin is lightly regulated, bitcoin whales have the ability, alone or in coordination, to manipulate the price of bitcoin by restricting or expanding the supply of bitcoin. Activities of bitcoin whales that reduce user confidence in bitcoin, the Bitcoin Network or the fairness of bitcoin trading venues, or that affect the price of bitcoin, could have a negative impact on the value of an investment in the Fund.

Bitcoin exchanges are unregulated and may be more exposed to fraud and failure.

Bitcoin exchanges and other trading venues on which bitcoin trades are relatively new and, in most cases, largely unregulated and may therefore be more exposed to fraud and failure than established, regulated exchanges for securities, derivatives and other currencies. The Fund's indirect investment in bitcoin remains subject to volatility experienced by the bitcoin exchanges and other bitcoin trading venues. Such volatility can adversely affect an investment in the Fund. Bitcoin exchanges have in the past stopped and may in the future stop operating or permanently shut down due to fraud, cybersecurity issues, manipulation, technical glitches, hackers or malware, which may also affect the price of bitcoin and thus the Fund's indirect investment in bitcoin. Fraud and failure related to such bitcoin exchanges could result in a loss of public confidence in bitcoin and a decline in the value of bitcoin, which could adversely impact the adoption of bitcoin or acceptance of bitcoin and cause a decline in value of the Fund's Bitcoin Futures Contracts.

The recent bankruptcy of the crypto exchange FTX has underscored the potential for fraud and manipulation in crypto exchanges generally. The financial distress experienced by crypto asset market participants as a result of the FTX bankruptcy has already led to the spread of a general contagion among some market participants, and may lead to additional regulation of the crypto markets.

Networked systems are vulnerable to attacks.

All networked systems are vulnerable to various kinds of attacks. As with any computer network, the Bitcoin network contains certain flaws. For example, the Bitcoin network is currently vulnerable to a "51% attack" where, if a mining pool were to gain control of more than 50% of the "hash" rate, or the amount of computing and process power being contributed to the network through mining, a malicious actor would be able to gain full control of the network and the ability to manipulate the blockchain. A significant portion of bitcoin is held by a small number of holders sometimes referred to as "whales." These holders have the ability to manipulate the price of bitcoin.

Cybersecurity risk.

As a digital asset, bitcoin is subject to cybersecurity risks, including the risk that malicious actors will exploit flaws in its code or structure that will allow them to, among other things, steal bitcoin held by others, control the blockchain, steal personally identifying information, or issue significant amounts of bitcoin in contravention of the Bitcoin Protocols. The occurrence of any of these events is likely to have a significant adverse impact on the price and liquidity of bitcoin and Bitcoin Futures Contracts and therefore the value of an investment in the Fund. Additionally, the Bitcoin network's functionality relies on the Internet. A significant disruption of Internet connectivity affecting large numbers of users or geographic areas could impede the functionality of the Bitcoin network. Any technical disruptions or regulatory limitations that affect Internet access may have an adverse effect on the Bitcoin Network, the price of bitcoin and Bitcoin Futures Contracts, and the value of an investment in the Fund.

Limited adoption and ability to use bitcoin to purchase goods.

Currently, there is relatively limited use of bitcoin in the retail and commercial marketplace in comparison to relatively extensive use as a store of value, thus contributing to price volatility that could adversely affect the Fund's Bitcoin Futures Contracts. Bitcoin is not currently a form of legal tender in the United States and has only recently become selectively accepted as a means of payment for goods and services by some retail and commercial outlets, and the use of bitcoin by consumers to pay such retail and commercial outlets remains limited. Banks and other established financial institutions may refuse to process funds for bitcoin transactions; process wire transfers to or from bitcoin trading venues, bitcoin-related companies or service providers; or maintain accounts for persons or entities transacting in bitcoin or providing bitcoin-related services. In addition, some taxing jurisdictions, including the U.S., treat the use of bitcoin as a medium of exchange for goods and services to be a taxable sale of bitcoin, which could discourage the use of bitcoin as a medium of exchange, especially for a holder of bitcoin that has appreciated in value.

Risks to Bitcoin from other parts of the digital assets market.

The price of bitcoin and the bitcoin market generally may be adversely impacted by developments in other parts of the digital assets market including, but not limited to, industry wide. The acceptance of bitcoin and digital assets generally depends on a number of factors, including adverse developments in the digital assets market that could impact investor confidence. For example, "stablecoins" have been developed to enhance the value of cryptocurrency to be used like fiat currency in transactions in goods and services. Adverse developments such as the recent "depegging" of the TerraUSD stablecoin and the FTX bankruptcy may undermine confidence in the cryptocurrency markets generally and cause decreases in the price of digital assets such as bitcoin.

    Registration No. 333-273364

Hacking risk of theft of private keys.

Due to the nature of private keys, bitcoin transactions are irrevocable and incorrectly transferred or stolen bitcoin may be irretrievable, and as a result, any incorrectly executed bitcoin transactions could adversely affect the price and liquidity of bitcoin, which may indirectly affect the price and liquidity of the Bitcoin Futures Contracts.

Environmental risks from Bitcoin mining.

Bitcoin mining currently requires computing hardware that consumes large amounts of electricity. By way of electrical power generation, many bitcoin miners rely on fossil fuels to power their operations. Public perception of the impact of bitcoin mining on climate change may reduce demand for bitcoin and increase the likelihood of regulation that limits bitcoin mining or restricts energy usage by bitcoin miners. Such events could have an impact on the price of bitcoin, bitcoin futures, and the performance of the Fund.

Risks Associated with Investing in Bitcoin Futures Contracts

Investing in Bitcoin futures contracts subjects the Fund to the risks of the Bitcoin market.

The Fund is subject to the risks and hazards of the bitcoin market because it invests in Bitcoin Futures Contracts listed on the CME. The risks and hazards that are inherent in the bitcoin market may cause the price of bitcoin and the Fund's Shares to fluctuate widely and you could incur a partial or total loss of your investment in the Fund. The prices of bitcoin and bitcoin futures contracts have historically been highly volatile. The value of the Fund's investments in bitcoin futures - and therefore the value of an investment in the Fund - could decline significantly and without warning, including to zero. If you are not prepared to accept significant and unexpected changes in the value of the Fund and the possibility that you could lose your entire investment in the Fund you should not invest in the Fund.

The Bitcoin futures contracts listed on the CME are a relatively new type of futures contract that may be less developed than other, more established futures markets.

The Bitcoin Futures Contracts listed on the CME are a relatively new type of futures contract that may be less developed than more established futures markets (such as the futures markets for corn or wheat). Accordingly, although BTC Contracts have traded on the CME since December 2017 and MBT Contracts have traded on the CME since May 2021 and the market for exchange listed Bitcoin Futures Contracts has grown since inception, the market for Bitcoin Futures Contracts may be riskier, less liquid, more volatile and more vulnerable to economic, market, industry, regulatory and other changes than more established futures contracts. The liquidity of the market for BTC Contracts and MBT Contracts will depend on, among other things, the supply and demand for Bitcoin Futures Contracts, speculative interest in the market for Bitcoin Futures Contracts and the potential ability to hedge against the price of bitcoin with Bitcoin Futures Contracts.

An investment in the Fund is subject to the risks of an investment in futures contracts.

An investment in the Fund is subject to the risks of an investment in futures contracts, which are complex instruments that are often subject to a high degree of price variability. Because the price of Bitcoin Futures Contracts is linked to the price of bitcoin, an investment in the Fund may be riskier than other exchange-traded products that do not hold financial instruments related to bitcoin and may not be suitable for all investors.

Futures contracts are subject to inherent leverage risk because they are typically secured by margin deposits representing a small percentage of a futures contract's entire market value.

Commodity pools' trading positions in futures contracts are typically required to be secured by the deposit of margin funds that represent only a small percentage of a futures contract's entire market value. This feature creates the potential for commodity pools to "leverage" their assets by purchasing or selling futures contracts with an aggregate notional amount in excess of the commodity pool's assets. While futures contracts are generally subject to leverage risk, NYSE Arca rule under which the Fund's Shares will be listed and traded prevents the Fund from utilizing leverage.

Pricing anomalies in the bitcoin futures market could cause losses.

Market fraud and/or manipulation and other fraudulent trading practices such as the intentional dissemination of false or misleading information (e.g., false rumors) can, among other things, lead to a disruption of the orderly functioning of markets, significant market volatility, and cause the value of bitcoin futures to fluctuate quickly and without warning. Depending on the timing of an investor's purchases and sales of the Fund's Shares, these pricing anomalies could cause the investor to incur losses.

Risks of government regulation.

The Financial Industry Regulatory Authority ("FINRA") issued a notice on March 8, 2022 seeking comment on measures that could prevent or restrict investors from buying a broad range of public securities and products designated as "complex products" - which could include each Exchange Traded Product offered by the Sponsor. The ultimate impact, if any, of these measures remain unclear. However, if regulations are adopted, they could, among other things, prevent or restrict investors' ability to buy the Fund.

    Registration No. 333-273364

Correlation Risk

The Benchmark is not designed to correlate with the spot price of bitcoin, and this could cause the changes in the price of the Shares to substantially vary from the changes in the spot price of bitcoin. Therefore, you may not be able to effectively use the Fund to hedge against bitcoin related losses or to indirectly invest in bitcoin.

The correlation between changes in such Bitcoin Futures Contracts and the spot price of bitcoin will be only approximate. Weak correlation between the Benchmark and the spot price of bitcoin may result from the factors discussed above. Imperfect correlation may also result from speculation in Benchmark Component Futures Contracts, and/or technical or other factors that may influence the trading of Benchmark Component Futures Contracts. If there is a weak correlation between the Benchmark and the spot price of bitcoin, then the price of Shares may not accurately track the spot price of bitcoin and you may not be able to effectively use the Fund as a way to hedge the risk of losses in your bitcoin related transactions or as a way to indirectly invest in bitcoin.

Moreover, while there is a spot bitcoin index calculated by the CME that is based on price feeds from certain designated bitcoin spot market exchanges, the Fund will generally not directly price off of this index. This is because the Fund will roll its futures holdings prior to settlement of the expiring contract and intends to never carry futures positions all the way to cash settlement (the only date that the BTC Contracts and MBT Contracts settle to the CME spot price index). The Fund will only price off of Bitcoin Futures Contracts volume-weighted average price (VWAP) daily settlement price, which might cause the Fund's NAV to differ from spot bitcoin prices.

Changes in the Fund's NAV may not correlate well with changes in the price of the Benchmark. If this were to occur, you may not be able to effectively use the Fund as a way to hedge against bitcoin related losses or as a way to indirectly invest in bitcoin.

The Sponsor endeavors to invest the Fund's assets as fully as possible in Benchmark Component Futures Contracts so that the changes in the NAV closely correlate with the changes in the Benchmark. However, changes in the Fund's NAV may not correlate with the changes in the Benchmark for various reasons, including those set forth below.

The Fund incurs certain expenses in connection with its operations and holds most of its assets in income producing, short-term financial instruments for margin and other liquidity purposes and to meet redemptions that may be necessary on an ongoing basis. To the extent these expenses are not covered by the Management Fee, and income from short-term financial instruments may cause imperfect correlation between changes in the Fund's NAV and changes in the Benchmark. Differences between returns based on the price of bitcoin and an investment in the Fund may also be attributable to additional costs related to futures investing and other fund expenses.

The Sponsor may not be able to invest the Fund's assets in Benchmark Component Futures Contracts having an aggregate notional amount exactly equal to the Fund's NAV. As a standardized contract, a single BTC Contract is for a specified amount of bitcoin, and the Fund's NAV and the proceeds from the sale of a Creation Basket is unlikely to be an exact multiple of that amount. In such case, the Fund might not invest the entire proceeds from the purchase of the Creation Basket in such futures contracts. (As an example, assume that a Creation Basket is sold by the Fund, and that the Fund's closing NAV per Share is $25.00. In that case, the Fund would receive $250,000 in proceeds from the sale of the Creation Basket ($25.00 NAV per Share multiplied by 10,000 Shares and ignoring the Creation Basket fee of $300). If one were to assume further that the Sponsor wants to invest the entire proceeds from the Creation Basket in the Benchmark Component Futures Contracts and that the market value of each such Benchmark Component Futures Contracts is $188,175 (or otherwise not a round number), the Fund would be unable to buy an exact number of BTC Contracts with an aggregate market value equal to $250,000. In this case, the Fund would be able to purchase 1 BTC Contract with an aggregate market value of approximately $188,175 and 16 MBT Contracts at $3,750 with an aggregate market value of approximately $60,000, bringing the aggregate value of proceeds to $248,175.) Any amounts not invested in Benchmark Component Futures Contracts are held in cash and cash equivalents.

The Benchmark Component Futures Contracts reflect the price of bitcoin for future delivery, not the current spot price of bitcoin, so at best the correlation between changes in such Bitcoin Futures Contracts and the spot price of bitcoin will be only approximate. Weak correlation between the Benchmark and the spot price of bitcoin may result from fluctuations in bitcoin prices discussed above. Imperfect correlation may also result from speculation in Benchmark Component Futures Contracts, technical factors in the trading of Benchmark Component Futures Contracts, and expected inflation in the economy as a whole. If there is a weak correlation between the Benchmark and the spot price of bitcoin, then the price of Shares may not accurately track the spot price of bitcoin and you may not be able to effectively use the Fund as a way to hedge the risk of losses in your bitcoin related transactions or as a way to indirectly invest in bitcoin.

As Fund assets increase, there may be more or less correlation. On the one hand, as the Fund grows it should be able to invest in Benchmark Component Futures Contracts with a notional amount that is closer on a percentage basis to the Fund's NAV. For example, if the Fund's NAV is equal to 4.9 times the value of a single futures contract, it can purchase only four futures contracts, which would cause only 81.6% of the Fund's assets to be exposed to the bitcoin market. On the other hand, if the Fund's NAV is equal to 100.9 times the value of a single Bitcoin Futures Contract, it can purchase 100 such contracts, resulting in 99.1% exposure.

There may be significant volatility in the market for Bitcoin Futures Contracts. This volatility, in turn, may make it more difficult for Authorized Purchasers and other market purchasers to be able to identify a reliable price for Bitcoin Futures Contracts. Without reliable prices, Authorized Purchasers and other market purchasers may reduce their role in the market arbitrage process or "step away" from these activities. This, in turn, might inhibit the effectiveness of the arbitrage process in maintaining the relationship between the underlying value of the Fund's Bitcoin Futures Contracts and the Fund's market price. This reduced effectiveness could result in Fund Shares trading at a price which differs materially from NAV and also in greater than normal intraday bid/ask spreads for Fund Shares.

    Registration No. 333-273364

Position limits, accountability levels and dynamic price fluctuation limits set by the CFTC and the exchanges have the potential to cause tracking error, which could cause the price of Shares to substantially vary from the Benchmark and prevent you from being able to effectively use the Fund as a way to hedge against bitcoin related losses or as a way to indirectly invest in bitcoin.

The CFTC and U.S. designated contract markets, such as the CME, have established position limits and accountability levels on the maximum net long or net short BTC Contracts that the Fund may hold, own or control. Spot position limits are set at 4,000 contracts. A position accountability level of 5,000 contracts will be applied to positions in single months outside the spot month and in all months combined. The MBT Contracts have a spot month limit of 200,000 contracts and a position accountability level of 250,000 contracts. Accountability levels are not fixed ceilings but rather thresholds above which the exchange may exercise greater scrutiny and control over an investor, including limiting the Fund to holding no more Bitcoin Futures Contracts than the amount established by the accountability level. The potential for the Fund to reach position or accountability limits will depend on if and how quickly the Fund's net assets increase.

In addition to position limits and accountability limits, the CME places daily price fluctuation limits on Bitcoin Futures Contracts that represent the maximum daily price range permitted for a contract. Once a price fluctuation limit has been reached, no trades may be made at a price beyond that limit. Under the price fluctuation mechanism that was initially put into place when Bitcoin Futures Contracts were launched on the CME in December 2017, price fluctuation limits were triggered 116 times. In March 2019, the CME adopted a dynamic price fluctuation mechanism. This mechanism assigns an initial opening price fluctuation limit equal to a percentage of the prior trading day's settlement price (or a different price if deemed more appropriate), which then moves with the market throughout the day. Since dynamic price fluctuation limits were introduced, price limits have been triggered 89 times and there has been one "hard limit move." A hard limit move is when the price of Bitcoin Futures Contracts exceeds a price limit that defines the minimum/maximum price to which such Bitcoin Futures Contracts can move for the given trade date. If the hard limit is reached, trade matching will not occur at prices above the maximum price or below the minimum price.

Position limits, accountability limits and dynamic price fluctuation limits may limit the Fund's ability to invest the proceeds of Creation Baskets in Bitcoin Futures Contracts. As result, when the Fund sells Creation Baskets it may be limited in its ability to invest in Bitcoin Futures Contracts, including the Benchmark Component Futures Contracts. In such case, the Fund may hold larger amounts of cash and cash equivalents, which will impair the Fund's ability to meet its investment objective of tracking the Benchmark.

Price fluctuation limits may contribute to a lack of liquidity and have a negative impact on Fund performance. During periods of market illiquidity, including periods of market disruption and volatility, it may be difficult or impossible for the Fund to buy or sell futures at desired prices or at all.

An investment in the Fund may provide you little or no diversification benefits. Thus, in a declining market, the Fund may have no gains to offset your losses from other investments, and you may suffer losses on your investment in the Fund at the same time you incur losses with respect to other asset classes.

It cannot be predicted to what extent the performance of Benchmark Component Futures Contracts will or will not correlate to the performance of other broader asset classes such as stocks and bonds. If the Fund's performance were to move more directly with the financial markets, you will obtain little or no diversification benefits from an investment in the Shares. In such a case, the Fund may have no gains to offset your losses from other investments, and you may suffer losses on your investment in the Fund at the same time you incur losses with respect to other investments.

Variables such as cost of electricity, regulation, market disruptions, cyber-attacks and political events may have a larger impact on bitcoin and bitcoin interest prices than on traditional securities and broader financial markets. These additional variables may create additional investment risks that subject the Fund's investments to greater volatility than investments in traditional securities.

Lower correlation should not be confused with negative correlation, where the performance of two asset classes would be opposite of each other. There is no historic evidence that the spot price of bitcoin and prices of other financial assets, such as stocks and bonds, are negatively correlated. In the absence of negative correlation, the Fund cannot be expected to be automatically profitable during unfavorable periods for the stock market, or vice versa.

If changes in the Fund's NAV do not correlate with changes in the Benchmark, then investing in the Fund may not be an effective way to hedge against bitcoin related losses or indirectly invest in bitcoin.

Futures Commission Merchant Risks

The Fund has two futures commission merchants.

The Fund currently has two futures commission merchants ("FCMs") through which it buys and sells futures contracts. Volatility in the bitcoin futures market may lead one or both of the Fund's FCMs to impose risk mitigation procedures that could limit the Fund's investment in Bitcoin Futures Contracts beyond the accountability and position limits imposed by the CME futures contract exchange as discussed herein. An FCM could impose a financial ceiling on initial margin that could change and become more or less restrictive on the Fund's activities depending upon a variety of conditions beyond the Sponsor's control. If the Fund's FCMs were to impose position limits, or if any other FCM with which the Fund establishes a relationship in the future were to impose position limits, the Fund's ability to meet its investment objective could be negatively impacted. The Fund continues to monitor and manage its existing relationships with its FCMs and will continue to seek additional relationships with FCMs as needed.

    Registration No. 333-273364

Risks Associated With the Fund's Investment In Cash and Cash Equivalents

The Fund may experience a loss if it is required to sell cash equivalents at a price lower than the price at which they were acquired.

If the Fund is required to sell its cash equivalents at a price lower than the price at which they were acquired, the Fund will experience a loss. This loss may adversely impact the price of the Shares and may decrease the correlation between the price of the Shares, the Benchmark, and the spot price of bitcoin. The value of cash equivalents held by the Fund generally moves inversely with movements in interest rates. The prices of longer maturity securities are subject to greater market fluctuations as a result of changes in interest rates. While the short-term nature of the Fund's investments in cash equivalents should minimize the interest rate risk to which the Fund is subject, it is possible that the cash equivalents held by the Fund will decline in value.

Risk Related To Lack of Liquidity

Certain of the Fund's investments could be illiquid, which could cause large losses to investors at any time or from time to time.

If the Fund's ability to obtain exposure to Bitcoin Futures Contracts in accordance with its investment objective is disrupted for any reason including, because of limited liquidity in the bitcoin futures market, a disruption to the bitcoin futures market, or as a result of margin requirements or position limits imposed by the Fund's futures commission merchants, the CME, or the CFTC, the Fund may not be able to achieve its investment objective and may experience significant losses. Any disruption in the Fund's ability to obtain exposure to Bitcoin Futures Contracts will cause the Fund's performance to deviate from the performance of Bitcoin Futures Contracts. In addition, the Fund might grow to a size where a lack of liquidity in the futures market meant that the Fund could not sell enough futures contracts to honor redemption requests. For further information regarding the impact if suspending redemptions, see "Suspension or Rejection of Redemption Orders" on page 46.

A market disruption, such as a government taking regulatory or other actions that disrupt the market in bitcoin, can also make it difficult to liquidate a position. Unexpected market illiquidity may cause major losses to investors at any time or from time to time. In addition, the Fund does not intend at this time to establish a credit facility, which would provide an additional source of liquidity, but instead will rely only on the cash and cash equivalents that it holds to meet its liquidity needs. The anticipated value of the positions in Benchmark Component Futures Contracts that the Sponsor will acquire or enter into for the Fund increases the risk of illiquidity. Because Benchmark Component Futures Contracts may be illiquid, the Fund's holdings may be more difficult to liquidate at favorable prices in periods of illiquid markets and losses may be incurred during the period in which positions are being liquidated.

The Fund and other funds with similar investment strategies may try to exit positions at the same time.

If the Fund and other funds with similar investment strategies try to exit their Bitcoin Futures Contract positions at the same time, such a mass exit could have detrimental effect on price and liquidity, and you could incur losses in your investment in Shares of the Fund.

Hedging Risk

If the nature of the purchasers in the futures market shifts such that bitcoin purchasers are the predominant hedgers in the market, the Fund might have to reinvest at higher futures prices or choose other bitcoin interests.

The changing nature of the purchasers in the bitcoin market will influence whether bitcoin futures prices are above or below the expected future spot price. Holders of bitcoin will typically seek to hedge against falling bitcoin prices by selling Bitcoin Futures Contracts. Therefore, if holders of bitcoin become the predominant hedgers in the futures market, prices of Bitcoin Futures Contracts will typically be below expected future spot prices. Conversely, if the predominant hedgers in the futures market are the holders of bitcoin who purchase Bitcoin Futures Contracts to hedge against a rise in prices, prices of Bitcoin Futures Contracts will likely be higher than expected future spot prices. This can have significant implications for the Fund when it is time to sell a Bitcoin Futures Contract that is no longer a Benchmark Component Futures Contract and purchase a new Bitcoin Futures Contract or to sell a Bitcoin Futures Contract to meet redemption requests.

The price relationship between the Benchmark Component Futures Contracts at any point in time and the Bitcoin Futures Contracts that will become Benchmark Component Futures Contracts on the next roll date will vary and may impact both the Fund's total return and the degree to which its total return tracks that of bitcoin price indices.

The design of the Fund's Benchmark is such that the Benchmark Component Futures Contracts will change on a monthly basis, and the Fund's investments may be rolled periodically to reflect the changing composition of the Benchmark. In the event of a bitcoin futures market where near to expire contracts trade at a higher price than longer to expire contracts, a situation referred to as "backwardation," then absent the impact of the overall movement in bitcoin prices the value of the Benchmark Component Futures Contracts would tend to rise as they approach expiration. As a result, the Fund may benefit because it may be selling more expensive contracts and buying less expensive ones on an ongoing basis. Conversely, in the event of a bitcoin futures market where near to expire contracts trade at a lower price than longer to expire contracts, a situation referred to as "contango," then absent the impact of the overall movement in bitcoin prices the value of the Benchmark Component Futures Contracts would tend to decline as they approach expiration. As a result, the Fund's total return may be lower than might otherwise be the case because it may be selling less expensive contracts and buying more expensive ones. The impact of backwardation and contango may lead the total return of the Fund to vary significantly from the total return of other price references, such as the spot price of bitcoin. In the event of a prolonged period of contango, and absent the impact of rising or falling bitcoin prices, this could have a significant negative impact on the Fund's NAV and total return, and you could incur a partial or total loss of your investment in the Fund.

    Registration No. 333-273364

The design of the Fund's Benchmark is such that the Benchmark Component Futures Contracts will change on a monthly basis, with the contracts with the shortest maturity being replaced with contracts with a longer maturity. Sometimes the Fund will have to pay more for longer maturity contracts to replace existing shorter maturity contracts about to expire. This situation is known as "contango" in the futures markets. In the event of a prolonged period of contango, and absent the impact of rising or falling bitcoin prices, this could have a negative impact on the Fund's NAV and total return, which in turn may have a negative impact on your investment in the Fund. By way of example, during the period from 6/30/2020 to 6/30/2023, the market for Bitcoin Component Futures Contracts were in contango approximately 87% of the time, which resulted in an average annual negative roll yield of approximately 4.5%.

If the futures market is in contango (i.e., when the price of bitcoin in the future is to be more than the current price), the Fund will buy later to expire contracts for a higher price than the soon to expire contracts that it sells. All other things being equal, a situation involving prolonged periods of contango may adversely impact the returns of the Fund.

Regulatory Risk

Lack of regulation of the Bitcoin market.

Bitcoin, the Bitcoin Network and the bitcoin trading venues are relatively new and, in most cases, largely unregulated. As a result of this lack of regulation, individuals, or groups may engage in insider trading, fraud or market manipulation with respect to bitcoin. Such manipulation could cause investors in bitcoin to lose money, possibly the entire value of their investments. Over the past several years, a number of bitcoin trading venues have been closed due to fraud, failure or security breaches. The nature of the assets held at bitcoin trading venues make them appealing targets for hackers and a number of bitcoin trading venues have been victims of cybercrimes and other fraudulent activity. These activities have caused significant, in some cases total, losses for bitcoin investors. Investors in bitcoin may have little or no recourse should such theft, fraud or manipulation occur. There is no central registry showing which individuals or entities own bitcoin or the quantity of bitcoin that is owned by any particular person or entity. There are no regulations in place that would prevent a large holder of bitcoin or a group of holders from selling their bitcoins, which could depress the price of bitcoin, or otherwise attempting to manipulate the price of bitcoin or the Bitcoin Network. Events that reduce user confidence in bitcoin, the Bitcoin Network and the fairness of bitcoin trading venues could have a negative impact on the price of bitcoin and the value of an investment in the Fund.

Risk of illicit activities.

As bitcoins have grown in both popularity and market size, the U.S. Congress and a number of U.S. federal and state agencies (including the Financial Crimes Enforcement Network of the U.S. Department of the Treasury ("FinCEN"), SEC, CFTC, the Financial Industry Regulatory Authority, Inc. ("FINRA"), the Consumer Financial Protection Bureau ("CFPB"), the Department of Justice, the Department of Homeland Security, the Federal Bureau of Investigation, the IRS, and state financial institution regulators) have been examining the Bitcoin Network, bitcoin users and the Bitcoin Exchange Market, with particular focus on the extent to which bitcoins can be used to launder the proceeds of illegal activities or fund criminal or terrorist enterprises and the safety and soundness of exchanges or other service providers that hold bitcoins for users. The imposition of stricter governmental regulation of the bitcoin market may adversely impact the activities of the Fund, for example, by reducing the liquidity of the bitcoin markets.

Regulation of futures markets, futures contracts and futures exchanges is extensive and constantly changing; future regulatory developments are impossible to predict but may significantly and adversely affect the Fund. This risk is especially heightened for cryptocurrency derivatives and cryptocurrencies.

The regulation of futures markets, futures contracts and futures exchanges has historically been comprehensive. The CFTC and the exchanges are authorized to take extraordinary actions in the event of a market emergency including, for example, the retroactive implementation of speculative position limits, increased margin requirements, the establishment of dynamic price limits and the suspension of trading on an exchange or trading facility.

The regulation of bitcoin interest and crypto derivatives transactions in the United States is a rapidly changing area of law and is subject to ongoing modification by governmental and judicial action. Congress enacted the Dodd-Frank Wall Street Reform and Consumer Protection Act (the "Dodd-Frank Act") in 2010. As the Dodd-Frank Act continues to be implemented by the CFTC and the SEC, there is a possibility of future regulatory changes within the United States altering, perhaps to a material extent, the nature of an investment in the Fund, or the ability for the Fund to continue to implement its investment strategy. In addition, various national governments outside of the United States have expressed concern regarding the disruptive effects of speculative trading in the commodities and crypto derivatives markets and the need to regulate the derivatives markets in general. The effect of any future regulatory change on the Fund is impossible to predict but could be substantial and adverse.

The regulation of cryptocurrency derivatives and cryptocurrencies continues to evolve. Inconsistent, changing and sometimes conflicting regulations may make it more difficult for Bitcoin businesses to provide services, which may slow the adoption of the Bitcoin economy and may impede consumer adoption of Bitcoin. Future regulatory changes may materially alter the ability to buy and sell Bitcoin and Bitcoin futures or could impact the ability of the Fund to achieve its investment objective. This may alter the nature of an investment in the Fund or the ability of the Fund to continue to operate as planned.

    Registration No. 333-273364

The Fund's Operating Risks

The Fund may change its investment objective, Benchmark or investment strategies at any time without Shareholder approval or advance notice.

Consistent with applicable provisions of the Trust Agreement and Delaware law, the Fund has broad authority to make changes to the Fund's operations. The Fund may change its investment objective, Benchmark, or investment strategies and Shareholders of the Fund will not have any rights with respect to these changes. Changes are subject to applicable regulatory requirements, including, but not limited to, any requirement to amend applicable listing rules of NYSE Arca. The reasons for and circumstances that may trigger any such changes may vary widely and cannot be predicted. By way of example, the Fund may change the term structure or underlying components of the Benchmark in furtherance of the Fund's investment objective if, due to market conditions, a potential or actual imposition of position limits by the CFTC or futures exchange rules, or the imposition of risk mitigation measures by a futures commission merchant restricts the ability of the Fund to invest in the current Benchmark Futures Contracts. Shareholders may experience losses on their investments in the Fund as a result of such changes.

The Fund is not a registered investment company, so you do not have the protections of the Investment Company Act of 1940.

The Fund is not an investment company subject to the Investment Company Act of 1940. Accordingly, you do not have the protections expressly provided by that statute, including: provisions preventing Fund insiders from managing the Fund to their benefit and to the detriment of Fund Shareholders; provisions preventing the Fund from issuing securities having inequitable or discriminatory provisions; provisions preventing Fund management by irresponsible persons; provisions preventing the use of unsound or misleading methods of computing Fund earnings and asset value; provisions prohibiting suspension of redemptions (except under limited circumstances); provisions limiting fund leverage; provisions imposing a fiduciary duty on fund managers with respect to receipt of compensation for services; and provisions preventing changes in the Fund's character without the consent of Fund Shareholders.

The Sponsor relies on key personnel to oversee commodity pool activities.

In overseeing the day to day activities of the Commodity Pool, the Sponsor relies on a single Series 3-registered individual, Mr. Gavin Filmore. If Mr. Filmore were to leave or be unable to carry out their present responsibilities, it will have an adverse effect on the management of the Fund. To the extent that the Sponsor establishes additional commodity pools, even greater demands will be placed on this individual. There is no guarantee that the Sponsor will be able to retain this individual.

The Sponsor has limited capital and may be unable to continue to manage the Fund if it sustains continued losses.

The Sponsor was formed for the purpose of managing the Trust, including the Fund, and any other series of the Trust that may be formed in the future, and has been provided with capital primarily by its principals and a small number of outside investors. If the Sponsor operates at a loss for an extended period, its capital will be depleted, and it may be unable to obtain additional financing necessary to continue its operations. If the Sponsor were unable to continue to provide services to the Fund, the Fund would be terminated if a replacement sponsor could not be found. Any expenses related to the operation of the Fund would need to be paid by the Fund at the time of termination.

There are technical and fundamental risks inherent in the trading system the Sponsor intends to employ.

You cannot be assured that the Sponsor will be willing or able to continue to service the Fund for any length of time. If the Sponsor discontinues its activities on behalf of the Fund or other investment fund complex, the Fund may be adversely affected. If the Sponsor's registrations with the CFTC or memberships in the NFA were revoked or suspended, the Sponsor would no longer be able to provide services to the Fund. The Sponsor's trading system is quantitative in nature, and it is possible that the Sponsor may make errors. Any errors or imperfections in the Sponsor's trading system's quantitative models, or in the data on which they are based, could adversely affect the Sponsor's effective use of such trading systems. It is not possible or practicable for the Sponsor's trading system to factor all relevant, available data into quantitative systems and/or trading decision. There is no guarantee that the Sponsor will use any specific data or type of data in making trading decisions on behalf of the Fund, nor is there any guarantee that the data actually utilized in making trading decisions on behalf of the Fund will be the most accurate data or free from errors. In addition, it is possible that a computer or software program may malfunction and cause an error in computation

You cannot be assured of the Sponsor's continued services, and discontinuance may be detrimental to the Fund.

You cannot be assured that the Sponsor will be willing or able to continue to service the Fund for any length of time. If the Sponsor discontinues its activities on behalf of the Fund or other investment fund complex, the Fund may be adversely affected. If the Sponsor's registrations with the CFTC or memberships in the NFA were revoked or suspended, the Sponsor would no longer be able to provide services to the Fund.

    Registration No. 333-273364

The Fund could terminate at any time and cause the liquidation and potential loss of your investment and could upset the overall maturity and timing of your investment portfolio.

The Fund may terminate at any time, regardless of whether the Fund has incurred losses, subject to the terms of the Trust Agreement. For example, the dissolution or resignation of the Sponsor would cause the Trust to terminate unless Shareholders holding a majority of the outstanding Shares of the Trust, voting together as a single class, elect within 90 days of the event to continue the Trust and appoint a successor Sponsor. In addition, the Sponsor may terminate the Fund if it determines that the Fund's aggregate net assets in relation to its operating expenses make the continued operation of the Fund unreasonable or imprudent. As of the date of this prospectus, the Sponsor pays the fees, costs, and expenses of the Fund. If the Sponsor and the Fund are unable to raise sufficient funds so that the expenses are reasonable in relation to the Fund's NAV, the Fund may be forced to terminate, and investors may lose all or part of their investment. Any expenses related to the operation of the Fund would need to be paid by the Sponsor at the time of termination.

However, no level of losses will require the Sponsor to terminate the Fund. The Fund's termination would result in the liquidation of its investments and the distribution of its remaining assets to the Shareholders on a pro rata basis in accordance with their Shares, and the Fund could incur losses in liquidating its investments in connection with a termination. Termination could also negatively affect the overall maturity and timing of your investment portfolio.

The Sponsor may manage a large amount of assets, and this could affect the Fund's ability to trade profitably.

Increases in assets under management may affect trading decisions. While the Fund's assets are currently at manageable levels, the Sponsor does not intend to limit the amount of Fund assets. The more assets the Sponsor manages, the more difficult it may be for it to trade profitably because of the difficulty of trading larger positions without adversely affecting prices and performance and of managing risk associated with larger positions.

The liability of the Sponsor and the Trustee are limited, and the value of the Shares will be adversely affected if the Fund is required to indemnify the Trustee or the Sponsor.

Under the Trust Agreement, the Trustee and the Sponsor are not liable, and have the right to be indemnified, for any liability or expense incurred absent gross negligence or willful misconduct on the part of the Trustee or Sponsor, as the case may be. That means the Sponsor may require the assets of the Fund to be sold in order to cover losses or liability suffered by the Sponsor or by the Trustee. Any sale of that kind would reduce the NAV of the Fund and the value of its Shares.

The Fund may incur higher fees and expenses upon renewing existing or entering into new contractual relationships.

The arrangements between clearing brokers and counterparties on the one hand and the Fund on the other generally are terminable by the clearing brokers or counterparty upon notice to the Fund. In addition, the agreements between the Fund and its third-party service providers, such as the Marketing Agent and the Custodian, are generally terminable at specified intervals. Upon termination, the Sponsor may be required to renegotiate or make other arrangements for obtaining similar services if the Fund intends to continue to operate. Comparable services from another party may not be available, or even if available, these services may not be available on the terms as favorable as those of the expired or terminated arrangements.

The Fund may experience a higher breakeven if interest rates decline.

The Fund seeks to earn interest on cash balances available for investment. If actual interest rates earned were lower than the current rate estimated and if the Sponsor were not able to waive expenses sufficient to cover the deficit, the breakeven estimated by the Fund in this prospectus could be higher.

The Fund is not actively managed.

The Fund is not actively managed and is designed to track a benchmark, regardless of whether the price of the Benchmark Component Futures Contracts is flat, declining or rising. As a result, the Fund may sustain losses that may have been avoidable if the Fund was actively managed.

The Net Asset Value calculation of the Fund may be overstated or understated due to the valuation method employed when a settlement price is not available on the date of net asset value calculation.

The Fund's NAV includes, in part, any unrealized profits or losses on open positions. Under normal circumstances, the NAV reflects the quoted CME settlement price of open futures contracts on the date when the NAV is being calculated. In instances when the quoted settlement price of futures contracts traded on an exchange may not be reflective of fair value based on market condition, generally due to the operation of daily limits or other rules of the exchange or otherwise, the NAV may not reflect the fair value of open futures contracts on such date. For purposes of financial statements and reports, when a bitcoin futures contract has closed at its price fluctuation limit the Fund will use the daily CME settlement price for the determination of NAV.

Purchases or redemptions of creation units in cash may cause the Fund to incur certain costs or recognize gains or losses.

Purchases and redemptions of creation units will be transacted in cash rather than 'in-kind' where creation units are purchased and redeemed in exchange for underlying constituent securities. Purchases of creation baskets with cash may cause the Fund to incur certain costs including brokerage commissions and redemptions of creation baskets with cash may result in the recognition of gains or losses that the Fund might not have incurred if it had made redemptions in-kind.

    Registration No. 333-273364

An unanticipated number of redemption requests during a short period of time could have an adverse effect on the NAV of the Fund.

If a substantial number of requests for redemption of Redemption Baskets are received by the Fund during a relatively short period of time, the Fund may not be able to satisfy the requests from the Fund's assets not committed to trading. As a consequence, it could be necessary to liquidate the Fund's trading positions before the time that its trading strategies would otherwise call for liquidation, which may result in losses.

Fund assets may be depleted if investment performance does not exceed fees.

In addition to certain fees paid to the Fund's service providers, the Fund pays the Sponsor a fee of 0.94% of assets under management per annum, regardless of Fund performance. Over time, the Fund's assets could be depleted if investment performance does not exceed such fees.

The liquidity of the Shares may be affected by the withdrawal from participation of Authorized Purchasers, market makers, or other significant secondary-market purchasers which could adversely affect the market price of the Shares.

Only an Authorized Purchaser may engage in creation or redemption transactions directly with the Fund. The Fund has a limited number of institutions that act as Authorized Purchasers. To the extent that these institutions exit the business or are unable to proceed with creation and/or redemption orders with respect to the Fund and no other Authorized Purchaser is able to step forward to create or redeem creation units, Fund Shares may trade at a discount to NAV and possibly face trading halts and/or delisting. In addition, a decision by a market maker, lead market maker, or other large investor to cease activities for the Fund or a decision by a secondary market purchaser to sell a significant number of the Fund's Shares could adversely affect liquidity, the spread between the bid and ask quotes, and potentially the price of the Shares. The Sponsor can make no guarantees that participation by Authorized Purchasers or market makers will continue.

If a minimum number of Shares is outstanding, market makers may be less willing to purchase Shares in the secondary market which may limit your ability to sell Shares.

There is a minimum number of baskets and associated Shares specified for the Fund. If the Fund experienced redemptions that caused the number of Shares outstanding to decrease to the minimum level of Shares required to be outstanding, until the minimum number of Shares is again exceeded through the purchase of a new Creation Basket, there can be no more redemptions by an Authorized Purchaser. In such case, market makers may be less willing to purchase Shares from investors in the secondary market, which may in turn limit the ability of Shareholders of the Fund to sell their Shares in the secondary market. These minimum levels for the Fund are 50,000 Shares representing five baskets. The minimum level of Shares specified for the Fund is subject to change. (The current number of Shares outstanding will be posted daily on our website, http://hashdex-etfs.com/.)

The postponement, suspension or rejection of purchase or redemption orders could adversely affect a Shareholder redeeming their Shares in the Fund.

The postponement, suspension or rejection of creation or redemption orders may adversely affect an investment in the Shares of the Fund. To the extent orders are suspended or rejected, the arbitrage mechanism resulting from the process through which Authorized Purchasers create and redeem Shares directly with the Fund may fail to closely link the price of the Shares to the value of the underlying Bitcoin Futures Contracts, as measured using the Benchmark. If this is the case, the liquidity of the Shares may decline, and the price of the Shares may fluctuate independently of the Benchmark and may fall.

There are no limitations on the Sponsor's discretion to postpone, suspend or reject purchase or redemption orders under the Securities Act or SEC listing orders permitting the listing and trading of the Fund's Shares on NYSE Arca. In addition, Shareholders of the Fund will not have the protections provided in this regard that are applicable to funds regulated under the Investment Company Act of 1940.

Investors may not be able to buy or sell Shares of the Fund through their current brokerages.

Because of volatility and other risks associated with bitcoin-related investments, brokerage firms may limit or not permit trading in such investments. Because of current or future brokerage policies regarding bitcoin-linked securities, investors could have difficulty selling Shares through their brokerage and potentially face restrictions when or how they could trade their Shares.

The failure or bankruptcy of a clearing broker could result in substantial losses for the Fund; the clearing broker could be subject to proceedings that impair its ability to execute the Fund's trades.

Under CFTC regulations, a clearing broker with respect to the Fund's exchange-traded bitcoin interests must maintain customers' assets in a bulk segregated account. If a clearing broker fails to do so or is unable to satisfy a substantial deficit in a customer account, its other customers may be subject to risk of a substantial loss of their funds in the event of that clearing broker's bankruptcy. In that event, the clearing broker's customers, such as the Fund, are entitled to recover, even in respect of property specifically traceable to them, only a proportional share of all property available for distribution to all of that clearing broker's customers. The Fund also may be subject to the risk of the failure of, or delay in performance by, any exchanges and markets and their clearing organizations, if any, on which bitcoin interests are traded.

    Registration No. 333-273364

From time to time, the clearing brokers may be subject to legal or regulatory proceedings in the ordinary course of their business. A clearing broker's involvement in costly or time-consuming legal proceedings may divert financial resources or personnel away from the clearing broker's trading operations, which could impair the clearing broker's ability to successfully execute and clear the Fund's trades.

The failure or insolvency of the Fund's Custodian or other financial institution in which the Fund has deposits could result in a substantial loss of the Fund's assets.

As noted above, the vast majority of the Fund's assets are held in cash and cash equivalents with the Custodian and other financial institutions, if applicable. The insolvency of the Custodian and any financial institution in which the Fund holds cash and cash equivalents could result in a complete loss of the Fund's assets.

Third parties may infringe upon or otherwise violate intellectual property rights or assert that the Sponsor has infringed or otherwise violated their intellectual property rights, which may result in significant costs, litigation, and diverted attention of Sponsor's management.

Third parties may assert that the Sponsor has infringed or otherwise violated their intellectual property rights. Third parties may independently develop business methods, trademarks or proprietary software and other technology similar to that of the Sponsor and claim that the Sponsor has violated their intellectual property rights, including their copyrights, trademark rights, trade names, trade secrets and patent rights. As a result, the Sponsor may have to litigate in the future to determine the validity and scope of other parties' proprietary rights or defend itself against claims that it has infringed or otherwise violated other parties' rights. Any litigation of this type, even if the Sponsor is successful and regardless of the merits, may result in significant costs, divert resources from the Fund, or require the Sponsor to change its proprietary software and other technology or enter into royalty or licensing agreements.

The Fund may experience substantial losses on transactions if the computer or communications system fails.

The Fund's trading activities depend on the integrity and performance of the computer and communications systems supporting them. Extraordinary transaction volume, hardware or software failure, power or telecommunications failure, a natural disaster, cyber-attack or other catastrophe could cause the computer systems to operate at an unacceptably slow speed or even fail. Any significant degradation or failure of the systems that the Sponsor uses to gather and analyze information, enter orders, process data, monitor risk levels and otherwise engage in trading activities may result in substantial losses on transactions, liability to other parties, lost profit opportunities, damages to the Sponsor's and Fund's reputations, increased operational expenses and diversion of technical resources.

If the computer and communications systems are not upgraded when necessary, the Fund's financial condition could be harmed.

The development of complex computer and communications systems and new technologies may render the existing computer and communications systems supporting the Fund's trading activities obsolete. In addition, these computer and communications systems must be compatible with those of third parties, such as the systems of exchanges, clearing brokers and the executing brokers. As a result, if these third parties upgrade their systems, the Sponsor will need to make corresponding upgrades to effectively continue its trading activities. The Sponsor may have limited financial resources for these upgrades or other technological changes. The Fund's future success may depend on the Sponsor's ability to respond to changing technologies on a timely and cost-effective basis.

The Fund depends on the reliable performance of the computer and communications systems of third parties, such as brokers and futures exchanges, and may experience substantial losses on transactions if they fail.

The Fund depends on the proper and timely function of complex computer and communications systems maintained and operated by the futures exchanges, brokers and other data providers that the Sponsor uses to conduct trading activities. Failure or inadequate performance of any of these systems could adversely affect the Sponsor's ability to complete transactions, including its ability to close out positions, and result in lost profit opportunities and significant losses on cryptocurrency derivative transactions. This could have a material adverse effect on revenues and materially reduce the Fund's available capital. For example, unavailability of price quotations from third parties may make it difficult or impossible for the Sponsor to conduct trading activities so that the Fund will closely track the Benchmark. Unavailability of records from brokerage firms may make it difficult or impossible for the Sponsor to accurately determine which transactions have been executed or the details, including price and time, of any transaction executed. This unavailability of information also may make it difficult or impossible for the Sponsor to reconcile its records of transactions with those of another party or to accomplish settlement of executed transactions.

An investment in a Fund faces numerous risks from its Shares being traded in the secondary market, any of which may lead to the Fund's Shares trading at a premium or discount to NAV.

Although the Fund's Shares are listed for trading on NYSE Arca, there can be no assurance that an active trading market for such Shares will develop or be maintained. Trading in the Fund's Shares may be halted due to market conditions or for reasons that, in the view of NYSE Arca, make trading in Shares inadvisable. There can be no assurance that the requirements of NYSE Arca necessary to maintain the listing of the Fund will continue to be met or will remain unchanged or that the Shares will trade with any volume, or at all. The NAV of the Fund's Shares will generally fluctuate with changes in the market value of the Fund's portfolio holdings. The market prices of Shares will generally fluctuate in accordance with changes in the Fund's NAV and supply and demand of Shares on NYSE Arca. It cannot be predicted whether the Fund's Shares will trade below at or above their NAV. Investors who buy the Fund's Shares at a market price that is a premium to NAV face a risk of loss if the market price of their Shares subsequently converges with NAV per Share. Investors buying or selling Fund Shares in the secondary market will pay brokerage commissions or other charges imposed by brokers as determined by that broker. Brokerage commissions are often a fixed amount and may be a significant proportional cost for investors seeking to buy or sell relatively small amounts of Shares.

    Registration No. 333-273364

NYSE Arca may halt trading in the Shares which would adversely impact your ability to sell Shares.

Trading in Shares of the Fund may be halted by NYSE Arca due to market conditions or, in light of NYSE Arca rules and procedures, for reasons that, in view of NYSE Arca, make trading in Shares inadvisable. Such market conditions or other reasons may include when there is significant news directly related to the Fund that, in NYSE Arca's view or per existing NYSE Arca rules, requires a trading halt, such as when the Sponsor announces news relating to changes/disruptions in the Fund's create/redeem process during market trading hours. In addition, market conditions that would result in trading halts may also include extraordinary market volatility that trigger rules requiring trading to be halted for a specified period based on a specified market decline. NYSE Arca might also halt trading if there is insufficient trading in BTC or MBT Contracts. There can be no assurance that the requirements necessary to maintain the listing of the Shares will continue to be met or will remain unchanged. The Fund will be terminated if its Shares are delisted.

A Pause in Bitcoin Futures Contracts May lead To Gaps Between Prices in Spot and Futures Markets.

On May 19, 2021, the CME Group temporarily paused trading of bitcoin futures after the bitcoin futures market opened to a large price gap between the derivatives and the underlying crypto asset that triggered CME circuit breakers. Due to the misaligned trading periods between spot and futures markets, such gaps, which can be positive or negative, have the potential to frequently exist and, when CME circuit breakers limit the trading in bitcoin futures markets, bid/ask spreads in Shares of the Fund trading on NYSE Arca may be significantly wider than when bitcoin futures markets are trading without restrictions, which may adversely impact your ability to buy or sell Shares in the Fund at a particular price.

The lack of active trading markets for the Shares of the Fund may result in losses on your investment in the Fund at the time of disposition of your Shares.

Although the Shares of the Fund will be listed and traded on NYSE Arca, there can be no guarantee that an active trading market for the Shares of the Fund will be maintained. If you need to sell your Shares at a time when no active market for them exists, the price you receive for your Shares, assuming that you are able to sell them, likely will be lower than what you would receive if an active market did exist.

The Fund is newly formed by virtue of the Merger with Predecessor Fund and may not be successful in implementing its investment objective or attracting sufficient assets.

The Fund is the survivor of the Merger with the Predecessor Fund and has a limited operating history and a small asset base. There can be no assurance that the Fund will grow to or maintain a viable size. Due to the Fund's small asset base, the Fund's portfolio transaction costs and any costs that are not paid by the Sponsor pursuant to the Management Fee, may be relatively higher than those of a fund with a larger asset base. To the extent that the Fund does not grow to or maintain a viable size, it may be liquidated, and the expenses, timing and tax consequences of such liquidation may not be favorable to some Shareholders. In this regard, as of the date of this prospectus there are at least seven bitcoin futures contracts, not including the Predecessor Fund. In this regard, as of the date of this prospectus there are three bitcoin futures-based ETFs. The first fund launched has obtained significantly more assets than the other two. To the extent that this "first mover" advantage continues to favor the first fund launched, this might constrain the Fund's growth.

Sponsoring the Fund will be the Sponsor's first experience in the crypto asset markets.

There are risks related to the Sponsor's lack of experience in the crypto asset markets, particularly with respect to marketing the Fund. To address this risk, the Sponsor has entered into the Support Agreement discussed above, under which Hashdex will provide crypto asset related marketing services. To the extent that the Fund does not grow to or maintain a viable size, it may be liquidated, and the expenses, timing and tax consequences of such liquidation may not be favorable to some Shareholders.

Existing or future bitcoin futures based ETFs may have significantly lower management fees, which may impede the growth of the Fund.

Existing and future bitcoin futures based ETFs may have fees that are significantly lower than the Fund's. To the extent that the Fund has relatively higher fees than other such funds, this could impede growth of the Fund, possibly result in a lower NAV per Share, and otherwise pose a material risk to investors.

The Market for Bitcoin Futures-Based ETFs May Reach Saturation

The market for bitcoin futures-based ETFs like the Fund may reach a point where there is little or no additional investor demand. If this happens, there can be no assurance that the Fund will grow to or maintain a viable size. Due to the Fund's small asset base, certain of the Fund's expenses and its portfolio transaction costs may be higher than those of a fund with a larger asset base. To the extent that the Fund does not grow to or maintain a viable size, it may be liquidated, and the expenses, timing and tax consequences of such liquidation may not be favorable to some Shareholders.

    Registration No. 333-273364

Potential Conflicts of Interest

The Fund and the Sponsor may have conflicts of interest, which may cause them to favor their own interests to your detriment.

The Fund and the Sponsor may have inherent conflicts to the extent the Sponsor attempts to maintain the Fund's asset size in order to preserve its fee income and this may not always be consistent with the Fund's objective of having the value of its Shares' NAV track changes in the Benchmark. The Sponsor's officers and employees do not devote their time exclusively to the Fund. These persons may be directors, trustees, officers or employees of other entities. They could have a conflict between their responsibilities to the Fund and to those other entities.

The Sponsor's principals, officers or employees may trade securities and futures and related contracts for their own accounts.

In addition, the Sponsor's principals, officers or employees may trade securities and futures and related contracts for their own accounts. A conflict of interest may exist if their trades are in the same markets and occur at the same time as the Fund trades using the clearing broker to be used by the Fund. A potential conflict also may occur if the Sponsor's principals, officers or employees trade their accounts more aggressively or take positions in their accounts that are opposite, or ahead of, the positions taken by the Fund.

The Sponsor has sole current authority to manage the investments and operations of the Fund, and this may allow it to act in a way that furthers its own interests and in conflict with your best interests, including the authority of the Sponsor to allocate expenses to and between the funds of the Trust. Shareholders have very limited voting rights, which will limit the ability to influence matters such as amendment of the Trust Agreement, changes in the Fund's basic investment policies, dissolution of the Fund, or the sale or distribution of the Fund's assets.

Shareholder Voting Rights and Liability

Shareholders have only very limited voting rights and generally will not have the power to replace the Sponsor. Shareholders will not participate in the management of the Fund and do not control the Sponsor so they will not have influence over basic matters that affect the Fund.

Shareholders will have very limited voting rights with respect to the Fund's affairs. Shareholders may elect a replacement sponsor only if the current Sponsor resigns voluntarily or loses its corporate charter. Shareholders will not be permitted to participate in the management or control of the Fund or the conduct of its business. Shareholders must therefore rely upon the duties and judgment of the Sponsor to manage the Fund's affairs.

Although the Shares of the Fund are limited liability investments, certain circumstances such as bankruptcy could increase a Shareholder's liability.

The Shares of the Fund are limited liability investments. Shareholders may not lose more than the amount that they invest plus any profits recognized on their investment. However, Shareholders could be required, as a matter of bankruptcy law, to return to the estate of the Fund any distribution they received at a time when the Fund was in fact insolvent or that was made in violation of its Trust Agreement.

As a Shareholder, you will not have the rights enjoyed by investors in certain other types of entities.

As interests in separate series of a Delaware statutory trust, the Shares do not involve the rights normally associated with the ownership of shares of a corporation (including, for example, the right to bring Shareholder oppression and derivative actions). In addition, the Shares have limited voting and distribution rights (for example, Shareholders do not have the right to elect directors, as the Trust does not have a board of directors, and generally will not receive regular distributions of the net income and capital gains earned by the Fund). The Fund is also not subject to certain investor protection provisions of the Sarbanes Oxley Act of 2002 and NYSE Arca governance rules (for example, audit committee requirements).

A court could potentially conclude that the assets and liabilities of the Fund are not segregated from those of another series of the Trust, thereby potentially exposing assets in the Fund to the liabilities of another series.

The Fund is a series of a Delaware statutory trust and not itself a legal entity separate from the other series. The Delaware Statutory Trust Act provides that if certain provisions are included in the formation and governing documents of a statutory trust organized in series and if separate and distinct records are maintained for any series and the assets associated with that series are held in separate and distinct records and are accounted for in such separate and distinct records separately from the other assets of the statutory trust, or any series thereof, then the debts, liabilities, obligations and expenses incurred by a particular series are enforceable against the assets of such series only, and not against the assets of the statutory trust generally or any other series thereof. Conversely, none of the debts, liabilities, obligations and expenses incurred with respect to any other series thereof is enforceable against the assets of such series. The Sponsor is not aware of any court case that has interpreted this inter-series limitation on liability or provided any guidance as to what is required for compliance. The Sponsor intends to maintain separate and distinct records for the Fund and account for the Fund separately from any other Trust series, but it is possible a court could conclude that the methods used do not satisfy the Delaware Statutory Trust Act, which would potentially expose assets in the Fund to the liabilities of one or more of the Funds and/or any other Trust series created in the future.

    Registration No. 333-273364

The Fund does not expect to make cash distributions.

The Sponsor intends to re-invest any income and realized gains of the Fund in additional Benchmark Component Futures Contracts or cash and cash equivalents rather than distributing cash to Shareholders. Therefore, unlike mutual funds, commodity pools or other investment pools that generally distribute income and gains to their investors, the Fund generally will not distribute cash to Shareholders. You should not invest in the Fund if you will need cash distributions from the Fund to pay taxes on your Share of income and gains of the Fund, if any, or for any other reason. Although the Fund does not intend to make cash distributions, it reserves the right to do so in the Sponsor's sole discretion, in certain situations, including for example, if the income earned from its investments held directly or posted as margin may reach levels that merit distribution, e.g., at levels where such income is not necessary to support its underlying investments in Benchmark Component Futures Contracts and investors adversely react to being taxed on such income without receiving distributions that could be used to pay such tax. Cash distributions may be made in these and similar instances.

Event Risk

The occurrence of a severe weather event, natural disaster, terrorist attack, outbreak or public health emergency as declared by the World Health Organization, the continuation or expansion of war or other hostilities, or a prolonged government shutdown may have significant adverse effects on the Fund and its investments and alter current assumptions and expectations.

The operations of the Fund, the exchanges, brokers and counterparties with which the Fund does business, and the markets in which the Fund does business could be severely disrupted in the event of a severe weather event, natural disaster, major terrorist attack, cyber-attack, data breach, outbreak or public health emergency as declared by the World Health Organization (such as the recent pandemic spread of the novel coronavirus known as COVID-19), or the continuation or expansion of war or other hostilities. Global terrorist attacks, anti-terrorism initiatives, war and other geopolitical events and political unrest, as well as the adverse impact the COVID-19 pandemic will have on the global and U.S. markets and economy, continue to fuel this concern. For example, events in Eastern Europe and Asia, including but not limited to the war in Ukraine or actions by China and North Korea, may cause volatility in bitcoin markets or the COVID-19 pandemic may adversely impact the level of services currently provided by the U.S. government, could weaken the U.S. economy, interfere with the commodities markets that rely upon data published by U.S. federal government agencies, and prevent the Fund from receiving necessary regulatory review or approvals. The types of events discussed above, including the COVID-19 pandemic, are highly disruptive to economies and markets and have recently led, and may continue to lead, to increased market volatility and significant market losses.

More generally, a climate of uncertainty and panic, including the contagion of the COVID-19 virus and other infectious viruses or diseases, may adversely affect global, regional, and local economies and reduce the availability of potential investment opportunities, and increases the difficulty of performing due diligence and modeling market conditions, potentially reducing the accuracy of financial projections. Under these circumstances, the Fund may have difficulty achieving its investment objective which may adversely impact performance. Further, such events can be highly disruptive to economies and markets, significantly disrupt the operations of individual companies (including, but not limited to, the Fund's Sponsor and third party service providers), sectors, industries, markets, securities and commodity exchanges, currencies, interest and inflation rates, credit ratings, investor sentiment, and other factors affecting the value of the Fund's investments. These factors could cause substantial market volatility, exchange trading suspensions and closures that could impact the ability of the Fund to complete redemptions and otherwise affect Fund performance and Fund trading in the secondary market. A widespread crisis may also affect the global economy in ways that cannot necessarily be foreseen at the current time. How long such events will last and whether they will continue or recur cannot be predicted. Impacts from these events could have significant impact on the Fund's performance, resulting in losses to your investment. The past, current and future global economic impact may cause the underlying assumptions and expectations of the Fund to become outdated quickly or inaccurate, resulting in significant losses.

Failures or breaches of electronic systems could disrupt the Fund's trading activity and materially affect the Fund's profitability.

Failures or breaches of the electronic systems of the Fund, the Sponsor, the Custodian or other financial institutions in which the Fund invests, or the Fund's other service providers, market makers, Authorized Purchasers, NYSE Arca, exchanges on which Bitcoin Futures Contracts or other bitcoin interests are traded or cleared, or counterparties have the ability to cause disruptions and negatively impact the Fund's business operations, potentially resulting in financial losses to the Fund and its Shareholders. Such failures or breaches may include intentional cyber-attacks that may result in an unauthorized party gaining access to electronic systems in order to misappropriate the Fund's assets or sensitive information. While the Fund has established business continuity plans and risk management systems seeking to address system breaches or failures, there are inherent limitations in such plans and systems. Furthermore, the Fund cannot control the cyber security plans and systems of the Custodian or other financial institutions in which the Fund invests, or the Fund's other service providers, market makers, Authorized Purchasers, NYSE Arca, exchanges on which bitcoin Futures Contracts or other bitcoin interests are traded or cleared, or counterparties.

Risk of Volatility

The price of bitcoin can be volatile which could cause large fluctuations in the price of Shares.

As discussed in more detail above, price movements for bitcoin are influenced by, among other things, the environment, natural or man-made disasters, governmental oversight and regulation, demographics, economic conditions, infrastructure limitations, existing and future technological developments, and a variety of other factors now known and unknown, any and all of which can have an impact on the supply, demand, and price fluctuations in the bitcoin markets. More generally, cryptocurrency prices may be influenced by economic and monetary events such as changes in interest rates, changes in balances of payments and trade, U.S. and international inflation rates, currency valuations and devaluations, U.S. and international economic events, and changes in the philosophies and emotions of market purchasers. Because the Fund invests in futures contracts in a single cryptocurrency, it is not a diversified investment vehicle, and therefore may be subject to greater volatility than a diversified portfolio of stocks or bonds or a more diversified commodity or cryptocurrency pool.

    Registration No. 333-273364

Volatility is a statistical measure of the dispersion of returns for a given security or market index. Volatility represents how large an asset's prices swing around the mean price-it is a statistical measure of its dispersion of returns.

According to Bloomberg from 6/30/2022 to 6/30/2023 front month Bitcoin Futures Contracts exhibited an average implied 30-Day volatility of 61.24. The highest volatility during that period was 92.86 on 7/12/22 and the lowest was 27.58 on 10/24/2022.

Bitcoin can be highly volatile, for example, after a 774% price increase from 1/1/2020 prices peaked in May 2021 and front month Bitcoin Futures Contracts began to decline with a peak to trough retracement of 47.06% by 7/20/2021. Prices then rose from that low until 11/9/2021 resulting in a price increase of 127.58%. Front month Bitcoin Futures Contracts prices peaked on 11/9/2021 and have since seen a retracement of 57.05% as of 5/27/2022. Front month bitcoin futures prices have declined 54.51% since May 2021.

The table below includes significant single day price declines since inception of the Bitcoin Futures Contracts in December 2017 for both bitcoin (as measured by the BRR) and for Bitcoin Futures Contracts (as measured by the front month Bitcoin Futures Contract), including the single day price decline that occurred on September 7, 2021, followed by a brief narrative disclosure describing the significant declines:

    Registration No. 333-273364

    Registration No. 333-273364

Tax Risk

Please refer to "U.S. Federal Income Tax Considerations" for information regarding the U.S. federal income tax consequences of the purchase, ownership and disposition of Shares.

The Fund could be treated as a corporation for U.S. federal income tax purposes, which may substantially reduce the value of your Shares.

The Trust has received an opinion of counsel that, under current U.S. federal income tax laws, the Fund more likely than not will be treated as a partnership that is not taxable as a corporation for U.S. federal income tax purposes, provided that, among other things, (i) at least 90 percent of the Fund's annual gross income consists of "qualifying income" as defined in the Internal Revenue Code of 1986, as amended (the "Code"), (ii) the Fund is organized and operated in accordance with its governing agreements and applicable law, and (iii) the Fund does not elect to be taxed as a corporation for U.S. federal income tax purposes. Opinions of counsel are not binding on the Internal Revenue Service (the "IRS") and no assurance can be given that the IRS or a court will agree with counsel's opinion. Although the Sponsor anticipates that the Fund will satisfy the "qualifying income" requirement for all of its taxable years, that result cannot be assured. There is very limited authority on the U.S. federal income tax treatment of bitcoin and no direct authority on bitcoin derivatives. The Fund has not requested and will not request any ruling from the IRS with respect to its classification as a partnership not taxable as a corporation for U.S. federal income tax purposes. If the IRS were to successfully assert that the Fund is taxable as a corporation for U.S. federal income tax purposes in any taxable year, rather than passing through its income, gains, losses and deductions proportionately to Shareholders, the Fund would be subject to tax on its net income for the year at corporate tax rates. In addition, although the Sponsor does not currently intend to make distributions with respect to Shares, any such distributions would be taxable to Shareholders as dividend income to the extent of the Fund's current and accumulated earnings and profits, then treated as a tax-free return of capital to the extent of the Shareholder's basis in the Shares (and will reduce the basis), and, to the extent they exceeds a Shareholder's basis in such Shares, as capital gain for Shareholders who hold their Shares as capital assets. Taxation of the Fund as a corporation could materially reduce the after-tax return on an investment in Shares and could substantially reduce the value of your Shares.

Your tax liability from holding Shares may exceed the amount of distributions, if any, on your Shares.

Cash or property will be distributed by the Fund at the sole discretion of the Sponsor, and the Sponsor currently does not intend to make cash or other distributions with respect to Shares. Assuming the Fund qualifies to be taxed as a partnership for U.S. federal income tax purposes, you will be required to pay U.S. federal income tax and, in some cases, state, local, or foreign income tax, on your allocable share of the Fund's taxable income, without regard to whether you receive distributions or the amount of any distributions. Therefore, the tax liability resulting from your ownership of Shares may exceed the amount of cash or value of property (if any) distributed.

Your allocable share of income or loss for U.S. federal income tax purposes may differ from your economic income or loss on your Shares.

Due to the application of the assumptions and conventions applied by the Fund in making allocations for U.S. federal income tax purposes and other factors, your allocable share of the Fund's income, gain, deduction or loss may be different than your economic profit or loss from your Shares for a taxable year. This difference could be temporary or permanent and, if permanent, could result in your being taxed on amounts in excess of your economic income.

Items of income, gain, deduction, loss and credit with respect to Shares could be reallocated and the Fund itself could be liable for U.S. federal income tax along with any interest or penalties if the IRS does not accept the assumptions and conventions applied by the Fund in allocating those items, with potential adverse consequences for you.

The Fund intends to be treated as a partnership for U.S. federal income tax purposes. The U.S. tax rules pertaining to entities taxed as partnerships are complex and their application to publicly traded partnerships such as the Fund, is in many respects uncertain. The Fund will apply certain assumptions and conventions in an attempt to comply with the intent of the applicable rules and to report taxable income, gains, deductions, losses and credits in a manner that properly reflects Shareholders' economic gains and losses. These assumptions and conventions may not fully comply with all aspects of the Code, and applicable Treasury Regulations, however, and it is possible that the IRS will successfully challenge our allocation methods and require us to reallocate items of income, gain, deduction, loss or credit in a manner that adversely affects you.

The Fund may be liable for U.S. federal income tax on any "imputed underpayment" of tax resulting from an adjustment as a result of an IRS audit. The amount of the imputed underpayment generally includes increases in allocations of items of income or gains to any investor and decreases in allocations of items of deduction, loss, or credit to any investor without any offset for any corresponding reductions in allocations of items of income or gain to any investor or increases in allocations of items of deduction, loss, or credit to any investor. If the Fund is required to pay any U.S. federal income tax on any imputed underpayment, the resulting tax liability would reduce the net assets of the Fund and would likely have an adverse impact on the value of the Shares. In such a case, the tax liability would in effect be borne by Shareholders that own Shares at the time of such assessment, which may be different persons, or persons with different ownership percentages, than persons owning Shares for the tax year under audit. Under certain circumstances, the Fund may be eligible to make an election to cause Shareholders to take into account the amount of any imputed underpayment, including any interest and penalties. The ability of a publicly traded partnership such as the Fund to make this election is uncertain. If the election is made, the Fund would be required to provide Shareholders who owned beneficial interests in the Shares in the year to which the adjusted allocations relate with a statement setting forth their proportionate shares of the adjustment ("Adjusted K-1s"). The investors would be required to take the adjustment into account in the taxable year in which the Adjusted K-1s are issued. For an additional discussion please see "U.S. Federal Income Tax Considerations - Other Tax Matters."

    Registration No. 333-273364

If the Fund is required to withhold tax with respect to any Non-U.S. Shareholders, all Shareholders may bear the cost of such withholding.

Under certain circumstances, the Fund may be required to pay withholding tax with respect to allocations to Non-U.S. Shareholders. Although the Trust Agreement provides that any such withholding will be treated as being distributed to the Non-U.S. Shareholder, the Fund may not be able to cause the economic cost of such withholding to be borne by the Non-U.S. Shareholder on whose behalf such amounts were withheld since the Fund does not intend to make any distributions. Under such circumstances, all Shareholders may bear the economic cost of the withholding, not just the Shareholders on whose behalf such amounts were withheld. This could have a material impact on the value of your Shares.

Shareholders will receive partner information tax returns on Schedule K-1, which could increase the complexity of tax returns.

The partner information tax returns on Schedule K-1, which the Fund will distribute to Shareholders, will contain information regarding the income items and expense items of the Fund. If you have not received Schedule K-1s from other investments, you may find that preparing your income tax returns may require additional time, or it may be necessary for you to retain an accountant or other tax preparer, at an additional expense to you, to assist you in the preparation of your returns.

Shareholders of the Fund may recognize significant amounts of ordinary income and short-term capital gain.

Due to the investment strategy of the Fund, the Fund may realize and pass through to Shareholders significant amounts of ordinary income and short-term capital gains as opposed to long-term capital gains. Ordinary income and short-term capital gains are generally taxed at higher U.S. federal income tax rates than the preferential U.S. federal income rates applicable to long-term capital gains.

Tax legislation that has been or could be enacted may affect you with respect to your investment in the Fund.

Legislative, regulatory or administrative changes could be enacted or promulgated at any time, either prospectively or with retroactive effect, and may adversely affect the Fund and its Shareholders. Please consult a tax advisor regarding the implications of an investment in Shares of the Fund, including without limitation the federal, state, local and foreign tax consequences.

PROSPECTIVE INVESTORS ARE STRONGLY URGED TO CONSULT THEIR OWN TAX ADVISORS WITH RESPECT TO THE POSSIBLE TAX CONSEQUENCES TO THEM OF AN INVESTMENT IN SHARES; SUCH TAX CONSEQUENCES MAY DIFFER IN RESPECT OF DIFFERENT INVESTORS.

    Registration No. 333-273364

    Registration No. 333-273364

The Fund in General

The Fund seeks to provide investors with a way to gain price exposure to the bitcoin market. In furtherance of this goal, the Fund's investment objective is for changes in the Shares' NAV to reflect the daily changes of the price of the Benchmark, less expenses from the Fund's operations. The Sponsor developed the Benchmark as a representation of the bitcoin market. As of August 23, 2023, the Fund's total net assets were $1,608,534. The Fund does not invest directly in bitcoin.

Under normal market conditions, the Fund will invest in the Benchmark Component Futures Contracts and cash and cash equivalents. The Sponsor believes that by investing in Benchmark Component Futures Contracts, the Fund's NAV will closely track the Benchmark. The Sponsor also believes that because of market arbitrage opportunities, the market price at which investors will purchase and sell Shares through their broker-dealer will closely track the Fund's NAV. The Sponsor believes that the net effect of these relationships is that the Fund's market price on NYSE Arca at which investors purchase and sell Shares will closely track the bitcoin market, as measured by the Benchmark. However, the Fund may not be successful in implementing its investment objective because the Fund is newly formed and because the BTC Contracts and MBT Contracts listed on the CME are a relatively new type of futures contract that may be less developed than more established futures markets (such as the futures markets for corn or wheat). The Fund will purchase MBT contracts only if the Fund has proceeds remaining from the sale of a Creation Basket that are less than the price of a BTC contract. BTC and MBT will count toward an aggregate position limit.

Consistent with applicable provisions of the Trust Agreement and Delaware law, the Fund has broad authority to make changes to the Fund's operations. The Fund may change its investment objective, Benchmark, or investment strategies and Shareholders of the Fund will not have any rights with respect to these changes. The Fund has no current intention to make any such change, and any change is subject to applicable regulatory requirements, including, but not limited to, any requirement to amend applicable listing rules of NYSE Arca.

The reasons for and circumstances that may trigger any such changes may vary widely and cannot be predicted. However, by way of example, the Fund may change the term structure or underlying components of the Benchmark in furtherance of the Fund's investment objective of tracking the price of the Benchmark Component Futures Contracts if, due to market conditions, a potential or actual imposition of position limits by the CFTC or futures exchange rules, or the imposition of risk mitigation measures by a futures commission merchant restricts the ability of the Fund to invest in the current Benchmark Futures Contracts. The Fund would file a current report on Form 8-K and a prospectus supplement to describe any such change and the effective date of the change. Shareholders may modify their holdings of the Fund's Shares in response to any change by purchasing or selling Fund Shares through their broker-dealer.

The Fund is organized as a series of the Tidal Commodities Trust I, a statutory trust organized under the laws of the State of Delaware on February 10, 2023. Currently, the Fund is the sole series of the Trust and it operates as a separate commodity pool. Additional series of the Trust may be created in the future at the Sponsor's discretion. The Fund maintains its main business office at 234 West Florida Street, Suite 203, Milwaukee, Wisconsin 53204. The Fund is a commodity pool. It operates pursuant to the terms of the Trust Agreement, which is dated as of February 10, 2023 and grants full management control to the Sponsor.

Market Price of Shares

The Fund's Shares have traded on NYSE Arca under the symbol "DEFI" since September 15, 2022. The following table sets forth the range of reported high and low sales prices of the Shares as reported on NYSE Arca for the periods indicated below.

Fiscal Year Ended December 31, 2022 High Low Quarter Ended September 30, 2022 $ 24.78 $ 23.77 December 31, 2022 $ 26.66 $ 19.77 March 31, 2023 $ 36.80 $ 21.48 June 30, 2023 $ 39.83 $ 32.37

As of June 30, 2023, the Fund had approximately 60 Shareholders.

Prior Performance of the Fund

PAST PERFORMANCE IS NOT NECESSARILY INDICATIVE OF FUTURE RESULTS

The Hashdex Bitcoin Futures ETF Fund commenced trading and investment operations on September 15, 2022. The Hashdex Bitcoin Futures ETF Fund is listed on NYSE Arca and is neither: (i) a privately offered pool pursuant to Section 4(a)(2) of the Securities Act of 1933, as amended. (ii) a multi-advisor pool as defined in CFTC Regulation 4.10(d)(2). or (iii) a principal protected pool as defined in CFTC Regulation 4.10(d)(3).

    Registration No. 333-273364

Units of beneficial interest issued (from inception until June 30, 2023) 110,000 Aggregate gross sale price for units issued $2,829,029 Pool NAV as of June 30, 2023 $1,938,929 NAV per Share as of June 30, 2023 $38.78 Worst monthly percentage drawdown* -14.91%/Nov 2022 -16.89% / Oct 2022 - Worst peak to valley drawdown** Dec 2022

* A drawdown is a loss experienced by the fund over a specified period. Drawdowns are measured on the basis of monthly returns only and do not reflect intra-month figures. The worst monthly percentage drawdown reflects the largest single month loss sustained over the most recent five calendar years and the current year to date.

** The worst peak to valley drawdown is the largest percentage decline in the NAV per unit over the most recent five calendar years and the current year to date. This need not be a continuous decline but can be a series of positive and negative returns. Worst peak to valley drawdown represents the greatest percentage decline from any month end NAV per unit that occurs without such month end NAV per unit being equaled or exceeded as of a subsequent month end. For example, if the NAV per unit declined by $1 in each of January and February, increased by $1 in March and declined again by $2 in April, a "peak to valley drawdown" analysis conducted as of the end of April would consider that "drawdown" to be continuing and to be $3 in amount, whereas if the NAV per unit had increased by $2 in March, the drawdown would have ended as of the end of February at the $2 level.

PAST PERFORMANCE IS NOT NECESSARILY INDICATIVE OF FUTURE RESULTS

    Registration No. 333-273364

* The monthly rate of return is calculated by dividing the ending NAV for a given month by the ending NAV for the previous month, subtracting 1 and multiplying this number by 100 to arrive at a percentage increase or decrease.

** Not annualized.

For performance information of the Sponsor's other commodity pools, see "General Pool Disclosure - Performance of Other Commodity Pools Operated by the Commodity Pool Operator" on page 62.

Discussion of Fund Performance

As of August 22, 2023, the Fund's year-to-date net asset value per share of the Fund's performance from January 1, 2023 through August 22, 2023 was 52.66%. The Sponsor believes the Fund's year to date performance can be attributed to a combination of technical factors and macro events. First, bitcoin started the year with highly depressed prices, following the November and December 2022 plunge (-19.0%, as per the Nasdaq Bitcoin Reference Price Index) in the wake of the bankruptcy of the crypto exchange FTX, which, together with other major adverse developments such as the "depegging" of Terra stablecoin, the distress involving the crypto hedge fund Three Arrows Capital and the crypto lending platform Celsius filing for bankruptcy, contributed to bitcoin's 63.8% correction in 2022 and to its 75.3% downward move from the late 2021 all-time-high.

On the back of these depressed prices, in early 2023 the market sentiment shifted toward a risk-on mode as Consumer Price Index figures indicated that U.S. inflation had been cooling off for six consecutive months, suggesting a reduced pace of U.S. federal reserve rate hikes throughout 2023. We believe these factors led the Fund to an upswing of 40.4% in the first month of 2023, following bitcoin's best January in ten years.

After a tame February performance of the Fund's Shares, March's performance shifted drastically as U.S. regional banks started crumbling due to the current high interest rate environment. As the fallout of the Silicon Valley Bank unfolded, the Fund's Shares responded very positively (+22.4% in March) due to a confluence of (i) the anticipation of more liquidity flowing into the system as the Federal Reserve's newly created Bank Term Funding Program started rescuing distressed banks, and (ii) the recognition of bitcoin as a possible safe-haven through its emerging digital store of value characteristics, a bearer asset with no counterparty risk that provides investors with an alternative to potential vulnerabilities inherent in our traditional financial system. April and May were months of predominantly lateral price movements, with no significant news directly impacting bitcoin's price.

    Registration No. 333-273364

In June, the SEC pressed charges against the exchanges Coinbase and Binance, triggering a decline in crypto prices. However, the last month of June 2023 ended on a highly positive trajectory after the news of applications for spot bitcoin ETFs in the United States. This initiated another rally in bitcoin, resulting in the Fund's performance concluding the month with a 12.8% upswing (+81.2% in June 2023)

The Sponsor

The Sponsor of the Trust is Tidal Investments LLC, a Delaware limited liability company. The principal office of the Sponsor is Milwaukee, Wisconsin and the Trust is located at 234 West Florida Street, Suite 203, Milwaukee, Wisconsin 53204. The Sponsor registered as a CPO with the CFTC and became a member of the NFA on March 8, 2022. The Sponsor has sponsored the Trust since 2023. Sponsoring the Fund will be the Sponsor's first experience in the crypto asset markets. The Sponsor's responsibilities are discussed in the following paragraph.

Under the Trust Agreement, the Sponsor is solely responsible for management and conducts or directs the conduct of the business of the Trust, the Fund, and any series of the Trust that may from time to time be established and designated by the Sponsor. The Sponsor is required to oversee the purchase and sale of Shares by Authorized Purchasers and to manage the Fund's investments, including to evaluate the credit risk of FCMs and swap counterparties and to review daily positions and margin/collateral requirements. The Sponsor has the power to enter into agreements as may be necessary or appropriate for the offer and sale of the Fund's Shares and the conduct of the Trust's activities. Accordingly, the Sponsor is responsible for selecting the Trustee, Administrator, Marketing Agent, the independent registered public accounting firm of the Trust, and any legal counsel employed by the Trust. The Sponsor is also responsible for preparing and filing periodic reports on behalf of the Trust with the SEC and will provide any required certification for such reports. The Sponsor may determine to engage marketing agents who will assist the Sponsor in marketing the Shares. See "Plan of Distribution" for more information. The Sponsor has discretion to appoint one or more of its affiliates as additional Sponsors. No person other than the Sponsor and its principals was involved in the organization of the Trust or the Fund. The Sponsor maintains a public website on behalf of the Fund, http://hashdex-etfs.com/, which contains information about the Trust, the Fund, and the Shares, and oversees certain services for the benefit of Shareholders.

The Fund pays the Sponsor a Management Fee, monthly in arrears, in an amount equal to 0.94% per annum of the daily NAV of the Fund. The Management Fee is paid in consideration of the Sponsor's services related to the management of the Fund's business and affairs, including the provision of commodity futures trading advisory services. The Fund is newly organized and as of the date of this prospectus has not paid any management fees to the Sponsor. The Sponsor pays all of the routine operational, administrative and other ordinary expenses of the Fund, generally as determined by the Sponsor, including but not limited to, fees and expenses of the Administrator, Sub-Administrator, Custodian, Marketing Agent, Transfer Agent, licensors, accounting and audit fees and expenses, tax preparation expenses, legal fees, ongoing SEC registration fees, individual Schedule K-1 preparation and mailing fees, and report preparation and mailing expenses. None of the costs and expenses related to the initial registration, offer and sale of Shares, which are estimated to be approximately $160,000, will be or are chargeable to the Fund, and the Sponsor did not and may not recover any of these costs and expenses from the Fund.

Shareholders have no right to elect the Sponsor on an annual or any other continuing basis or to remove the Sponsor. If the Sponsor voluntarily withdraws, the holders of a majority of the Trust's outstanding Shares (excluding for purposes of such determination Shares owned by the withdrawing Sponsor and its affiliates) may elect its successor. Prior to withdrawing, the Sponsor must give ninety days' written notice to the Shareholders and the Trustee.

The Sponsor is majority owned and controlled by Mr. Guillermo Trias, Mr. Michael Venuto, and a non-officer member who have provided working capital to the Sponsor. Messrs. Messrs. Trias and Venuto each currently own, directly or indirectly, 15% of the Sponsor while the non-officer member holds approximately 24.9%.

The Sponsor has an information security program and policy in place. The program takes reasonable care to look beyond the security and controls developed and implemented for the Trust and the Fund directly to the platforms and controls in place for the key service providers. Such review of cybersecurity and information technology plans of key service providers are part of the Sponsor's disaster recovery and business continuity planning. The Sponsor provides regular training to all employees of the Sponsor regarding cybersecurity topics, in addition to real-time dissemination of information regarding cybersecurity matters as needed. The information security plan is reviewed and updated as needed, but at a minimum on an annual basis.

Management of the Sponsor

Since the Merger of the Fund in 2023, the Sponsor has sponsored the Fund of the Trust and advises two investment company complexes comprising a total of 82 exchange-traded funds, as of the date of this prospectus, registered and regulated under the Investment Company Act of 1940. Sponsoring the Fund will be the Sponsor's first experience in the crypto asset markets. In general, under the Sponsor's Amended and Restated Limited Liability Company Operating Agreement, as amended from time to time, the Sponsor is managed by a board of managers, who have delegated day-to-day operational matters to the officers of the Sponsor. The Chief Executive Officer of the Sponsor is responsible for the overall strategic direction of the Sponsor and has general control of its business. The Chief Investment Officer and President of the Sponsor is primarily responsible for new investment product development with respect to the Fund. The Chief Operating Officer has primary responsibility for trade operations, trade execution, and portfolio activities with respect to the Fund. The Chief Financial Officer acts as the Sponsor's principal financial and accounting officer.

    Registration No. 333-273364

Furthermore, certain fundamental actions regarding the Sponsor, such as the removal of officers, the addition or substitution of members, or the incurrence of liabilities other than those incurred in the ordinary course of business and de minimis liabilities, may not be taken without the affirmative vote of a majority of the members. The Sponsor has a board of managers, however, and the Trust has no board of directors or officers. The five managers of the Sponsor are: Guillermo Trias, Michael Venuto, Dan Carlson, Gavin Filmore, and Eric Falkeis.

The Officers of the Sponsor, two of whom are a member's of the Sponsor, are the following:

Guillermo Trias is Co-Founder & CEO of the Sponsor, a Tidal Financial Group company, an ETF investment platform facilitating the creation, operation and growth of ETFs. Prior to Tidal, Guillermo led the strategy, sales and business development efforts at Global X Funds helping the company reach approx. $4 billion dollars in AUM before its successful sale in 2018 to an international Asset Manager. Previously, he was the founder and managing partner of two venture capital firms (MC Capital Advisors and GT Capital Advisors) dedicated to the incubation and growth of start-ups in the US and LATAM. Prior to that, he was founder and CEO of a pioneer food distributor in the US (sold to a larger distributor in 2008). Guillermo began his career in M&A investment banking with Bankers Trust & Deutsche Bank in Europe. He has a degree in Business Administration from CUNEF (top finance college in Spain) and holds an MBA from the Kellogg School of Management (Northwestern University) in Chicago, where he studied with a scholarship from Bankia (formerly Caja Madrid).

Mr. Michael Venuto is a co-founder and has been the Chief Investment Officer of the Sponsor since 2012. Mr. Venuto is an ETF industry veteran with over a decade of experience in the design and implementation of ETF-based investment strategies. Previously, he was Head of Investments at Global X Funds where he provided portfolio optimization services to institutional clients. Before that, he was Senior Vice President at Horizon Kinetics where his responsibilities included new business development, investment strategy and client and strategic initiatives.

Mr. Dan Carlson is a co-founder and currently serves as the CFO of the Sponsor, a Tidal Financial Group company. Prior to 2023, Dan was also Tidal's CCO. Previously, Dan served as the Chief Marketing Officer at Avatar Associates in New York City, where he led the firm's business development efforts. Avatar grew assets in managed portfolios of ETFs which represented over 80% of the Firm's AUM. Prior to that, Dan headed the marketing and product development efforts at Delaware Investments in Philadelphia. He started his career in Chicago, first with BMO Harris and then as a partner at Buck Consultants, serving large pension and retirement programs. Dan has served on a national industry board and currently heads a non-profit educational foundation. Dan is also a member of the Board of Directors of Tidal ETF Services LLC. Dan holds a BS degree in Accounting from the University of Illinois, Champaign-Urbana.

Mr. Eric Falkeis is the Chief Growth Officer and Co-Founder of the Administrator, a Tidal Financial Group company, and is the Chairman and an Interested Trustee of the Tidal ETF Trust I and Tidal Trust II. Before joining Tidal, Eric was the President and Chief Operating Officer of Direxion Investments, a Top 15 ETF Adviser with over 80 ETFs and $14 billion. Eric was instrumental in product development, national accounts, trading, operations and sales and marketing for their ETFs during the 5 years he worked there. Prior to Direxion, Eric was Director of ETF operations for U.S. Bancorp Fund Services, LLC ("US Bancorp"), where he built out the ETF Services Business and supporting technology. He was also a Trustee and President of US Bancorp's ETF Trust and managed the ETF servicing teams that supported that trust. During the 16 years at US Bancorp, Eric built out the Fund Administration business to over 200 employees and was also the Chief Financial Officer and Chief Technology Officer. With over 25 years of experience in the investment industry and 15 years in the ETF industry, Eric is a well-recognized expert in the industry. He has received various accolades in the industry including Innovator of the Year. Eric holds a BS degree in Accounting from Marquette University and is a Certified Public Accountant.

Mr. Gavin Filmore, Chief Operating Officer since July 2022, joined the Sponsor, a Tidal Financial Group company, in September 2021 as the Head of Product Development. He has over 15 years of experience in financial markets, with a wide range of experience including structuring, sales, and operations specifically focused on exotic cross-asset products. Most recently, he served as the head of Exchange Traded Products structuring at Barclays Capital, where he led the iPath ETN business, looking after all facets of the business including product development, regulatory affairs, capital market support, sales, and marketing. Gavin holds the Series 24, 63, 3, 7, 99, and SIE licenses.

Mr. William Woolverton is Chief Compliance Officer of the Sponsor, a Tidal Financial Group company, and of Tidal ETF Trust and Tidal Trust II. He served as General Counsel of Putnam Investments, Gottex Funds Management, and the US division of DMS Governance. He has also practiced law in the Financial Services Groups of Dechert, LLP and Rogers & Wells (Clifford Chance). Bill formerly served as Chairman of the Independent Trustees of the Thomas White Mutual Funds. He is currently an Operating Partner of Altamont Capital Partners, a private equity fund manager. He is a magna cum laude and Phi Beta Kappa graduate of Amherst College, and he attended King's College, Cambridge University as a Keasbey Fellow, where he was awarded an M.A. He earned his law degree at Columbia University School of Law. Earlier in his career Mr. Woolverton was a staff member of the Committee on the Judiciary of the United States Senate.

    Registration No. 333-273364

The Trustee

The sole Trustee of the Trust is Wilmington Trust, a national banking association. The Trustee's principal offices are located at 1100 North Market Street, Wilmington, Delaware 19890-0001. The Trustee is unaffiliated with the Sponsor. The Trustee's duties and liabilities with respect to the offering of Shares and the management of the Trust and the Fund are limited to its express obligations under the Trust Agreement.

The Trustee will accept service of legal process on the Trust in the State of Delaware and will make certain filings under the Delaware Statutory Trust Act. The Trustee does not owe any other duties to the Trust, the Sponsor or the Shareholders. The Trustee is permitted to resign upon at least sixty (60) days' notice to the Sponsor. If no successor trustee has been appointed by the Sponsor within such sixty-day period, the Trustee may, at the expense of the Trust, petition a court to appoint a successor. The Trust Agreement provides that the Trustee is entitled to reasonable compensation for its services from the Sponsor or an affiliate of the Sponsor (including the Trust), and is indemnified by the Sponsor against any expenses it incurs relating to or arising out of the formation, operation or termination of the Trust, or any action or inaction of the Trustee under the Trust Agreement, except to the extent that such expenses result from the fraud, or the gross negligence or willful misconduct of the Trustee. The Sponsor has the discretion to replace the Trustee.

The Trustee has not signed the registration statement of which this prospectus is a part and is not subject to issuer liability under the federal securities laws for the information contained in this prospectus and under federal securities laws with respect to the issuance and sale of the Shares. Under such laws, neither the Trustee, either in its capacity as Trustee or in its individual capacity, nor any director, officer or controlling person of the Trustee is, or has any liability as, the issuer or a director, officer or controlling person of the issuer of the Shares.

Under the Trust Agreement, the Trustee has delegated to the Sponsor the exclusive management and control of all aspects of the business of the Trust and the Fund. The Trustee has no duty or liability to supervise or monitor the performance of the Sponsor, nor does the Trustee have any liability for the acts or omissions of the Sponsor.

Because the Trustee has delegated substantially all of its authority over the operation of the Trust to the Sponsor, the Trustee itself is not registered in any capacity with the CFTC.

Operation of the Fund

The investment objective of the Fund is for changes in the Shares' NAV to reflect the daily changes of the price of the Benchmark, less expenses from the Fund's operations. Under normal market conditions, the Fund expects that the Fund's assets will be used to invest in Bitcoin Futures Contracts and cash and cash equivalents, such as short-term Treasury bills, money market funds, and demand deposit accounts. The term "normal market conditions" includes, but is not limited to, the absence of: trading halts in the applicable financial markets generally; operational issues (e.g., systems failure) causing dissemination of inaccurate market information; or force majeure type events such as natural or man-made disaster, act of God, armed conflict, act of terrorism, riot or labor disruption or any similar intervening circumstance. NYSE Arca rule under which the Shares will be listed and traded prevents the Fund from utilizing leverage.

The Fund invests in Benchmark Component Futures Contracts to the fullest extent possible without being leveraged or unable to satisfy its current or potential margin or collateral obligations with respect to its investments in Benchmark Component Futures Contracts. After fulfilling such margin and collateral requirements, the Fund invests the remainder of its proceeds from the sale of baskets in cash and cash equivalents, including money-market funds, and/or merely holds such assets in cash in interest-bearing accounts. The Fund seeks to earn interest and other income from the cash equivalents that it purchases, and on the cash, it holds at financial institutions.

The Fund seeks to achieve its investment objective primarily by investing in Benchmark Component Futures Contracts such that the changes in its NAV are expected to closely track the changes in the Benchmark, less expenses from the Fund's operations. The Benchmark is the average of the closing settlement prices for the first to expire and second to expire Bitcoin futures contracts listed on the CME. The Benchmark will roll prior the expiration of the spot month CME Bitcoin Futures. The Benchmark is not designed to track the spot price of bitcoin. The Sponsor endeavors to place the Fund's trades in Benchmark Component Futures Contracts and otherwise manage the Fund's investments so that the Fund's average daily tracking error against the Benchmark is less than 10 percent over any period of 30 trading days.

The Fund's total portfolio composition is disclosed each business day that NYSE Arca is open for trading on the Fund's website at http://hashdex-etfs.com/. The website disclosure of portfolio holdings is made daily and includes, as applicable, the security name, market price, CUSIP, and total weight of each futures contract month reflected as a percentage, and value of each cash and cash equivalents held in the Fund. The Fund's website also includes the NAV, the 4:00 p.m. (ET) Bid/Ask Midpoint as reported by NYSE Arca, the last trade price as reported by NYSE Arca, the Median bid-ask spread for the past 30 days, the Shares outstanding, the Shares available for issuance. Historical premium/discount information will be updated quarterly and daily as needed. The prospectus, Monthly Statements of Account, Quarterly Performance of the Midpoint versus the NAV (as required by the CFTC), and the Roll Dates, as well as Forms 10-Q, Forms 10-K, and other SEC filings for the Fund, are also posted on the website. The Fund's website is publicly accessible at no charge.

The Fund's investment objective is to provide investors with a way to gain price exposure to the bitcoin market. The Sponsor developed the Benchmark as a representation of the bitcoin market. Under normal market conditions, the Fund will invest in the Benchmark Component Futures Contracts. The Sponsor believes that by investing in Benchmark Component Futures Contracts, the Fund's NAV will closely track the Benchmark. The Sponsor also believes that because of market arbitrage opportunities, the market price at which investors will purchase and sell Shares through their broker-dealer will closely track the Fund's NAV. The Sponsor believes that the net effect of these relationships is that the Fund's market price on NYSE Arca at which investors purchase and sell Shares will closely track the bitcoin market, as measured by the Benchmark.

    Registration No. 333-273364

An investment in the Shares can potentially provide a means for diversifying an investor's portfolio or hedging exposure to changes in bitcoin prices. An investment in the Shares allows both retail and institutional investors to easily gain this exposure to the bitcoin market in a transparent, cost-effective manner.

The Sponsor employs a "neutral" investment strategy intended to track changes in the Benchmark regardless of whether the Benchmark goes up or goes down. The Fund's "neutral" investment strategy is designed to permit investors generally to purchase and sell the Fund's Shares for the purpose of investing indirectly in the bitcoin market. Such investors may include those seeking to hedge the risk of losses in their bitcoin related transactions as well as investors seeking exposure to the bitcoin market. Accordingly, depending on the investment objective of an individual investor, the risks generally associated with investing in the bitcoin market and/or the risks involved in hedging may exist. In addition, the Fund does not expect there to be any meaningful correlation between the performance of the Fund's investments in cash and cash equivalents and the changes in the price of bitcoin or Benchmark Component Futures Contracts. While the level of interest earned on, or the market price of, these investments may in some respects correlate to changes in the price of bitcoin, this correlation is not anticipated as part of the Fund's efforts to meet its objective. This and certain risk factors discussed in this prospectus may cause a lack of correlation between changes in the Fund's NAV and changes in the price of bitcoin.

The Shares issued by the Fund may only be purchased by Authorized Purchasers and only in blocks of 10,000 Shares called Creation Baskets. The amount of the purchase payment for a Creation Basket is equal to the total NAV of Shares in the Creation Basket. Similarly, only Authorized Purchasers may redeem Shares and only in blocks of 10,000 Shares called Redemption Baskets. The initial Shares will be offered and sold, in creation basket aggregation at an offering price of $ per Share, which is the same per Share price used in the Merger closing. Thereafter, Shares will be sold at the next determined NAV per Share. The amount of the redemption proceeds for a Redemption Basket is equal to the total NAV of Shares in the Redemption Basket. The purchase price for Creation Baskets and the redemption price for Redemption Baskets are the actual NAV calculated at the end of the business day when a request for a purchase or redemption is received by the Fund. NYSE Arca publishes an approximate NAV intra-day based on the prior day's NAV and the current price of the Benchmark Component Futures Contracts, but the price of Creation Baskets and Redemption Baskets is determined based on the actual NAV calculated at the end of each trading day.

While the Fund issues Shares only in Creation Baskets, Shares may also be purchased and sold in much smaller increments on NYSE Arca. These transactions, however, are effected at the bid and ask prices established by the specialist firm(s). Like any listed security, Shares can be purchased and sold at any time a secondary market is open.

The Fund's Investment Strategy

In managing the Fund's assets, the Sponsor does not use a technical trading system that automatically issues buy and sell orders. Instead, each time one or more baskets are purchased or redeemed, the Sponsor purchases or sells Benchmark Component Futures Contracts with an aggregate market value that approximates the amount of cash received or paid upon the purchase or redemption of the basket(s).

As an example, assume that a Creation Basket is sold by the Fund, and that the Fund's closing NAV per Share is $25.00. In that case, the Fund would receive $250,000 in proceeds from the sale of the Creation Basket ($25.00 NAV per Share multiplied by 10,000 Shares and ignoring the Creation Basket fee of $300). If one were to assume further that the Sponsor wants to invest the entire proceeds from the Creation Basket in the Benchmark Component Futures Contracts and that the market value of each such Benchmark Component Futures Contracts is $188,175 (or otherwise not a round number), the Fund would be unable to buy an exact number of Bitcoin Futures Contracts with an aggregate market value equal to $250,000. In this case, the Fund would be able to purchase 1 BTC Contract with an aggregate market value of approximately $188,175 and 16 MBT Contracts (each of which represent 0.10 bitcoin) at $3,763 per contract with an aggregate market value of approximately $60,208, bringing the aggregate value of proceeds to $248,383. Assuming a margin requirement equal to 32% of the notional amount based on the previous settlement price of the BTC Contracts and MBT Contracts, the Fund would be required to deposit approximately $79,483 in cash with the FCM through which the Bitcoin Futures Contracts were purchased. The remainder of the proceeds from the sale of the Creation Basket, approximately $170,517, composed of the approximately $168,900 not deposited with the FCM and the remaining $1,617 that was unable to be invested in Bitcoin Futures Contracts, would remain invested in cash and/or cash equivalents, as determined by the Sponsor from time to time based on factors such as potential calls for margin or anticipated redemptions.

The Benchmark Component Futures Contracts are cash-settled, and the Fund will not be required to take delivery of bitcoin. Positions may also be closed out to meet orders for Redemption Baskets, in which case the proceeds from closing the positions will not be reinvested.

Futures Contracts

Futures contracts are agreements between two parties that are executed on a designated contract market ("DCM"), i.e., a commodity futures exchange, and that are cleared and margined through a derivatives clearing organization ("DCO"), i.e., a clearing house. Bitcoin Futures Contacts are financially settled, which means that one party agrees to buy a commodity such as bitcoin from the other party at a later date at a price and quantity agreed upon when the contract is made, but instead of taking physical delivery of the commodity at such later date, settlement occurs in a dollar amount that is equivalent to the amount of bitcoin agreed to in the contract. In market terminology, a party who purchases a futures contract is long in the market and a party who sells a futures contract is short in the market. The contractual obligations of a buyer or seller may generally be satisfied by financial settlement or by making an offsetting sale or purchase of an identical futures contract on the same or linked exchange before the designated date of delivery. The difference between the price at which the futures contract is purchased or sold and the price paid for the offsetting sale or purchase, after allowance for brokerage commissions, constitutes the profit or loss to the trader.

    Registration No. 333-273364

If the price of the cryptocurrency increases after the original futures contract is entered into, the buyer of the futures contract will generally be able to sell a futures contract to close out its original long position at a price higher than that at which the original contract was purchased, generally resulting in a profit to the buyer. Conversely, the seller of a futures contract will generally profit if the price of the underlying bitcoin cryptocurrency decreases, as it will generally be able to buy a futures contract to close out its original short position at a price lower than that at which the original contract was sold. Because the Fund seeks to track the Benchmark directly, the Fund intends to hold only long positions in bitcoin futures contracts and intends to roll its CME Bitcoin Futures Contracts prior to expiration via sales of existing long positions and the acquisition of new long positions as replacements for contracts sold. Futures contracts are typically traded on futures exchanges (i.e. DCMs) such as the CME, which provide centralized market facilities in which multiple persons may trade contracts. Members of a particular futures exchange and the trades executed on such exchange are subject to the rules of that exchange. Futures exchanges and their related clearing organizations (i.e. DCOs) are given reasonable latitude in promulgating rules and regulations to control and regulate their members.

Trades on a futures exchange are generally cleared by the DCO, which provides services designed to mutualize or transfer the credit risk arising from the trading of contracts on an exchange. The clearing organization effectively becomes the other party to the trade, and each clearing member party to the trade looks only to the clearing organization for performance.

Bitcoin Futures Contracts

CME began offering trading in BTC Contracts in 2017 (and in MBT Contracts in 2021). The CME needed a transparent and readily available way to determine the price of bitcoin for its futures contract customers. However, there are numerous exchanges on which one can buy and sell bitcoin, and the prices of bitcoin can differ greatly from exchange to exchange. CME wanted to use pricing information from what it considered to be reputable bitcoin exchanges to calculate a once-a-day reference rate of the U.S. dollar price of bitcoin.

The CME developed the CME CF Bitcoin Reference Rate (the "BRR") to serve these purposes. Each of the BTC and MBT contract's final daily cash settlement is based on the BRR. It serves as a once-a-day reference rate of the U.S. dollar price of bitcoin and is used as the rate on which bitcoin futures contracts are cash-settled in U.S. dollars at the close of CME daily trading. The BRR is calculated by collecting purchase and sale transactions from specified constituent bitcoin exchanges, which currently include Bitstamp, Coinbase, Gemini, itBit, Kraken and LMAX Digital, during a calculation window between 3:00 p.m. and 4:00 p.m. London time. It is published at 4:00 p.m. London time each day.

The CME selects constituent exchanges for the BRR on the basis of the following criteria, which each exchange must demonstrate that it continues to fulfill on an ongoing basis:

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

Should the average daily contribution of a constituent exchange fall below 3%, then the continued inclusion of the venue as a constituent exchange is assessed.

Qualifying transactions from the constituent exchanges that take place during the one-hour calculation window are added to a list, with the trade price and size for each transaction recorded. The one-hour calculation is partitioned into twelve intervals of five minutes each, and for each partition, the volume-weighted median trade price is calculated from the trade prices and sizes of relevant transactions. (A volume-weighted median differs from a standard median in that a weighting factor, in this case trade size, is factored into the calculation.) The BRR is the equally-weighted average of the volume-weighted medians of all twelve partitions.

Impact of Position Limits, Accountability Levels, and Price Fluctuation Limits.

Position Limits, Accountability Levels, and Dynamic Price Fluctuation Limits may potentially cause a tracking error between the price of the Shares and the Benchmark. This may in turn prevent you from being able to effectively use the Fund as a way to hedge against bitcoin related losses or as a way to indirectly invest in bitcoin.

    Registration No. 333-273364

The Fund does not intend to limit the size of the offering and will attempt to expose substantially all of its proceeds to Benchmark Component Futures Contracts and cash and cash equivalents. If the Fund encounters position limits, accountability levels, or price fluctuation limits for Bitcoin Futures Contracts, it could force the Fund to limit the number of Creation Baskets that it sells.

Price Volatility

Despite dynamic price limits, the price volatility of futures contracts generally has been historically greater than that for traditional securities such as stocks and bonds. Price volatility often is greater day to day as opposed to intra-day. Economic factors that may cause volatility in Bitcoin Futures Contracts include but are not limited to cost of electricity, regulation, market disruptions, cyber-attacks, political events and existing and future technologic developments. There are also various other factors now known and unknown, any and all of which can have an impact on the supply, demand, and price fluctuations in the bitcoin markets. See "Risks Associated with Investing in Bitcoin." Because the Fund invests a significant portion of its assets in futures contracts, the assets of the Fund, and therefore the price of the Fund's Shares, may be subject to greater volatility than traditional securities.

Term Structure of Futures Contracts and the Impact on Total Return

Over time, the price of bitcoin fluctuates based on a number of market factors, including demand for bitcoin. The value of Bitcoin Futures Contracts likewise fluctuates in reaction to a number of market factors. Because the Fund seeks to maintain its holdings in Bitcoin Futures Contracts, the Fund must periodically "roll" futures contract positions, closing out soon to expire contracts that will no longer be part of the Benchmark and entering into subsequent to expire contracts. One factor determining the total return from investing in futures contracts is the price relationship between soon to expire contracts and later to expire contracts.

If the futures market is in a state of backwardation (i.e., when the price of bitcoin in the future is expected to be less than the current price), the Fund will buy later to expire contracts for a lower price than the sooner to expire contracts that it sells. Hypothetically, and assuming no changes to either prevailing bitcoin prices or the price relationship between soon to expire contracts and later to expire contracts, the value of a contract will rise as it approaches expiration. Over time, if backwardation remained constant, the differences would continue to increase. If the futures market is in contango, the Fund will buy later to expire contracts for a higher price than the sooner to expire contracts that it sells. Hypothetically, and assuming no other changes to either prevailing bitcoin prices or the price relationship between the spot price, soon to expire contracts and later to expire contracts, the value of a contract will fall as it approaches expiration. Over time, if contango remained constant, the difference would continue to increase. All other things being equal, a situation involving prolonged periods of contango may adversely impact the returns of the Fund; conversely a situation involving prolonged periods of backwardation may positively impact the returns of the Fund. By way of example, during the period from 6/30/2020 to 6/30/2023, the market for Bitcoin Component Futures Contracts were in contango approximately 87% of the time, which resulted in an average annual negative roll yield of approximately 7%.

Margin Requirements and Marking to Market Futures Positions

"Initial margin" is an amount of funds that must be deposited by a bitcoin interest trader with the trader's broker to initiate an open position in futures contracts. A margin deposit is like a cash performance bond. It helps assure the trader's performance of the futures contracts that he or she purchases or sells. Futures contracts are customarily bought and sold on initial margin that represents a small percentage of the aggregate purchase or sales price of the contract. The amount of margin required in connection with a particular futures contract is set by the exchange on which the contract is traded. Brokerage firms, such as the Fund's clearing broker, carrying accounts for traders in bitcoin interest contracts may require higher amounts of margin as a matter of policy to further protect themselves.

Futures contracts are marked to market at the end of each trading day and the margin required with respect to such contracts is adjusted accordingly. This process of marking to market is designed to prevent losses from accumulating in any futures account. Therefore, if the Fund's futures positions have declined in value, the Fund may be required to post "variation margin" to cover this decline. Alternatively, if the Fund's futures positions have increased in value, this increase will be credited to the Fund's account.

The Fund's Investments in Cash and Cash Equivalents

The Fund seeks to have the aggregate "notional" amount of the Benchmark Component Futures Contracts it holds approximate at all times the Fund's total NAV. At any given time, however, most of the Fund's investments are in cash and cash equivalents that support the Fund's positions in Benchmark Component Futures Contracts. For example, the purchase of a BTC Contract with a stated or notional amount of $188,175 would not require the Fund to pay $188,175 upon entering into the contract; rather, only a margin deposit, approximately 32% of the notional amount based on the previous settlement price, would be required. To secure its BTC Contract obligations, the Fund would deposit the required margin with the FCM and would separately hold its remaining assets through its Custodian or other financial institution in cash and cash equivalents, specifically in demand deposits, in short-term Treasury Securities held by the FCM, or in money-market funds. Such remaining assets may be used to meet future margin payments that the Fund is required to make on its BTC Contracts and/or MBT Contracts.

The Fund earns interest and other income from the cash equivalents that it purchases, and on the cash, it holds through the Custodian or other financial institutions. The earned interest and other income increase the Fund's NAV. The Fund applies the earned interest and other income to the acquisition of additional investments or uses it to pay its expenses. When the Fund reinvests the earned interest and other income, it makes investments that are consistent with its investment objectives.

    Registration No. 333-273364

Any cash equivalent invested in by the Fund will have a remaining maturity of less than 90 days at the time of investment or will be subject to a demand feature that enables that Fund to sell the security within that time period at approximately the security's face value (plus accrued interest). Any cash equivalents invested in by the Fund will be or will be deemed by the Sponsor to be of investment grade credit quality.

Other Trading Policies of the Fund

Exchange for Related Position

An "exchange for related position" ("EFRP") can be used by the Fund as a technique to facilitate the exchanging of a futures hedge position against a creation or redemption order, and thus the Fund may use an EFRP transaction in connection with the creation and redemption of Shares. The market specialist/market maker that is the ultimate purchaser or seller of Shares in connection with the creation or redemption basket, respectively, agrees to sell or purchase a corresponding offsetting Shares or futures position which is then settled on the same business day as a cleared futures transaction by the FCMs. The Fund will become subject to the credit risk of the market specialist/market maker until the EFRP is settled within the business day, which is typically 7 hours or less. The Fund reports all activity related to EFRP transactions under the procedures and guidelines of the CFTC and the exchanges on which the futures are traded. EFRPs are subject to specific rules of the CME and CFTC guidance.

Liquidity

The Fund invests only in Bitcoin Futures Contracts that, in the opinion of the Sponsor, are traded in sufficient volume to permit the ready taking and liquidation of positions in these financial interests or other bitcoin interests based on the spot price of bitcoin.

Spot Commodities

While most futures contracts can be physically settled, the Bitcoin Futures Contracts are cash settled.

Borrowings

The Fund does not intend to nor foresee the need to borrow money or establish credit lines. The Fund maintains cash and cash equivalents, either held by the Fund or posted as margin or collateral, with a value that at all times approximates the aggregate market value of its obligations under Benchmark Component Futures Contracts. The Fund meets its liquidity needs in the normal course of business from the proceeds of the sale of its investments or from the cash and cash equivalents that it intends to hold at all times.

Benchmark Performance

The chart below shows the percent change in the NAV per share for the Fund, the market price of the Fund shares, represented by the closing price of the Fund on NYSE Arca, and the Benchmark for five specific periods. The Benchmark does not reflect any impact of expenses, which would generally reduce the Fund's NAV, or interest income, which would generally increase the NAV. The actual results for the NAV include the impacts of both expenses and interest income.

Hashdex Bitcoin Futures ETF Fund Performance as of 7/31/2023

    Registration No. 333-273364

The Bitcoin Industry

Bitcoin

Bitcoin is a digital asset that serves as the unit of account on an open-source, decentralized, peer-to-peer computer network. It may be used to pay for goods and services, stored for future use, or converted to government-backed currency. As of the date of this prospectus, the adoption of bitcoin for these purposes has been limited. The value of bitcoin is not backed by any government, corporation, or other identified body.

The value of bitcoin depends on its supply (which is limited), and demand for bitcoin in the markets for exchange that have been organized to facilitate the trading of bitcoin. By design, the supply of bitcoin is intentionally limited to 21 million bitcoins. As of the date of this prospectus, there are approximately 19 million bitcoins in circulation.

    Registration No. 333-273364

Bitcoin is maintained on the decentralized, open source, peer-to-peer computer network (the "Bitcoin Network"). No single entity owns or operates the Bitcoin Network. The Bitcoin Network is accessed through software and governs bitcoin's creation and movement. The source code for the Bitcoin Network, often referred to as the Bitcoin Protocol, is open-source, and anyone can contribute to its development.

The Bitcoin Network

The infrastructure of the Bitcoin Network is collectively maintained by various participants in the Bitcoin Network, which include miners, developers, and users. Miners validate transactions and provide security to the network, and are currently compensated for that service in bitcoin. Developers maintain and contribute updates to the Bitcoin Network's source code, often referred to as the Bitcoin Protocol. Users access the Bitcoin Network using open-source software. Anyone can be a user, developer, or miner.

Bitcoin is "stored" on a digital transaction ledger commonly known as a "blockchain." A blockchain is a distributed database that is continuously updated and reconciled among certain users and is protected by cryptography. The Bitcoin Blockchain contains a complete record and history for each bitcoin transaction.

New bitcoins are created through a process called "mining." Miners use specialized computer software and hardware to solve a highly complex mathematical problem presented by the Bitcoin Protocol. The first miner to successfully solve the problem is permitted to add a block of transactions to the Bitcoin Blockchain. The new block is then confirmed through acceptance by a majority of users who maintain versions of the blockchain on their individual computers. Miners that successfully add a block to the Bitcoin Blockchain are automatically rewarded with a fixed amount of bitcoin for their effort plus any transaction fees paid by transferors whose transactions are recorded in the block. This reward system is the means by which new bitcoin enter circulation and is the mechanism by which versions of the blockchain held by users on a decentralized network are kept in consensus.

The Bitcoin Protocol

The Bitcoin Protocol is an open source project with no official company or group in control, and anyone can review the underlying code. There are, however, a number of individual developers that regularly contribute to a specific distribution of bitcoin software known as the "Bitcoin Core." Developers of the Bitcoin Core loosely oversee the development of the source code. There are many other compatible versions of the bitcoin software, but Bitcoin Core is the most widely adopted and currently provides the de facto standard for the Bitcoin Protocol. The core developers are able to access, and can alter, the Bitcoin Network source code and, as a result, they are responsible for quasi-official releases of updates and other changes to the Bitcoin Network's source code.

However, because bitcoin has no central authority, the release of updates to the Bitcoin Network's source code by the core developers does not guarantee that the updates will be automatically adopted by the other purchasers. Users and miners must accept any changes made to the source code by downloading the proposed modification and that modification is effective only with respect to those bitcoin users and miners who choose to download it. As a practical matter, a modification to the source code becomes part of the Bitcoin Network only if it is accepted by purchasers that collectively have a majority of the processing power on the Bitcoin Network. If a modification is accepted by only a percentage of users and miners, a division will occur such that one network will run the pre-modification source code and the other network will run the modified source code. Such a division is known as a "fork."

The Fund's Service Providers

Contractual Arrangements with the Sponsor and Third-Party Service Providers

Sponsor

The Sponsor is responsible for investing the assets of the Fund in accordance with the objectives and policies of the Fund. In addition, the Sponsor arranges for one or more third parties to provide administrative, custodial, accounting, transfer agency and other necessary services to the Fund. For these third-party services, the Fund pays the fees set forth in the table below entitled "Contractual Fees and Compensation Arrangements with the Sponsor and Third-Party Service Providers." For the Sponsor's services, the Fund is contractually obligated to pay a monthly management fee to the Sponsor, based on average daily net assets, at a rate equal to 0.94% per annum.

Administrator

The Fund employs Tidal ETF Services LLC as Fund's administrator (the "Administrator"). In turn, the Administrator has engaged U.S. Bancorp Fund Services, LLC, doing business as U.S. Bank Global Fund Services ("Global Fund Services") to act as sub-administrator. The Administrator is a wholly-owned subsidiary of Sponsor. The Administrator is located at 234 West Florida Street, Suite 203, Milwaukee, Wisconsin 53204. The Administrator also assists the Fund and the Sponsor with certain functions and duties relating to marketing, which include the following: marketing and sales strategy, and marketing related services.

Custodian, Registrar, Transfer Agent, Fund Sub-Administrator

In its capacity as the Fund's custodian, the Custodian, currently U.S. Bank, N.A., holds the Fund's securities, cash and/or cash equivalents pursuant to a custodial agreement. U.S. Bank Global Fund Services ("Global Fund Services"), an entity affiliated with U.S. Bank, N.A., is the registrar and transfer agent for the Fund's Shares. In addition, Global Fund Services also serves as sub-administrator for the Fund, performing certain sub-administrative, and accounting services, and support in preparing certain SEC and CFTC reports on behalf of the Fund. The Custodian is located at 1555 North Rivercenter Drive, Suite 302, Milwaukee, Wisconsin 53212. U.S. Bank N.A. is a nationally chartered bank, regulated by the Office of the Comptroller of the Currency, Department of the Treasury, and is subject to regulation by the Board of Governors of the Federal Reserve System. The principal address for Global Fund Services is 615 East Michigan Street, Milwaukee, WI, 53202.

    Registration No. 333-273364

Marketing Agent

The Fund employs Foreside Fund Services, LLC, a wholly-owned subsidiary of Foreside Financial Group, LLC (d/b/a ACA Group) as the Marketing Agent for the Fund. The Marketing Agent Agreement among the Marketing Agent, the Sponsor, and the Trust calls for the Marketing Agent to work with the Custodian in connection with the receipt and processing of orders for Creation Baskets and Redemption Baskets and the review and approval of all Fund sales literature and advertising material. The Marketing Agent's principal business address is Three Canal Plaza, Suite 100, Portland, Maine 04101. The Marketing Agent is a broker-dealer registered with the U.S. Securities and Exchange Commission ("SEC") and a member of FINRA.

Support Agent

Tidal ETF Services LLC ("Tidal") assists the Fund and the Sponsor with certain functions and duties relating to administration, distribution and marketing, which include the following: marketing and sales strategy, and marketing and distribution related services.

Digital Asset Adviser

Hashdex Asset Management Ltd. ("Hashdex" or the "Digital Asset Adviser") is a Cayman Islands investment manager (and an Exempt Reporting Advisor under SEC rules) that specializes in, among other things, the management, research, investment analysis and other investment support services of funds and ETFs with investment strategies involving bitcoin and other crypto assets. As Digital Asset Adviser, Hashdex is responsible for providing the Sponsor and Tidal with research and analysis regarding bitcoin and bitcoin markets for use in the operation and marketing of the Fund. Hashdex has no role in maintaining, calculating or publishing the Benchmark. Hashdex also has no responsibility for the investment or management of the Fund's portfolio or for the overall performance or operation of the Fund.

Support Agreement

The Sponsor, Tidal, Digital Asset Adviser and Teucrium Trading, LLC ("Predecessor Sponsor") (collectively, the "Parties") have entered into an agreement, as amended (the "Support Agreement") that sets forth the terms and conditions applicable to the launch, marketing, promotion, development, and ongoing operation of the Fund, as well the respective rights in profits and obligations for expenses. Specifically, Hashdex and the Sponsor have experience in the digital asset and exchange-traded fund industry, and seek to offer a bitcoin futures based fund as part of their long-term business goals. Additionally, the parties to the Support Agreement ("Parties") agreed that, in furtherance of their long-term business goals, the Fund will be the successor and surviving entity from the merger (the "Merger") into the Fund of Hashdex Bitcoin Futures ETF (the "Predecessor Fund") that is a series of the Teucrium Commodity Trust (the "Predecessor Trust") sponsored by the Predecessor Sponsor. The Merger is contingent on the contemporaneous commencement of trading of the Shares on NYSE Arca pursuant to offering made under this prospectus. The Parties do not believe that the Merger will have any impact on a shareholder's investment in the Fund. The Merger is not expected to materially modify the rights of Fund shareholders. The Fund and the Predecessor Fund have filed current reports on Form 8-K including a press release notifying shareholders that the Merger has been consummated.

The primary responsibilities and rights of each Party under the Support Agreement, with respect to the Fund after the Merger, are described below:

    Registration No. 333-273364

? Tidal will provide fund administration and related services for the Fund.

    Registration No. 333-273364

    Registration No. 333-273364

Merger

The Sponsor and Prior Sponsor entered into a Support Agreement where in furtherance of their long-term business goals, the Fund will be the successor and surviving entity from the Merger into the Fund of the Predecessor Fund that is a series of the Trust sponsored by the Prior Sponsor. The Predecessor Fund's Declaration of Trust permits the Prior Sponsor, without a shareholder vote, to transfer the assets of the Predecessor Fund to the Fund.

    Registration No. 333-273364

The Prior Sponsor and Sponsor entered into an agreement and plan of partnership merger and liquidation (the "Plan of Reorganization") dated October 30, 2023. Pursuant to the Plan of Reorganization, the Fund delivered its Shares to the Predecessor Fund and assumed the liabilities of the Predecessor Fund on January 3, 2024 (the "Closing Date"). On the Closing Date, the Predecessor Fund delivered its assets to the Custodian and the Fund's FCMs, in exchange for the Shares. The Fund distributed to the Predecessor Fund's record holders, determined as of the Closing Date, it's Shares in an amount equal to one for one exchange of the Predecessor Fund's shares. Pursuant to the terms of the Plan of Reorganization, the Predecessor Fund liquidated in accordance with the laws of Delaware and applicable federal securities laws and regulations. The Predecessor Fund and the Fund will be required to make representations and warranties that are customary in matters such as the Plan of Reorganization. With respect to the Plan of Reorganization, the obligations of the Predecessor Fund and the Fund are subject to the following conditions, among others:

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

The Merger did not materially modify the rights of Fund shareholders. Prior to the Merger, the Fund had no operations, received $100 in cash from the Sponsor for four Shares to complete the pre-operational formation of the Fund and had no liabilities. The Fund and the Predecessor Fund have filed current reports on Form 8-K including a press release notifying shareholders that the Merger has been consummated.

The Fund has the same investment objective and investment strategies, and substantially similar risks and investment restrictions as the Predecessor Fund.

The Merger constituted a "reorganization" within the meaning of Section 368(a) of the Internal Revenue Code of 1986, as amended (the "Code"). The Merger was conditioned upon the receipt by the Sponsor of an opinion to such effect from tax counsel to the Trust. The Predecessor Fund and the shareholders generally did not recognize any gain or loss for federal income tax purposes on the transfer of assets, the assumption of liabilities, and the receipt of Fund shares in the Merger.

The Predecessor Fund did not pay for the costs of the Merger. The Sponsor paid the costs associated with the Merger, including the expenses associated with preparing and filing this prospectus and the cost of copying, printing and mailing this prospectus.

Clearing Brokers

StoneX Financial Inc. - FCM (f/k/a INTL FCStone Financial Inc. - FCM Division) ("StoneX"), and Phillip Capital Inc. ("Phillip Capital") serve as the Fund's clearing brokers (the "Clearing Brokers") to execute and clear the Fund's futures transactions and provide other brokerage-related services. The Clearing Brokers are each registered as an FCM with the CFTC, are members of the National Futures Association ("NFA") and are clearing members of all major U.S. futures exchanges. The Clearing Brokers are registered as broker-dealers ("BDs") with the U.S. Securities and Exchange Commission ("SEC") and are each a member of the Financial Industry Regulatory Authority, Inc. ("FINRA").

Except as indicated below, there have been no material civil, administrative, or criminal proceedings pending, on appeal, or concluded against the Clearing Brokers or their principals in the past five (5) years.

    Registration No. 333-273364

    Registration No. 333-273364

Listed below are material administrative, civil, enforcement, or criminal complaints or actions filed against StoneX Financial Inc. - FCM Division (f/k/a INTL FCStone Financial Inc. - FCM Division) where such complaints or actions have not concluded and any material enforcement actions or complaints filed against the StoneX Financial Inc. - FCM Division in the past three years.

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

Further, StoneX Financial Inc. is subject to litigation and regulatory enforcement in the normal course of business. Except as discussed above, the current or pending civil litigation or administrative proceedings in which StoneX Financial Inc. is involved are not expected to have a material effect upon its condition, financial or otherwise. StoneX Financial Inc. vigorously defends, as a matter of policy, civil litigation, reparation, arbitration proceedings, and enforcement actions brought against it.

    Registration No. 333-273364

Phillip Capital Inc. ("Phillip Capital") is a registered futures commission merchant and is a member of the NFA. Its main office is located at 141 West Jackson Blvd., Suite 1531A, Chicago, Illinois 60604. In the normal course of its business, Phillip Capital is involved in various legal actions incidental to its commodities business. None of these actions are expected either individually or in aggregate to have a material adverse impact on Phillip Capital. Except for the below, neither Phillip Capital nor any of its principals have been the subject of any material administrative, civil or criminal actions within the past five years.

On September 12, 2019, the U.S. Commodity Futures Trading Commission issued an order settling charges against Phillip Capital Inc. (PCI) for allowing cyber criminals to breach PCI email systems, access customer information, and successfully withdrawing $1 million in PCI customer funds. The order found that PCI failed to disclose the cyber breach to its customers in a timely manner and that PCI failed to supervise its employees with respect to cybersecurity policy and procedures, a written information systems security program, and customer disbursements. The order imposed monetary sanctions totaling $1.5 million, which includes a civil monetary penalty of $500,000, and $1 million in restitution. PCI was credited the $1 million restitution based on its prompt reimbursement of the customer funds when the fraud was discovered. The order also required PCI to, among other things, provide reports to the Commission on its remediation efforts.

On June 11, 2021, pursuant to an offer of settlement in which Phillip Capital Inc. neither admitted nor denied the rule violation upon which the penalty is based, the Clearing House Risk Committee found that Phillip Capital Inc. violated CME Rule 980.A - Required Records and Reports. In accordance with the settlement offer, the Committee imposed a $50,000 fine for non-current books and records due to an issue with the firm's middleware provider. In a related matter, the CME Group had previously fined Phillip Capital Inc. on March 19, 2021, for its violation of Rule 811 and 561. During the month of February 2021, Phillip Capital Inc. inaccurately reported its open interest and large trader positions in several instances of CME, CBT, NYMEX, and COMEX contracts due to the aforementioned middleware issue. A fine in the amount of $5,000 was assessed against Phillip Capital Inc.

    Registration No. 333-273364

Commodity Trading Advisor

Currently, the Sponsor does not employ commodity trading advisors. If, in the future, the Sponsor does employ commodity trading advisors, it will choose each advisor based on arm's length negotiations and will consider the advisor's experience, fees, and reputation.

Contractual Fees and Compensation Arrangements with the Sponsor and Third-Party Service Providers

Service Provider Compensation Paid by the Fund Tidal Investments LLC, 0.94% of average net assets annually Sponsor

Phillip Capital Inc., The Fund pays $5.00-$10.00 per Futures Contract Futures Commission half-turn exclusive of pass through fees for the Merchant and Clearing exchange, NFA, execution fees, and platform and Broker exchange data fees.

StoneX Financial Inc., The Fund pays $10.00-$25.00 per Futures Contract Futures Commission half-turn exclusive of pass through fees for the Merchant and Clearing exchange and NFA. Additionally, if the monthly Broker commissions paid do not equal or exceed 20% return on the Maintenance Margin Requirement at 9.6% of Exchange Maintenance Margin, the Fund will pay a true up to meet that return at the end of each month.

Wilmington Trust, Trustee $3,300 annually for the Trust

Other Non-Contractual Payments by the Fund

The Fund pays the Sponsor a Management Fee, monthly in arrears, in an amount equal to 0.94% per annum of the daily NAV of the Fund. The Management Fee is paid in consideration of the Sponsor's services related to the management of the Fund's business and affairs, including the provision of commodity futures trading advisory services. Purchases of creation units with cash may cause the Fund to incur certain costs including brokerage commissions and redemptions of creation units with cash may result in the recognition of gains or losses that the Fund might not have incurred if it had made redemptions in-kind. The Fund pays all of its respective brokerage commissions, including applicable exchange fees, NFA fees and give-up fees, and other transaction related fees and expenses charged in connection with trading activities for the Fund's investments in CFTC regulated investments. The Fund bears other transaction costs related to the FCM capital requirements on a monthly basis. The Sponsor pays all of the routine operational, administrative and other ordinary expenses of the Fund, generally as determined by the Sponsor, including but not limited to, fees and expenses of the Administrator, Sub-Administrator, Custodian, Marketing Agent, Transfer Agent, licensors, accounting and audit fees and expenses, tax preparation expenses, legal fees, ongoing SEC registration fees, individual Schedule K-1 preparation and mailing fees, and report preparation and mailing expenses. The Fund pays all of its non-recurring and unusual fees and expenses, if any, as determined by the Sponsor. Non-recurring and unusual fees and expenses are unexpected or unusual in nature, such as legal claims and liabilities and litigation costs or indemnification or other unanticipated expenses. Extraordinary fees and expenses also include material expenses which are not currently anticipated obligations of the Fund. Routine operational, administrative and other ordinary expenses are not deemed extraordinary expenses.

Form of Shares

Registered Form

Shares are issued in registered form in accordance with the Trust Agreement. Global Fund Services has been appointed registrar and transfer agent for the purpose of transferring Shares in certificated form. Global Fund Services keeps a record of all Shareholders and holders of the Shares in certificated form in the registry ("Register"). The Sponsor recognizes transfers of Shares in certificated form only if done in accordance with the Trust Agreement. The beneficial interests in such Shares are held in book-entry form through purchasers and/or accountholders in DTC.

Book Entry

Individual certificates are not issued for the Shares. Instead, Shares are represented by one or more global certificates, which are deposited by the Sub-Administrator with DTC and registered in the name of Cede & Co., as nominee for DTC. The global certificates evidence all of the Shares outstanding at any time. Shareholders are limited to (1) purchasers in DTC such as banks, brokers, dealers and trust companies, (2) those who maintain, either directly or indirectly, a custodial relationship with a DTC purchaser, and (3) those who hold interests in the Shares through DTC purchasers or Indirect purchasers, in each case who satisfy the requirements for transfers of Shares. DTC purchasers acting on behalf of investors holding Shares through such purchasers' accounts in DTC will follow the delivery practice applicable to securities eligible for DTC's Same Day Funds Settlement System. Shares are credited to DTC purchasers' securities accounts following confirmation of receipt of payment.

    Registration No. 333-273364

DTC

DTC is a limited purpose trust company organized under the laws of the State of New York and is a member of the Federal Reserve System, a "clearing corporation" within the meaning of the New York Uniform Commercial Code and a "clearing agency" registered pursuant to the provisions of Section 17A of the Exchange Act. DTC holds securities for DTC purchasers and facilitates the clearance and settlement of transactions between DTC purchasers through electronic book-entry changes in accounts of DTC purchasers.

Transfer of Shares

The Shares are only transferable through the book-entry system of DTC. Shareholders who are not DTC purchasers may transfer their Shares through DTC by instructing the DTC purchaser holding their Shares (or by instructing the Indirect purchaser or other entity through which their Shares are held) to transfer the Shares. Transfers are made in accordance with standard securities industry practice.

Transfers of interests in Shares with DTC are made in accordance with the usual rules and operating procedures of DTC and the nature of the transfer. DTC has established procedures to facilitate transfers among the Purchasers and/or accountholders of DTC. Because DTC can only act on behalf of DTC Purchasers, who in turn act on behalf of Indirect Purchasers, the ability of a person or entity having an interest in a global certificate to pledge such interest to persons or entities that do not participate in DTC, or otherwise take actions in respect of such interest, may be affected by the lack of a certificate or other definitive document representing such interest.

DTC has advised us that it will take any action permitted to be taken by a Shareholder (including, without limitation, the presentation of a global certificate for exchange) only at the direction of one or more DTC purchasers in whose account with DTC interests in global certificates are credited and only in respect of such portion of the aggregate principal amount of the global certificate as to which such DTC purchaser or purchasers has or have given such direction.

Inter-Series Limitation on Liability

Because the Trust was established as a Delaware statutory trust, the Fund and each other series that may be established under the Trust in the future will be operated so that it will be liable only for obligations attributable to such series and will not be liable for obligations of any other series or affected by losses of any other series. If any creditor or Shareholder of any particular series (such as the Fund) asserts against the series a valid claim with respect to its indebtedness or Shares, the creditor or Shareholder will only be able to obtain recovery from the assets of that series and not from the assets of any other series or the Trust generally. The assets of the Fund and any other series will include only those funds and other assets that are paid to, held by or distributed to the series on account of and for the benefit of that series, including, without limitation, amounts delivered to the Trust for the purchase of Shares in a series. This limitation on liability is referred to as the Inter-Series Limitation on Liability. The Inter-Series Limitation on Liability is expressly provided for under the Delaware Statutory Trust Act, which provides that if certain conditions (as set forth in Section 3804(a)) are met, then the debts of any particular series will be enforceable only against the assets of such series and not against the assets of any other series or the Trust generally. In furtherance of the Inter-Series Limitation on Liability, every party providing services to the Trust, the Fund or the Sponsor on behalf of the Trust or the Fund, will acknowledge and consent in writing to the Inter-Series Limitation on Liability with respect to such party's claims.

The existence of a Trustee should not be taken as an indication of any additional level of management or supervision over the Fund. Consistent with Delaware law, the Trustee acts in an entirely passive role, delegating all authority for the management and operation of the Fund and the Trust to the Sponsor. The Trustee does not provide custodial services with respect to the assets of the Fund.

Plan of Distribution

Buying and Selling Shares

Most investors buy and sell Shares of the Fund in secondary market transactions through brokers. Shares trade on NYSE Arca under the ticker symbol "DEFI." Shares are bought and sold throughout the trading day like other publicly traded securities. When buying or selling Shares through a broker, most investors incur customary brokerage commissions and charges. Investors are encouraged to review the terms of their brokerage account for details on applicable charges and, as discussed below under "U.S. Federal Income Tax Considerations," any provisions authorizing the broker to borrow Shares held on your behalf.

Marketing Agent and Authorized Purchasers

The offering of the Fund's Shares is a best efforts offering. The Fund continuously offers Creation Baskets consisting of 10,000 Shares at their NAV through the Marketing Agent to Authorized Purchasers. The initial Shares will be offered and sold, in creation basket aggregation at an offering price of $ per Share, which is the same per Share price used in the Merger closing. Thereafter, Shares will be sold at the next determined NAV per Share. The Merger closed on January 3, 2024. The share price used for the delivery of shares of the Predecessor Fund was the net asset value per share of the Predecessor Fund determined after the close of business of NYSE Arca on January 2, 2024. Consequently, the Merger resulted in a one for one exchange of shares between the Predecessor Fund and the Fund. Prior to the Merger, the Fund had no operations, received $100 in cash from the Sponsor for four Shares to complete the pre-operational formation of the Fund and had no liabilities. All Authorized Purchasers pay a $300 fee for each Creation Basket order.

    Registration No. 333-273364

The following entities have entered into Authorized Purchaser Agreements with respect to the Fund: [ ]

Because new Shares can be created and issued on an ongoing basis, at any point during the life of the Fund, a "distribution," as such term is used in the 1933 Act, will be occurring. Authorized Purchasers, other broker-dealers and other persons are cautioned that some of their activities may result in their being deemed purchasers in a distribution in a manner that would render them statutory underwriters and subject them to the prospectus delivery and liability provisions of the 1933 Act. For example, an Authorized Purchaser, other broker-dealer firm or its client will be deemed a statutory underwriter if it purchases a basket from the Fund, breaks the basket down into the constituent Shares and sells the Shares to its customers; or if it chooses to couple the creation of a supply of new Shares with an active selling effort involving solicitation of secondary market demand for the Shares. In contrast, Authorized Purchasers may engage in secondary market or other transactions in Shares that would not be deemed "underwriting." For example, an Authorized Purchaser may act in the capacity of a broker or dealer with respect to Shares that were previously distributed by other Authorized Purchasers. A determination of whether a particular market purchaser is an underwriter must take into account all the facts and circumstances pertaining to the activities of the broker-dealer or its client in the particular case, and the examples mentioned above should not be considered a complete description of all the activities that would lead to designation as an underwriter and subject them to the prospectus delivery and liability provisions of the 1933 Act.

Dealers who are neither Authorized Purchasers nor "underwriters" but are nonetheless participating in a distribution (as contrasted to ordinary secondary trading transactions), and thus dealing with Shares that are part of an "unsold allotment" within the meaning of Section 4(a)(3)(C) of the 1933 Act, would be unable to take advantage of the prospectus delivery exemption provided by Section 4(a)(3) of the 1933 Act.

Investors are cautioned that they might not be able to buy or sell Shares of the Fund through their current brokerages. Moreover, even if an investor were able to purchase Shares through their current brokerage, that brokerage might decide to stop trading in bitcoin-linked securities and the investor would potentially face restrictions on when and or how they could trade their existing bitcoin position.

The Sponsor expects that any broker-dealers selling Shares will be members of FINRA. Investors intending to create or redeem baskets through Authorized Purchasers in transactions not involving a broker-dealer registered in such investor's state of domicile or residence should consult their legal advisor regarding applicable broker-dealer regulatory requirements under the state securities laws prior to such creation or redemption.

While the Authorized Purchasers may be indemnified by the Sponsor, they will not be entitled to receive a discount or commission from the Trust or the Sponsor for their purchases of Creation Baskets.

Calculating NAV

The Fund's NAV per Share is calculated by:

? taking the current market value of its total assets, and ? subtracting any liabilities and dividing the balance by the number of Shares.

Global Fund Services, in its capacity as the Sub-Administrator calculates the NAV of the Fund once each trading day. It calculates the NAV as of the earlier of the close of trading on NYSE Arca or 4:00 p.m. (ET). The NAV for a particular trading day is released after 4:15 p.m. (ET).

In determining the value of Bitcoin Futures Contracts, the Sub-Administrator uses the settlement price for the Benchmark Component Futures Contracts, as reported on the CME. CME Group staff determines the daily settlements for the Benchmark Component Futures Contracts based on trading activity on CME Globex exchange between 14:59:00 and 15:00:00 Central Time (CT), the settlement period, except that the "fair value" of Bitcoin Futures Contracts (as described in more detail below) may be used when Bitcoin Futures Contracts close at their price fluctuation limit for the day. The Sub-Administrator determines the value of all other Fund investments as of the earlier of the close of NYSE Arca or 4:00 p.m. (ET), in accordance with the current Services Agreement between the Administrator, Sub-Administrator and the Trust. NAV includes any unrealized profit or loss on open bitcoin interests and any other credit or debit accruing to the Fund but unpaid or not received by the Fund.

The fair value of a bitcoin interest is determined by the Sponsor in good faith and in a manner that assesses the bitcoin interest's value based on a consideration of all available facts and all available information on the valuation date. When a Bitcoin Futures Contract has closed at its daily price fluctuation limit, that limit price will be the daily settlement price that the CME publishes. The Fund will use the published settlement price to price its Shares on that day. If the CME halted trading in Bitcoin Futures Contracts for other reasons, including if trading were halted for an entire trading day or several trading days, the Fund would value its Bitcoin Futures Contracts by using the settlement price that the CME publishes.

In addition, in order to provide updated information relating to the Fund for use by investors and market professionals, ICE Data Indices, LLC calculates and disseminates throughout the trading day an updated "indicative fund value." The indicative fund value is calculated by using the prior day's closing NAV per Share of the Fund as a base and updating that value throughout the trading day to reflect changes in the value of the Fund's bitcoin interests during the trading day. Changes in the value of cash equivalents are not included in the calculation of indicative value. For this and other reasons, the indicative fund value disseminated during NYSE Arca trading hours should not be viewed as an actual real time update of the NAV. NAV is calculated only once at the end of each trading day.

    Registration No. 333-273364

The indicative fund value is disseminated on a per Share basis every 15 seconds during regular NYSE Arca trading hours of 9:30 a.m. (ET) to 4:00 p.m. (ET). The trading hours for the CME can be found at: https://www.cmegroup.com/education/bitcoin/cme-bitcoin-futures-frequently-asked-questions.html.

ICE Data Indices, LLC disseminates the indicative fund value through the facilities of CTA/CQ High Speed Lines. In addition, the indicative fund value is available through on-line information services such as Bloomberg and Reuters.

Dissemination of the indicative fund value provides additional information that is not otherwise available to the public and is useful to investors and market professionals in connection with the trading of Fund Shares on NYSE Arca. Investors and market professionals are able throughout the trading day to compare the market price of the Fund and the indicative fund value. If the market price of Fund Shares diverges significantly from the indicative fund value, market professionals may have an incentive to execute arbitrage trades. For example, if the Fund appears to be trading at a discount compared to the indicative fund value, a market professional could buy Fund Shares on NYSE Arca, aggregate them into Redemption Baskets, and receive the NAV of such Shares by redeeming them to the Trust provided that there is not a minimum number of Shares outstanding for the Fund. Such arbitrage trades can tighten the tracking between the market price of the Fund and the indicative fund value.

Creation and Redemption of Shares

The Fund creates and redeems Shares from time to time, but only in one or more Creation Baskets or Redemption Baskets. To the extent creations and redemptions involve the exchange of cash and cash equivalents, the Fund may incur certain costs including brokerage costs or recognize gains or losses that it might not have incurred if the transaction were made in-kind. Authorized Purchasers are the only persons that may place orders to create and redeem baskets. Authorized Purchasers must be (1) either registered broker-dealers or other securities market purchasers, such as banks and other financial institutions, which are not required to register as broker-dealers to engage in securities transactions as described below, and (2) DTC purchasers. To become an Authorized Purchaser, a person must enter into an Authorized Purchaser Agreement with the Sponsor. The Authorized Purchaser Agreement provides the procedures for the creation and redemption of baskets and for the delivery of the cash and cash equivalents required for such creations and redemptions. The Authorized Purchaser Agreement and the related procedures attached thereto may be amended by the Sponsor, without the consent of any Shareholder, and the related procedures may generally be amended by the Sponsor without the consent of the Authorized Purchaser. Authorized Purchasers pay a transaction fee of $300 to the Custodian for each creation order they place and a fee of $300 per order for redemptions, which is a nominal fee. Authorized Purchasers who make deposits with the Fund in exchange for baskets receive no fees, commissions or other form of compensation or inducement of any kind from either the Trust or the Sponsor, and no such person will have any obligation or responsibility to the Trust or the Sponsor to effect any sale or resale of Shares.

Certain Authorized Purchasers are expected to be capable of participating directly in the physical bitcoin and the bitcoin interest markets. Some Authorized Purchasers or their affiliates may from time to time buy or sell bitcoin or bitcoin interests and may profit in these instances.

Each Authorized Purchaser will be required to be registered as a broker-dealer under the Exchange Act and a member in good standing with FINRA or be exempt from being or otherwise not required to be registered as a broker-dealer or a member of FINRA, and will be qualified to act as a broker or dealer in the states or other jurisdictions where the nature of its business so requires. Certain Authorized Purchasers may also be regulated under federal and state banking laws and regulations. Each Authorized Purchaser has its own set of rules and procedures, internal controls and information barriers it deems appropriate in light of its own regulatory regime.

Under the Authorized Purchaser Agreement, the Sponsor has agreed to indemnify the Authorized Purchasers against certain liabilities, including liabilities under the 1933 Act, and to contribute to the payments the Authorized Purchasers may be required to make in respect of those liabilities.

The following description of the procedures for the creation and redemption of baskets is only a summary and an investor should refer to the relevant provisions of the Trust Agreement and the form of Authorized Purchaser Agreement for more detail, each of which has been incorporated by reference as an exhibit to the registration statement of which this prospectus is a part. See "Where You Can Find More Information" for information about where you can obtain the registration statement.

Creation Procedures

On any business day, an Authorized Purchaser may place an order with Global Fund Services in its capacity as the transfer agent to create one or more baskets. For purposes of processing purchase and redemption orders, a "business day" means any day other than a day when any of NYSE Arca or the CME is closed for regular trading. Purchase orders must be placed by 3:00 p.m. (ET) or the close of regular trading on NYSE Arca, whichever is earlier. The day on which the Marketing Agent receives a valid purchase order is referred to as the purchase order date.

    Registration No. 333-273364

By placing a purchase order, an Authorized Purchaser agrees to deposit cash and/or cash equivalents with the Fund, as described below. Prior to the delivery of baskets for a purchase order, the Authorized Purchaser must also have wired to the Sponsor the non-refundable transaction fee due for the purchase order. Authorized Purchasers may not withdraw a purchase order without the prior consent of the Sponsor in its discretion.

Determination of Required Deposits

The total deposit required to create each basket ("Creation Basket Deposit") is the amount of cash and/or cash equivalents that is in the same proportion to the total assets of the Fund (net of estimated accrued but unpaid fees, expenses and other liabilities) on the purchase order date as the number of Shares to be created under the purchase order is in proportion to the total number of Shares outstanding on the purchase order date. The Sponsor determines, directly in its sole discretion or in consultation with the Custodian and the Sub-Administrator, the requirements for cash and/or cash equivalents, including the remaining maturities of the cash equivalents, which may be included in deposits to create baskets. If cash equivalents are to be included in a Creation Basket Deposit for orders placed on a given business day, the Sub-Administrator will publish an estimate of the Creation Basket Deposit requirements at the beginning of such day.

Delivery of Required Deposits

An Authorized Purchaser who places a purchase order is responsible for transferring to the Fund's account with the Custodian the required amount of cash and cash equivalents by the end of the next business day following the purchase order date or by the end of such later business day, not to exceed three business days after the purchase order date, as agreed to between the Authorized Purchaser and the Custodian when the purchase order is placed (the "Purchase Settlement Date"). Upon receipt of the deposit amount, the Custodian directs DTC to credit the number of baskets ordered to the Authorized Purchaser's DTC account on the Purchase Settlement Date.

Because orders to purchase baskets must be placed by 3:00 p.m., (ET), but the total payment required to create a basket during the continuous offering period will not be determined until 4:00 p.m., (ET), on the date the purchase order is received, Authorized Purchasers will not know the total amount of the payment required to create a basket at the time they submit an irrevocable purchase order for the basket. The Fund's NAV and the total amount of the payment required to create a basket could rise or fall substantially between the time an irrevocable purchase order is submitted and the time the amount of the purchase price in respect thereof is determined.

Rejection of Purchase Orders

The Sponsor acting by itself or through the Marketing Agent or transfer agent may reject a purchase order or a Creation Basket Deposit if:

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

None of the Sponsor, Marketing Agent or transfer agent will be liable for the rejection of any purchase order or Creation Basket Deposit.

Redemption Procedures

The procedures by which an Authorized Purchaser can redeem one or more baskets mirror the procedures for the creation of baskets. On any business day, an Authorized Purchaser may place an order with the transfer agent to redeem one or more baskets. Redemption orders must be placed by 3:00 p.m. (ET) or the close of regular trading on the NYSE Arca, whichever is earlier. A redemption order so received will be effective on the date it is received in satisfactory form by the Marketing Agent. The redemption procedures allow Authorized Purchasers to redeem baskets and do not entitle an individual Shareholder to redeem any Shares in an amount less than a Redemption Basket, or to redeem baskets other than through an Authorized Purchaser. By placing a redemption order, an Authorized Purchaser agrees to deliver the baskets to be redeemed through DTC's book-entry system to the Fund by the end of the next business day following the effective date of the redemption order or by the end of such later business day. Prior to the delivery of the redemption distribution for a redemption order, the Authorized Purchaser must also have wired to the Sponsor's account at the Custodian the non-refundable transaction fee due for the redemption order. An Authorized Purchaser may not withdraw a redemption order without the prior consent of the Sponsor in its discretion.

    Registration No. 333-273364

Determination of Redemption Distribution

The redemption distribution from the Fund consists of a transfer to the redeeming Authorized Purchaser of an amount of cash and/or cash equivalents that is in the same proportion to the total assets of the Fund (net of estimated accrued but unpaid fees, expenses and other liabilities) on the date the order to redeem is properly received as the number of Shares to be redeemed under the redemption order is in proportion to the total number of Shares outstanding on the date the order is received. The Sponsor, directly or in consultation with the Custodian and the Sub-Administrator, determines the requirements for cash and/or cash equivalents, including the remaining maturities of the cash equivalents and cash, which may be included in distributions to redeem baskets. If cash equivalents are to be included in a redemption distribution for orders placed on a given business day, the Custodian and Sub-Administrator will publish an estimate of the redemption distribution composition as of the beginning of such day.

Delivery of Redemption Distribution

The redemption distribution due from a Fund will be delivered to the Authorized Purchaser on the Redemption Settlement Date if the Fund's DTC account has been credited with the baskets to be redeemed. If the Fund's DTC account has not been credited with all of the baskets to be redeemed by the end of such date, the redemption distribution will be delivered to the extent of whole baskets received. Any remainder of the redemption distribution will be delivered on the next business day after the Redemption Settlement Date to the extent of remaining whole baskets received. Pursuant to information from the Sponsor, the Custodian will also be authorized to deliver the redemption distribution notwithstanding that the baskets to be redeemed are not credited to the Fund's DTC account by noon (ET) on the Redemption Settlement Date if the Authorized Purchaser has collateralized its obligation to deliver the baskets through DTC's book-entry system on such terms as the Sponsor may from time to time determine.

Suspension or Rejection of Redemption Orders

The Sponsor may, in its discretion, suspend the right of redemption, or postpone the redemption settlement date, (1) for any period during which NYSE Arca or CME is closed other than customary weekend or holiday closings, or trading on NYSE Arca or CME is suspended or restricted, (2) for any period during which an emergency exists as a result of which delivery, disposal or evaluation of cash equivalents is not reasonably practicable, (3) for such other period as the Sponsor determines to be necessary for the protection of the Shareholders, (4) if there is a possibility that any or all of the Benchmark Component Futures Contracts of the Fund on the CME from which the NAV of the Fund is calculated will be priced at a daily price limit restriction, or (5) if, in the sole discretion of the Sponsor, the execution of such an order would not be in the best interest of the Fund or its Shareholders. For example, the Sponsor may determine that it is necessary to suspend redemptions to allow for the orderly liquidation of the Fund's assets at an appropriate value to fund a redemption. If the Sponsor has difficulty liquidating the Fund's positions, e.g., because of a market disruption event in the futures markets, it may be appropriate to suspend redemptions until such time as such circumstances are rectified. None of the Sponsor, the Marketing Agent or the transfer agent will be liable to any person or in any way for any loss or damages that may result from any such suspension or postponement.

Redemption orders must be made in whole baskets. The Sponsor will reject a redemption order if the order is not in proper form as described in the Authorized Purchaser Agreement or if the fulfillment of the order, in the opinion of its counsel, might be unlawful. The Sponsor may also reject a redemption order if the number of Shares being redeemed would reduce the remaining outstanding Shares below 50,000 Shares (i.e., five baskets of 10,000 Shares each) or less, unless the Sponsor has reason to believe that the placer of the redemption order does in fact possess all the outstanding Shares of the Fund and can deliver them.

Creation and Redemption Transaction Fees

To compensate for expenses in connection with the creation and redemption of baskets, an Authorized Purchaser is required to pay a transaction fee of $300 per order to the Custodian. The transaction fees may be reduced, increased or otherwise changed by the Sponsor.

Tax Responsibility

Authorized Purchasers are responsible for any transfer tax, sales or use tax, stamp tax, recording tax, value added tax or similar tax or governmental charge applicable to the creation or redemption of baskets, regardless of whether or not such tax or charge is imposed directly on the Authorized Purchaser, and agree to indemnify the Sponsor and the Fund if they are required by law to pay any such tax, together with any applicable penalties, additions to tax and interest thereon.

Secondary Market Transactions

As noted, the Fund will create and redeem Shares from time to time, but only in one or more Creation Baskets or Redemption Baskets. The creation and redemption of baskets are only made in exchange for delivery to the Fund or the distribution by the Fund of the amount of cash and cash equivalents equal to the total NAV of the number of Shares included in the baskets being created or redeemed determined on the day the order to create or redeem baskets is properly received.

    Registration No. 333-273364

As discussed above, Authorized Purchasers are the only persons that may place orders to create and redeem baskets. Authorized Purchasers must be registered broker-dealers or other securities market purchasers, such as banks and other financial institutions that are not required to register as broker-dealers to engage in securities transactions. An Authorized Purchaser is under no obligation to create or redeem baskets, and an Authorized Purchaser is under no obligation to offer to the public Shares of any baskets it does create. Authorized Purchasers that do offer to the public Shares from the baskets they create will do so at per Share offering prices that are expected to reflect, among other factors, the trading price of the Shares on NYSE Arca, the NAV of the Shares at the time the Authorized Purchaser purchased the Creation Baskets, the NAV of the Shares at the time of the offer of the Shares to the public, the supply of and demand for Shares at the time of sale, and the liquidity of the bitcoin interest markets. The prices of Shares offered by Authorized Purchasers are expected to fall between the Fund's NAV and the trading price of the Shares on NYSE Arca at the time of sale. Shares initially comprising the same basket but offered by Authorized Purchasers to the public at different times may have different offering prices. An order for one or more baskets may be placed by an Authorized Purchaser on behalf of multiple clients. Shares are expected to trade in the secondary market on NYSE Arca. Shares may trade in the secondary market at prices that are lower or higher relative to their NAV per Share. The amount of the discount or premium in the trading price relative to the NAV per Share may be influenced by various factors, including the number of investors who seek to purchase or sell Shares in the secondary market and the liquidity of the bitcoin interest markets. While the Shares trade on NYSE Arca until 4:00 p.m. (ET), liquidity in the markets for bitcoin interests may be reduced after the close of the CME. As a result, during this time, trading spreads, and the resulting premium or discount, on the Shares may widen.

Use of Proceeds

The Sponsor causes the Fund to transfer the proceeds of the sale of Creation Baskets to the Custodian or another financial institution for use in trading activities and/or investment in Benchmark Component Futures Contracts and cash and cash equivalents. Under normal market conditions, the Sponsor invests the Fund's assets in Benchmark Component Futures Contracts and cash and cash equivalents. When the Fund purchases Benchmark Component Futures Contracts, the Fund is required to deposit with the FCM on behalf of the exchange a portion of the value of the contract or other interest as security to ensure payment for the obligation under the Benchmark Component Futures Contracts at maturity. This deposit is known as initial margin. The Sponsor invests the Fund's assets that remain after margin and collateral is posted in cash and cash equivalents. Subject to these margin and collateral requirements, the Sponsor has sole authority to determine the percentage of assets that will be:

? held as margin or collateral with FCMs or other custodian;

? used for other investments; and

? held in bank accounts to pay current obligations and as reserves.

In general, the Fund expects that it will be required to post approximately 32% of the previous day settlement price of a Benchmark Component Futures Contracts as initial margin. Ongoing margin and collateral payments will generally be required for exchange-traded bitcoin interests based on changes in the value of the bitcoin interests. In light of the differing requirements for initial payments under exchange-traded bitcoin interests and the fluctuating nature of ongoing margin and collateral payments, it is not possible to estimate what portion of the Fund's assets will be posted as margin or collateral at any given time. Cash and cash equivalents held by the Fund constitute reserves that are available to meet ongoing margin and collateral requirements. All interest or other income is used for the Fund's benefit.

An FCM, counterparty, government agency or exchange could increase margin or collateral requirements applicable to the Fund to hold trading positions at any time. Moreover, margin is merely a security deposit and has no bearing on the profit or loss potential for any positions held.

The approximate 8-10% of the Fund's assets held by the FCM are held in segregation pursuant to the CEA and CFTC regulations.

The Trust Agreement

The following paragraphs are a summary of certain provisions of the Trust Agreement. The following discussion is qualified in its entirety by reference to the Trust Agreement.

Authority of the Sponsor

The Sponsor is generally authorized to perform all acts deemed necessary to carry out the purposes of the Trust and to conduct the business of the Trust. The Trust and the Fund will continue to exist until terminated in accordance with the Trust Agreement.

The Sponsor's Obligations

In addition to the duties imposed by the Delaware Trust Statute, under the Trust Agreement the Sponsor has obligations as a Sponsor of the Trust, which include, among others, responsibility for certain organizational and operational requirements of the Trust, as well as fiduciary responsibility for the safekeeping and use of the Trust's assets, whether or not in the Sponsor's immediate possession or control.

To the extent that, at law (common or statutory) or in equity, the Sponsor has duties (including fiduciary duties) and liabilities relating thereto to the Trust, the Fund, the Shareholders or to any other person, the Sponsor will not be liable to the Trust, the Fund, the Shareholders or to any other person for its good faith reliance on the provisions of the Trust Agreement or this prospectus unless such reliance constitutes gross negligence or willful misconduct on the part of the Sponsor. The provisions of the Trust Agreement, to the extent they restrict or eliminate the duties and liabilities of the Sponsor otherwise existing at law or in equity, replace such other duties and liabilities of the Sponsor.

    Registration No. 333-273364

Liability and Indemnification

Under the Trust Agreement, the Sponsor, the Trustee and their respective Affiliates (collectively, "Covered Persons") shall have no liability to the Trust, the Fund, or to any Shareholder for any loss suffered by the Trust or the Fund which arises out of any action or inaction of such Covered Person if such Covered Person, in good faith, determined that such course of conduct was in the best interest of the Trust or the Fund and such course of conduct did not constitute gross negligence or willful misconduct of such Covered Person. Subject to the foregoing, neither the Sponsor nor any other Covered Person shall be personally liable for the return or repayment of all or any portion of the capital or profits of any Shareholder or assignee thereof, it being expressly agreed that any such return of capital or profits made pursuant to the Trust Agreement shall be made solely from the assets of the Fund without any rights of contribution from the Sponsor or any other Covered Person. A Covered Person shall not be liable for the conduct or willful misconduct of any administrator or other delegate selected by the Sponsor with reasonable care, provided, however, that the Trustee and its Affiliates shall not, under any circumstances be liable for the conduct or willful misconduct of any administrator or other delegate or any other person selected by the Sponsor to provide services to the Trust.

The Trust Agreement also provides that the Sponsor shall be indemnified by the Trust (or by a series separately to the extent the matter in question relates to a single series or disproportionately affects a specific series in relation to other series) against any losses, judgments, liabilities, expenses (excluding any taxes on the compensation received for services as Sponsor or on indemnity payments received), and amounts paid in settlement of any claims sustained by it in connection with its activities for the Trust, provided that (i) the Sponsor was acting on behalf of or performing services for the Trust and has determined, in good faith, that such course of conduct was in the best interests of the Trust and such liability or loss was not the result of gross negligence, willful misconduct, or a breach of the Trust Agreement on the part of the Sponsor and (ii) any such indemnification will only be recoverable from the assets of the applicable series. The Sponsor's rights to indemnification permitted under the Trust Agreement shall not be affected by the dissolution or other cessation to exist of the Sponsor, or the withdrawal, adjudication of bankruptcy or insolvency of the Sponsor, or the filing of a voluntary or involuntary petition in bankruptcy under Title 11 of the Bankruptcy Code by or against the Sponsor.

Notwithstanding the above, the Sponsor shall not be indemnified for any losses, liabilities or expenses arising from or out of an alleged violation of U.S. federal or state securities laws unless (i) there has been a successful adjudication on the merits of each count involving alleged securities law violations as to the particular indemnitee and the court approves the indemnification of such expenses (including, without limitation, litigation costs), (ii) such claims have been dismissed with prejudice on the merits by a court of competent jurisdiction as to the particular indemnitee and the court approves the indemnification of such expenses (including, without limitation, litigation costs), or (iii) a court of competent jurisdiction approves a settlement of the claims against a particular indemnitee and finds that indemnification of the settlement and related costs should be made.

The payment of any indemnification shall be allocated, as appropriate, among the Trust's series. The Trust and its series shall not incur the cost of that portion of any insurance which insures any party against any liability, the indemnification of which is prohibited under the Trust Agreement.

Expenses incurred in defending a threatened or pending action, suit or proceeding against the Sponsor shall be paid by the Trust in advance of the final disposition of such action, suit or proceeding, if (i) the legal action relates to the performance of duties or services by the Sponsor on behalf of the Trust; (ii) the legal action is initiated by a party other than the Trust; and (iii) the Sponsor undertakes to repay the advanced funds with interest to the Trust in cases in which it is not entitled to indemnification.

The Trust Agreement provides that the Sponsor and the Trust shall indemnify the Trustee and its successors, assigns, legal representatives, officers, directors, Shareholders, employees, agents and servants (the "Trustee Indemnified Parties") against any liabilities, obligations, losses, damages, penalties, taxes (excluding any taxes on the compensation received for services as Trustee or on indemnity payments received), claims, actions, suits, costs, expenses or disbursements which may be imposed on a Trustee Indemnified Party relating to or arising out of the formation, operation or termination of the Trust, the execution, delivery and performance of any other agreements to which the Trust is a party, or the action or inaction of the Trustee under the Trust Agreement or any other agreement, except for expenses resulting from the gross negligence or willful misconduct of a Trustee Indemnified Party. Further, certain officers of the Sponsor are insured against liability for certain errors or omissions which an officer may incur or that may arise out of his or her capacity as such.

In the event the Trust is made a party to any claim, dispute, demand or litigation or otherwise incurs any liability or expense as a result of or in connection with any Shareholder's (or assignee's) obligations or liabilities unrelated to the Trust business, such Shareholder (or assignees cumulatively) is required under the Trust Agreement to indemnify the Trust for all such liability and expense incurred, including attorneys' and accountants' fees.

Withdrawal of the Sponsor

The Sponsor may withdraw voluntarily as the Sponsor of the Trust only upon ninety (90) days' prior written notice to the holders of the Trust's outstanding Shares and the Trustee. If the withdrawing Sponsor is the last remaining Sponsor, Shareholders holding a majority (over 50%) of the outstanding Shares of the Fund, voting together as a single class (not including Shares acquired by the Sponsor through its initial capital contribution) may vote to elect a successor Sponsor. The successor Sponsor will continue the business of the Trust. Shareholders have no right to remove the Sponsor.

    Registration No. 333-273364

In the event of withdrawal, the Sponsor is entitled to a redemption of the Shares it acquired through its initial capital contribution to any of the series of the Trust at their NAV per Share. If the Sponsor withdraws and a successor Sponsor is named, the withdrawing Sponsor shall pay all expenses as a result of its withdrawal.

Meetings

Meetings of the Trust's Shareholders may be called by the Sponsor and will be called by it upon the written request of Shareholders holding at least 25% of the outstanding Shares of the Trust or the Fund, as applicable (not including Shares acquired by the Sponsor through its initial capital contribution). The Sponsor shall deposit in the United States mail or electronically transmit written notice to all Shareholders of the Fund of the meeting and the purpose of the meeting, which shall be held on a date not less than 30 nor more than 60 days after the date of mailing of such notice, at a reasonable time and place. Where the meeting is called upon the written request of the Shareholders of the Fund, or any other Fund, as applicable, such written notice shall be mailed or transmitted not more than 45 days after such written request for a meeting was received by the Sponsor.

Voting Rights

Shareholders have no voting rights with respect to the Trust or the Fund except as expressly provided in the Trust Agreement. The Trust Agreement provides that Shareholders representing at least a majority (over 50%) of the outstanding Shares of the Fund together as a single class (excluding Shares acquired by the Sponsor in connection with its initial capital contribution to any Trust series) may vote to (i) continue the Trust by electing a successor Sponsor as described above, and (ii) approve amendments to the Trust Agreement that impair the right to surrender Redemption Baskets for redemption. (Trustee consent to any amendment to the Trust Agreement is required if the Trustee reasonably believes that such amendment adversely affects any of its rights, duties or liabilities.) In addition, Shareholders holding Shares representing seventy-five percent (75%) of the outstanding Shares of the Fund, voting together as a single class (excluding Shares acquired by the Sponsor in connection with its initial capital contribution to any Trust series) may vote to dissolve the Trust upon not less than ninety (90) days' notice to the Sponsor.

Limited Liability of Shareholders

Shareholders shall be entitled to the same limitation of personal liability extended to stockholders of private corporations for profit organized under the general corporation law of Delaware, and no Shareholder shall be liable for claims against, or debts of the Trust or the Fund in excess of his Share of the Fund's assets. The Trust or the Fund shall not make a claim against a Shareholder with respect to amounts distributed to such Shareholder or amounts received by such Shareholder upon redemption unless, under Delaware law, such Shareholder is liable to repay such amount.

The Trust or the Fund shall indemnify to the full extent permitted by law and the Trust Agreement each Shareholder (excluding the Sponsor to the extent of its ownership of any Shares acquired through its initial capital contribution) against any claims of liability asserted against such Shareholder solely because of its ownership of Shares (other than for taxes on income from Shares for which such Shareholder is liable).

The Trust Agreement provides that every written note, bond, contract, instrument, certificate or undertaking made or issued by or on behalf of the Fund shall give notice to the effect that the obligations of such instrument are not binding upon the Shareholders individually but are binding only upon the assets and property of the Fund.

The Sponsor Has Conflicts of Interest

There are present and potential future conflicts of interest in the Trust's structure and operation you should consider before you purchase Shares. The Sponsor may use this notice of conflicts as a defense against any claim or other proceeding made.

The Sponsor's principals, managers, officers and employees, do not devote their time exclusively to the Fund. Notwithstanding obligations and expectations related to the management of the Sponsor, the Sponsor's principals, officers and employees may be directors, officers or employees of other entities, and may manage assets of other entities, including the other funds of the Trust, through the Sponsor or otherwise. As a result, the principals could have a conflict between responsibilities to the Fund on the one hand and to those other entities on the other.

The Sponsor and its principals, officers and employees may trade securities, futures and related contracts for their own accounts, creating the potential for preferential treatment of their own accounts. Shareholders will not be permitted to inspect the trading records of such persons, or any written policies of the Sponsor related to such trading. A conflict of interest may exist if their trades are in the same markets and at approximately the same times as the trades for the Fund. A potential conflict also may occur when the Sponsor's principals trade their accounts more aggressively or take positions in their accounts that are opposite, or ahead of, the positions taken by the Fund.

    Registration No. 333-273364

The Sponsor has sole current authority to manage the investments and operations of the Fund, and this may allow it to act in a way that furthers its own interests which may create a conflict with your best interests, including the authority of the Sponsor to allocate expenses to and between the funds of the Trust. Shareholders have very limited voting rights with respect to the Fund, which will limit the ability to influence matters such as amendment of the Trust Agreement, change in the Fund's basic investment policies, or dissolution of the Fund or the Trust.

The Sponsor serves as the Sponsor to the Fund and serves as the sponsor or investment adviser to investment companies and commodity pools other than the Fund. The Sponsor may have a conflict to the extent that its trading decisions for the Fund may be influenced by the effect they would have on the other investment companies or pools it manages. In addition, the Sponsor may be required to indemnify the officers and directors of the other investment companies or pools, if the need for indemnification arises. This potential indemnification will cause the Sponsor's assets to decrease. If the Sponsor's other sources of income are not sufficient to compensate for the indemnification, it could cease operations, which could in turn result in Fund losses and/or termination of the Fund.

If the Sponsor acquires knowledge of a potential transaction or arrangement that may be an opportunity for the Fund, it shall have no duty to offer such opportunity to the Fund. The Sponsor will not be liable to the Fund or the Shareholders for breach of any fiduciary or other duty if the Sponsor pursues such opportunity or directs it to another person or does not communicate such opportunity to the Fund and is not required to share income or profits derived from such business ventures with the Fund.

The Sponsor might have a potential future conflict of interest if the Sponsor, a new sponsor, or sub-adviser were to register as a broker-dealer or become affiliated with a broker-dealer. In such case, the Sponsor, new sponsor, or sub-adviser, as the case may be, would develop and implement appropriate procedures designed to prevent the use and dissemination of material non-public information regarding the Fund's holdings.

Resolution of Conflicts Procedures

The Trust Agreement provides that whenever a conflict of interest exists between the Sponsor or any of its Affiliates, on the one hand, and the Trust, any shareholder of a Trust series, or any other person, on the other hand, the Sponsor shall resolve such conflict of interest, take such action or provide such terms, considering in each case the relative interest of each party (including its own interest) to such conflict, agreement, transaction or situation and the benefits and burdens relating to such interests, any customary or accepted industry practices, and any applicable generally accepted accounting practices or principles. In the absence of bad faith by the Sponsor, the resolution, action or terms so made, taken or provided by the Sponsor shall not constitute a breach of the Trust Agreement or any other agreement contemplated therein or of any duty or obligation of the Sponsor at law or in equity or otherwise.

Ownership or Beneficial Interest in the Fund

As of the date of this prospectus, the Sponsor owns four (4) Shares of the Fund. As of the date of this Prospectus, none of the principals of the Sponsor have an ownership interest in the Fund.

Interests of Named Experts and Counsel

No expert hired by the Fund to give advice on the preparation of this offering document has been hired on a contingent fee basis, nor do any of them have any present or future expectation of interest in the Sponsor, Marketing Agent, Authorized Purchasers, Custodian/Administrator or other service providers to the Fund.

Provisions of Federal and State Securities Laws

This offering is made pursuant to federal and state securities laws. The SEC and state securities agencies take the position that indemnification of the Sponsor that arises out of an alleged violation of such laws is prohibited unless certain conditions are met. Those conditions require that no indemnification of the Sponsor or any underwriter for the Fund may be made in respect of any losses, liabilities or expenses arising from or out of an alleged violation of federal or state securities laws unless: (i) there has been a successful adjudication on the merits of each count involving alleged securities law violations as to the party seeking indemnification and the court approves the indemnification; (ii) such claim has been dismissed with prejudice on the merits by a court of competent jurisdiction as to the party seeking indemnification; or (iii) a court of competent jurisdiction approves a settlement of the claims against the party seeking indemnification and finds that indemnification of the settlement and related costs should be made, provided that, before seeking such approval, the Sponsor or other indemnitee must apprise the court of the position held by regulatory agencies against such indemnification.

Books and Records

The Trust keeps its books of record and account at its office located at 234 West Florida Street, Suite 203, Milwaukee, Wisconsin 53204, or at the offices of the Sub-Administrator, Global Fund Services, doing business as U.S. Bancorp Fund Services, LLC, doing business as U.S. Bank Global Fund Services, located at 777 E. Wisconsin Ave, Milwaukee, Wisconsin 53202, or such office, including of an administrative agent, as it may subsequently designate upon notice. The books of account of the Fund are open to inspection by any Shareholder (or any duly constituted designee of a Shareholder) at all times during the usual business hours of the Fund upon reasonable advance notice to the extent such access is required under CFTC rules and regulations. In addition, the Trust keeps a copy of the Trust Agreement on file in its office which will be available for inspection by any Shareholder at all times during its usual business hours upon reasonable advance notice.

    Registration No. 333-273364

Statements, Filings, and Reports to Shareholders

The Trust will furnish annual reports (as of the end of each fiscal year) for the Fund to DTC purchasers for distribution to Shareholders, as required to be provided to Shareholders by the CFTC and the NFA. These annual reports will contain financial statements prepared by the Sponsor and audited by an independent registered public accounting firm designated by the Sponsor. The Trust will also post monthly reports to the Fund's website (http://hashdex-etfs.com/). These monthly reports will contain certain unaudited financial information regarding the Fund, including the Fund's NAV. The Sponsor will furnish to the Shareholders other reports or information which the Sponsor, in its discretion, determines to be necessary or appropriate. In addition, under SEC rules the Trust will be required to file quarterly and annual reports for the Fund with the SEC, which need not be sent to Shareholders but will be publicly available through the SEC. The Trust will post the same information that would otherwise be provided in the Trust's CFTC, NFA and SEC reports on the Fund's website: http://hashdex-etfs.com/.

The accountants' report on its audit of the Fund's financial statements will be furnished by the Trust to Shareholders upon request. The Trust will file such tax returns, and prepare, disseminate and file such tax reports for the Fund as it is advised by its counsel or accountants are from time to time required by any applicable statute, rule or regulation and will make such tax elections for the Fund as it deems advisable.

The Fund or its appointed agent will provide tax information in accordance with the Code and applicable U.S. Treasury Regulations. Persons treated as intermediaries for purposes of these regulations may obtain tax information regarding the Fund by contacting the Fund at 234 West Florida Street, Suite 203, Milwaukee, Wisconsin 53204 or from the Fund's website, http://hashdex-etfs.com/.

Fiscal Year

The fiscal year of the Fund is the calendar year.

Governing Law

The rights of the Sponsor, the Trust, the Fund, DTC (as registered owner of the Fund's global certificate for Shares) and the Shareholders are governed by the laws of the State of Delaware, except with respect to causes of action for violations of U.S. federal or state securities laws. The Trust Agreement and the effect of every provision thereof shall control over any contrary or limiting statutory or common law of the State of Delaware, other than the Delaware Trust Statute.

Legal Matters

Litigation and Claims

Except as described above, within the past 10 years of the date of this prospectus, there have been no material administrative, civil or criminal actions against the Sponsor, the Trust or the Fund, or any principal or affiliate of any of them. This includes any actions pending, on appeal, concluded, threatened, or otherwise known to them.

Legal Opinion

K&L Gates LLP ("KLG") has been retained to advise the Trust and the Sponsor with respect to the Shares being offered hereby and has passed upon the validity of the Shares being issued hereunder. KLG has also provided the Sponsor with its opinion with respect to U.S. federal income tax matters addressed below in "U.S. Federal Income Tax Considerations."

Experts

The financial statements of Hashdex Bitcoin Futures ETF, a series of Teucrium Commodity Trust, included in this prospectus and elsewhere in the registration statement have been so included in reliance upon the report of Grant Thornton LLP, independent registered public accountants, upon the authority of said firm as experts in accounting and auditing.

The financial statements of the Fund are included in this prospectus and elsewhere in the registration statement in reliance upon the report of Tait, Weller, & Baker, LLP "Tait Weller", independent registered public accountants, upon the authority of said firm as experts in accounting and auditing. Tait Weller is not opining on the internal control over financial reporting.

Privacy Policy

The following discussion is qualified in its entirety by reference to the privacy policy. A copy of the privacy policy is available at www..com.

    Registration No. 333-273364

The Sponsor, the Trust, and the Fund have adopted a privacy policy relating to the collection, maintenance, and use of nonpublic personal information about the Fund's current and former investors, as required under federal law. Federal law gives investors the right to limit some but not all sharing of their nonpublic personal information. Federal law also requires the Sponsor to tell investors how it collects, Shares, and protects such nonpublic personal information.

Collection of Nonpublic Personal Information

The Sponsor may collect or have access to nonpublic personal information about current and former Fund investors for certain purposes relating to the operation of the Fund. This information may include information received from investors, such as their name, social security number, telephone number, and address, and information about investors' holdings and transactions in Shares of the Fund.

Use and Disclosure of Nonpublic Personal Information

The Sponsor does not sell nonpublic personal information to any third parties. The Sponsor primarily uses investors' nonpublic personal information to complete financial transactions that may be requested. The Sponsor may disclose investors' nonpublic personal information to third parties under specific circumstances described in the privacy policy. These circumstances include, among others, information needed to complete financial transactions, information released at the direction of an investor, and certain information requested by courts, regulators, law enforcement, or tax authorities. Investors may not opt out of these disclosures.

Investors' nonpublic personal information, particularly information about investors' holdings and transactions in Shares of the Fund, may be shared between and amongst the Sponsor and the Fund. An investor cannot opt-out of the sharing of nonpublic personal information between and amongst the Sponsor and the Fund. However, the Sponsor and the Fund will not use this information for any cross-marketing purposes. In other words, all investors will be treated as having "opted out" of receiving marketing solicitations from the Fund.

Protection of Nonpublic Personal Information

As described in the privacy policy, the Sponsor takes safeguards to protect investors' nonpublic personal information, which include, among others, restricting access to such information, requiring third parties to follow appropriate standards of security and confidentiality, and maintaining physical, technical, administrative, and procedural safeguards.

The Sponsor's Website is hosted in the United States and any data provided to the Sponsor is stored in the United States. If you choose to provide Personal Data from regions outside of the United States, then by your submission of such data, you acknowledge and agree that: (a) you are transferring your personal information outside of those regions to the United States voluntarily and with consent; (b) the laws and regulations of the United States shall govern your use of the provision of your information, which laws and regulations may differ from those of your country of residence; and (c) you permit your personal information to be used for the purposes herein and in the Privacy Policy above.

U.S. Federal Income Tax Considerations

The following discussion summarizes the material U.S. federal income tax consequences of the purchase, ownership and disposition of Shares of the Fund and the U.S. federal income tax treatment of the Fund. Except where noted otherwise, it deals only with the U.S. federal income tax consequences relating to Shares held as capital assets by U.S. Shareholders (as defined below) who are not subject to special tax treatment. For example, in general it does not address the tax consequences, such as, but not limited to consequences to dealers in securities or currencies or commodities, traders in securities or dealers or traders in commodities that elect to use a mark to market method of accounting, financial institutions, regulated investment companies (except as discussed below), tax-exempt entities (except as discussed below), insurance companies, persons holding Shares as a part of a position in a "straddle" or as part of a "hedging," "conversion" or other integrated transaction for U.S. federal income tax purposes, persons with "applicable financial statements" within the meaning of section 451(b) of the Internal Revenue Code of 1986, as amended (the "Code"), or holders of Shares whose "functional currency" is not the U.S. dollar. Furthermore, the discussion below is based on the provisions of the Code, and regulations ("Treasury Regulations"), rulings and judicial decisions thereunder as of the date hereof, and such authorities may be repealed, revoked or modified (possibly with retroactive effect) so as to result in U.S. federal income tax consequences different from those discussed below.

The Sponsor has received the opinion of KLG, counsel to the Trust, regarding the material U.S. federal income tax consequences to the Fund and to U.S. Shareholders and Non-U.S. Shareholders (as defined below) as described in the following paragraphs. In rendering its opinion, KLG has relied on the facts and assumptions described in this prospectus as well as certain factual representations made by the Trust, the Fund, and the Sponsor. This opinion is not binding on the Internal Revenue Service (the "IRS") and will not be a guarantee of the results. No ruling has been requested from the IRS with respect to any matter affecting the Fund or prospective investors, and the IRS may disagree with the tax positions taken by the Trust. If the IRS were to challenge the Trust's tax positions in litigation, they might not be sustained by the courts. No statutory, administrative or judicial authority directly addresses the treatment of the Shares or instruments similar to the Shares for U.S. federal income tax purposes. As a result, the Trust cannot assure investors that the IRS or the courts will agree with the tax consequences described herein. A different treatment from that described below could adversely affect the amount, timing and character of income, gain or loss in respect of an investment in the Shares and could adversely affect the value of the Shares.

    Registration No. 333-273364

As used herein, the term "U.S. Shareholder" means a Shareholder that is, for U.S. federal income tax purposes, (i) a citizen or resident of the United States, (ii) a corporation created or organized in or under the laws of the United States or any political subdivision thereof, (iii) an estate the income of which is subject to U.S. federal income taxation regardless of its source or (iv) a trust that (a) is subject to the supervision of a court within the United States and the control of one or more United States persons as described in section 7701(a)(30) of the Code, or (b) has a valid election in effect under applicable Treasury Regulations to be treated as a United States person. A "Non-U.S. Shareholder" is a holder that is not a U.S. Shareholder. If a partnership or other entity or arrangement treated as a partnership holds our Shares, the tax treatment of a partner will generally depend upon the status of the partner and the activities of the partnership. If you are a partner of a partnership holding our Shares, the discussion below may not be applicable to you and you should consult your own tax advisor regarding the tax consequences of acquiring, owning and disposing of Shares.

EACH PROSPECTIVE INVESTOR IS ADVISED TO CONSULT ITS OWN TAX ADVISOR REGARDING THE U.S. FEDERAL INCOME TAX CONSEQUENCES OF AN INVESTMENT IN SHARES, AS WELL AS ANY APPLICABLE STATE, LOCAL OR FOREIGN TAX CONSEQUENCES, IN LIGHT OF ITS PARTICULAR CIRCUMSTANCES.

Tax Classification of the Trust and the Fund

The Trust is organized and will be operated as a statutory trust in accordance with the provisions of the Trust Agreement and applicable Delaware law. Notwithstanding the Trust's status as a statutory trust and the Fund's status as a series of the Trust, due to the nature of its activities the Fund will not be classified as a trust for U.S. federal income tax purposes, but rather it is more likely than not that it will be classified as a partnership for such purposes. The trading of Shares on NYSE Arca will cause the Fund to be classified as a "publicly traded partnership" for U.S. federal income tax purposes. Under section 7704 of the Code, a publicly traded partnership is generally taxable as a corporation. In the case of an entity not registered under the Investment Company Act of 1940 as amended, (such as the Fund) and not meeting certain other conditions, however, an exception to this general rule applies if at least 90% of the entity's gross income is "qualifying income" for each taxable year of its existence (the "qualifying income exception"). For this purpose, qualifying income is defined as including, in pertinent part, interest (other than from a financial business), dividends, and gains from the sale or disposition of capital assets held for the production of interest or dividends. In the case of a partnership of which a principal activity is the buying and selling of commodities other than as inventory or of futures, forwards and options with respect to commodities, "qualifying income" also includes income and gains from commodities and from such futures, forwards, options, and, provided the partnership is a trader or investor with respect to such assets, swaps and other notional principal contracts with respect to commodities.

There is very limited authority on the U.S. federal income tax treatment of bitcoin and no direct authority on bitcoin derivatives, such as Bitcoin Futures Contracts. KLG is of the opinion that Bitcoin Futures Contracts more likely than not will be considered futures with respect to commodities for purposes of the qualifying income exception under section 7704 of the Code. Based on the opinion of KLG and a CFTC determination that treats bitcoin as a commodity under the CEA, the Fund intends to take the position that Bitcoin Futures Contracts consist of futures on commodities for purposes of the qualifying income exception under section 7704 of the Code. Shareholders should be aware that the Fund's position is not binding on the IRS, and no assurance can be given that the IRS will not challenge the Fund's position, or that the IRS or a court will not ultimately reach a contrary conclusion, which would result in the material adverse consequences to Shareholders and the Fund discussed below.

The Trust and the Sponsor have represented the following to KLG:

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

Based in part on these representations, KLG is of the opinion that the Fund more likely than not will be treated as a partnership that it is not taxable as a corporation for U.S. federal income tax purposes. The Fund's taxation as a partnership rather than a corporation will require the Sponsor to conduct the Fund's business activities in such a manner that it satisfies the requirements of the qualifying income exception on a continuing basis. No assurances can be given that the Fund's operations for any given year will produce income that satisfies these requirements. KLG will not review the Fund's ongoing compliance with these requirements and will have no obligation to advise the Trust, the Fund or the Fund's Shareholders in the event of any subsequent change in the facts, representations or applicable law relied upon in reaching its opinion.

If the Fund failed to satisfy the qualifying income exception in any year, other than a failure that is determined by the IRS to be inadvertent and that is cured within a reasonable time after discovery (in which case, as a condition of relief, the Fund could be required to pay the government amounts determined by the IRS), the Fund would be taxable as a corporation for U.S. federal income tax purposes and would pay U.S. federal income tax on its income at regular corporate tax rates. In that event, Shareholders would not report their share of the Fund's income or loss on their tax returns. Distributions by the Fund (if any) would be treated as dividend income to the Shareholders to the extent of the Fund's current and accumulated earnings and profits, then treated as a tax-free return of capital to the extent of the Shareholder's basis in the Shares (and will reduce the basis), and, to the extent it exceeds a Shareholder's basis in such Shares, as capital gain for Shareholders who hold their Shares as capital assets. Accordingly, if the Fund were to be taxable as a corporation, it would likely have a material adverse effect on the economic return from an investment in the Fund and on the value of the Shares.

    Registration No. 333-273364

The remainder of this summary assumes that the Fund is classified for U.S. federal income tax purposes as a partnership that it is not taxable as a corporation.

U.S. Shareholders

Tax Consequences of Ownership of Shares

Taxation of the Fund's Income. No U.S. federal income tax is paid by the Fund on its income. Instead, the Fund files annual partnership returns, and each U.S. Shareholder is required to report on its U.S. federal income tax return its allocable share of the income, gain, loss, deductions and credits reflected on such partnership returns. If the Fund recognizes income, including interest on cash equivalents and net capital gains from cash settlement of Benchmark Component Futures Contracts for a taxable year, Shareholders must report their share of these items even though the Fund makes no distributions of cash or property during the taxable year. Consequently, a Shareholder may be taxable on income or gain recognized by the Fund but receive no cash distribution with which to pay the resulting tax liability or may receive a distribution that is insufficient to pay such liability. Because the Sponsor currently does not intend to make distributions, it is likely that a U.S. Shareholder that realizes net income or gain with respect to Shares for a taxable year will be required to pay any resulting tax from sources other than Fund distributions. Additionally, individuals with modified adjusted gross income in excess of $200,000 ($250,000 in the case of married individuals filing jointly) and certain estates and trusts are subject to an additional 3.8% tax on their "net investment income," which generally includes net income from interest, dividends, annuities, royalties, and rents, and net capital gains (other than certain amounts earned from trades or businesses). Also included as income subject to the additional 3.8% tax is income from businesses involved in the trading of financial instruments or commodities. Shareholders subject to this provision may be required to pay this 3.8% tax on interest income and capital gains allocated to them by the Fund.

Monthly Conventions for Allocations of the Fund's Profit and Loss and Capital Account Restatements. Under Code section 704, the determination of a partner's distributive share of any item of income, gain, loss, deduction or credit is governed by the applicable organizational document unless the allocation provided by such document lacks "substantial economic effect." An allocation that lacks substantial economic effect nonetheless will be respected if it is in accordance with the partners' interests in the partnership, determined by considering all facts and circumstances relating to the economic arrangements among the partners. Subject to the possible exception for certain conventions to be used by the Fund as discussed below, allocations pursuant to the Trust Agreement should be considered as having substantial economic effect or being in accordance with Shareholders' interests in the Fund.

In situations where a partner's interest in a partnership is redeemed or sold during a taxable year, the Code generally requires that partnership tax items for the year be allocated to the partner using either an interim closing of the books or a daily proration method. The Fund intends to allocate tax items using an interim closing of the book's method under which income, gains, losses and deductions will be determined on a monthly basis, taking into account the Fund's accrued income and deductions and gains and losses (both realized and unrealized) for the month. The tax items for each month during a taxable year will then be allocated among the holders of Shares in proportion to the number of Shares owned by them as of the close of trading on the last trading day of the preceding month (the "monthly allocation convention").

Under the monthly allocation convention, an investor who disposes of a Share during the current month will be treated as disposing of the Share as of the end of the last day of the calendar month. For example, an investor who buys a Share on April 10 of a year and sells it on May 20 of the same year will be allocated all of the tax items attributable to May (because it is deemed to hold the Share through the last day of May) but none of those attributable to April. The tax items attributable to that Share for April will be allocated to the person who held the Share as of the close of trading on the last trading day of March. Under the monthly allocation convention, an investor who purchases and sells a Share during the same month, and therefore does not hold (and is not deemed to hold) the Share at the close of the last trading day of either that month or the previous month, will receive no allocations with respect to that Share for any period. Accordingly, investors may receive no allocations with respect to Shares that they actually held or may receive allocations with respect to Shares attributable to periods that they did not actually hold the Shares.

By investing in Shares, a U.S. Shareholder agrees that, in the absence of new legislation, regulatory or administrative guidance, or judicial rulings to the contrary, it will file its U.S. income tax returns in a manner that is consistent with the monthly allocation convention as described above and with the IRS Schedule K-1 or any successor form provided to Shareholders by the Fund or the Trust.

For any month in which a Creation Basket is issued or a Redemption Basket is redeemed, the Fund will credit or debit the "book" capital accounts of existing Shareholders with the amount of any unrealized gain or loss, respectively, on Fund assets. For this purpose, the Fund will use a convention whereby unrealized gain or loss will be computed based on the lowest NAV of the Fund's assets during the month in which Shares are issued or redeemed, which may be different than the value of the assets on the date of an issuance or redemption. The capital accounts as adjusted in this manner will be used in making tax allocations intended to account for differences between the tax basis and fair market value of property owned by the Fund at the time new Shares are issued or outstanding Shares are redeemed (so-called "reverse Code section 704(c) allocations"). The intended effect of these adjustments is to equitably allocate among Shareholders any unrealized appreciation or depreciation in the Fund's assets existing at the time of a contribution or redemption for book and tax purposes.

    Registration No. 333-273364

The conventions used by the Fund, as noted above, in making tax allocations may cause a Shareholder to be allocated more or less income or loss for U.S. federal income tax purposes than its proportionate share of the economic income or loss realized by the Fund during the period it held its Shares. This mismatch between taxable and economic income or loss in some cases may be temporary, reversing itself in a later year when the Shares are sold, but could be permanent. As one example, a Shareholder could be allocated income accruing after it sold its Shares, resulting in an increase in the basis of the Shares (see "Tax Basis of Shares," below). In connection with the disposition of the Shares, the additional basis might produce a capital loss the deduction of which may be limited (see "Limitations on Deductibility of Losses and Certain Expenses," below).

Section 754 election. The Fund intends to make the election permitted by section 754 of the Code, which election is irrevocable without the consent of the IRS. The effect of this election is that when a secondary market sale of Shares occurs, the Fund adjusts the purchaser's proportionate share of the tax basis of the Fund's assets to fair market value, as reflected in the price paid for the Shares, as if the purchaser had directly acquired an interest in the Fund's assets. The section 754 election is intended to eliminate disparities between a partner's basis in its partnership interest and its share of the tax basis of the partnership's assets, so that the partner's allocable share of taxable gain or loss on a disposition of an asset will correspond to its share of the appreciation or depreciation in the value of the asset since it acquired its interest. Depending on the price paid for Shares and the tax basis of the Fund's assets at the time of the purchase, the effect of the section 754 election on a purchaser of Shares may be favorable or unfavorable. In order to make the appropriate basis adjustments in a cost-effective manner, the Fund will use certain simplifying conventions and assumptions. In particular, the Fund will obtain information regarding secondary market transactions in its Shares and use this information to adjust the Shareholders' indirect basis in the Fund's assets. It is possible the IRS could successfully assert that the conventions and assumptions applied are improper and require different basis adjustments to be made, which could adversely affect some Shareholders.

Section 1256 Contracts. Under the Code, special rules apply to instruments constituting "section 1256 contracts." A section 1256 contract is defined as including, in relevant part: (1) a futures contract that is traded on or subject to the rules of a national securities exchange which is registered with the SEC, a domestic board of trade designated as a contract market by the CFTC, or any other board of trade or exchange designated by the Secretary of the Treasury (a "qualified board or exchange"), and with respect to which the amount required to be deposited and the amount that may be withdrawn depends on a system of "marking to market"; and (2) a non-equity option traded on or subject to the rules of a qualified board or exchange. Section 1256 contracts held at the end of each taxable year are treated as if they were sold for their fair market value on the last business day of the taxable year (i.e., are "marked to market"). In addition, any gain or loss realized from a disposition, termination or marking to market of a section 1256 contract is treated as long-term capital gain or loss to the extent of 60% thereof, and as short-term capital gain or loss to the extent of 40% thereof, without regard to the actual holding period ("60-40 treatment").

The Sponsor expects that many of the Fund's Bitcoin Futures Contracts will qualify as "section 1256 contracts" under the Code. Some other bitcoin interests that are cleared through a qualified board or exchange will also constitute section 1256 contracts. Any gain or loss recognized as a result of the disposition, termination or marking to market of the Fund's section 1256 contracts will be subject to 60-40 treatment and allocated to Shareholders in accordance with the monthly allocation convention. Commodity swaps will most likely not qualify as section 1256 contracts. If a commodity swap is not taxable as a section 1256 contract, any gain or loss on the swap will be recognized at the time of disposition or termination as long-term or short-term capital gain or loss depending on the holding period of the swap in the Fund's hands.

Foreign exchange gains and losses realized by the Fund in connection with certain transactions involving foreign currency-denominated debt securities, certain futures contracts, forward contracts, options and similar investments denominated in a foreign currency, and payables or receivables denominated in a foreign currency are subject to section 988 of the Code, which generally causes such gain and loss to be treated as ordinary income or loss. To the extent the Fund hold foreign investments, it may be subject to withholding and other taxes imposed by foreign countries. Tax treaties between certain countries and the United States may reduce or eliminate such taxes. Because the amount of the Fund's investments in various countries will change from time to time, it is not possible to determine the effective rate of such taxes in advance.

Limitations on Deductibility of Losses and Certain Expenses. A number of different provisions of the Code may defer or disallow the deduction of losses or expenses allocated to Shareholders by the Fund, including but not limited to those described below.

A Shareholder's deduction of its allocable share of any loss of the Fund is limited to the lesser of (1) the tax basis in its Shares or (2) in the case of a Shareholder that is an individual or a closely held corporation, the amount which the Shareholder is considered to have "at risk" with respect to the Fund's activities. In general, the amount at risk initially will be a Shareholder's invested capital. Losses in excess of the amount at risk must be deferred until years in which the Fund generates additional taxable income against which to offset such carryover losses or until additional capital is placed at risk.

Individuals and other non-corporate taxpayers are permitted to deduct capital losses only to the extent of their capital gains for the taxable year plus $3,000 of other income. Unused capital losses can be carried forward and used in future years, subject to these same limitations. In addition, an individual taxpayer may elect to carry back net losses on section 1256 contracts to each of the three preceding years and use them to offset section 1256 contract gains in those years, subject to certain limitations. Corporate taxpayers generally may deduct capital losses only to the extent of capital gains, subject to special carryback and carryforward rules.

    Registration No. 333-273364

The deduction for expenses incurred by non-corporate taxpayers constituting "miscellaneous itemized deductions," generally including investment-related expenses (other than interest and certain other specified expenses), is suspended for taxable years beginning after December 31, 2017 and before January 1, 2026. During these taxable years, non-corporate taxpayers will not be able to deduct miscellaneous itemized deductions. Provided the suspension is not extended, for taxable years ending on or after January 1, 2026, miscellaneous itemized deductions are deductible only to the extent they exceed 2% of the taxpayer's adjusted gross income for the year. Although the matter is not free from doubt, we believe management fees the Fund pays to the Sponsor and other expenses of the Fund will constitute investment-related expenses subject to this miscellaneous itemized deduction limitation, rather than expenses incurred in connection with a trade or business and will report these expenses consistent with that interpretation. For taxable years beginning on or after January 1, 2026, the Code imposes additional limitations on the amount of certain itemized deductions allowable to individuals with adjusted gross income in excess of certain amounts by reducing the otherwise allowable portion of such deductions by an amount equal to the lesser of:

    Registration No. 333-273364

    Registration No. 333-273364

Non-corporate Shareholders generally may deduct "investment interest expense" only to the extent of their "net investment income." Investment interest expense of a Shareholder will generally include any interest expense accrued by the Fund and any interest paid or accrued on direct borrowings by a Shareholder to purchase or carry its Shares, such as interest with respect to a margin account. Net investment income generally includes gross income from property held for investment (including "portfolio income" under the passive loss rules but not, absent an election, long-term capital gains or certain qualifying dividend income) less deductible expenses other than interest directly connected with the production of investment income.

If the Fund incurs indebtedness that is treated as allocable to a trade or business, the Fund's ability to deduct interest on such indebtedness allocable is limited to an amount equal to the sum of (1) the Fund's business interest income during the year and (2) 30% of the Fund's adjusted taxable income for such taxable year. If the Fund is not entitled to fully deduct its business interest in any taxable year, such excess business interest expense will be allocated to each Shareholder as excess business interest and can be carried forward by the Shareholder to successive taxable years and used to offset any excess taxable income allocated by the Fund to such Shareholder. Any excess business interest expense allocated to a Shareholder will reduce such Shareholder's basis in its Shares in the year of the allocation even if the expense does not give rise to a deduction to the Shareholder in that year. Immediately prior to a Shareholder's disposition of its Shares, the Shareholder's basis will be increased by the amount by which such basis reduction exceeds the excess interest expense that has been deducted by such Shareholder.

To the extent that the Fund allocates losses or expenses to you that must be deferred or are disallowed as a result of these or other limitations in the Code, you may be taxed on income in excess of your economic income or distributions (if any) on your Shares. As one example, you could be allocated and required to pay tax on your share of interest income accrued by the Fund for a particular taxable year, and in the same year be allocated a share of a capital loss that you cannot deduct currently because you have insufficient capital gains against which to offset the loss. As another example, you could be allocated and required to pay tax on your share of interest income and capital gain for a year but be unable to deduct some or all of your share of management fees and/or margin account interest incurred by you with respect to your Shares. Shareholders are urged to consult their own tax advisor regarding the effect of limitations under the Code on their ability to deduct their allocable share of the Fund's losses and expenses.

Tax Basis of Shares

A Shareholder's tax basis in its Shares is important in determining (1) the amount of taxable gain or loss it will realize on the sale or other disposition of its Shares, (2) the amount of non-taxable distributions that it may receive from the Fund, and (3) its ability to utilize its distributive share of any losses of the Fund on its U.S. federal income tax return. A Shareholder's initial tax basis of its Shares will equal its cost for the Shares plus its share of the Fund's liabilities (if any) at the time of purchase. In general, a Shareholder's "share" of those liabilities will equal the sum of (i) the entire amount of any otherwise nonrecourse liability of the Fund as to which the Shareholder or certain affiliates of the Shareholder is the creditor (a "partner nonrecourse liability") and (ii) a pro rata share of any nonrecourse liabilities of the Fund that are not partner nonrecourse liabilities as to any Shareholder.

A Shareholder's tax basis in its Shares generally will be (1) increased by (a) its allocable share of the Fund's taxable income and gain and (b) any additional contributions by the Shareholder to the Fund and (2) decreased (but not below zero) by (a) its allocable share of the Fund's tax deductions and losses and (b) any distributions by the Fund to the Shareholder. For this purpose, an increase in a Shareholder's share of the Fund's liabilities will be treated as a contribution of cash by the Shareholder to the Fund and a decrease in that share will be treated as a distribution of cash by the Fund to the Shareholder. Pursuant to certain IRS rulings, a Shareholder will be required to maintain a single, "unified" basis in all Shares that it owns. As a result, when a Shareholder that acquired its Shares at different prices sells less than all of its Shares, such Shareholder will not be entitled to specify particular Shares (e.g., those with a higher basis) as having been sold. Rather, it must determine its gain or loss on the sale by using an "equitable apportionment" method to allocate a portion of its unified basis in its Shares to the Shares sold.

Treatment of Fund Distributions.

If the Fund makes non-liquidating distributions to Shareholders, such distributions generally will not be taxable to the Shareholders for U.S. federal income tax purposes except to the extent that the amount of money distributed exceeds the Shareholder's adjusted basis of its interest in the Fund immediately before the distribution. Any money distributed that is in excess of a Shareholder's tax basis generally will be treated as gain from the sale or exchange of Shares. For purposes of determining the gain recognized on a distribution from a partnership, a marketable security distributed to a partner is generally treated as money. This treatment, however, does not apply to distributions to "eligible partners" of an "investment partnership," as those terms are defined in the Code.

    Registration No. 333-273364

Tax Consequences of Disposition of Shares

If a Shareholder sells its Shares, it will recognize gain or loss equal to the difference between the amount realized and its adjusted tax basis for the Shares sold. A Shareholder's amount realized will be the sum of the cash or the fair market value of other property received plus its share of the Fund's liabilities.

Gain or loss recognized by a Shareholder on the sale or exchange of Shares held for more than one year will generally be taxable as long-term capital gain or loss; otherwise, such gain or loss will generally be taxable as short-term capital gain or loss. A special election is available under the Treasury Regulations that allows Shareholders to identify and use the actual holding periods for the Shares sold for purposes of determining whether the gain or loss recognized on a sale of Shares will give rise to long-term or short-term capital gain or loss. It is expected that most Shareholders will be eligible to elect, and generally will elect, to identify and use the actual holding period for Shares sold. If a Shareholder who has differing holding periods for its Shares fails to make the election or is not able to identify the holding periods of the Shares sold, the Shareholder will have a split holding period in the Shares sold. Under such circumstances, a Shareholder will be required to determine its holding period in the Shares sold by first determining the portion of its entire interest in the Fund that would give rise to long-term capital gain or loss if its entire interest were sold and the portion that would give rise to short-term capital gain or loss if the entire interest were sold. The Shareholder would then treat each Share sold as giving rise to long-term capital gain or loss and short-term capital gain or loss in the same proportions as if it had sold its entire interest in the Fund.

Under Section 751 of the Code, a portion of a Shareholder's gain or loss from the sale of Shares (regardless of the holding period for such Shares), will be separately computed and taxed as ordinary income or loss to the extent attributable to "unrealized receivables" or "inventory" owned by the Fund. The term "unrealized receivables" includes, among other things, market discount bonds and short-term debt instruments to the extent such items would give rise to ordinary income if sold by the Fund. However, the short-term capital gain on section 1256 contracts resulting from 60-40 treatment, described above, should not be subject to this rule.

If some or all of a Shareholder's Shares are lent by its broker or other agent to a third party - for example, for use by the third party in covering a short sale - the Shareholder may be considered as having made a taxable disposition of the loaned Shares, in which case:

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

Shareholders desiring to avoid these and other possible consequences of a deemed disposition of their Shares should consider modifying any applicable brokerage account agreements to prohibit the lending of their Shares.

Other U.S. Federal Income Tax Matters

Information Reporting. The Fund provides tax information to the Shareholders and to the IRS, as required. Shareholders of the Fund are treated as partners for U.S. federal income tax purposes. Accordingly, the Fund will furnish Shareholders each year, with tax information on IRS Schedule K-1 (Form 1065), which will be used by the Shareholders in completing their U.S. federal income tax returns. The IRS has ruled that assignees of partnership interests who have not been admitted to a partnership as partners but who have the capacity to exercise substantial dominion and control over the assigned partnership interests will be considered partners for U.S. federal income tax purposes. On the basis of this ruling, except as otherwise provided herein, we will treat as a Shareholder any person whose Shares are held on their behalf by a broker or other nominee if that person has the right to direct the nominee in the exercise of all substantive rights attendant to the ownership of the Shares.

Persons who hold an interest in the Fund as a nominee for another person are required to furnish to us the following information: (1) the name, address and taxpayer identification number of the beneficial owner and the nominee; (2) whether the beneficial owner is (a) a person that is not a U.S. person, (b) a foreign government, an international organization or any wholly-owned agency or instrumentality of either of the foregoing, or (c) a tax-exempt entity; (3) the number and a description of Shares acquired or transferred for the beneficial owner; and (4) certain information including the dates of acquisitions and transfers, means of acquisitions and transfers, and acquisition cost for purchases, as well as the amount of net proceeds from sales. Brokers and financial institutions are required to furnish additional information, including whether they are U.S. persons and certain information on Shares they acquire, hold or transfer for their own account. A penalty of $250 per failure (as adjusted for inflation), up to a maximum of $3,000,000 per calendar year (as adjusted for inflation), is imposed by the Code for failure to report such information correctly to the Fund. If the failure to furnish such information correctly is determined to be willful, the per failure penalty increases to $500 (as adjusted for inflation) or, if greater, 10% of the aggregate amount of items required to be reported, and the $3,000,000 maximum does not apply. The nominee is required to supply the beneficial owner of the Shares with the U.S. federal income tax information furnished by the Fund.

    Registration No. 333-273364

Partnership Audit Procedures. The IRS may audit the U.S. federal income tax returns filed by the Fund. Partnerships are generally treated as separate entities for purposes of U.S. federal tax audits, judicial review of administrative adjustments by the IRS, and tax settlement proceedings. The tax treatment of partnership items of income, gain, loss and deduction are determined at the partnership level in a unified partnership proceeding rather than in separate proceedings with the partners.

Tax deficiencies (including interest and penalties) that arise from an adjustment to partnership items generally are assessed and collected from the partnership (rather than from the partners), and generally are calculated using maximum applicable tax rates (although such partnership level tax may be reduced or eliminated under limited circumstances). A narrow category of partnerships (generally, partnerships having no more than 100 partners that consist exclusively of individuals, C corporations, S corporations and estates) are permitted to elect out of the partnership-level audit rules. As an alternative to partnership-level tax liability, a partnership may elect to furnish adjusted Schedule K-1s to the IRS and to each person who was a partner in the audit year, stating such partner's share of any partnership adjustments, and each such partner would then take the adjustments into account on its tax returns in the year in which it receives its adjusted Schedule K-1 (rather than by amending their tax returns for the audited year). If the Fund were subject to a partnership level tax, the economic return of all Shareholders (including Shareholders that did not own Shares in the Fund during the taxable year to which the audit relates) may be affected.

The Trust Agreement provides that if the Fund becomes subject to any tax as a result of any adjustment to taxable income, gain, loss, deduction or credit for any taxable year of the Fund (pursuant to a tax audit or otherwise), such Shareholder (and each former Shareholder) is obligated to indemnify the Fund and the Sponsor against any such taxes (including any interest and penalties) to the extent such tax (or portion thereof) is properly attributable to such Shareholder (or former Shareholder). In addition, the Sponsor, on behalf of the Fund, will be authorized to take any action permitted under applicable law to avoid the assessment of any such taxes against the Fund (including an election to issue adjusted Schedule K-1s to the Shareholders (and/or former Shareholders) that take such adjustments to taxable income, gain, loss, deduction or credit into account, resulting in each such Shareholder taking those adjustments into account on its tax returns.

Reportable Transaction Rules. In certain circumstances the Code and Treasury Regulations require that the IRS be notified of transactions through a disclosure statement attached to a taxpayer's U.S. federal income tax return. These disclosure rules may apply to transactions irrespective of whether they are structured to achieve particular tax benefits. They could require disclosure by the Trust or Shareholders if a Shareholder incurs a loss in excess of a specified threshold from a sale or redemption of its Shares and possibly in other circumstances. While these rules generally do not require disclosure of a loss recognized on the disposition of an asset in which the taxpayer has a "qualifying basis" (generally a basis equal to the amount of cash paid by the taxpayer for such asset), they apply to a loss recognized with respect to interests in a pass-through entity, such as the Shares, even if the taxpayer's basis in such interests is equal to the amount of cash it paid. In addition, significant monetary penalties may be imposed in connection with a failure to comply with these reporting requirements. Investors should consult their own tax advisor concerning the application of these reporting requirements to their specific situation.

Tax-Exempt Organizations. Subject to numerous exceptions, qualified retirement plans and individual retirement accounts, charitable organizations and certain other organizations that otherwise are exempt from U.S. federal income tax (collectively, "exempt organizations") nonetheless are subject to the tax on unrelated business taxable income ("UBTI"). Generally, UBTI means the gross income derived by an exempt organization from a trade or business that it regularly carries on, the conduct of which is not substantially related to the exercise or performance of its exempt purpose or function, less allowable deductions directly connected with that trade or business. If the Fund were to regularly carry on (directly or indirectly) a trade or business that is unrelated with respect to an exempt organization Shareholder, then in computing its UBTI, the Shareholder must include its share of (1) the Fund's gross income from the unrelated trade or business, whether or not distributed, and (2) the Fund's allowable deductions directly connected with that gross income. An exempt organization that has more than one unrelated trade or business generally must compute its UBTI separately for each such trade or business.

UBTI generally does not include dividends, interest, or payments with respect to securities loans and gains from the sale of property (other than property held for sale to customers in the ordinary course of a trade or business). Nonetheless, income on, and gain from the disposition of, "debt-financed property" is UBTI. Debt-financed property generally is income-producing property (including securities), the use of which is not substantially related to the exempt organization's tax-exempt purposes, and with respect to which there is "acquisition indebtedness" at any time during the taxable year (or, if the property was disposed of during the taxable year, the 12-month period ending with the disposition). Acquisition indebtedness includes debt incurred to acquire property, debt incurred before the acquisition of property if the debt would not have been incurred but for the acquisition, and debt incurred subsequent to the acquisition of property if the debt would not have been incurred but for the acquisition and at the time of acquisition the incurrence of debt was foreseeable. The portion of the income from debt-financed property attributable to acquisition indebtedness is equal to the ratio of the average outstanding principal amount of acquisition indebtedness over the average adjusted basis of the property for the year. The Fund currently does not anticipate that it will borrow money to acquire investments; however, the Fund cannot be certain that it will not borrow for such purpose in the future, which could result in an exempt organization Shareholder having UBTI. In addition, an exempt organization Shareholder that incurs acquisition indebtedness to purchase its Shares in the Fund may have UBTI.

The U.S. federal income tax rate applicable to an exempt organization Shareholder on its UBTI generally will be either the corporate or trust tax rate, depending upon the Shareholder's form of organization. The Fund may report to each such Shareholder information as to the portion, if any, of the Shareholder's income and gains from the Fund for any year that will be treated as UBTI; the calculation of that amount is complex, and there can be no assurance that the Fund's calculation of UBTI will be accepted by the IRS. An exempt organization Shareholder will be required to make payments of estimated U.S. federal income tax with respect to its UBTI.

    Registration No. 333-273364

Regulated Investment Companies. Interests in and income from "qualified publicly traded partnerships" satisfying certain gross income tests are treated as qualifying assets and income, respectively, for purposes of determining eligibility for regulated investment company ("RIC") status. A RIC may invest up to 25% of its assets in interests in qualified publicly traded partnerships. The determination of whether a publicly traded partnership such as the Fund is a qualified publicly traded partnership is made on an annual basis. While the tax treatment of bitcoin derivatives is not entirely clear, it is possible that the Fund may be a qualified publicly traded partnership. However, such qualification is not assured, and prospective RIC investors should consult a tax advisor regarding the treatment of an investment in the Fund under current tax rules and in light of their particular circumstances.

Non-U.S. Shareholders

Generally, non-U.S. persons who derive U.S. source income or gain from investing or engaging in a U.S. business are taxable on two categories of income. The first category consists of amounts that are fixed or determinable, annual or periodic income, such as interest, dividends and rent that are not connected with the operation of a U.S. trade or business ("FDAP"). The second category is income that is effectively connected with the conduct of a U.S. trade or business ("ECI"). FDAP income (other than interest that is considered "portfolio interest;" as discussed below) is generally subject to a 30% withholding tax, which may be reduced for certain categories of income by a treaty between the U.S. and the recipient's country of residence. In contrast, ECI is generally subject to U.S. tax on a net basis at graduated rates upon the filing of a U.S. tax return. Where a non-U.S. person has ECI as a result of an investment in a partnership, the ECI is currently subject to a withholding tax at a rate of 37% for individual Shareholders and a rate of 21% for corporate Shareholders. The tax withholding on ECI, which is the highest tax rate under Code section 1 for non-corporate Non-U.S. Shareholders and Code section 11(b) for corporate Non-U.S. Shareholders, may increase in future tax years if tax rates increase from their current levels.

Withholding on Allocations and Distributions. The Code provides that a non-U.S. person who is a partner in a partnership that is engaged in a U.S. trade or business during a taxable year will also be considered to be engaged in a U.S. trade or business during that year. Classifying an activity by a partnership as an investment or an operating business is a factual determination. Under certain safe harbors in the Code, an investment fund whose activities consist of trading in stocks, securities, or commodities for its own account generally will not be considered to be engaged in a U.S. trade or business unless it is a dealer in such stocks, securities, or commodities. This safe harbor applies to investments in commodities only if the commodities are of a kind customarily dealt in on an organized commodity exchange and if the transaction is of a kind customarily consummated at such place. As noted above, there is limited authority on the U.S. federal income tax treatment of bitcoin and no direct authority on bitcoin derivatives. However, based on the CFTC treatment of bitcoin as a commodity and on the assumption that the Fund will invest in Bitcoin Futures Contracts through the CME, the Fund intends to take the position that investing in Bitcoin Futures Contracts falls within the commodities trading safe harbor. Thus, the Fund anticipates that the activities directly conducted by the Fund should not result in the Fund being engaged in a trade or business within the United States for purposes of this rule. However, there can be no assurance that the IRS would not successfully assert, or that a court would not decide, that the Fund's activities constitute a U.S. trade or business.

In the event that the Fund's activities were considered to constitute a U.S. trade or business, the Fund would be required to withhold at the highest rate specified in Code section 1 (currently 37%) on allocations of our income to non-corporate Non-U.S. Shareholders and the highest rate specified in Code section 11(b) (currently 21%) on allocations of our income to corporate Non-U.S. Shareholders, when such income is distributed. Non-U.S. Shareholders would also be subject to a 10% withholding tax on the consideration payable upon a sale or exchange of such Non-U.S. Shareholder's Shares, although the IRS has announced proposed amendments applicable to this withholding for transfers of interests in publicly traded partnerships occurring on or after January 1, 2023. In the case of a transfer made through a broker, the obligation to withhold will generally be imposed on the transferor's broker. A Non-U.S. Shareholder with ECI will generally be required to file a U.S. federal income tax return, and the return will provide the Non-U.S. Shareholder with the mechanism to seek a refund of any withholding in excess of such Shareholder's actual U.S. federal income tax liability. Any amount withheld by the Fund will be treated as a distribution to the Non-U.S. Shareholder to the extent possible. In some cases, the Fund may not be able to match the economic cost of satisfying its withholding obligations to a particular Non-U.S. Shareholder, which may result in said cost being borne by the Fund, generally, and accordingly, by all Shareholders.

If the Fund is not treated as engaged in a U.S. trade or business, a Non-U.S. Shareholder may nevertheless be treated as having FDAP income, which would be subject to a 30% withholding tax (possibly subject to reduction by treaty), with respect to some or all of its distributions from the Fund or its allocable share of Fund income. Amounts withheld on behalf of a Non-U.S. Shareholder will be treated as being distributed to such Shareholder. If the Fund is not able to match the economic cost of satisfying its withholding obligation to a particular Non-U.S. Shareholder, said cost may have to be borne by the Fund and accordingly by all Shareholders.

To the extent any interest income allocated to a Non-U.S. Shareholder that otherwise constitutes FDAP is considered "portfolio interest," neither the allocation of such interest income to the Non-U.S. Shareholder nor a subsequent distribution of such interest income to the Non-U.S. Shareholder will be subject to withholding, provided that the Non-U.S. Shareholder is not otherwise engaged in a trade or business in the U.S. and provides the Fund with a timely and properly completed and executed IRS Form W-8BEN or other applicable form. In general, portfolio interest is interest paid on debt obligations issued in registered form, unless the recipient owns 10% or more of the voting power of the issuer. A Non-U.S. Shareholder's allocable share of interest on U.S. bank deposits, certificates of deposit and discount obligations with maturities from original issue of 183 days or less should also not be subject to withholding. Generally, other interest from U.S. sources paid to the Fund and allocable to Non-U.S. Shareholders will be subject to withholding.

    Registration No. 333-273364

In order for the Fund to avoid withholding on any interest income allocable to Non-U.S. Shareholders that would qualify as portfolio interest, it will be necessary for all Non-U.S. Shareholders to provide the Fund with a timely and properly completed and executed Form W-8BEN (or other applicable form).

Gain from Sale of Shares. Gain from the sale or exchange of Shares may be taxable to a Non-U.S. Shareholder if the Non-U.S. Shareholder is a nonresident alien individual who is present in the U.S. for 183 days or more during the taxable year. In such case, the nonresident alien individual may be subject to a 30% withholding tax on the amount of such individual's gain.

Branch Profits Tax on Corporate Non-U.S. Shareholders. In addition to the taxes noted above, any Non-U.S. Shareholders that are corporations may also be subject to an additional tax, the branch profits tax, at a rate of 30%. The branch profits tax is imposed on a non-U.S. corporation's dividend equivalent amount, which generally consists of the corporation's after-tax earnings and profits that are effectively connected with the corporation's U.S. trade or business but are not reinvested in a U.S. business. This tax may be reduced or eliminated by an income tax treaty between the United States and the country in which the Non-U.S. Shareholder is a "qualified resident."

Foreign Account Tax Compliance Act. Legislation commonly referred to as the Foreign Account Tax Compliance Act or "FATCA," generally imposes a 30% U.S. withholding tax on payments of certain types of income to foreign financial institutions that fail to enter into an agreement with the United States Treasury to report certain required information with respect to accounts held by U.S. persons (or held by foreign entities that have U.S. persons as substantial owners). The types of income subject to the withholding tax include U.S.-source interest and dividends and the gross proceeds from the sale of any property that could produce U.S.-source interest or dividends. Proposed Treasury Regulations, however, generally eliminate withholding under FATCA on gross proceeds. Taxpayers generally may rely on these proposed Treasury Regulations until final Treasury Regulations are issued. The information required to be reported includes the identity and taxpayer identification number of each account holder that is a U.S. person and transaction activity within the holder's account. In addition, subject to certain exceptions, this legislation also imposes a 30% U.S. withholding tax on payments to foreign entities that are not financial institutions unless the foreign entity certifies that it does not have a greater than 10% U.S. owner or provides the withholding agent with identifying information on each greater than 10% U.S. owner. Depending on the status of a Non-U.S. Shareholder and the status of the intermediaries through which it holds Shares, a Non-U.S. Shareholder could be subject to this 30% U.S. withholding tax with respect to distributions on its Shares. Under certain circumstances, a Non-U.S. Shareholder may be eligible for a refund or credit of such taxes.

Prospective Non-U.S. Shareholders should consult their own tax advisor regarding these and other tax issues unique to Non-U.S. Shareholders.

Backup Withholding

The Fund may be required to withhold U.S. federal income tax ("backup withholding") from payments to: (1) any Shareholder who fails to furnish the Fund with his, her or its correct taxpayer identification number or a certificate that the Shareholder is exempt from backup withholding, and (2) any Shareholder with respect to whom the IRS notifies the Fund that the Shareholder is subject to backup withholding. Backup withholding is not an additional tax and may be returned or credited against a taxpayer's regular U.S. federal income tax liability if appropriate information is provided to the IRS. The backup withholding rate is the fourth lowest rate applicable to individuals under Code section 1(c) (currently 24%) and may increase in future tax years.

Other Tax Considerations

In addition to U.S. federal income taxes, a Shareholder may be subject to other taxes, such as state and local income taxes, unincorporated business taxes, business franchise taxes, and estate, gift, inheritance or intangible taxes that may be imposed by the various jurisdictions in which the Fund does business or owns property or where the Shareholder resides. Although an analysis of those various taxes is not presented here, each prospective Shareholder should consider their potential impact on its investment in the Fund. It is each Shareholder's responsibility to file the appropriate U.S. federal, state, local, and foreign tax returns. KLG has not provided an opinion concerning any aspects of state, local or foreign tax and its opinion on U.S. federal tax issues is limited to those issues discussed under the heading "U.S. Federal Income Tax Considerations."

Investment by ERISA Accounts and IRAs

General

Most employee benefit plans and individual retirement accounts ("IRAs") are subject to the Employee Retirement Income Security Act of 1974, as amended ("ERISA"), or the Code, or both. This section discusses certain considerations that arise under ERISA and the Code that a fiduciary of (i) an employee benefit plan as defined in ERISA; (ii) a plan as defined in Section 4975 of the Code; or (iii) entity whose underlying assets include "plan assets" by reason of an employee benefits plan or other plan's investment in the entity ("plan asset entity") who has investment discretion should take into account before deciding to invest the plan's assets in the Fund. Employee benefit plans under ERISA, plans under the Code and plan asset entities are collectively referred to below as "plans," and fiduciaries with investment discretion are referred to below as "plan fiduciaries."

    Registration No. 333-273364

This summary is based on the provisions of ERISA and the Code as of the date hereof. This summary is general in nature and is not intended to be complete, but only to address certain matters under ERISA and the Code. The summary does not include state, local, or non-U.S. law. Accordingly, investors are urged to consult with their own professional advisors to understand the issues affecting the Fund and the investor. The Sponsor is not undertaking to provide investment advice, or to give advice in a fiduciary capacity, in connection with a plan's investment in the Fund.

Investment Considerations

Each plan fiduciary must consider the facts and circumstances that are relevant to an investment in the Fund, including the role that an investment in the Fund would play in the plan's overall investment portfolio. Each plan fiduciary, before deciding to invest in the Fund, must be satisfied that (i) the investment is prudent for the plan, (ii) the investments of the plan are diversified so as to minimize the risk of large losses, (iii) an investment in the Fund complies with the terms of the plan, and (iv) the acquisition and holding of Shares does not result in a non-exempt "prohibited transaction" under Section 406 of ERISA or Section 4975 of the Code (see "Prohibited Transactions" below).

The Fund and Plan Assets

If the underlying assets of an entity, such as statutory trust, are considered to be assets of a plan for purposes of ERISA or Section 4975 of the Code, the operations of that entity would be subject to and, in some cases, limited by the provisions of ERISA and Section 4975 of the Code. A regulation issued under ERISA contains rules for determining when an investment by a plan in an equity interest of an entity will result in the underlying assets of the entity being deemed plan assets for purposes of ERISA and Section 4975 of the Code. The regulation includes an exception that provides that assets of an entity will not be plan assets of a plan that purchases an equity interest in the entity, if the equity interest purchased is a "publicly offered security."

The publicly offered security exception applies if the equity interest is a security that is:

(1) freely transferable (see discussion below);

    Registration No. 333-273364

    Registration No. 333-273364

The determination of whether a security is freely transferable is to be made based on all the relevant facts and circumstances. In the case of a security that is part of an offering in which the minimum investment is $10,000 or less, the following requirements, alone or in combination, ordinarily will not affect a finding that the security is freely transferable: (i) a requirement that no transfer or assignment of the security or rights relating to the security be made that would violate any federal or state law; and (ii) a requirement that no transfer or assignment be made without advance written notice given to the entity that issued the security.

The Sponsor believes that the conditions described above should be satisfied with respect to the Shares. The Sponsor believes that the Shares therefore should constitute publicly offered securities, and the underlying assets of the Fund should not be considered to constitute plan assets of any plan that purchases Shares.

Prohibited Transactions

ERISA and the Code generally prohibit certain transactions involving a plan and persons who have certain specified relationships to the plan. In general, Shares may not be purchased with the assets of a plan if the Sponsor, the clearing brokers, the trading advisors (if any), or any of their affiliates, agents or employees either:

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

Also, a prohibited transaction may occur under ERISA or the Code when circumstances indicate that (i) the investment in Shares is made or retained for the purpose of avoiding application of the fiduciary standards of ERISA, (ii) the investment in Shares constitutes an arrangement under which the Fund is expected to engage in transactions that would otherwise be prohibited if entered into directly by the plan purchasing the Shares, (iii) the investing plan, by itself, has the authority or influence to cause the Fund to engage in such transactions, or (iv) a person who is prohibited from transacting with the investing plan may, but only with the aid of certain of its affiliates and the investing plan, cause the Fund to engage in such transactions with such person.

    Registration No. 333-273364

Special IRA Rules

IRAs are not subject to ERISA's fiduciary standards, but are subject to their own rules, including the prohibited transaction rules of Section 4975 of the Code, which generally mirror ERISA's prohibited transaction rules. For example, IRAs are subject to special custody rules and must maintain a qualifying IRA custodial arrangement separate and distinct from the Fund and its custodial arrangement. If a separate qualifying custodial arrangement is not maintained, an investment in the Shares will be treated as a distribution from the IRA. Second, IRAs are prohibited from investing in certain commingled investments, and the Sponsor makes no representation regarding whether an investment in Shares is an inappropriate commingled investment for an IRA. Third, in applying the prohibited transaction provisions of Section 4975 of the Code, in addition to the rules summarized above, the individual for whose benefit the IRA is maintained is also treated as the creator of the IRA. For example, if the owner or beneficiary of an IRA enters into any transaction, arrangement, or agreement involving the assets of his or her IRA to benefit the IRA owner or beneficiary (or his or her relatives or business affiliates) personally, or with the understanding that such benefit will occur, directly or indirectly, such transaction could give rise to a prohibited transaction that is not exempted by any available exemption. Moreover, in the case of an IRA, the consequences of a non-exempt prohibited transaction are that the IRA's assets will be treated as if they were distributed, causing immediate U.S. federal income taxation of the assets (including any early distribution penalty tax applicable under Section 72 of the Code), in addition to any other fines or penalties that may apply.

Exempt Plans

Employee benefit plans may be governmental plans (as defined in Section 3(32) of ERISA) or church plans (as defined in Section 3(33) of ERISA). Certain governmental plans and church plans are not subject to ERISA or the prohibited transaction provisions described above. These plans are, however, subject to prohibitions against certain related-party transactions under Section 503 of the Code, which are similar to the prohibited transaction rules described above. In addition, the fiduciary of any governmental or church plan must consider any applicable state or local laws and any restrictions and duties of common law imposed upon the plan.

No view is expressed as to whether an investment in the Fund (and any continued investment in the Fund), or the operation and administration of the fund, is appropriate or permissible for any governmental plan or church plan under Code Section 503, or under any state, county, local or other law relating to that type of plan.

Allowing an investment in the Fund is not to be construed as a representation by the Trust, the Fund, the Sponsor, any trading advisor, any clearing broker, Marketing Agent or legal counsel or other advisors to such parties or any other party that this investment meets some or all of the relevant legal requirements with respect to investments by any particular plan or that this investment is appropriate for any particular plan. The person with investment discretion should consult legal counsel and financial advisors as to the propriety of an investment in the Fund in light of the circumstances of the particular plan, and compliance with ERISA, Section 4975 of the Code and similar law, as applicable.

    Registration No. 333-273364

PERFORMANCE OF THE OTHER COMMODITY POOLS OPERATED BY THE COMMODITY POOL OPERATOR

All summary performance information is as of June 30, 2023. Performance information is set forth, in accordance with CFTC regulations, on a monthly basis for each other commodity pool's past five calendar years and for the year to date. No performance information is presented with respect to the Hashdex Bitcoin Futures ETF, which has not commenced investment operations prior to the date of this Prospectus, and which will not begin trading until after the initial creation units of the Fund are purchased by the initial Authorized Participant (all as described in the "Plan of Distribution" Section of this Prospectus). The performance of the Hashdex Bitcoin Futures ETF will be materially different from the funds and the past performance summaries of the other funds below are generally not representative of how the funds might perform in the future. Tidal Investments LLC serves as the commodity pool operator for the Amplify Inflation Fighter ETF which commenced operations on February 2, 2022, the CNIC ICE US Carbon Neutral Power Futures Index which commenced operations on May 9, 2023, the Ionic Inflation Protection ETF which commenced operations on June 29, 2022 and the Return Stacked(TM) Bonds & Managed Futures ETF which commenced operations on February 8, 2023.

The monthly rate of return for each fund presented below is calculated by dividing the ending NAV for a given month by the ending NAV for the previous month, subtracting 1 and multiplying this number by 100 to arrive at a percentage increase or decrease.

*A drawdown is a loss experienced by the fund over a specified period. Drawdowns are measured on the basis of monthly returns only and do not reflect intra-month figures. The worst monthly percentage drawdown reflects the largest single month loss sustained over the most recent five calendar years and the current year-to-date.

**The worst peak-to-valley drawdown is the largest percentage decline in the NAV per unit over the most recent five calendar years and the current year to date. This need not be a continuous decline but can be a series of positive and negative returns. Worst peak-to-valley drawdown represents the greatest percentage decline from any month end NAV per unit that occurs without such month end NAV per unit being equaled or exceeded as of a subsequent month end. For example, if the NAV per unit declined by $1 in each of January and February, increased by $1 in March and declined again by $2 in April, a "peak to valley drawdown" analysis conducted as of the end of April would consider that "drawdown" to be continuing and to be $3 in amount, whereas if the NAV per unit had increased by $2 in March, the drawdown would have ended as of the end of February at the $2 level.

    Registration No. 333-273364

Amplify Inflation Fighter ETF (TICKER: IWIN)

The Amplify Inflation Fighter ETF commenced trading and investment operations on February 2, 2022. The Fund is listed on NYSE Arca and is neither: (i) a privately offered pool pursuant to Section 4(a)(2) of the 1933 Act; (ii) a multi-advisor pool as defined in CFTC Regulation 4.10(d)(2); or (iii) a principal-protected pool as defined in CFTC Regulation 4.10(d)(3).

Units of beneficial interest issued (from inception until June 30, 2023): 925,000

Aggregate gross sale price for units issued: $23,953,132.50

Pool NAV as of June 30, 2023: $8,901,525

NAV per Share as of June 30, 2023: $23.86

Worst monthly percentage drawdown*: -14.83% / June 2022

Worst peak to valley drawdown**: -28.50% / March 2022 - September 2022

PAST PERFORMANCE IS NOT NECESSARILY INDICATIVE OF FUTURE RESULTS

    Registration No. 333-273364

CNIC ICE US Carbon Neutral Power Futures Index ETF (TICKER: AMPD)

The CNIC ICE US Carbon Neutral Power Futures Index ETF commenced trading and investment operations on May 9, 2023. The Fund is listed on NYSE Arca and is neither: (i) a privately offered pool pursuant to Section 4(a)(2) of the 1933 Act; (ii) a multi-advisor pool as defined in CFTC Regulation 4.10(d)(2); or (iii) a principal-protected pool as defined in CFTC Regulation 4.10(d)(3).

Units of beneficial interest issued (from inception until June 30, 2023): 200,000

Aggregate gross sale price for units issued: $4,792,890.00

Pool NAV as of June 30, 2023: $4,724,778.05

NAV per Share as of June 30, 2023: $23.62

Worst monthly percentage drawdown*: -8.02% / May 2023

Worst peak to valley drawdown**: N/A

    Registration No. 333-273364

PAST PERFORMANCE IS NOT NECESSARILY INDICATIVE OF FUTURE RESULTS

Rates of Return* Month 2023 January % February % March % April % May (8.02)% June 4.79 % July % August % September % October % November % December % Annual Rate of Return (5.50)%

Ionic Inflation Protection ETF (TICKER: CPII)

The Ionic Inflation Protection ETF commenced trading and investment operations on June 29, 2022. The Fund is listed on NYSE Arca and is neither: (i) a privately offered pool pursuant to Section 4(a)(2) of the 1933 Act; (ii) a multi-advisor pool as defined in CFTC Regulation 4.10(d)(2); or (iii) a principal-protected pool as defined in CFTC Regulation 4.10(d)(3).

Units of beneficial interest issued (from inception until June 30, 2023): 475,000

Aggregate gross sale price for units issued: $9,491,175.00

Pool NAV as of June 30, 2023: $9,740,859.49

NAV per Share as of June 30, 2023: $19.48

Worst monthly percentage drawdown*: -2.40% / January 2023

Worst peak to valley drawdown**: -5.0% / July 2022 - January 2023

PAST PERFORMANCE IS NOT NECESSARILY INDICATIVE OF FUTURE RESULTS

    Registration No. 333-273364

    Registration No. 333-273364

Return Stacked(TM) Bonds & Managed Futures ETF (TICKER: RSBT)

The Return Stacked(TM) Bonds & Managed Futures ETF commenced trading and investment operations on February 8, 2023. The Fund is listed on CBOE and is neither: (i) a privately offered pool pursuant to Section 4(a)(2) of the 1933 Act; (ii) a multi-advisor pool as defined in CFTC Regulation 4.10(d)(2); or (iii) a principal-protected pool as defined in CFTC Regulation 4.10(d)(3).

Units of beneficial interest issued (from inception until June 30, 2023): 1,075,000

Aggregate gross sale price for units issued: $20,422,317.50

Pool NAV as of June 30, 2023: $18,957,950.11

NAV per Share as of June 30, 2023: $18.50

Worst monthly percentage drawdown*: -1.34% / May 2023

Worst peak to valley drawdown**: -8.9% / February 2023 - May 2023

PAST PERFORMANCE IS NOT NECESSARILY INDICATIVE OF FUTURE RESULTS

Rates of Return* Month 2023 January % February (1.08)% March 8.26 % April 0.39 % May (1.34)% June 2.68 % July % August % September % October % November % December % Annual Rate of Return %

    Registration No. 333-273364

The Trust is a reporting company and files annual, quarterly and current reports and other information with the SEC. The rules of the SEC allow the Trust to "incorporate by reference" information that the Trust files with them, which means that the Trust can disclose important information to you by referring you to those documents. The information incorporated by reference is an important part of this prospectus.

Any statement contained in a document incorporated by reference in this prospectus shall be deemed to be modified or superseded for purposes of this prospectus to the extent that a statement contained in this prospectus or in any other subsequently filed document that also is or is deemed to be incorporated by reference in this prospectus modifies or supersedes such statement. Any statement so modified or superseded shall not be deemed, except as so modified or superseded, to constitute a part of this prospectus.

We will provide to each person to whom a prospectus is delivered, including any beneficial owner, a copy of any document incorporated by reference in the prospectus (excluding any exhibits to those documents unless the exhibit is specifically incorporated by reference as an exhibit in that document) at no cost, upon written or oral request at the following address or telephone number:

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

The Trust's Internet website is http://hashdex-etfs.com The Trust makes its electronic filings with the SEC, including its annual reports on Form 10-K, quarterly reports on Form 10-Q, current reports on Form 8-K and amendments to these reports available on the Trust's website free of charge as soon as practicable after we file or furnish them with the SEC. The information contained on the Trust's website is not incorporated by reference in this prospectus and should not be considered a part of this prospectus.

    Registration No. 333-273364

    Registration No. 333-273364

This prospectus contains information you should consider when making an investment decision about the Shares. You should rely only on the information contained in this prospectus or any applicable prospectus supplement. None of the Trust, the Fund or the Sponsor has authorized any person to provide you with different information and, if anyone provides you with different or inconsistent information, you should not rely on it. This prospectus is not an offer to sell the Shares in any jurisdiction where the offer or sale of the Shares is not permitted.

The information contained in this prospectus was obtained from us and other sources believed by us to be reliable.

You should disregard anything we said in an earlier document that is inconsistent with what is included in this prospectus or any applicable prospectus supplement. Where the context requires, when we refer to this "prospectus," we are referring to this prospectus and (if applicable) the relevant prospectus supplement.

You should not assume that the information in this prospectus or any applicable prospectus supplement is current as of any date other than the date on the front page of this prospectus or the date on the front page of any applicable prospectus supplement.

We include cross references in this prospectus to captions in these materials where you can find further related discussions. The table of contents tells you where to find these captions.

    Registration No. 333-273364

The Trust has filed on behalf of the Fund a registration statement with the SEC under the 1933 Act. This prospectus does not contain all of the information set forth in the registration statement (including the exhibits to the registration statement), parts of which have been omitted in accordance with the rules and regulations of the SEC. For further information about the Trust, the Fund or the Shares, please refer to the registration statement, which you may inspect online at www.sec.gov. Information about the Trust, the Fund and the Shares can also be obtained from the Fund's website, which is http://hashdex-etfs.com/. The Fund's website address is only provided here as a convenience to you and the information contained on or connected to the website is not part of this prospectus or the registration statement of which this prospectus is part. The Trust is subject to the informational requirements of the Exchange Act and will file certain reports and other information with the SEC under the Exchange Act. The Sponsor will file an updated prospectus annually for the Fund pursuant to the 1933 Act. The reports and other information can be inspected online at www.sec.gov, which is the Internet site maintained by the SEC that contains reports, proxy and information statements and other information regarding issuers that file electronically with the SEC.

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

67

[[Image Removed]]

    Registration No. 333-273364

To the Shareholder and the Board of Trustees

Of Hashdex Bitcoin Futures ETF

Opinion on the Financial Statement

We have audited the accompanying statement of assets and liabilities of Hashdex Bitcoin Futures ETF, a series of Tidal Commodities Trust I, (the "Fund") as of October 24, 2023, and the related notes (collectively referred to as the "financial statement"). In our opinion, the financial statement presents fairly, in all material respects, the financial position of the Fund as of October 24, 2023, in conformity with accounting principles generally accepted in the United States of America.

Basis for Opinion

This financial statement is the responsibility of the Fund's management. Our responsibility is to express an opinion on the Fund's financial statement based on our audit. We are a public accounting firm registered with the Public Company Accounting Oversight Board (United States) ("PCAOB") and are required to be independent with respect to the Fund in accordance with the U.S. federal securities laws and the applicable rules and regulations of the Securities and Exchange Commission and the PCAOB. We have served as the auditor of the Fund since 2023.

We conducted our audit in accordance with the standards of the PCAOB. Those standards require that we plan and perform the audit to obtain reasonable assurance about whether the financial statement is free of material misstatement, whether due to error or fraud. The Fund is not required to have, nor were we engaged to perform, an audit of its internal control over financial reporting. As part of our audit, we are required to obtain an understanding of internal control over financial reporting, but not for the purpose of expressing an opinion on the effectiveness of the Fund's internal control over financial reporting. Accordingly, we express no such opinion.

Our audit included performing procedures to assess the risks of material misstatement of the financial statement, whether due to error or fraud, and performing procedures that respond to those risks. Such procedures included examining, on a test basis, evidence regarding the amounts and disclosures in the financial statement. Our audit also included evaluating the accounting principles used and significant estimates made by management, as well as evaluating the overall presentation of the financial statement. We believe that our audit provides a reasonable basis for our opinion.

[[Image Removed]]

TAIT, WELLER & BAKER LLP

Philadelphia, Pennsylvania

October 30, 2023

    Registration No. 333-273364

    Registration No. 333-273364

HASHDEX BITCOIN FUTURES ETF, A SERIES OF THE TIDAL COMMODITIES TRUST I

    Registration No. 333-273364

Hashdex Bitcoin Futures ETF STATEMENT OF ASSETS AND LIABILITIES October 24, 2023

    Registration No. 333-273364

NET ASSETS $ 100

    Registration No. 333-273364

TOTAL NET ASSETS $ 100

Fund shares issued and outstanding (par value $0.00 per share; unlimited number of shares authorized) 4

Net asset value per share $ 25.00

See accompanying Notes to Financial Statement.

The accompanying notes are an integral part of these financial statements.

    Registration No. 333-273364

NOTES TO FINANCIAL STATEMENT October 24, 2023

Note 1 - Organization and Significant Accounting Policies

Hashdex Bitcoin Futures ETF (the "Fund") is a series of Tidal Commodities Trust I ("Trust"), a Delaware statutory trust organized on February 10, 2023. The Fund operates pursuant to the First Amended and Restated Declaration of Trust and Trust Agreement ("Trust Agreement"), dated March 10, 2023. The Trust is registered with the U.S. Securities and Exchange Commission ("SEC") under the Securities Act of 1933, as amended (together with the rules and regulations adopted thereunder, as amended, the "1933 Act"), as a exchange-traded fund.

The Fund's investment objective is for changes in the shares' net asset value ("NAV") to reflect the daily changes of the price of the Hashdex U.S. Bitcoin Futures Fund Benchmark (the "Benchmark"), less expenses from the Fund's operations. The Benchmark currently is the average of the closing settlement prices for the first to expire and second to expire bitcoin futures contracts ("Bitcoin Futures Contracts") listed on the Chicago Mercantile Exchange ("CME"). The Bitcoin Futures Contracts that at any given time make up the Benchmark are referred to hereinafter as the "Benchmark Component Futures Contracts." Under normal market conditions, the Fund invests in Benchmark Component Futures Contracts and cash and cash equivalents. Because the Fund's investment objective is to track the price of the Benchmark by investing in Benchmark Futures Contracts rather than bitcoin, changes in the price of the Shares will vary from changes in the spot price of bitcoin. These futures contracts are the Benchmark Component Futures Contracts. The CME currently offers two Bitcoin Futures Contracts, one contract representing 5 bitcoin ("BTC Contracts") and another contract representing 0.10 bitcoin ("MBT Contracts"). The Fund will invest in BTC Contracts and MBT Contracts to the extent necessary to achieve maximum exposure to the bitcoin futures market.

As of October 24, 2023, the Trust has had no operations other than the sale and issuance of four shares of the Fund to Toroso Investments, LLC (the "Sponsor" and/or "Toroso") in the amount of $100. The Fund currently offers one class of shares that has no front-end sales load, no deferred sales charge, and no redemption fee. The Fund may issue an unlimited number of shares ("Shares") of beneficial interest, with a $0.00 par value. All shares of the Fund have equal rights and privileges.

The Fund continuously offers and redeems shares in blocks of at least 10,000 shares (each such block, a "Creation Unit") at an initial price per Share of $25. Only Authorized Participants may purchase and redeem shares from the Fund and then only in Creation Units. An Authorized Participant is an entity that has entered into an Authorized Participant Agreement with the Trust and the Sponsor. Shares are offered on a continuous basis to Authorized Participants in Creation Units at NAV. Authorized Participants may then offer to the public, from time to time, shares from any Creation Unit they create at a per-share market price. The form of Authorized Participant Agreement sets forth the terms and conditions under which an Authorized Participant may purchase or redeem a Creation Unit. Authorized Participants will not receive from the Fund, the Sponsor, or any of their affiliates, any fee or other compensation in connection with their sale of shares to the public. An Authorized Participant may receive commissions or fees from investors who purchase shares through their commission or fee-based brokerage accounts.

Significant accounting policies of the Fund are as follows:

Use of Estimates

The preparation of financial statements in conformity with U.S. GAAP requires management to make estimates and assumptions that affect the reported amount of assets and liabilities and disclosure of contingent assets and liabilities at the date of the financial statements, and the reported amounts of the revenue and expenses during the reporting period. Actual results could differ from those estimates.

Indemnifications

In the normal course of business, the Fund enters into contracts that contain a variety of representations which provide general indemnifications. The Fund's maximum exposure under these arrangements cannot be known; however, the Fund expects any risk of loss to be remote.

Cash

Cash includes non-interest bearing non-restricted cash with one institution.

Income Taxes

For U.S. federal income tax purposes, the Fund will be classified as a publicly traded partnership. A publicly traded partnership is generally taxable as a corporation for U.S. federal income tax purposes unless 90% or more of the publicly traded partnership's gross income for each taxable year of its existence consists of qualifying income as defined in section 7704(d) of the Internal Revenue Code of 1986, as amended (the "Code"). Qualifying income is defined as generally including, in pertinent part, interest (other than from a financial business), dividends, and gains from the sale or disposition of capital assets held for the production of interest or dividends. In the case of a partnership of which a principal activity is the buying and selling of commodities, other than as inventory, or of futures, forwards, and options with respect to commodities, qualifying income also includes income and gains from commodities and from futures, forwards, options with respect to commodities and, provided the partnership is a trader or investor with respect to such assets, swaps and other notional principal contracts with respect to commodities. There is very limited authority on the U.S. federal income tax treatment of bitcoin and no direct authority on bitcoin derivatives, such as Bitcoin Futures Contracts. Based on an opinion received by Toroso from their independent legal counsel and a Commodity Futures Trading Commission determination that treats bitcoin as a commodity under the Commodity Exchange Act, the Fund intends to take the position that Bitcoin Futures Contracts consist of futures on commodities for purposes of the qualifying income exception under section 7704 of the Code. Accordingly, the Fund expects that at least 90% of the Fund's gross income for each taxable year will consist of qualifying income and that the Fund will be taxed as a partnership for U.S. federal income tax purposes. Therefore, the Fund does not record a provision for income taxes because the shareholders report their share of the Fund's income or loss on their income tax returns.

    Registration No. 333-273364

The Fund is required to determine whether a tax position is more likely than not to be sustained upon examination by the applicable taxing authority, including resolution of any related appeals or litigation processes, based on the technical merits of the position. The Fund will file income tax returns in the U.S. federal jurisdiction and may file income tax returns in various U.S. states and foreign jurisdictions.

The Fund may be subject to potential examination by U.S. federal, U.S. state, or foreign jurisdictional authorities in the area of income taxes. These potential examinations may include among other things questioning the tax classification of the Fund, the timing and amount of deductions, the nexus of income among various tax jurisdictions, and compliance with U.S. federal, U.S. state and foreign tax laws.

Basis of Presentation

The preparation of these financial statements in conformity with U.S. generally accepted accounting principles requires management to make estimates and assumptions that affect the reported amount of net assets and liabilities and disclosure of contingent assets and liabilities at the balance sheet date. Actual results could differ from those estimates.

Organizational and Offering Costs

All organizational and initial offering costs for the Trust and the Fund were borne directly by the Sponsor. The Trust and the Fund do not have an obligation to reimburse the Adviser for organization and offering costs paid on their behalf.

Note 2 - Sponsor Fee Allocation of Expenses and Related Party Transactions

The Fund pays Toroso a Management Fee, monthly in arrears, in an amount equal to 0.94% per annum of the daily NAV of the Fund. The Management Fee is paid in consideration of the Sponsor's services related to the management of the Fund's business and affairs, including the provision of commodity futures trading advisory services. Purchases of creation units with cash may cause the Fund to incur certain costs including brokerage commissions and redemptions of creation units with cash may result in the recognition of gains or losses that the Fund might not have incurred if it had made redemptions in-kind. The Fund pays all of its respective brokerage commissions, including applicable exchange fees, National Futures Association fees and give-up fees, and other transaction related fees and expenses charged in connection with trading activities for the Fund's investments in Commodity Futures Trading Commission regulated investments. The Fund bears other transaction costs related to the futures commission merchants capital requirements on a monthly basis. The Sponsor pays all of the routine operational, administrative and other ordinary expenses of the Fund, generally as determined by the Sponsor, including but not limited to, fees and expenses of the Administrator, Sub-Administrator, Custodian, Marketing Agent, Transfer Agent, licensors, accounting and audit fees and expenses, tax preparation expenses, legal fees, ongoing SEC registration fees, individual Schedule K-1 preparation and mailing fees, and report preparation and mailing expenses. The Fund pays all of its non-recurring and unusual fees and expenses, if any, as determined by the Sponsor. Non-recurring and unusual fees and expenses are unexpected or unusual in nature, such as legal claims and liabilities and litigation costs or indemnification or other unanticipated expenses. Extraordinary fees and expenses also include material expenses which are not currently anticipated obligations of the Fund. Routine operational, administrative and other ordinary expenses are not deemed extraordinary expenses.

Tidal ETF Services LLC ("Tidal," or the "Administrator") serves as the Fund's administrator. In addition, as support agent, Tidal assists the Fund and the Sponsor with certain functions and duties relating to marketing, which include the following: marketing and sales strategy, and marketing-related services.

Hashdex Asset Management Ltd. ("Hashdex" or the "Digital Asset Adviser") is a Cayman Islands investment manager (and an Exempt Reporting Advisor under SEC rules) that specializes in, among other things, the management, research, investment analysis and other investment support services of funds and ETFs with investment strategies involving bitcoin and other crypto assets. As Digital Asset Adviser, Hashdex is responsible for providing Toroso and Tidal with research and analysis regarding bitcoin and bitcoin markets for use in the operation and marketing of the Fund. Hashdex has no role in maintaining, calculating or publishing the Benchmark. Hashdex also has no responsibility for the investment or management of the Fund's portfolio or for the overall performance or operation of the Fund.

U.S. Bancorp Fund Services, LLC, doing business as U.S. Bank Global Fund Services ("Fund Services"), an indirect subsidiary of U.S. Bancorp, intends to serve as the Fund's fund accountant, sub-administrator and transfer agent pursuant to certain fund accounting servicing, fund sub-administration servicing and transfer agent servicing agreements. U.S. Bank National Association, a subsidiary of U.S. Bancorp and parent company of Fund Services, intends to serve as the Fund's custodian pursuant to a custody agreement. Foreside Fund Service, LLC intends to serve as the Fund's marketing agent pursuant to a marketing agent agreement.

Note 3 - Transactions with Affiliates

Certain officers of the Trust are affiliated with the Sponsor. None of the affiliated Trust's officers receive compensation from the Fund. The Administrator is a wholly-owned subsidiary of the Sponsor.

    Registration No. 333-273364

Note 4 - Subsequent Events

In preparing these financial statements, Management has evaluated subsequent events through the date of issuance of the financial statements included herein. There have been no subsequent events that occurred during such period that would require disclosure or would be required to be recognized in the financial statement.

    Registration No. 333-273364

[[Image Removed]]

grant thornton llp REPORT OF INDEPENDENT REGISTERED PUBLIC ACCOUNTING FIRM 757 Third Ave., 9th Floor New York, NY 10017

D +1 212 599 0100 F +1 212 370 4520 To the Sponsor and Shareholders of Hashdex Bitcoin Futures ETF

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

[[Image Removed]]

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

Assets Cash and cash equivalents $ 701,969 Interest receivable 2,961 Equity in trading accounts: Cryptocurrency futures contracts 29,152 Due from broker 337,049 Total equity in trading accounts 366,201 Total assets $ 1,071,131

Liabilities Management fee payable to Sponsor $ 868

Net assets $ 1,070,263

Shares outstanding 50,004

Shares available *

Net asset value per share $ 21.40

Market value per share $ 21.39

* On September 14, 2022, the Hashdex Bitcoin Futures ETF registered an indeterminate number of shares of the Fund pursuant to Rule 456(d) under the Securities Act of 1933.

The accompanying notes are an integral part of these financial statements.

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

Cash equivalents Money market funds First American Government Obligations Fund - Class X 4.105 % $ 701,969 $ 701,969 65.59 % 701,969

    Registration No. 333-273364

The accompanying notes are an integral part of these financial statements.

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

Expenses Management fees 4,249 Professional fees 54,416 Distribution and marketing fees 1,076 Custodian fees and expenses 213 Business permits and licenses fees 10,842 General and administrative expenses 8,744 Total expenses $ 79,540

Expenses waived by the Sponsor (75,291)

Total expenses, net $ 4,249

Net Loss $ (386,037)

Net loss per share $ (3.60) Net loss per weighted average share $ (5.82) Weighted average shares outstanding 66,359

The accompanying notes are an integral part of these financial statements.

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

Net assets, beginning of period $ -

Net assets, end of period $ 1,070,263

Net asset value per share at beginning of period $ 25.00

Net asset value per share at end of period $ 21.40

Creation of Shares 100,004 Redemption of Shares 50,000

The accompanying notes are an integral part of these financial statements.

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

Cash flows from financing activities: Proceeds from sale of Shares 2,461,340 Redemption of Shares (1,005,040) Net cash provided by financing activities 1,456,300

Net change in cash and cash equivalents 701,969 Cash and cash equivalents, beginning of period - Cash and cash equivalents, end of period $ 701,969

The accompanying notes are an integral part of these financial statements.

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

Note 1 - Organization and Operation

Hashdex Bitcoin Futures ETF (the "Fund") is a series of Teucrium Commodity Trust ("Trust"), a Delaware statutory trust organized on September 11, 2009. The Fund operates pursuant to the Fifth Amended and Restated Declaration of Trust and Trust Agreement ("Trust Agreement"), dated April 26, 2019. The Trust Agreement may be found on the SEC's EDGAR filing database at https://www.sec.gov/Archives/edgar/data/1471824/000165495419004865/ex31.htm. The Fund was formed and is managed and controlled by the Sponsor, a limited liability company formed in Delaware on July 28, 2009. The Sponsor is registered as a commodity pool operator ("CPO") and a commodity trading adviser ("CTA") with the Commodity Futures Trading Commission ("CFTC") and is a member of the National Futures Association ("NFA"). The Fund intends to be treated as a partnership for U.S. federal income tax purposes.

On September 14, 2022, the Fund's initial registration of an indeterminate number of shares on Form S-1 was declared effective by the SEC. On September 15, 2022, the Fund listed it's shares on the NYSE Arca under the ticker symbol "DEFI". On the business day prior to that, the Fund issued 50,000 shares in exchange for $1,250,000 at the Fund's initial NAV of $25 per share.

The Fund's investment objective is for changes in the Shares' NAV to reflect the daily changes of the price of a specified benchmark (the "Benchmark"), less expenses from the Fund's operations. The Benchmark currently is the average of the closing settlement prices for the first to expire and second to expire bitcoin futures contracts ("Bitcoin Futures Contracts") listed on the CME. These futures contracts are the Benchmark Component Futures Contracts. The CME currently offers two Bitcoin Futures Contracts, one contract representing 5 bitcoin ("BTC Contracts") and another contract representing 0.10 bitcoin ("MBT Contracts"). The Fund will invest in BTC Contracts and MBT Contracts to the extent necessary to achieve maximum exposure to the bitcoin futures market.

    Registration No. 333-273364

CME Bitcoin Futures Contracts Weighting First to expire 50 % Second to expire 50 %

Subject to the terms of the Trust Agreement, Teucrium Trading, LLC, in its capacity as the Sponsor ("Sponsor"), may terminate a Fund at any time, regardless of whether the Fund has incurred losses, including, for instance, if it determines that the Fund's aggregate net assets in relation to its operating expenses make the continued operation of the Fund unreasonable or imprudent. However, no level of losses will require the Sponsor to terminate a Fund.

Note 2 - Principal Contracts and Agreements

The Sponsor employs U.S. Bancorp Fund Services, LLC, doing business as U.S. Bank Global Fund Services ("Global Fund Services"), for Transfer Agency, Fund Accounting and Fund Administration services. The principal address for Global Fund Services is 615 E. Michigan Street, Milwaukee, WI 53202.

For custody services, the Funds will pay to U.S. Bank N.A. 0.0075% of average gross assets up to $1 billion, and.0050% of average gross assets over $1 billion, annually, plus certain per-transaction charges. For Transfer Agency, Fund Accounting and Fund Administration services, which are based on the total assets for all the Funds in the Trust, the Funds will pay to Global Fund Services 0.05% of average gross assets on the first $500 million, 0.04% on the next $500 million, 0.03% on the next $2 billion and 0.02% on the balance over $3 billion annually. A combined minimum annual fee of up to $47,000 for custody, transfer agency, accounting and administrative services is assessed per Fund. These services are recorded as custodian fees and expenses on the statements of operations. A summary of these expenses is included below.

The Sponsor employs Foreside Fund Services, LLC ("Foreside" or the "Distributor") as the Distributor for the Funds. The Distribution Services Agreement among the Distributor and the Sponsor calls for the Distributor to work with the Custodian in connection with the receipt and processing of orders for Creation Baskets and Redemption Baskets and the review and approval of all Fund sales literature and advertising materials. For its services as the Distributor, Foreside receives a fee of 0.01% of each Fund's average daily net assets and an aggregate annual fee of $100,000 for all Funds, along with certain expense reimbursements. These services are recorded as distribution and marketing fees on the statements of operations. A summary of these expenses is included below. Pursuant to a Consulting Services Agreement, Foreside Consulting Services, LLC, performs certain consulting support services for the Trust's Sponsor.

StoneX Financial Inc. ("StoneX") and Phillip Capital Inc. ("Phillip Capital") serve as the Fund's clearing brokers to execute futures contracts and provide other brokerage-related services. StoneX and Phillip Capital are each registered as futures commission merchants ("FCM") with the U.S. CFTC and are members of the NFA. The clearing brokers are registered as broker-dealers with the SEC and are each a member of FINRA. StoneX and Phillip Capital are each clearing members of ICE Futures U.S., Inc., Chicago Board of Trade, Chicago Mercantile Exchange, New York Mercantile Exchange, and all other major United States commodity exchanges. StoneX is paid 10.00 - $25.00 per half-turn exclusive of pass through fees for the exchange, and the NFA. Phillip Capital is paid $35.00 - $45.00 per half-turn exclusive of pass through fees for the exchange, the NFA, execution fees and platform and exchange data fees. Additionally, if the monthly commissions paid do not equal or exceed 20% return on the StoneX Capital Requirement at 9.6% of the Exchange Maintenance Margin, the Fund will pay a true up to meet that return at the end of each month. A summary of these expenses is included below.

    Registration No. 333-273364

The sole Trustee of the Trust is Wilmington Trust Company, a Delaware banking corporation. The Trustee will accept service of legal process on the Trust in the State of Delaware and will make certain filings under the Delaware Statutory Trust Act. For its services, the Trustee receives an annual fee of $3,300 from the Trust. These services are recorded in business permits and licenses fees on the statements of operations. A summary of these expenses is included below.

    Registration No. 333-273364

Amount Recognized for Distribution Services $ 95 Amount of Distribution Services Waived $ 95

Amount Recognized for Wilmington Trust $ 550 Amount of Wilmington Trust Waived $ 550

Note 3 - Summary of Significant Accounting Policies

Basis of Presentation

The accompanying financial statements have been prepared in accordance with accounting principles generally accepted in the United States of America ("U.S. GAAP") as detailed in the Financial Accounting Standards Board's Accounting Standards Codification.

Revenue Recognition

Investment transactions are accounted for on a trade-date basis. All such transactions are recorded on the identified cost basis and marked to market daily. Unrealized appreciation or depreciation on investments are reflected in the statements of operations as the difference between the original amount and the fair market value as of the last business day of the year or as of the last date of the financial statements. Changes in the appreciation or depreciation between periods are reflected in the statements of operations.

Brokerage Commissions

The Sponsor recognizes the expense for brokerage commissions for futures contract trades on a per-trade basis. The below table shows the amounts included on the statements of operations as total brokerage commissions paid inclusive of unrealized loss from the commencement of operations (September 15, 2022) through December 31, 2022.

    Registration No. 333-273364

Income Taxes

For federal income tax purposes, the Fund will be treated as a publicly traded partnership. A publicly traded partnership is generally treated as a corporation for federal income tax purposes unless 90% or more of the publicly traded partnership's gross income for each taxable year of its existence consists of qualifying income as defined in section 7704(d) of the Internal Revenue Code of 1986, as amended. Qualifying income is defined as generally including, in pertinent part, interest (other than from a financial business), dividends, and gains from the sale or disposition of capital assets held for the production of interest or dividends. In the case of a partnership of which a principal activity is the buying and selling of commodities, other than as inventory, or of futures, forwards and options with respect to commodities, qualifying income also includes income and gains from commodities and from futures, forwards, options with respect to commodities and, provided the partnership is a trader or investor with respect to such assets, swaps and other notional principal contracts with respect to commodities. The Fund expects that at least 90% of the Fund's gross income for each taxable year will consist of qualifying income and that the Fund will be taxed as a partnership for federal income tax purposes. The Fund does not record a provision for income taxes because the shareholders report their share of the Fund's income or loss on their income tax returns. The financial statements reflect the Fund's transactions without adjustment, if any, required for income tax purposes.

There is very limited authority on the U.S. federal income tax treatment of bitcoin and no direct authority on bitcoin derivatives, such as Bitcoin Futures Contracts. Bitcoin Futures Contracts more likely than not will be considered futures with respect to commodities for purposes of the qualifying income exception under section 7704 of the Code. Based on a CFTC determination that treats bitcoin as a commodity under the CEA, the Fund intends to take the position that Bitcoin Futures Contracts consist of futures on commodities for purposes of the qualifying income exception under section 7704 of the Code. Shareholders should be aware that the Fund's position is not binding on the IRS, and no assurance can be given that the IRS will not challenge the Fund's position, or that the IRS or a court will not ultimately reach a contrary conclusion, which would result in the material adverse consequences to Shareholders and the Fund.

    Registration No. 333-273364

The Fund recognizes interest accrued related to unrecognized tax benefits and penalties related to unrecognized tax benefits in income tax fees payable, if assessed. No interest expense or penalties have been recognized as of and from the commencement of operations (September 15, 2022) through December 31, 2022.

The Fund may be subject to potential examination by U.S. federal, U.S. state, or foreign jurisdictional authorities in the area of income taxes. These potential examinations may include questioning the timing and amount of deductions, the nexus of income among various tax jurisdictions, and compliance with U.S. federal, U.S. state and foreign tax laws.

Creations and Redemptions

Authorized Purchasers may purchase Creation Baskets consisting of 10,000 shares from the Fund. The amount of the proceeds required to purchase a Creation Basket will be equal to the NAV of the shares in the Creation Basket determined as of 4:00 p.m. (ET) on the day the order to create the basket is received in good order.

Authorized Purchasers may redeem shares from the Fund only in blocks of 10,000 shares called "Redemption Baskets." The amount of the redemption proceeds for a Redemption Basket will be equal to the NAV of the shares in the Redemption Basket determined as of 4:00 p.m. (ET) on the day the order to redeem the basket is received in good order.

The Fund will receive the proceeds from shares sold or will pay for redeemed shares within three business days after the trade date of the purchase or redemption, respectively. The amounts due from Authorized Purchasers will be reflected in the Fund's statements of assets and liabilities as capital shares receivable. Amounts payable to Authorized Purchasers upon redemption will be reflected in the Fund's statements of assets and liabilities as payable for shares redeemed.

As outlined in the most recent Form S-1 filing, 50,000 shares represent five Redemption Baskets for the Fund and a minimum level of shares. If the Fund experienced redemptions that caused the number of Shares outstanding to decrease to the minimum level of Shares required to be outstanding, until the minimum number of Shares is again exceeded through the purchase of a new Creation Basket, there can be no more redemptions by an Authorized Purchaser.

Allocation of Shareholder Income and Losses

Profit or loss is allocated among the shareholders of the Fund in proportion to the number of shares each shareholder holds as of the close of each month.

Cash Equivalents

Cash equivalents are highly liquid investments with maturity dates of 90 days or less when acquired. The Fund reported its cash equivalents in the statements of assets and liabilities at market value, or at carrying amounts that approximate fair value, because of their highly liquid nature and short-term maturities. The Fund has these balances of its assets on deposit with banks. Assets deposited with a financial institution may, at times, exceed federally insured limits. DEFI had a balance of $701,969 in money market funds at December 31, 2022; these balances are included in cash equivalents on the statements of assets and liabilities.

Due from/to Broker

The amount recorded by the Fund for the amount due from and to the clearing broker includes, but is not limited to, cash held by the broker, amounts payable to the clearing broker related to open transactions, payables for cryptocurrency futures accounts liquidating to an equity balance on the clearing broker's records and amounts of brokerage commissions paid and recognized as unrealized losses.

Margin is the minimum amount of funds that must be deposited by a cryptocurrency interest trader with the trader's broker to initiate and maintain an open position in futures contracts. A margin deposit acts to assure the trader's performance of the futures contracts purchased or sold. Futures contracts are customarily bought and sold on initial margin that represents a very small percentage of the aggregate purchase or sales price of the contract. Because of such low margin requirements, price fluctuations occurring in the futures markets may create profits and losses that, in relation to the amount invested, are greater than customary in other forms of investment or speculation. As discussed below, adverse price changes in the futures contract may result in margin requirements that greatly exceed the initial margin. In addition, the amount of margin required in connection with a particular futures contract is set from time to time by the exchange on which the contract is traded and may be modified from time to time by the exchange during the term of the contract. Brokerage firms, such as the Fund's clearing brokers, carrying accounts for traders in commodity interest contracts generally require higher amounts of margin as a matter of policy to further protect themselves. Over the counter trading generally involves the extension of credit between counterparties, so the counterparties may agree to require the posting of collateral by one or both parties to address credit exposure.

    Registration No. 333-273364

When a trader purchases an option, there is no margin requirement; however, the option premium must be paid in full. When a trader sells an option, on the other hand, he or she is required to deposit margin in an amount determined by the margin requirements established for the underlying interest and, in addition, an amount substantially equal to the current premium for the option. The margin requirements imposed on the selling of options, although adjusted to reflect the probability that out-of-the-money options will not be exercised, can in fact be higher than those imposed in dealing in the futures markets directly. Complicated margin requirements apply to spreads and conversions, which are complex trading strategies in which a trader acquires a mixture of options positions and positions in the underlying interest.

Ongoing or "maintenance" margin requirements are computed each day by a trader's clearing broker. When the market value of a particular open futures contract changes to a point where the margin on deposit does not satisfy maintenance margin requirements, a margin call is made by the broker. If the margin call is not met within a reasonable time, the broker may close out the trader's position. With respect to the Fund's trading, the Fund (and not its shareholders personally) is subject to margin calls. Finally, many major U.S. exchanges have passed certain cross margining arrangements involving procedures pursuant to which the futures and options positions held in an account would, in the case of some accounts, be aggregated and margin requirements would be assessed on a portfolio basis, measuring the total risk of the combined positions.

Calculation of Net Asset Value

The Fund's NAV is calculated by:

- Taking the current market value of its total assets and

- Subtracting any liabilities.

The administrator, Global Fund Services, will calculate the NAV of the Fund once each trading day. It will calculate the NAV as of the earlier of the close of the New York Stock Exchange or 4:00 p.m. (ET). The NAV for a particular trading day will be released after 4:15 p.m. (ET).

In determining the value of Bitcoin Futures Contracts, the Administrator uses the settlement price for the Benchmark Component Futures Contracts, as reported on the CME. CME Group staff determines the daily settlements for the Benchmark Component Futures Contracts based on trading activity on CME Globex exchange between 14:59:00 and 15:00:00 Central Time (CT), the settlement period, except that the "fair value" of Bitcoin Futures Contracts (as described in more detail below) may be used when Bitcoin Futures Contracts close at their price fluctuation limit for the day. The Administrator determines the value of all investments as of the earlier of the close of the New York Stock Exchange or 4:00 p.m. (ET), in accordance with the current Services Agreement between the Administrator and the Trust. NAV includes any unrealized profit or loss on open bitcoin interests and any other credit or debit accruing to the Fund but unpaid or not received by the Fund.

Sponsor Fee Allocation of Expenses and Related Party Transactions

The Sponsor is responsible for investing the assets of the Fund in accordance with the objectives and policies of the Fund. DEFI is contractually obligated to pay a monthly management fee to the Sponsor, based on average daily net assets, at a rate equal to 0.94% per annum. From the Management Fee, the Sponsor pays all of the routine operational, administrative and other ordinary expenses of the Fund, generally as determined by the Sponsor, including but not limited to, fees and expenses of the Administrator, Custodian, Distributor, Transfer Agent, licensors, accounting and audit fees expenses, tax preparation expenses, legal fees, ongoing SEC registration fees, individual Schedule K-1 preparation and mailing fees, and report preparation and mailing expenses. These fees and expenses are not included in the breakeven table and are not part of the audited financial statements because they are paid for by the Sponsor through the proceeds from the Management Fee. The Fund pays all of its non-recurring and unusual fees and expenses, if any, as determined by the Sponsor. Non-recurring and unusual fees and expenses are unexpected or unusual in nature, such as legal claims and liabilities and litigation costs or indemnification or other unanticipated expenses. Extraordinary fees and expenses also include material expenses which are not currently anticipated obligations of the Fund. Routine operational, administrative, and other ordinary expenses are not deemed extraordinary expenses.

The Sponsor has the ability to elect to pay certain expenses on behalf of the Funds or waive the management fee. This election is subject to change by the Sponsor, at its discretion. Expenses paid by the Sponsor and Management fees waived by the Sponsor are, if applicable, presented as waived expenses in the statements of operations for each Fund. The Sponsor has determined that there will be no recovery sought for the amounts below in any future period:

    Registration No. 333-273364

Expenses

Expenses are recorded using the accrual method of accounting.

Use of Estimates

The preparation of financial statements in conformity with accounting principles generally accepted in the United States of America requires management to make estimates and assumptions that affect the reported amount of assets and liabilities and disclosure of contingent assets and liabilities at the date of the financial statements, and the reported amounts of the revenue and expenses during the reporting period. Actual results could differ from those estimates.

    Registration No. 333-273364

New Accounting Pronouncements

The Financial Accounting Standards Board ("FASB") issued Accounting Standards Update ("ASU") 2022-03, related to fair value measurement (Topic 820) of equity securities subject to contractual sale restrictions. Under the clarified guidance, contractual restrictions on the sale of an equity security are not considered part of the unit of account of the equity security and, therefore, are not considered in measuring fair value, however they do require disclosures. The amendment was early adopted for the quarter ended September 30, 2022; the early adoption did not have a material impact on the financial statements and disclosures of the Trust or the Fund.

Fair Value - Definition and Hierarchy

In accordance with GAAP, fair value is defined as the price that would be received to sell an asset or paid to transfer a liability (i.e., the "exit price") in an orderly transaction between market participants at the measurement date.

In determining fair value, the Fund uses various valuation approaches. In accordance with GAAP, a fair value hierarchy for inputs is used in measuring fair value that maximizes the use of observable inputs and minimizes the use of unobservable inputs by requiring that the most observable inputs be used when available. Observable inputs are those that market participants would use in pricing the asset or liability based on market data obtained from sources independent of the Fund. Unobservable inputs reflect the Fund's assumptions about the inputs market participants would use in pricing the asset or liability developed based on the best information available in the circumstances. The fair value hierarchy is categorized into three levels based on the inputs as follows:

Level 1 - Valuations based on unadjusted quoted prices in active markets for identical assets or liabilities that the Fund has the ability to access. Valuation adjustments and block discounts are not applied to Level 1 financial instruments. Since valuations are based on quoted prices that are readily and regularly available in an active market, valuation of these financial instruments does not entail a significant degree of judgment.

Level 2 - Valuations based on quoted prices in markets that are not active or for which all significant inputs are observable, either directly or indirectly.

Level 3 - Valuations based on inputs that are unobservable and significant to the overall fair value measurement.

The availability of valuation techniques and observable inputs can vary from financial instrument to financial instrument and is affected by a wide variety of factors including, the type of financial instrument, whether the financial instrument is new and not yet established in the marketplace, and other characteristics particular to the transaction. To the extent that valuation is based on models or inputs that are less observable or unobservable in the market, the determination of fair value requires more judgment. Those estimated values do not necessarily represent the amounts that may be ultimately realized due to the occurrence of future circumstances that cannot be reasonably determined. Because of the inherent uncertainty of valuation, those estimated values may be materially higher or lower than the values that would have been used had a ready market for the financial instruments existed. Accordingly, the degree of judgment exercised by the Fund in determining fair value is greatest for financial instruments categorized in Level 3. In certain cases, the inputs used to measure fair value may fall into different levels of the fair value hierarchy. In such cases, for disclosure purposes, the level in the fair value hierarchy, within which the fair value measurement in its entirety falls, is determined based on the lowest level input that is significant to the fair value measurement.

On December 31, 2022, the reported value at the close of the market for each cryptocurrency contract fairly reflected the value of the futures and no alternative valuations were required.

Net Income (Loss) per Share

Net income (loss) per share is the difference between the NAV per unit at the beginning of each period and at the end of each period. The weighted average number of units outstanding was computed for purposes of disclosing net income (loss) per weighted average unit. The weighted average units are equal to the number of units outstanding at the end of the period, adjusted proportionately for units created or redeemed based on the amount of time the units were outstanding during such period.

Note 4 - Fair Value Measurements

The Fund's assets and liabilities recorded at fair value have been categorized based upon a fair value hierarchy as described in the Fund's significant accounting policies in Note 3. The following table presents information about the Fund's assets and liabilities measured at fair value as of December 31, 2022:

December 31, 2022

    Registration No. 333-273364

    Registration No. 333-273364

From the commencement of operations (September 15, 2022) through December 31, 2022, the Fund did not have any significant transfers between any of the levels of the fair value hierarchy.

See the Fair Value - Definition and Hierarchy section in Note 3 above for an explanation of the transfers into and out of each level of the fair value hierarchy.

Note 5 - Derivative Instruments and Hedging Activities

In the normal course of business, the Fund utilizes derivative contracts in connection with its proprietary trading activities. Investments in derivative contracts are subject to additional risks that can result in a loss of all or part of an investment. The Fund's derivative activities and exposure to derivative contracts are classified by the following primary underlying risks: interest rate, credit, commodity price, and equity price risks. In addition to its primary underlying risks, the Fund is also subject to additional counterparty risk due to inability of its counterparties to meet the terms of their contracts. For the period from commencement of operations (September 15, 2022) through December 31, 2022, the Fund invested only in cryptocurrency futures contracts.

Futures Contracts

The Fund is subject to cryptocurrency price risk in the normal course of pursuing its investment objectives. A futures contract represents a commitment for the future purchase or sale of an asset at a specified price on a specified date.

The purchase and sale of futures contracts requires margin deposits with a Futures Commission Merchant ("FCM"). Subsequent payments (variation margin) are made or received by the Fund each day, depending on the daily fluctuations in the value of the contract, and are recorded as unrealized gains or losses by the Fund. Futures contracts may reduce the Fund's exposure to counterparty risk since futures contracts are exchange-traded; and the exchange's clearinghouse, as the counterparty to all exchange-traded futures, guarantees the futures against default.

The Commodity Exchange Act requires an FCM to segregate all customer transactions and assets from the FCM's proprietary activities. A customer's cash and other equity deposited with an FCM are considered commingled with all other customer funds subject to the FCM's segregation requirements. In the event of an FCM's insolvency, recovery may be limited to the Fund's pro rata share of segregated customer funds available. It is possible that the recovery amount could be less than the total of cash and other equity deposited.

The following table discloses information about offsetting assets and liabilities presented in the statements of assets and liabilities to enable users of these financial statements to evaluate the effect or potential effect of netting arrangements for recognized assets and liabilities. These recognized assets and liabilities are presented as defined in the Financial Accounting Standards Board's ("FASB") Accounting Standards Update ("ASU") No. 2011-11 "Balance Sheet (Topic 210): Disclosures about Offsetting Assets and Liabilities" and subsequently clarified in FASB ASU 2013-01 "Balance Sheet (Topic 210): Clarifying the Scope of Disclosures about Offsetting Assets and Liabilities."

    Registration No. 333-273364

The following table also identifies the fair value amounts of derivative instruments included in the statements of assets and liabilities as derivative contracts, categorized by primary underlying risk, and held by the FCMs, StoneX as of December 31, 2022.

Offsetting of Financial Assets and Derivative Assets as of December 31, 2022

    Registration No. 333-273364

The following tables identify the net gain and loss amounts included in the statements of operations as realized and unrealized gains and losses on trading of cryptocurrency futures contracts categorized by primary underlying risk:

From the commencement of operations (September 15, 2022) through December 31, 2022

    Registration No. 333-273364

Volume of Derivative Activities

The average notional market value categorized by primary underlying risk for all futures contracts held was $1.4 million from the commencement of operations (September 15, 2022) through December 31, 2022.

Note 6 - Financial Highlights

The following table presents per unit performance data and other supplemental financial data from the commencement of operations (September 15, 2022) through December 31, 2022. This information has been derived from information presented in the financial statements and is presented with total expenses gross of expenses waived by the Sponsor and with total expenses net of expenses waived by the Sponsor, as appropriate.

    Registration No. 333-273364

    Registration No. 333-273364

The financial highlights per share data are calculated consistent with the methodology used to calculate asset-based fees and expenses.

Note 7 - Organizational and Offering Costs

Expenses incurred in organizing of the Trust and the initial offering of the Shares of the Fund, including applicable SEC registration fees, were borne directly by the Sponsor. The Fund will not be obligated to reimburse the Sponsor.

Note 8 - Subsequent Events

Management has evaluated the financial statements for the period ended December 31, 2022 for subsequent events through the date of this filing and noted no material events requiring either recognition through the date of the filing or disclosure herein for the Fund other than those noted below:

The total net assets of the Fund increased by $431,977, or 40%, for the period December 31, 2022 to February 28, 2023. This was driven by a 40% increase in the NAV/share.

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

Liabilities Management fee payable to Sponsor 1,525 868

Net assets $ 1,938,929 $ 1,070,263

Shares outstanding 50,004 50,004

Shares authorized * *

Net asset value per share $ 38.78 $ 21.40

Market value per share $ 38.85 $ 21.39

* On September 14, 2022, the Hashdex Bitcoin Futures ETF registered an indeterminate number of shares of the Fund pursuant to Rule 456(d) under the Securities Act of 1933.

The accompanying notes are an integral part of these financial statements.

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

Cash equivalents Money market funds First American Government Obligations Fund - Class X 5.015 % $ 1,414,157 $ 1,414,157 72.93 % 1,414,157

    Registration No. 333-273364

The accompanying notes are an integral part of these financial statements.

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

Cash equivalents Money market funds First American Government Obligations Fund - Class X 4.105 % $ 701,969 $ 701,969 65.59 % 701,969

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

Expenses Management fees 4,892 8,287 Professional fees 50,284 109,104 Distribution and marketing fees 3,379 4,741 Custodian fees and expenses 858 1,117 Business permits and licenses fees 6,032 16,161 General and administrative expenses 496 496 Total expenses 65,941 139,906

Expenses waived by the Sponsor (61,049) (131,619)

Total expenses, net 4,892 8,287

Net income $ 56,845 $ 824,917

Net gain per share $ 2.02 $ 17.38 Net gain per weighted average share $ 0.97 $ 15.20 Weighted average shares outstanding 58,466 54,258

The accompanying notes are an integral part of these financial statements.

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

Net assets, beginning of period $ 1,070,263

Net assets, end of period $ 1,938,929

Net asset value per share at beginning of period $ 21.40

Net asset value per share at end of period $ 38.78

Creation of Shares 10,000 Redemption of Shares 10,000

The accompanying notes are an integral part of these financial statements.

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

Cash flows from financing activities: Proceeds from sale of Shares 367,689 Redemption of Shares (323,940) Net cash provided by financing activities 43,749

Net change in cash and cash equivalents 712,188 Cash and cash equivalents beginning of period 701,969 Cash and cash equivalents end of period $ 1,414,157

The accompanying notes are an integral part of these financial statements.

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

Note 1 - Organization and Operation

Hashdex Bitcoin Futures ETF (the "Fund") is a series of Teucrium Commodity Trust ("Trust"), a Delaware statutory trust organized on September 11, 2009. The Fund operates pursuant to the Fifth Amended and Restated Declaration of Trust and Trust Agreement ("Trust Agreement"), dated April 26, 2019. The Trust Agreement may be found on the SEC's EDGAR filing database at https://www.sec.gov/Archives/edgar/data/1471824/000165495419004865/ex31.htm. The Fund was formed and is managed and controlled by the Sponsor, a limited liability company formed in Delaware on July 28, 2009. The Sponsor is registered as a commodity pool operator ("CPO") and a commodity trading adviser ("CTA") with the Commodity Futures Trading Commission ("CFTC") and is a member of the National Futures Association ("NFA"). The Fund intends to be treated as a partnership for U.S. federal income tax purposes.

On September 14, 2022, the Fund's initial registration of an indeterminate number of shares on Form S-1 was declared effective by the SEC. On September 16, 2022, the Fund listed it's shares on the NYSE Arca under the ticker symbol "DEFI". On the business day prior to that, the Fund issued 50,000 shares in exchange for $1,250,000 at the Fund's initial NAV of $25 per share.

The Fund's investment objective is for changes in the Shares' NAV to reflect the daily changes of the price of a specified benchmark (the "Benchmark"), less expenses from the Fund's operations. The Benchmark currently is the average of the closing settlement prices for the first to expire and second to expire bitcoin futures contracts ("Bitcoin Futures Contracts") listed on the CME. These futures contracts are the Benchmark Component Futures Contracts. The CME currently offers two Bitcoin Futures Contracts, one contract representing 5 bitcoin ("BTC Contracts") and another contract representing 0.10 bitcoin ("MBT Contracts"). The Fund will invest in BTC Contracts and MBT Contracts to the extent necessary to achieve maximum exposure to the bitcoin futures market.

    Registration No. 333-273364

CME Bitcoin Futures Contracts Weighting First to expire 50 % Second to expire 50 %

The accompanying unaudited financial statements have been prepared in accordance with Rule 10-01 of Regulation S-X promulgated by the SEC and, therefore, do not include all information and footnote disclosures required under accounting principles generally accepted in the United States of America ("GAAP"). The financial information included herein is unaudited; however, such financial information reflects all adjustments which are, in the opinion of management, necessary for the fair presentation of the Fund's financial statements for the interim period. It is suggested that these interim financial statements be read in conjunction with the financial statements and related notes included in the Trust's Annual Report on Form 10-K, as well as the most recent Form S-1 filing, as applicable. The operating results through June 30, 2023 are not necessarily indicative of the results to be expected from the full year ended December 31, 2023.

Subject to the terms of the Trust Agreement, Teucrium Trading, LLC, in its capacity as the Sponsor ("Sponsor"), may terminate a Fund at any time, regardless of whether the Fund has incurred losses, including, for instance, if it determines that the Fund's aggregate net assets in relation to its operating expenses make the continued operation of the Fund unreasonable or imprudent. However, no level of losses will require the Sponsor to terminate a Fund.

Note 2 - Principal Contracts and Agreements

The Sponsor employs U.S. Bancorp Fund Services, LLC, doing business as U.S. Bank Global Fund Services ("Global Fund Services"), for Transfer Agency, Fund Accounting and Fund Administration services. The principal address for Global Fund Services is 615 E. Michigan Street, Milwaukee, WI 53202.

    Registration No. 333-273364

For custody services, the Funds will pay to U.S. Bank N.A. 0.0075% of average gross assets up to $1 billion, and.0050% of average gross assets over $1 billion, annually, plus certain per-transaction charges. For Transfer Agency, Fund Accounting and Fund Administration services, which are based on the total assets for all the Funds in the Trust, the Funds will pay to Global Fund Services 0.05% of average gross assets on the first $500 million, 0.04% on the next $500 million, 0.03% on the next $2 billion and 0.02% on the balance over $3 billion annually. A combined minimum annual fee of up to $47,000 for custody, transfer agency, accounting and administrative services is assessed per Fund. These services are recorded as custodian fees and expenses on the statements of operations. A summary of these expenses is included below.

The Sponsor employs Foreside Fund Services, LLC ("Foreside" or the "Distributor") as the Distributor for the Funds. The Distribution Services Agreement among the Distributor and the Sponsor calls for the Distributor to work with the Custodian in connection with the receipt and processing of orders for Creation Baskets and Redemption Baskets and the review and approval of all Fund sales literature and advertising materials. For its services as the Distributor, Foreside receives a fee of 0.01% of each Fund's average daily net assets and an aggregate annual fee of $100,000 for all Funds, along with certain expense reimbursements. These services are recorded as distribution and marketing fees on the statements of operations. A summary of these expenses is included below. Pursuant to a Consulting Services Agreement, Foreside Consulting Services, LLC, performs certain consulting support services for the Trust's Sponsor.

StoneX Financial Inc. ("StoneX") and Phillip Capital Inc. ("Phillip Capital") serve as the Fund's clearing brokers to execute futures contracts and provide other brokerage-related services. StoneX and Phillip Capital are each registered as futures commission merchants ("FCM") with the U.S. CFTC and are members of the NFA. The clearing brokers are registered as broker-dealers with the SEC and are each a member of FINRA. StoneX and Phillip Capital are each clearing members of ICE Futures U.S., Inc., Chicago Board of Trade, Chicago Mercantile Exchange, New York Mercantile Exchange, and all other major United States commodity exchanges. StoneX is paid 10.00 - $25.00 per half-turn exclusive of pass through fees for the exchange, and the NFA. Phillip Capital is paid $35.00 - $45.00 per half-turn exclusive of pass through fees for the exchange, the NFA, execution fees and platform and exchange data fees. A summary of these expenses is included below.

The sole Trustee of the Trust is Wilmington Trust Company, a Delaware banking corporation. The Trustee will accept service of legal process on the Trust in the State of Delaware and will make certain filings under the Delaware Statutory Trust Act. For its services, the Trustee receives an annual fee of $3,300 from the Trust. These services are recorded in business permits and licenses fees on the statements of operations. A summary of these expenses is included below.

    Registration No. 333-273364

Amount Recognized for Distribution Services $ 224 $ - $ 284 $ - Amount of Distribution Services Waived $ 224 $ - $ 284 $ -

Note 3 - Summary of Significant Accounting Policies

Basis of Presentation

The accompanying financial statements have been prepared in accordance with accounting principles generally accepted in the United States of America ("U.S. GAAP") as detailed in the Financial Accounting Standards Board's Accounting Standards Codification.

Revenue Recognition

Investment transactions are accounted for on a trade-date basis. All such transactions are recorded on the identified cost basis and marked to market daily. Unrealized appreciation or depreciation on investments are reflected in the statements of operations as the difference between the original amount and the fair market value as of the last business day of the year or as of the last date of the financial statements. Changes in the appreciation or depreciation between periods are reflected in the statements of operations.

    Registration No. 333-273364

Brokerage Commissions

The Sponsor recognizes the expense for brokerage commissions for futures contract trades on a per-trade basis. The below table shows the amounts included on the statements of operations as total brokerage commissions paid inclusive of unrealized loss for the quarter ended June 30, 2023.

    Registration No. 333-273364

Income Taxes

For federal income tax purposes, the Fund will be treated as a publicly traded partnership. A publicly traded partnership is generally treated as a corporation for federal income tax purposes unless 90% or more of the publicly traded partnership's gross income for each taxable year of its existence consists of qualifying income as defined in section 7704(d) of the Internal Revenue Code of 1986, as amended. Qualifying income is defined as generally including, in pertinent part, interest (other than from a financial business), dividends, and gains from the sale or disposition of capital assets held for the production of interest or dividends. In the case of a partnership of which a principal activity is the buying and selling of commodities, other than as inventory, or of futures, forwards and options with respect to commodities, qualifying income also includes income and gains from commodities and from futures, forwards, options with respect to commodities and, provided the partnership is a trader or investor with respect to such assets, swaps and other notional principal contracts with respect to commodities. The Fund expects that at least 90% of the Fund's gross income for each taxable year will consist of qualifying income and that the Fund will be taxed as a partnership for federal income tax purposes. The Fund does not record a provision for income taxes because the shareholders report their share of the Fund's income or loss on their income tax returns. The financial statements reflect the Fund's transactions without adjustment, if any, required for income tax purposes.

There is very limited authority on the U.S. federal income tax treatment of bitcoin and no direct authority on bitcoin derivatives, such as Bitcoin Futures Contracts. Bitcoin Futures Contracts more likely than not will be considered futures with respect to commodities for purposes of the qualifying income exception under section 7704 of the Code. Based on a CFTC determination that treats bitcoin as a commodity under the CEA, the Fund intends to take the position that Bitcoin Futures Contracts consist of futures on commodities for purposes of the qualifying income exception under section 7704 of the Code. Shareholders should be aware that the Fund's position is not binding on the IRS, and no assurance can be given that the IRS will not challenge the Fund's position, or that the IRS or a court will not ultimately reach a contrary conclusion, which would result in the material adverse consequences to Shareholders and the Fund.

The Fund is required to determine whether a tax position is more likely than not to be sustained upon examination by the applicable taxing authority, including resolution of any related appeals or litigation processes, based on the technical merits of the position. The Fund files an income tax return in the U.S. federal jurisdiction and may file income tax returns in various U.S. states and foreign jurisdictions. For the tax year December 31, 2022, the Fund remains subject to income tax examinations by major taxing authorities. The tax benefit recognized is measured as the largest amount of benefit that has a greater than fifty percent likelihood of being realized upon ultimate settlement. De-recognition of a tax benefit previously recognized results in the Fund recording a tax liability that reduces net assets. This policy has been applied to all existing tax positions upon the Fund's initial adoption. Based on its analysis, the Fund has determined that it has not incurred any liability for unrecognized tax benefits as of June 30, 2023 and for the year ended December 31, 2022. However, the Fund's conclusions regarding this policy may be subject to review and adjustment at a later date based on factors including, but not limited to, ongoing analysis of and changes to tax laws, regulations, and interpretations thereof.

The Fund recognizes interest accrued related to unrecognized tax benefits and penalties related to unrecognized tax benefits in income tax fees payable, if assessed. No interest expense or penalties have been recognized as of a June 30, 2023.

The Fund may be subject to potential examination by U.S. federal, U.S. state, or foreign jurisdictional authorities in the area of income taxes. These potential examinations may include questioning the timing and amount of deductions, the nexus of income among various tax jurisdictions, and compliance with U.S. federal, U.S. state and foreign tax laws.

    Registration No. 333-273364

Creations and Redemptions

Authorized Purchasers may purchase Creation Baskets consisting of 10,000 shares from the Fund. The amount of the proceeds required to purchase a Creation Basket will be equal to the NAV of the shares in the Creation Basket determined as of 4:00 p.m. (ET) on the day the order to create the basket is received in good order.

Authorized Purchasers may redeem shares from the Fund only in blocks of 10,000 shares called "Redemption Baskets." The amount of the redemption proceeds for a Redemption Basket will be equal to the NAV of the shares in the Redemption Basket determined as of 4:00 p.m. (ET) on the day the order to redeem the basket is received in good order.

The Fund will receive the proceeds from shares sold or will pay for redeemed shares within three business days after the trade date of the purchase or redemption, respectively. The amounts due from Authorized Purchasers will be reflected in the Fund's statements of assets and liabilities as capital shares receivable. Amounts payable to Authorized Purchasers upon redemption will be reflected in the Fund's statements of assets and liabilities as payable for shares redeemed.

As outlined in the most recent Form S-1 filing, 50,000 shares represent five Redemption Baskets for the Fund and a minimum level of shares. If the Fund experienced redemptions that caused the number of Shares outstanding to decrease to the minimum level of Shares required to be outstanding, until the minimum number of Shares is again exceeded through the purchase of a new Creation Basket, there can be no more redemptions by an Authorized Purchaser.

Allocation of Shareholder Income and Losses

Profit or loss is allocated among the shareholders of the Fund in proportion to the number of shares each shareholder holds as of the close of each month.

Cash Equivalents

Cash equivalents are highly liquid investments with maturity dates of 90 days or less when acquired. The Fund reported its cash equivalents in the statements of assets and liabilities at market value, or at carrying amounts that approximate fair value, because of their highly liquid nature and short-term maturities. The Fund has these balances of its assets on deposit with banks. Assets deposited with a financial institution may, at times, exceed federally insured limits. DEFI had a balance of $1,414,157 and $701,969 in money market funds at June 30, 2023 and December 31, 2022 respectively; these balances are included in cash equivalents on the statements of assets and liabilities.

Due from/to Broker

The amount recorded by the Fund for the amount due from and to the clearing broker includes, but is not limited to, cash held by the broker, amounts payable to the clearing broker related to open transactions, payables for cryptocurrency futures accounts liquidating to an equity balance on the clearing broker's records and amounts of brokerage commissions paid and recognized as unrealized losses.

Margin is the minimum amount of funds that must be deposited by a cryptocurrency interest trader with the trader's broker to initiate and maintain an open position in futures contracts. A margin deposit acts to assure the trader's performance of the futures contracts purchased or sold. Futures contracts are customarily bought and sold on initial margin that represents a very small percentage of the aggregate purchase or sales price of the contract. Because of such low margin requirements, price fluctuations occurring in the futures markets may create profits and losses that, in relation to the amount invested, are greater than customary in other forms of investment or speculation. As discussed below, adverse price changes in the futures contract may result in margin requirements that greatly exceed the initial margin. In addition, the amount of margin required in connection with a particular futures contract is set from time to time by the exchange on which the contract is traded and may be modified from time to time by the exchange during the term of the contract. Brokerage firms, such as the Fund's clearing brokers, carrying accounts for traders in commodity interest contracts generally require higher amounts of margin as a matter of policy to further protect themselves. Over the counter trading generally involves the extension of credit between counterparties, so the counterparties may agree to require the posting of collateral by one or both parties to address credit exposure.

When a trader purchases an option, there is no margin requirement; however, the option premium must be paid in full. When a trader sells an option, on the other hand, he or she is required to deposit margin in an amount determined by the margin requirements established for the underlying interest and, in addition, an amount substantially equal to the current premium for the option. The margin requirements imposed on the selling of options, although adjusted to reflect the probability that out-of-the-money options will not be exercised, can in fact be higher than those imposed in dealing in the futures markets directly. Complicated margin requirements apply to spreads and conversions, which are complex trading strategies in which a trader acquires a mixture of options positions and positions in the underlying interest.

    Registration No. 333-273364

Ongoing or "maintenance" margin requirements are computed each day by a trader's clearing broker. When the market value of a particular open futures contract changes to a point where the margin on deposit does not satisfy maintenance margin requirements, a margin call is made by the broker. If the margin call is not met within a reasonable time, the broker may close out the trader's position. With respect to the Fund's trading, the Fund (and not its shareholders personally) is subject to margin calls. Finally, many major U.S. exchanges have passed certain cross margining arrangements involving procedures pursuant to which the futures and options positions held in an account would, in the case of some accounts, be aggregated and margin requirements would be assessed on a portfolio basis, measuring the total risk of the combined positions.

Calculation of Net Asset Value

The Fund's NAV is calculated by:

? Taking the current market value of its total assets and ? Subtracting any liabilities.

The administrator, Global Fund Services, will calculate the NAV of the Fund once each trading day. It will calculate the NAV as of the earlier of the close of the New York Stock Exchange or 4:00 p.m. (ET). The NAV for a particular trading day will be released after 4:15 p.m. (ET).

In determining the value of Bitcoin Futures Contracts, the Administrator uses the settlement price for the Benchmark Component Futures Contracts, as reported on the CME. CME Group staff determines the daily settlements for the Benchmark Component Futures Contracts based on trading activity on CME Globex exchange between 14:59:00 and 15:00:00 Central Time (CT), the settlement period, except that the "fair value" of Bitcoin Futures Contracts (as described in more detail below) may be used when Bitcoin Futures Contracts close at their price fluctuation limit for the day. The Administrator determines the value of all investments as of the earlier of the close of the New York Stock Exchange or 4:00 p.m. (ET), in accordance with the current Services Agreement between the Administrator and the Trust. NAV includes any unrealized profit or loss on open bitcoin interests and any other credit or debit accruing to the Fund but unpaid or not received by the Fund.

Sponsor Fee Allocation of Expenses and Related Party Transactions

The Sponsor is responsible for investing the assets of the Fund in accordance with the objectives and policies of the Fund. DEFI is contractually obligated to pay a monthly management fee to the Sponsor, based on average daily net assets, at a rate equal to 0.94% per annum. From the Management Fee, the Sponsor pays all of the routine operational, administrative and other ordinary expenses of the Fund, generally as determined by the Sponsor, including but not limited to, fees and expenses of the Administrator, Custodian, Distributor, Transfer Agent, licensors, accounting and audit fees expenses, tax preparation expenses, legal fees, ongoing SEC registration fees, individual Schedule K-1 preparation and mailing fees, and report preparation and mailing expenses. These fees and expenses are not included in the breakeven table because they are paid for by the Sponsor through the proceeds from the Management Fee. The Fund pays all of its non-recurring and unusual fees and expenses, if any, as determined by the Sponsor. Non-recurring and unusual fees and expenses are unexpected or unusual in nature, such as legal claims and liabilities and litigation costs or indemnification or other unanticipated expenses. Extraordinary fees and expenses also include material expenses which are not currently anticipated obligations of the Fund. Routine operational, administrative, and other ordinary expenses are not deemed extraordinary expenses.

The Sponsor has the ability to elect to pay certain expenses on behalf of the Funds or waive the management fee. This election is subject to change by the Sponsor, at its discretion. Expenses paid by the Sponsor and Management fees waived by the Sponsor are, if applicable, presented as waived expenses in the statements of operations for each Fund. The Sponsor has determined that there will be no recovery sought for the amounts below in any future period:

    Registration No. 333-273364

    Registration No. 333-273364

Expenses

Expenses are recorded using the accrual method of accounting.

Use of Estimates

The preparation of financial statements in conformity with accounting principles generally accepted in the United States of America requires management to make estimates and assumptions that affect the reported amount of assets and liabilities and disclosure of contingent assets and liabilities at the date of the financial statements, and the reported amounts of the revenue and expenses during the reporting period. Actual results could differ from those estimates.

New Accounting Pronouncements

The Financial Accounting Standards Board ("FASB") issued Accounting Standards Update ("ASU") issued ASU 2023-01, related to Leases - (Topic 842). The response to concerns about applying Topic 842 to related party arrangements between entities under common control. The update was adopted early for the quarter ended March 31, 2023; the adoption did not have a material impact on the financial statements and disclosures of the Trust or the Fund.

Fair Value - Definition and Hierarchy

In accordance with GAAP, fair value is defined as the price that would be received to sell an asset or paid to transfer a liability (i.e., the "exit price") in an orderly transaction between market participants at the measurement date.

In determining fair value, the Fund uses various valuation approaches. In accordance with GAAP, a fair value hierarchy for inputs is used in measuring fair value that maximizes the use of observable inputs and minimizes the use of unobservable inputs by requiring that the most observable inputs be used when available. Observable inputs are those that market participants would use in pricing the asset or liability based on market data obtained from sources independent of the Fund. Unobservable inputs reflect the Fund's assumptions about the inputs market participants would use in pricing the asset or liability developed based on the best information available in the circumstances. The fair value hierarchy is categorized into three levels based on the inputs as follows:

Level 1 - Valuations based on unadjusted quoted prices in active markets for identical assets or liabilities that the Fund has the ability to access. Valuation adjustments and block discounts are not applied to Level 1 financial instruments of the Underlying Funds and securities of the Fund, together the "financial instruments". Since valuations are based on quoted prices that are readily and regularly available in an active market, valuation of these financial instruments does not entail a significant degree of judgment.

Level 2 - Valuations based on quoted prices in markets that are not active or for which all significant inputs are observable, either directly or indirectly.

Level 3 - Valuations based on inputs that are unobservable and significant to the overall fair value measurement.

The availability of valuation techniques and observable inputs can vary from financial instrument to financial instrument and is affected by a wide variety of factors including, the type of financial instrument, whether the financial instrument is new and not yet established in the marketplace, and other characteristics particular to the transaction. To the extent that valuation is based on models or inputs that are less observable or unobservable in the market, the determination of fair value requires more judgment. Those estimated values do not necessarily represent the amounts that may be ultimately realized due to the occurrence of future circumstances that cannot be reasonably determined. Because of the inherent uncertainty of valuation, those estimated values may be materially higher or lower than the values that would have been used had a ready market for the financial instruments existed. Accordingly, the degree of judgment exercised by the Fund in determining fair value is greatest for financial instruments categorized in Level 3. In certain cases, the inputs used to measure fair value may fall into different levels of the fair value hierarchy. In such cases, for disclosure purposes, the level in the fair value hierarchy, within which the fair value measurement in its entirety falls, is determined based on the lowest level input that is significant to the fair value measurement.

On June 30, 2023 and December 31, 2022, the reported value at the close of the market for each cryptocurrency contract fairly reflected the value of the futures and no alternative valuations were required.

    Registration No. 333-273364

Net Income (Loss) per Share

Net income (loss) per share is the difference between the NAV per unit at the beginning of each period and at the end of each period. The weighted average number of units outstanding was computed for purposes of disclosing net income (loss) per weighted average unit. The weighted average units are equal to the number of units outstanding at the end of the period, adjusted proportionately for units created or redeemed based on the amount of time the units were outstanding during such period.

Note 4 - Fair Value Measurements

The Fund's assets and liabilities recorded at fair value have been categorized based upon a fair value hierarchy as described in the Fund's significant accounting policies in Note 3. The following table presents information about the Fund's assets and liabilities measured at fair value as of June 30, 2023 and December 31, 2022:

June 30, 2023

    Registration No. 333-273364

December 31, 2022 (Audited)

    Registration No. 333-273364

For the three and six months ended June 30, 2023 and year ended December 31, 2022, the Fund did not have any significant transfers between any of the levels of the fair value hierarchy.

See the Fair Value - Definition and Hierarchy section in Note 3 above for an explanation of the transfers into and out of each level of the fair value hierarchy.

Note 5 - Derivative Instruments and Hedging Activities

In the normal course of business, the Fund utilizes derivative contracts in connection with its proprietary trading activities. Investments in derivative contracts are subject to additional risks that can result in a loss of all or part of an investment. The Fund's derivative activities and exposure to derivative contracts are classified by the following primary underlying risks: interest rate, credit, commodity price, and equity price risks. In addition to its primary underlying risks, the Fund is also subject to additional counterparty risk due to inability of its counterparties to meet the terms of their contracts. For the quarter ended June 30, 2023, the Fund invested only in cryptocurrency futures contracts.

Futures Contracts

The Fund is subject to cryptocurrency price risk in the normal course of pursuing its investment objectives. A futures contract represents a commitment for the future purchase or sale of an asset at a specified price on a specified date.

    Registration No. 333-273364

The purchase and sale of futures contracts requires margin deposits with a Futures Commission Merchant ("FCM"). Subsequent payments (variation margin) are made or received by the Fund each day, depending on the daily fluctuations in the value of the contract, and are recorded as unrealized gains or losses by the Fund. Futures contracts may reduce the Fund's exposure to counterparty risk since futures contracts are exchange-traded; and the exchange's clearinghouse, as the counterparty to all exchange-traded futures, guarantees the futures against default.

The Commodity Exchange Act requires an FCM to segregate all customer transactions and assets from the FCM's proprietary activities. A customer's cash and other equity deposited with an FCM are considered commingled with all other customer funds subject to the FCM's segregation requirements. In the event of an FCM's insolvency, recovery may be limited to the Fund's pro rata share of segregated customer funds available. It is possible that the recovery amount could be less than the total of cash and other equity deposited.

The following table discloses information about offsetting assets and liabilities presented in the statements of assets and liabilities to enable users of these financial statements to evaluate the effect or potential effect of netting arrangements for recognized assets and liabilities. These recognized assets and liabilities are presented as defined in the Financial Accounting Standards Board's ("FASB") Accounting Standards Update ("ASU") No. 2011-11 "Balance Sheet (Topic 210): Disclosures about Offsetting Assets and Liabilities" and subsequently clarified in FASB ASU 2013-01 "Balance Sheet (Topic 210): Clarifying the Scope of Disclosures about Offsetting Assets and Liabilities."

The following table also identifies the fair value amounts of derivative instruments included in the statements of assets and liabilities as derivative contracts, categorized by primary underlying risk, and held by the FCMs, StoneX as of June 30, 2023.

*The amount of collateral presented in Collateral, Due from Broker, is limited to the liability for the futures contracts and accordingly does not include the excess collateral pledged.

Offsetting of Financial Assets and Derivative Assets as of June 30, 2023

    Registration No. 333-273364

Offsetting of Financial Assets and Derivative Assets as of December 31, 2022 (Audited)

    Registration No. 333-273364

    Registration No. 333-273364

The following tables identify the net gain and loss amounts included in the statements of operations as realized and unrealized gains and losses on trading of cryptocurrency futures contracts categorized by primary underlying risk:

Three months ended June 30, 2023

    Registration No. 333-273364

Six months ended June 30, 2023

    Registration No. 333-273364

Volume of Derivative Activities

The average notional market value categorized by primary underlying risk for all futures contracts held was $2.1 million and $1.9 million, respectively, for the three and six months ended June 30, 2023.

Note 6 - Financial Highlights

The following table presents per unit performance data and other supplemental financial data for the three months ended June 30, 2023. This information has been derived from information presented in the financial statements and is presented with total expenses gross of expenses waived by the Sponsor and with total expenses net of expenses waived by the Sponsor, as appropriate.

    Registration No. 333-273364

    Registration No. 333-273364

The financial highlights per share data are calculated consistent with the methodology used to calculate asset-based fees and expenses.

Note 7 - Organizational and Offering Costs

Expenses incurred in organizing of the Trust and the initial offering of the Shares of the Fund, including applicable SEC registration fees, were borne directly by the Sponsor. The Fund will not be obligated to reimburse the Sponsor.

Note 8 - Subsequent Events

Management has evaluated the financial statements for the quarter-ended June 30, 2023 for subsequent events through the date of this filing and noted no material events requiring either recognition through the date of the filing or disclosure herein for the Fund other than those noted below:

The Hashdex Bitcoin Futures ETF ("Tidal Fund"), sponsored by Toroso Investments, LLC ("Toroso"), a series of the Tidal Commodities Trust I has not commenced operations and was recently formed. The Tidal Fund will be the successor and surviving entity from the merger (the "Merger") into the Tidal Fund of Hashdex Bitcoin Futures ETF (the "Teucrium Fund") that is a series of the Teucrium Commodity Trust (the "Teucrium Trust") sponsored by Teucrium Trading, LLC ("Teucrium"). The Merger is expected to close in 2023. Teucrium, Toroso, and Tidal ETF Services, LLC ("Tidal") and Victory Capital Management Inc. ("Victory Capital") (the "Marketing Agents") have entered into a support agreement ("Support Agreement") that, among other things, will cause the Merger in furtherance of their long-term business goals, the Tidal Fund will be the successor and surviving entity from the Merger. The Tidal Fund and the Teucrium Fund will file current reports on Form 8-K including a press release notifying shareholders that the Merger has been consummated.

    Registration No. 333-273364

    Registration No. 333-273364

This prospectus includes "forward-looking statements" which generally relate to future events or future performance. In some cases, you can identify forward-looking statements by terminology such as "may," "will," "should," "expect," "plan," "anticipate," "believe," "estimate," "predict," "potential" or the negative of these terms or other comparable terminology. All statements (other than statements of historical fact) included in this prospectus that address activities, events or developments that will or may occur in the future, including such matters as movements in the commodities markets and indexes that track such movements, the Fund's operations, the Sponsor's plans and references to the Fund's future success and other similar matters, are forward-looking statements. These statements are only predictions. Actual events or results may differ materially. These statements are based upon certain assumptions and analyses the Sponsor has made based on its perception of historical trends, current conditions and expected future developments, as well as other factors appropriate in the circumstances. Whether or not actual results and developments will conform to the Sponsor's expectations and predictions, however, is subject to a number of risks and uncertainties, including the special considerations discussed in this prospectus, general economic, market and business conditions, changes in laws or regulations, including those concerning taxes, made by governmental authorities or regulatory bodies, and other world economic and political developments. See "What Are the Risk Factors Involved with an Investment in the Fund?" Consequently, all the forward-looking statements made in this prospectus are qualified by these cautionary statements, and there can be no assurance that actual results or developments the Sponsor anticipates will be realized or, even if substantially realized, that they will result in the expected consequences to, or have the expected effects on, the Fund's operations or the value of its Shares.

    Registration No. 333-273364

    Registration No. 333-273364

In this prospectus, each of the following terms have the meanings set forth after such term:

Administrator: Tidal ETF Services LLC.

Authorized Purchaser: One that purchases or redeems Creation Baskets or Redemption Baskets, respectively, from or to the Fund.

Benchmark: The Hashdex U.S. Bitcoin Futures Fund Benchmark, which is the mean average of the closing settlement prices for the first to expire and second to expire CME Bitcoin Futures Contracts.

Benchmark Component Futures Contracts: The Bitcoin Futures Contracts that at any given time make up the Benchmark.

Business Day: Any day other than a day when any of NYSE Arca or CME is closed for regular trading.

CFTC: Commodity Futures Trading Commission, an independent federal agency with the mandate to regulate commodity futures and options in the United States.

Code: Internal Revenue Code of 1986, as amended.

Commodity Pool: An enterprise in which several individuals contribute funds in order to trade futures contracts or options on futures contracts collectively.

Commodity Pool Operator or CPO: Any person engaged in a business which is of the nature of an investment trust, syndicate, or similar enterprise, and who, in connection therewith, solicits, accepts, or receives from others, funds, securities, or property, either directly or through capital contributions, the sale of stock or other forms of securities, or otherwise, for the purpose of trading in any swap or commodity for future delivery or commodity option on or subject to the rules of any contract market.

Creation Basket: A block of 10,000 Shares used by the Fund to issue Shares.

Custodian: means U.S. Bank, N.A

DTC: The Depository Trust Company. DTC will act as the securities depository for the Shares.

DTC Purchaser: An entity that has an account with DTC.

Exchange Act: The Securities Exchange Act of 1934.

Exchange for Related Position: A privately negotiated and simultaneous exchange of a futures contract position is exchanged for cash or physical, swap, over the counter instrument or other financial instrument such as the creation or redemption of shares in a fund.

FINRA: Financial Industry Regulatory Authority.

Futures Contract: An exchange-traded contract traded with standard terms that calls for the delivery of a specified quantity of a cryptocurrency at a specified price, on a specified date and at a specified location. Typically, a futures contract is traded out or rolled on an exchange before delivery or receipt of the underlying cryptocurrency is required.

Indirect Purchasers: Banks, brokers, dealers and trust companies that clear through or maintain a custodial relationship with a DTC purchaser, either directly or indirectly.

    Registration No. 333-273364

Limited Liability Company (LLC): A type of business ownership combining several features of corporation and partnership structures.

Margin: The amount of equity required for an investment in futures contracts.

Marketing Agent: means Foreside Fund Services, LLC, a wholly-owned subsidiary of Foreside Financial Group, LLC (d/b/a ACA Group)

NAV: Net Asset Value of the Fund.

NFA: National Futures Association.

NSCC: National Securities Clearing Corporation.

1933 Act: The Securities Act of 1933.

Redemption Basket: A block of 10,000 Shares used by the Fund to redeem Shares.

SEC: Securities and Exchange Commission.

Secondary Market: The stock exchanges and the over the counter market. Securities are first issued as a primary offering to the public. When the securities are traded from that first holder to another, the issued securities trade in these secondary markets.

Shareholders: Holders of Shares.

Shares: Common units representing fractional undivided beneficial interests in the Fund.

Sponsor: Tidal Investments LLC, a Delaware limited liability company, which is registered as a Commodity Pool Operator, who controls the investments and other decisions of the Fund.

Spot Contract: A cash market transaction in which the buyer and seller agree to the immediate purchase and sale of a cryptocurrency, usually with a two-day settlement.

Bitcoin Futures Contracts: Futures contracts for bitcoin.

Swap Agreement: An over the counter derivative that generally involves an exchange of a stream of payments between the contracting parties based on a notional amount and a specified index.

Tracking Error: Possibility that the daily NAV of the Fund will not track the Benchmark.

Trust Agreement: The First Amended and Restated Declaration of Trust and Trust Agreement of the Trust effective as of March 10, 2023.

Valuation Day: Any day as of which the Fund calculates its NAV.

You: The owner of Shares.

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

This statement of additional information is the second part of a two-part document. The first part is the Fund's disclosure document. The disclosure document and this statement of additional information are bound together, and both parts contain important information. This statement of additional information should be read in conjunction with the disclosure document. To obtain a copy of the disclosure document without charge, call the Fund at (844)-986-7700. Before you decide whether to invest, you should read the entire prospectus carefully and consider the risk factors beginning on page 11.

This statement of additional information and accompanying disclosure document are both dated November [ ], 2023.

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

Cryptocurrency Derivatives Market Purchasers

Two broad classes of persons who trade cryptocurrency futures are hedgers and speculators. Hedgers include financial institutions and entities that manage or deal in cryptocurrency instruments or crypto related stock portfolios, and commercial market purchasers, such as crypto mining companies or Decentralized Finance (DeFi) purchasers, that mine, lend, accept, or otherwise conduct business using cryptocurrencies. Hedging is a protective procedure designed to effectively lock in prices that would otherwise change due to an adverse movement in the price of the underlying commodity or cryptocurrency, such as the adverse price movement between the time a producer enters into a contract to sell a product for cryptocurrency at a certain price and the time it acquires the cryptocurrency against the delivery of the product to the customer. For example, if a manufacturer contracts to physically sell its product at a future date for a fixed amount of cryptocurrency, it may simultaneously sell a futures or forward contract for the necessary equivalent quantity of the cryptocurrency. At the time the producer delivers the physical product to the customer, the producer/hedger will accept customer payment in cryptocurrency, the value of which will offset the producer's short cryptocurrency futures contract thereby locking in the original financial value of the amount of cryptocurrency the producer had accepted when it agreed to sell its product in return for a fixed amount of cryptocurrency.

Futures markets enable the hedger to shift the risk of price fluctuations. The usual objective of the hedger is to protect the profit it expects to earn from its ordinary business activities rather than to profit from trading. Unlike the hedger, the speculator generally expects neither to make nor take delivery of cryptocurrencies in return for a product or services. Instead, the speculator risks his capital with the hope of making profits from price fluctuations in the cryptocurrency markets. The speculator is, in effect, the risk bearer who assumes the risks that the hedger seeks to avoid. Speculators attempt to close out their positions prior to the expiration of a futures contract. A speculator who takes a long position generally will make a profit if the price of the underlying cryptocurrency or futures contract goes up in value and incur a loss if the price of the cryptocurrency or futures contract goes down, while a speculator who takes a short position generally will make a profit if the price of the cryptocurrency or futures contract goes down and incur a loss if the price of the cryptocurrency or futures contract goes up.

Regulation

The regulation of futures markets, futures contracts, and futures exchanges has historically been comprehensive. The CFTC and the exchanges are authorized to take extraordinary actions in the event of a market emergency including, for example, the retroactive implementation of speculative position limits, increased margin requirements, the establishment of daily price limits and the suspension of trading on an exchange or trading facility.

Pursuant to authority in the CEA, the NFA has been formed and registered with the CFTC as a registered futures association. At the present time, the NFA is the only SRO for commodity interest professionals, other than futures exchanges. The CFTC has delegated to the NFA responsibility for the registration of CPOs and FCMs and their respective associated persons. The Sponsor and the Fund's clearing broker are members of the NFA. As such, they will be subject to NFA standards relating to fair trade practices, financial condition and consumer protection. The NFA also arbitrates disputes between members and their customers and conducts registration and fitness screening of applicants for membership and audits of its existing members. Neither the Trust nor the Fund is required to become a member of the NFA. The regulation of commodity interest transactions in the United States is a rapidly changing area of law and is subject to ongoing modification by governmental and judicial action. Considerable regulatory attention has been focused on non-traditional investment pools that are publicly distributed in the United States. There is a possibility of future regulatory changes within the United States altering, perhaps to a material extent, the nature of an investment in the Fund, or the ability of the Fund to continue to implement its investment strategy. In addition, various national governments outside of the United States have expressed concern regarding the disruptive effects of speculative trading in the commodities markets and the need to regulate the derivatives markets in general. The effect of any future regulatory change on the Fund is impossible to predict but could be substantial and adverse.

The CFTC possesses exclusive jurisdiction to regulate the activities of commodity pool operators and commodity trading advisors with respect to "commodity interests," such as futures, swaps, and options, and has adopted regulations with respect to the activities of those persons and/or entities. Under the Commodity Exchange Act ("CEA"), a registered commodity pool operator, such as the Sponsor, is required to make annual filings with the CFTC and the NFA describing its organization, capital structure, management and controlling persons. In addition, the CEA authorizes the CFTC to require and review books and records of, and documents prepared by, registered commodity pool operators. Pursuant to this authority, the CFTC requires commodity pool operators to keep accurate, current and orderly records for each pool that they operate. The CFTC may suspend the registration of a commodity pool operator (1) if the CFTC finds that the operator's trading practices tend to disrupt orderly market conditions, (2) if any controlling person of the operator is subject to an order of the CFTC denying such person trading privileges on any exchange, and (3) in certain other circumstances. Suspension, restriction or termination of the Sponsor's registration as a commodity pool operator would prevent it, until that registration were to be reinstated, from managing the Fund, and might result in the termination of the Fund if a successor sponsor is not elected pursuant to the Trust Agreement. Neither the Trust nor the Fund is required to be registered with the CFTC in any capacity.

    Registration No. 333-273364

The Fund's investors are afforded prescribed rights for reparations under the CEA. Investors may also be able to maintain a private right of action for violations of the CEA. The CFTC has adopted rules implementing the reparation provisions of the CEA, which provide that any person may file a complaint for a reparations award with the CFTC for violation of the CEA against a floor broker or an FCM, introducing broker, commodity trading advisor, CPO, and their respective associated persons.

The regulations of the CFTC and the NFA prohibit any representation by a person registered with the CFTC or by any member of the NFA, that registration with the CFTC, or membership in the NFA, in any respect indicates that the CFTC or the NFA has approved or endorsed that person or that person's trading program or objectives. The registrations and memberships of the parties described in this summary must not be considered as constituting any such approval or endorsement. Likewise, no futures exchange has given or will give any similar approval or endorsement.

Trading venues in the United States are subject to varying degrees of regulation under the CEA depending on whether such exchange is a designated contract market (i.e. a futures exchange) or a swap execution facility. Clearing organizations are also subject to the CEA and the rules and regulations adopted thereunder as administered by the CFTC. The CFTC's function is to implement the CEA's objectives of preventing price manipulation and excessive speculation and promoting orderly and efficient commodity interest markets. In addition, the various exchanges and clearing organizations themselves as SROs exercise regulatory and supervisory authority over their member firms.

The Dodd-Frank Wall Street Reform and Consumer Protection Act (the "Dodd-Frank Act") was enacted in response to the economic crisis of 2008 and 2009 and it significantly altered the regulatory regime to which the securities and commodities markets are subject. To date, the CFTC has issued proposed or final versions of almost all of the rules it is required to promulgate under the Dodd-Frank Act, and it continues to issue proposed versions of additional rules that it has authority to promulgate. Provisions of the new law include the requirement that position limits be established on a wide range of commodity interests, including agricultural, energy, and metal-based commodity futures contracts, options on such futures contracts and uncleared swaps that are economically equivalent to such futures contracts and options ("Reference Contracts"); new registration and recordkeeping requirements for swap market purchasers; capital and margin requirements for "swap dealers" and "major swap," as determined by the new law and applicable regulations; reporting of all swap transactions to swap data repositories; and the mandatory use of clearinghouse mechanisms for sufficiently standardized swap transactions that were historically entered into in the OTC market, but are now designated as subject to the clearing requirement; and margin requirements for OTC swaps that are not subject to the clearing requirements.

In addition, considerable regulatory attention has recently been focused on non-traditional publicly distributed investment pools such as the Fund. Furthermore, various national governments have expressed concern regarding the disruptive effects of speculative trading in certain commodity markets and the need to regulate the derivatives markets in general. The effect of any future regulatory change on the Funds is impossible to predict but could be substantial and adverse.

The Dodd-Frank Act was intended to reduce systemic risks that may have contributed to the 2008/2009 financial crisis. Since the first draft of what became the Dodd-Frank Act, supporters and opponents have debated the scope of the legislation. As the Administrations of the U.S. change, the interpretation and implementation will change along with them. Nevertheless, regulatory reform of any kind may have a significant impact on U.S. regulated entities.

Position Limits, Aggregation Limits, Price Fluctuation Limits

The CFTC and US futures exchanges impose limits on the maximum net long or net short speculative positions that any person may hold or control in any particular futures or options contracts traded on US futures exchanges. For example, the CFTC currently imposes speculative position limits on cryptocurrencies and a number of commodities (e.g., corn, oats, wheat, soybeans and cotton) and US futures exchanges currently impose speculative position limits on many other commodities. The Fund could be required to liquidate positions it holds in order to comply with position limits or may not be able to fully implement trading instructions generated by its trading models, in order to comply with position limits. Any such liquidation or limited implementation could result in substantial costs to the Fund.

    Registration No. 333-273364

The Dodd-Frank Act significantly expanded the CFTC's authority to impose position limits with respect to futures contracts and options on futures contracts, swaps that are economically equivalent to futures or options on futures, and swaps that are traded on a regulated exchange and certain swaps that perform a significant price discovery function. Aggregate position limits for BTC and MBT count toward open positions across the bitcoin product suite (Bitcoin futures contracts (BTC), and options on Bitcoin futures contracts and Micro Bitcoin futures contracts (MBT)) will count toward an aggregate position limit which is established in terms of the larger BTC contract limits. For example, a long position of 1,000 BTC and a long position of 1,000 MBT, would be, in this case, 1,020 contracts (1,000 BTC + 1,000 MBT/50) that go toward the position limit test. The aggregate position limits currently in place under the current position limits and the Aggregation Requirements are as follows for each of the cryptocurrency derivatives traded by the Fund:

    Registration No. 333-273364

The CFTC has attempted to exercise authority to enact additional and more restricted speculative position limits with respect to futures and options on futures on so-called "exempt commodities" (which includes most energy and metals contracts) and with respect to agricultural commodities, but those proposed limits were vacated by a United States District Court. The CFTC has once again attempted to enact additional and more restrictive limits. For a discussion generally regarding the risks that position limits may pose for the Fund, see the risk factor in "WHAT ARE THE RISK FACTORS INVOLVED WITH AN INVESTMENT IN THE FUND" regarding position limits, accountability levels and dynamic price fluctuation limits.

With the exception of the nine legacy agricultural contracts, the CFTC's position limits would apply only in the spot month. These limits would generally be set at 25 percent of the deliverable supply but may be higher or lower for certain contracts. With respect to the non-legacy contracts, the rule would require the relevant exchange on which the contracts are traded to adopt either position limits or position accountability levels.

The proposed rules also would expand the current list of enumerated bona fide hedges to include, for example, hedges of anticipated merchandizing. To provide market purchasers with greater flexibility on managing their business risks, the proposal also provides guidance on whether and when market purchasers are permitted to measure risk on a gross basis rather than a net basis. However, firms will be required to measure risk on a consistent basis. Enumerated hedges are self-effectuating. That is, no prior approval would be required from the CFTC, although a market purchaser would be required to obtain approval from the relevant exchange. Self-effectuating hedge exemptions also would be available for other transactions such as spreads and pass-through swaps as approved by exchanges. With respect to non-enumerated hedge exemptions, a market purchaser would be required to file a request to exceed the position limit with the relevant exchange. If the exchange grants the request for a non-enumerated hedge exemption, the exchange will forward its decision to the CFTC for review. The exemption will be deemed granted provided the CFTC does not intervene during a 10-day review period. The market purchaser would not be permitted to exceed the applicable position limit until the 10-day review period lapses. Importantly, the CFTC may act solely through its commissioners and not through staff. In terms of process changes, the CFTC is proposing to eliminate Form 204 cash positions report and the cash information reported under Form 304. Comments on the proposed rule must be submitted no later than 90 days after approval of the proposal by the CFTC (i.e., April 29, 2020). The CFTC does not intend to extend the comment period.

It is unknown at this time the effect that such passage, adoption or modification will have, positively or negatively, on our industry or on the Fund. The size or duration of positions available to the Fund may be severely limited. Pursuant to the CFTC's and the exchanges' aggregation requirements, all accounts owned or managed by the Sponsor are likely to be combined for speculative position limits purposes. The Fund could be required to liquidate positions it holds in order to comply with such limits or may not be able to fully implement trading instructions generated by its trading models, in order to comply with such limits. Any such liquidation or limited implementation could result in substantial costs to the Fund.

These new regulations and the resulting increased costs and regulatory oversight requirements may result in market purchasers being required or deciding to limit their trading activities, which could lead to decreased market liquidity and increased market volatility. In addition, transaction costs incurred by market purchasers are likely to be higher due to the increased costs of compliance with the new regulations. These consequences could adversely affect the Fund's returns.

    Registration No. 333-273364

FCMs

The CEA requires all FCMs, such as the Fund's clearing brokers, to meet and maintain specified fitness and financial requirements, to segregate customer funds from proprietary funds and account separately for all customers' funds and positions, and to maintain specified books and records open to inspection by the staff of the CFTC. The CFTC has similar authority over introducing brokers, or persons who solicit or accept orders for commodity interest trades but who do not accept margin deposits for the execution of trades. The CEA authorizes the CFTC to regulate trading by FCMs and by their officers and directors, permits the CFTC to require action by exchanges in the event of market emergencies, and establishes an administrative procedure under which customers may institute complaints for damages arising from alleged violations of the CEA. The CEA also gives the states powers to enforce its provisions and the regulations of the CFTC.

On November 14, 2013, the CFTC published final regulations that require enhanced customer protections, risk management programs, internal monitoring and controls, capital and liquidity standards, customer disclosures and auditing and examination programs for FCMs. The rules are intended to afford greater assurances to market purchasers that customer segregated funds and secured amounts are protected, customers are provided with appropriate notice of the risks of futures trading and of the FCMs with which they may choose to do business, FCMs are monitoring and managing risks in a robust manner, the capital and liquidity of FCMs are strengthened to safeguard the continued operations and the auditing and examination programs of the CFTC and the SROs are monitoring the activities of FCMs in a thorough manner.

Potential Advantages of Investment

Interest Income and Expense

Unlike some alternative investment funds, the Fund does not borrow money in order to obtain leverage, so the Fund does not incur any interest expense. Rather, the Fund's margin deposits, and cash reserves are maintained in cash and cash equivalents and interest is generally earned on available assets, which include unrealized profits credited to the Fund's accounts

Fund Performance

The following graph sets forth the historical performance of the Fund from commencement of operations on September 15, 2022 until July 31, 2023.

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

Item 13.

Other Expenses of Issuance and Distribution.

Set forth below is an estimate (except as indicated) of the amount of fees and expenses (other than underwriting commissions and discounts) payable by the registrant in connection with the issuance and distribution of the units pursuant to the prospectus contained in this registration statement.

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

Item 14.

Indemnification of Directors and Officers.

The Trust's Declaration of Trust and Trust Agreement (the "Trust Agreement") provides that the Sponsor shall be indemnified by the Trust (or, by a series of the Trust separately to the extent the matter in question relates to a single series or disproportionately affects a series in relation to other series) against any losses, judgments, liabilities, expenses and amounts paid in settlement of any claims sustained by it in connection with its activities for the Trust, provided that (i) the Sponsor was acting on behalf of or performing services for the Trust and has determined, in good faith, that such course of conduct was in the best interests of the Trust and such liability or loss was not the result of gross negligence, willful misconduct, or a breach of the Trust Agreement on the part of the Sponsor and (ii) any such indemnification will only be recoverable from the applicable trust estate or trust estates. All rights to indemnification permitted by the Trust Agreement and payment of associated expenses shall not be affected by the dissolution or other cessation to exist of the Sponsor, or the withdrawal, adjudication of bankruptcy or insolvency of the Sponsor, or the filing of a voluntary or involuntary petition in bankruptcy under Title 11 of the Bankruptcy Code by or against the Sponsor.

Notwithstanding the foregoing, the Sponsor shall not be indemnified for any losses, liabilities or expenses arising from or out of an alleged violation of U.S. federal or state securities laws unless (i) there has been a successful adjudication on the merits of each count involving alleged securities law violations as to the particular indemnitee and the court approves the indemnification of such expenses (including, without limitation, litigation costs), (ii) such claims have been dismissed with prejudice on the merits by a court of competent jurisdiction as to the particular indemnitee and the court approves the indemnification of such expenses (including, without limitation, litigation costs) or (iii) a court of competent jurisdiction approves a settlement of the claims against a particular indemnitee and finds that indemnification of the settlement and related costs should be made.

    Registration No. 333-273364

The Trust and its series shall not incur the cost of that portion of any insurance which insures any party against any liability, the indemnification of which is prohibited by the Trust Agreement.

Expenses incurred in defending a threatened or pending civil, administrative or criminal action, suit or proceeding against the Sponsor shall be paid by the Trust or the applicable series of the Trust in advance of the final disposition of such action, suit or proceeding, if (i) the legal action relates to the performance of duties or services by the Sponsor on behalf of the Trust or a series of the Trust; (ii) the legal action is initiated by a party other than the Trust; and (iii) the Sponsor undertakes to repay the advanced funds with interest to the Trust or the applicable series of the Trust in cases in which it is not entitled to indemnification under the Trust Agreement.

For purposes of the indemnification provisions of the Trust Agreement, the term "Sponsor" includes, in addition to the Sponsor, any other covered person performing services on behalf of the Trust and acting within the scope of the Sponsor's authority as set forth in the Trust Agreement.

In the event the Trust or a series of the Trust is made a party to any claim, dispute, demand or litigation or otherwise incurs any loss, liability, damage, cost or expense as a result of or in connection with any Shareholder's (or assignee's) obligations or liabilities unrelated to Trust business, such Shareholder (or assignees cumulatively) shall indemnify, defend, hold harmless, and reimburse the Trust or the applicable series of the Trust for all such loss, liability, damage, cost and expense incurred, including attorneys' and accountants' fees.

The payment of any amount pursuant to the Trust Agreement shall take into account the allocation of liabilities and other amounts, as appropriate, among the series of the Trust.

Item 15.

Recent Sales of Unregistered Securities.

Not applicable.

Item 16.

    Registration No. 333-273364

(a) Exhibits

3.1 First Amended and Restated Declaration of Trust and Trust Agreement1

5.1 Opinion of K&L Gates, LLP relating to the legality of the Shares *

    Registration No. 333-273364

    Registration No. 333-273364

10.2 Form of Distribution Services Agreement2

10.3 Form of Custody Agreement2

10.4 Form of Fund Accounting Servicing Agreement2

10.5 Form of Transfer Agent Servicing Agreement2

10.6 Form of Fund Administration Servicing Agreement2

23.1 Consents of K&L Gates, LLP (included in Exhibit 5.1)*

    Registration No. 333-273364

23.3 Consent of Grant Thornton LLP*

    Registration No. 333-273364

107 Filing Fee Table1

1 Previously filed as an exhibit to the Registrant's Registration Statement on Form S-1 (333-273364), filed on July 21, 2023 and incorporated by reference herein.

2 Previously filed as an exhibit to the Registrant's Registration Statement on Form S-4 (333-275227), filed on October 31, 2023 and incorporated by reference herein.

* Filed herewith

    Registration No. 333-273364

Item 17.

Undertakings.

(a) The undersigned registrant hereby undertakes:

(1) To file, during any period in which offers, or sales are being made, a post-effective amendment to this registration statement:

(i) To include any prospectus required by section 10(a)(3) of the Securities Act of 1933;

(ii) To reflect in the prospectus any facts or events arising after the effective date of the registration statement (or the most recent post-effective amendment thereof) which, individually or in the aggregate, represent a fundamental change in the information set forth in the registration statement. Notwithstanding the foregoing, any increase or decrease in volume of securities offered (if the total dollar value of securities offered would not exceed that which was registered) and any deviation from the low or high end of the estimated maximum offering range may be reflected in the form of prospectus filed with the Securities and Exchange Commission pursuant to Rule 424(b) if, in the aggregate, the changes in volume and price represent no more than 20 percent change in the maximum aggregate offering price set forth in the "Calculation of Registration Fee" table in the effective registration statement.

(iii) To include any material information with respect to the plan of distribution not previously disclosed in the registration statement or any material change to such information in the registration statement.

Provided, however, that paragraphs (a)(1)(i), (ii), and (iii) of this section do not apply if the registration statement is on Form S-1, Form S-3, Form SF-3 or Form F-3 and the information required to be included in a post-effective amendment by those paragraphs is contained in reports filed with or furnished to the Commission by the registrant pursuant to section 13 or section 15(d) of the Securities Exchange Act of 1934 that are incorporated by reference in the registration statement, or, as to a registration statement on Form S-3, is contained in a form of prospectus filed pursuant to 230.424(b) that is part of the registration statement.

(2) That, for the purpose of determining any liability under the Securities Act of 1933, each such post-effective amendment shall be deemed to be a new registration statement relating to the securities offered therein, and the offering of such securities at that time shall be deemed to be the initial bona fide offering thereof.

(3) To remove from registration by means of a post-effective amendment any of the securities being registered which remain unsold at the termination of the offering.

(4) That, for the purpose of determining liability under the Securities Act of 1933 to any purchaser:

(i) If the registrant is subject to Rule 430C, each prospectus filed pursuant to Rule 424(b) as part of a registration statement relating to an offering, other than registration statements relying on Rule 430B or other than prospectuses filed in reliance on Rule 430A, shall be deemed to be part of and included in the registration statement as of the date it is first used after effectiveness. Provided, however, that no statement made in a registration statement or prospectus that is part of the registration statement or made in a document incorporated or deemed incorporated by reference into the registration statement or prospectus that is part of the registration statement will, as to a purchaser with a time of contract of sale prior to such first use, supersede or modify any statement that was made in the registration statement or prospectus that was part of the registration statement or made in any such document immediately prior to such date of first use.

    Registration No. 333-273364

(5) That, for the purpose of determining liability of the registrant under the Securities Act of 1933 to any purchaser in the initial distribution of the securities: The undersigned registrant undertakes that in a primary offering of securities of the undersigned registrant pursuant to this registration statement, regardless of the underwriting method used to sell the securities to the purchaser, if the securities are offered or sold to such purchaser by means of any of the following communications, the undersigned registrant will be a seller to the purchaser and will be considered to offer or sell such securities to such purchaser:

(i) Any preliminary prospectus or prospectus of the undersigned registrant relating to the offering required to be filed pursuant to Rule 424;

(ii) Any free writing prospectus relating to the offering prepared by or on behalf of the undersigned registrant or used or referred to by the undersigned registrant;

(iii) The portion of any other free writing prospectus relating to the offering containing material information about the undersigned registrant or its securities provided by or on behalf of the undersigned registrant; and

(iv) Any other communication that is an offer in the offering made by the undersigned registrant to the purchaser.

(6) That, for purposes of determining any liability under the Securities Act of 1933, each filing of the registrant's annual report pursuant to Section 13(a) or 15(d) of the Securities Exchange Act of 1934 (and, where applicable, each filing of an employee benefit plan's annual report pursuant to Section 15(d) of the Securities Exchange Act of 1934) that is incorporated by reference in the registration statement shall be deemed to be a new registration statement relating to the securities offered therein, and the offering of such securities at that time shall be deemed to be the initial bona fide offering thereof.

(7) Insofar as indemnification for liabilities arising under the Securities Act of 1933 may be permitted to directors, officers and controlling persons of the registrant pursuant to the foregoing provisions, or otherwise, the registrant has been advised that in the opinion of the Securities and Exchange Commission such indemnification is against public policy as expressed in the Act and is, therefore, unenforceable. In the event that a claim for indemnification against such liabilities (other than the payment by the registrant of expenses incurred or paid by a director, officer or controlling person of the registrant in the successful defense of any action, suit or proceeding) is asserted by such director, officer or controlling person in connection with the securities being registered, the registrant will, unless in the opinion of its counsel the matter has been settled by controlling precedent, submit to a court of appropriate jurisdiction the question whether such indemnification by it is against public policy as expressed in the Act and will be governed by the final adjudication of such issue.

    Registration No. 333-273364

    Registration No. 333-273364

Pursuant to the requirements of the Securities Act of 1933, the Registrant has duly caused this Registration Statement on Form S-1 to be signed on its behalf by the undersigned, thereunto duly authorized, in the city of Milwaukee, on November 2, 2023.

Tidal Commodities Trust I

By: Tidal Investments LLC, Sponsor

By: Guillermo Trias

/s/ Guillermo Trias Date: November 2, 2023

Principal Executive Officer of Sponsor

Pursuant to the requirements of the Securities Act of 1933, this registration statement has been signed by the following persons in the capacities and on the dates as indicated. The document may be executed by signatories hereto on any number of counterparts, all of which shall constitute one and the same instrument. The undersigned members and officers of Tidal Investments LLC, the sponsor of Tidal Commodities Trust I, hereby constitute and appoint Guillermo Trias and Daniel Carlson, each of them with full power to act with full power of substitution and resubstitution, our true and lawful attorneys-in-fact with full power to execute in our name and behalf in the capacities indicated below this Registration Statement on Form S-1 and any and all amendments thereto, including post-effective amendments to this Registration Statement and to sign any and all additional registration statements relating to the same offering of securities as this Registration Statement that are filed pursuant to Rule 462(b) of the Securities Act of 1933, as amended, and to file the same, with all exhibits thereto and other documents in connection therewith, with the Securities and Exchange Commission and thereby ratify and confirm that such attorneys-in-fact, or any of them, or their substitutes shall lawfully do or cause to be done by virtue hereof.

Signature Title Date

Guillermo Trias

    Registration No. 333-273364

Daniel Carlson

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

5.1 Opinion of K&L Gates, LLP relating to the legality of the Shares

    Registration No. 333-273364

    Registration No. 333-273364

23.3 Consent of Grant Thornton LLP

    Registration No. 333-273364

Tidal Commodities Trust I S-1/A

    Registration No. 333-273364

    Registration No. 333-273364

    Registration No. 333-273364

Tidal Commodities Trust I

c/o Tidal Investments LLC

234 West Florida Street, Suite 203

Milwaukee, WI 53204

Re : Hashdex Bitcoin Futures ETF (the "Fund")

Ladies and Gentlemen:

We have acted as counsel to Tidal Commodities Trust I, a Delaware statutory trust (the "Trust"), in connection with the filing of a pre-effective amendment no. 1 to the Registration Statement on Form S-1 (the "Registration Statement"), to be filed with the U.S. Securities and Exchange Commission (the "Commission") on or about November 2, 2023, registering an unlimited number of shares of beneficial interest in the Fund (the "Shares") under the Securities Act of 1933, as amended (the "Securities Act").

This opinion letter is being delivered at your request in accordance with the requirements of paragraph 29 of Schedule A of the Securities Act and Item 16 of Form S-1 under the Securities Act.

For purposes of this opinion letter, we have examined originals or copies, certified or otherwise identified to our satisfaction, of:

    Registration No. 333-273364

    Registration No. 333-273364

We also have examined and relied upon certificates of public officials and, as to certain matters of fact that are material to our opinions, relied upon resolutions and other statements by Tidal Investments LLC, as sponsor of the Trust. We have not independently established any of the facts on which we have so relied.

For purposes of this opinion letter, we have assumed the accuracy and completeness of each document submitted to us, the genuineness of all signatures on original documents, the authenticity of all documents submitted to us as originals, the conformity to original documents of all documents submitted to us as facsimile, electronic, certified, conformed, or photostatic copies thereof, and the due execution and delivery of all documents where due execution and delivery are prerequisites to the effectiveness thereof. We have further assumed the legal capacity of natural persons, that persons identified to us as officers of the Trust are actually serving in such capacity, and that the representations of officers of the Trust are correct as to matters of fact. We have not independently verified any of these assumptions.

The opinions expressed in this opinion letter are based on the facts in existence and the laws in effect on the date hereof and are limited to the laws of the state of Delaware and the provisions of the Securities Act. We are not opining on, and we assume no responsibility for, the applicability to or effect on any of the matters covered herein of any other laws.

Based upon and subject to the foregoing, it is our opinion that (1) the Shares to be issued pursuant to the Registration Statement, when issued and paid for by the purchasers upon the terms described in the Registration Statement, will be validly issued, and (2) such purchasers will have no obligation to make any further payments for the purchase of the Shares or contributions to the Trust solely by reason of their ownership of the Shares.

This opinion is rendered solely in connection with the filing of the Registration Statement and supersedes any previous opinions of this firm in connection with the issuance of Shares. We hereby consent to the filing of this opinion with the Commission in connection with the Registration Statement and to the reference to this firm's name under the heading "Legal Matters" in the Registration Statement. In giving this consent, we do not thereby admit that we are experts with respect to any part of the Registration Statement within the meaning of the term "expert" as used in Section 11 of the Securities Act or the rules and regulations promulgated thereunder by the Commission, nor do we admit that we are within the category of persons whose consent is required under Section 7 of the Securities Act or the rules and regulations of the Commission promulgated thereunder.

Very truly yours,

[[Image Removed]]

Tidal Commodities Trust I S-1/A

    Registration No. 333-273364

[[Image Removed]]

November 2, 2023

Tidal Commodities Trust I

c/o Tidal Investments LLC

234 West Florida Street

Milwaukee, WI 53204

Re: Hashdex Bitcoin Futures ETF

Ladies and Gentlemen:

We have acted as counsel to Tidal Commodities Trust I, a Delaware statutory trust (the "Trust"), in connection with the preparation and filing with the Securities Exchange Commission (the "SEC") under the Securities Act of 1933, as amended, of a Registration Statement on Form S-1 (the "Registration Statement") relating to the registration of common units representing undivided beneficial interests ("Shares") in the series of the Trust designated as Hashdex Bitcoin Futures ETF (the "Fund").

In rendering this opinion, we have examined the Registration Statement and have reviewed and relied upon representations made to us by a duly authorized officer of Tidal Investments LLC, the sponsor of the Fund (the "Sponsor"), concerning the organization and operation of the Trust and the Fund, the nature of the Fund's annual gross income and certain other factual matters in a letter dated as of the date hereof (the "Representation Letter"), We have also examined such other agreements, documents and records and other materials as we have deemed necessary in order for us to render this opinion. In such review and examination, we have assumed the genuineness of all signatures, the legal capacity and authority of the parties who executed such documents, the authenticity of all documents submitted to us as originals, the conformity to originals of all documents submitted to us as copies and the authenticity of the originals so copied.

In addition, in rendering this opinion, we have relied upon and have assumed, with your permission, (i) the accuracy and completeness of the statements contained in the Registration Statement, (ii) that the Fund will operate at all times in the manner discussed in its organizational documents, the Prospectus included in the Registration Statement (the "Prospectus") and the Representation Letter, (iii) the accuracy and completeness of the facts, representations and assumptions set forth or referenced herein and (iv) that any representation qualified by knowledge, intention, belief, disclaimer of responsibility or any similar qualification is true, correct and complete without such qualification. You have not requested that we undertake, and we have not undertaken, any independent investigation of the accuracy of the facts, representations and assumptions set forth or referred to herein. Any inaccuracy or subsequent change in such facts, representations or assumptions could adversely affect our opinion.

K&L Gates LLP

One Congress Street Boston MA 02114

T +1 617 261 3100 F +1 617 261 3175 klgates.com

November 2, 2023

Page 2

Based upon and subject to the foregoing, we confirm that the discussion in the Registration Statement under the heading "U.S. Federal Income Tax Considerations," to the extent it consists of statements of U.S. federal income tax law and legal conclusions with respect thereto, and subject to the limitations and qualifications set forth therein, constitutes our opinion as to the material U.S. federal income tax consequences that will apply under currently applicable law to the purchase, ownership and disposition of the Shares.

Our opinion is based on, and is conditioned on the continued applicability of, the provisions of the Internal Revenue Code of 1986, as amended, and the Treasury Regulations thereunder, judicial decisions, and rulings and other pronouncements of the Internal Revenue Service ("Service") in existence on the date hereof. All the foregoing authorities are subject to change or modification that can be applied retroactively and thus also could affect the conclusions expressed herein; we assume no responsibility to update our opinion after the date hereof with respect to any such change or modification. Our opinion addresses only the specific federal income tax consequences set forth above and does not address any other federal, or any state, local, or foreign tax law issues. Our opinion represents our best judgment regarding how a court would decide the issues addressed herein and is not binding on the Service or any court. Moreover, our opinion does not provide any assurance that a position taken in reliance thereon will not be challenged by the Service, and although we believe that our opinion would be sustained by a court if challenged, there can be no assurances to that effect.

This opinion is furnished to the Fund for its benefit in connection with the Registration Statement and is not to be relied upon, for any other purpose, in whole or in part, without our express written consent. Shareholders of the Fund may rely on this opinion; it being understood that we are not establishing any attorney-client relationship with any shareholder of the Fund. This letter may not be relied upon for the benefit of any other person.

We hereby consent to the filing of this letter with the SEC as an exhibit to the Registration Statement and to the references to this letter and to us under the heading ""U.S. Federal Income Tax Considerations" in the Prospectus. In giving such consent, we do not hereby admit that we are within the category of persons whose consent is required under Section 7 of the Securities Act of 1933, as amended.

Very truly yours,

[[Image Removed]]

Tidal Commodities Trust I S-1/A

    Registration No. 333-273364

[[Image Removed]] taitweller.com

    Registration No. 333-273364

We consent to the incorporation by reference in the Registration Statement filed on Form S-1 by Tidal Commodities Trust I of our report dated October 30, 2023, relating to our audit of the Statement of Assets and Liabilities of the Hashdex Bitcoin Futures ETF, a series of Tidal Commodities Trust I, as of October 24, 2023, included in this Form S-1.

/s/ TAIT, WELLER & BAKER LLP

Philadelphia, Pennsylvania

November 1, 2023

    Registration No. 333-273364

Tait Weller - Philadelphia Office - O: 215.979.8800 - F: 215.979.8811 - Two Liberty Place - 50 S. 16th Street - Suite 2900 - Philadelphia, PA 19102-2529

    Registration No. 333-273364

Tidal Commodities Trust I S-1/A

    Registration No. 333-273364

CONSENT OF INDEPENDENT REGISTERED PUBLIC ACCOUNTING FIRM

We have issued our report dated March 1, 2023, with respect to the financial statements of Hashdex Bitcoin Futures ETF, a series of the Teucrium Commodity Trust contained in the Registration Statement and Prospectus. We consent to the use of the aforementioned report in the Registration Statement and Prospectus, and to the use of our name as it appears under the caption "Experts."

/s/ GRANT THORNTON LLP

New York, NY

November 2, 2023

COMTEX_442862179/2255/2023-11-02T19:40:31

(c) 1995-2023 Cybernet Data Systems, Inc. All Rights Reserved

EDGAR Online-Prospectus and Proxies
Tuesday, November 14, 2023 42100 mots, p. NA

424B3: Nexscient, Inc.

(EDGAR Online via COMTEX) --

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

There is no minimum number of shares that must be sold by us for the Offering to proceed, and we will retain the proceeds from the sale of any of the offered shares, except that we will not receive any proceeds from the sale of shares by Selling Shareholders. This Offering is being conducted on a "best efforts/no minimum" basis, meaning that no aggregate minimum offering amount is required to be raised by us in this Offering. As such, the actual public offering amount and proceeds to us, if any, are not presently determinable and net proceeds may be substantially less than the total maximum offering set forth above. The Offering is being self-underwritten, which means our officers and directors will attempt to sell the shares directly to friends, family members and business acquaintances. Our officers and directors will not receive commissions or any other remuneration from any such sales. In offering the securities on our behalf, our officers and directors will rely on the "safe harbor" provisions of SEC Rule 3a4-1, promulgated under the Securities Exchange Act of 1934, as amended (the "Exchange Act"). Generally speaking, Rule 3a4-1 provides an exemption from the broker-dealer registration requirements of the Exchange Act for persons associated with an issuer that participate in the sale of the securities of such issuer. We are an "emerging growth company" under applicable Securities and Exchange Commission rules and will be subject to reduced public company reporting requirements.

The shares will be offered for sale at a fixed price of $0.75 per share for a period of one hundred and eighty (180) days from the effective date of this Prospectus, unless extended by our Board of Directors for an additional 90 days. If all of the shares offered by us are purchased, the gross proceeds to us will be $3,000,000. All funds raised hereunder will become immediately available to the Company and will be used in accordance with the Company's intended "Use of Proceeds" as set forth herein. Investors are advised that they will not be entitled to a refund and could lose their entire investment.

The Company is a development stage company and currently has limited operations. Any investment in the shares offered herein involves a high degree of risk. You should only purchase shares if you can afford a loss of your investment. Our independent registered public accountant has issued an audit opinion for the Company, which includes a statement expressing substantial doubt as to our ability to continue as a going concern.

This Prospectus covers the primary public offering by the Company of 4,000,000 shares of Common Stock. The Company is concurrently conducting a resale offering for 7,682,980 shares of Common Stock, which is covered in a separate Resale Prospectus.

THE PURCHASE OF THE SECURITIES OFFERED THROUGH THIS PROSPECTUS INVOLVES A HIGH DEGREE OF RISK. YOU SHOULD CAREFULLY READ AND CONSIDER THE SECTION OF THIS PROSPECTUS ENTITLED "RISK FACTORS" BEFORE BUYING ANY SHARES OF NEXSCIENT'S COMMON STOCK.

NEITHER THE SECURITIES AND EXCHANGE COMMISSION NOR ANY STATE SECURITIES COMMISSION HAS APPROVED OR DISAPPROVED OF THESE SECURITIES OR PASSED UPON THE ADEQUACY OR ACCURACY OF THIS PROSPECTUS. ANY REPRESENTATION TO THE CONTRARY IS A CRIMINAL OFFENSE.

    Filed Pursuant to Rule 424(b)(3)

Table of Contents

No dealer, salesperson or any other person is authorized to give any information or make any representations in connection with this offering other than those contained in this Prospectus and, if given or made, the information or representations must not be relied upon as having been authorized by us. This Prospectus does not constitute an offer to sell or a solicitation of an offer to buy any security other than the securities offered by this Prospectus, or an offer to sell or a solicitation of an offer to buy any securities by anyone in any jurisdiction in which the offer or solicitation is not authorized or is unlawful.

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

This Registration Statement contains two prospectuses, as set forth below.

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

The Resale Prospectus is substantively identical to the Public Offering Prospectus, except for the following principal points:

? they contain different outside and inside front covers; ? they contain different Offering sections; ? they contain different Use of Proceeds sections; ? a Selling Shareholders section is included in the Resale Prospectus; ? they contain different Plan of Distribution sections; ? the Dilution section is deleted from the Resale Prospectus; ? they contain different outside back covers.

The Registrant has included in this Registration Statement, after the financial statements, a set of alternate pages to reflect the foregoing differences of the Resale Prospectus as compared to the Public Offering Prospectus.

    Filed Pursuant to Rule 424(b)(3)

Table of Contents

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

You should rely only on the information contained or incorporated by reference to this prospectus in deciding whether to purchase our common stock. We have not authorized anyone to provide you with information different from that contained or incorporated by reference to this prospectus. Under no circumstances should the delivery to you of this prospectus or any sale made pursuant to this prospectus create any implication that the information contained in this prospectus is correct as of any time after the date of this prospectus. To the extent that any facts or events arising after the date of this prospectus, individually or in the aggregate, represent a fundamental change in the information presented in this prospectus, this prospectus will be updated to the extent required by law.

    Filed Pursuant to Rule 424(b)(3)

Table of Contents

    Filed Pursuant to Rule 424(b)(3)

The following summary highlights material information contained elsewhere in this prospectus. This summary does not contain all of the information you should consider before investing in our common stock. Before making an investment decision, you should read the entire prospectus carefully, including the "Risk Factors" section, the "Management's Discussion and Analysis of Financial Condition and Results of Operations" section, the financial statements and the notes to the financial statements. You should also review the other available information referred to in the section entitled "Where You Can Find More Information" in this prospectus and any amendment or supplement hereto. Unless otherwise indicated, the terms the "Company," "Nexscient," "we," "us," and "our" refer and relate to Nexscient, Inc.

Corporate History and General Information about the Company

Nexscient, Inc. (the "Company") is an early-stage company, which was incorporated in the State of Delaware on March 14, 2023. Our fiscal year-end is June 30. We are a development stage enterprise. The Company is engaged in the business of developing and commercializing a Software as a Service platform that exploits Industrial Internet-of-Things (IIoT), Artificial Intelligence (AI), and Cloud-computing technologies to deliver an innovative solution for manufacturers and continuous production facilities in the industrial automation sector that helps reduce equipment failures, avoid unscheduled downtimes, decrease equipment maintenance costs, and improve overall equipment efficiencies.

The Company has not yet developed its software platform and generated no revenues to date. Most of management's time, and the Company's limited resources have been spent on research and development of the Company's condition monitoring and predictive analytics platform and developing its business strategy.

Our principal office is located at 2029 Century Park East, Suite 400, Los Angeles, CA 90067. Our telephone number is (310) 494-6620 and our e-mail contact is [email protected]. Our website can be viewed at https://nexscient.com/. The Company has not filed for bankruptcy, receivership or any similar proceedings nor is in the process of filing for bankruptcy, receivership or any similar proceedings.

Company Overview

The Company was incorporated in the State of Delaware on March 14, 2023. We intend to offer of a continuous, remote condition-based monitoring solution for manufacturers and continuous production facilities seeking to implement a Predictive Maintenance (PdM) program. Our platform intends to leverage the latest IIoT technology with edge processing, machine-learning/AI algorithms, and Cloud computing infrastructure to collect, diagnose and transmit critical information about machine health and performance. Unlike other condition-monitoring programs on the market today, we plan to take a unique approach by offering a remote, continuous monitoring solution that is autonomous and machine agnostic with no equipment purchase requirement. Designed as a scalable, stand-alone solution, our solution does not depend on integration with any control or IT system for its data source. Our design plans to utilize a mesh network of data collection nodes that are externally-mounted to the outer casing of the equipment being monitored and data is collected via three on-board sensors, including acoustic, vibration and temperature. Compatible with virtually all rotating machinery, regardless of age, make, model or condition, the nodes collect and securely transmit pertinent data from the on-board sensors via a secure gateway to our Cloud-based analytics platform for processing and diagnosis.

Nexscient Cloud software intends to use rule-based logic, which incorporates anomaly detection and domain-level expertise to analyze the data and deliver immediate actionable insights and corrective recommendations without the reliance upon a large historical data set. Our initial deployment of the system will rely primarily on rule-based anomaly detection. Critical information about the machine's health and performance are processed and analyzed in real-time. Advance-warning alerts of impending issues are generated and transmitted to select maintenance personnel with recommended corrective procedures delivered as work orders.

Contemporaneously, the data collected from each Nexscient Node will be processed and stored in our data lake so that over time we will have aggregated sufficient amounts of data to train machine learning algorithms to build predictive models that can be used in the future releases as an enhancement to our service offering. Future enhancements to the Nexscient system will leverage our machine learning/AI models to perform long-term assessments, such as root cause analysis and estimate remaining useful life.

An intuitive user interface displaying detailed information about alert conditions can be viewed for further investigation, via a Web browser or mobile device. Our distinct advantage is realized through our ability to rapidly deploy a continuous remote monitoring solution that produces actionable insights with highly accurate predictions of incipient failures well in advance of their occurrence.

We believe Nexscient will offer significant improvements and innovations to be brought to the growing market for predictive maintenance by substantially improving efficacy, safety and cost. We expect to drastically simplify the implementation of Predictive Maintenance programs by offering its machine health monitoring solution as a subscription-based service. We intend to generate revenues initially through our subscription service and may generate additional revenues from premium service offerings as well as consulting services that will be offered directly to customers.

The proceeds of the Offering will largely be utilized for development and commercialization of the Nexscient Predictive Maintenance Platform, marketing of the service and software platform, and payroll expenses. The Company plans to retain five full time staff and lease nominal executive office facilities in Los Angeles, California. All legal, accounting, and shareholder relations may be outsourced to consultants as needed. Business development is limited to developing and maintaining a website presence, and nominal travel and business expenses.

    Filed Pursuant to Rule 424(b)(3)

Table of Contents

Competition

We compete with an array of established and emerging vendors of condition-based monitoring products and services and IIOT-equipped devices. As organizations increasingly embrace predictive maintenance, IIoT and other new industrial automation technologies, an increasing number of companies offering machine monitoring products and services strive could result to fill the growing demand. The introduction of new technologies and market entrants will continue to fuel an intense competitive environment as companies seek solutions to predicting equipment failures and maintaining equipment performance. Our competitors include condition-based monitoring equipment vendors, diversified diagnostic equipment and services vendors, and providers of machine monitoring products that compete with some of the features present in our solution such as Fluke, Emerson, and Augury. We compete based on several factors, including product functionality; scope of offerings; performance; brand, reputation, and customer satisfaction; ease of implementation, use and service; price, scalability, reliability, and security. We believe that we will compete favorably with respect to these factors and are well positioned as an emerging provider of predictive maintenance solution, data analysis, and professional services.

Background

The Company had its genesis in Spring 2022 when our team of seasoned entrepreneurs and engineers with relevant backgrounds and experience in engineering, finance, and wireless communications, came together for the purpose of developing and commercializing a monitoring solution to exploit the benefits of acoustic and vibration analysis coupled with Industrial Internet of Things (IIOT), wireless mesh communications, Machine Learning/Artificial Intelligence (AI), and Cloud computing to address unmet needs of predictive equipment maintenance.

Industrial Internet of Things (IIoT)

The Internet of Things (IoT) refers to the network of physical objects or "things" embedded with sensors, software, and other technologies, interconnected through various communication protocols, networks, and cloud-based platforms. These interconnected objects collect and exchange data, enabling them to interact with the external environment or other systems in an intelligent manner. The Industrial Internet of Things (IIoT) is a transformative manufacturing strategy that integrates advanced digital technologies into the industrial sector to enhance operational efficiencies, improve performance, and create new revenue models. IIoT is an extension of the Internet of Things (IoT) paradigm, specifically tailored to industrial contexts, encompassing sectors including manufacturing, energy, oil and gas, and transportation.

Artificial Intelligence (AI) & Machine Learning (ML)

Artificial Intelligence (AI) is a branch of computer science focused on creating systems capable of performing tasks that would typically require human intelligence. These tasks include, but are not limited to, problem-solving, understanding natural language, perception (such as vision or speech recognition), and decision-making. AI systems are designed to mimic or simulate human cognitive functions, and they can operate either based on predefined rules (via algorithms) or by learning from data. Machine Learning is a subset of AI that provides systems the ability to learn and improve from experience without being explicitly programmed. In essence, ML focuses on the development of algorithms that can process vast amounts of data, derive patterns from this data, and then make decisions or predictions based on it.

Cloud Computing

Cloud computing is a technology paradigm that provides scalable, on-demand computing resources, delivered as a service over the internet. Instead of owning and maintaining physical data centers and servers, businesses can rent access to anything from applications to storage from a cloud service provider. This offers flexibility, cost-effectiveness, and the ability to scale services according to the need of the user. In the case of Nexscient, we intend to leverage cloud computing to offer Software as a Service (SaaS) to deliver our software solution over the Internet on a subscription basis, which will be hosted and maintained "in the cloud," thus eliminating the need for users to install or maintain the software locally.

While vibration analysis offered tremendous benefits for identifying potential problems with rotating machinery, we found that the vast majority of products on the market require a sizable capital investment with the purchase of diagnostic equipment and accessories; licensing, installation and upkeep of proprietary software; and specialized training of personnel. Furthermore, because of the manual nature of route-based, condition monitoring systems currently utilized methods, maintenance staff must patrol the factory on a regular basis, typically in 30 to 40-day intervals to manually collect measurement readings from the machines and then has to spend time for reviewing and analyzing the collected data.

Realizing the shortcomings of most existing products on the market and understanding that significant benefits of condition monitoring can truly be realized through an efficient, streamlined, and cost-effective solution, we decided to take a unique approach by developing a continuous monitoring solution as a subscription-based service - one that not only offered all of the benefits of condition-based monitoring diagnostic system through vibration and acoustic analysis, but also offered those benefits with (i) no upfront capital expense of equipment and software purchases; (ii) no need to update and maintain and update purchased diagnostic equipment and software, (iii) no requirement for specialized training of maintenance personnel; and (iv) no need for licensing, maintaining, and updating software. From a financial perspective, our solution is more affordable because it does not require upfront investment and shifts what would be a capital expenditure to an operating expense for the customer. For the Company, our business model provides a pathway to profitability through recurring stream of revenues that can be realized through a growing base of subscribers and subscriptions.

Our Growth Strategy

We believe the Nexscient Predictive Maintenance solution will be viewed by businesses as a cost-effective way to reduce maintenance costs while increasing productivity, giving them advance warning of potential machine failure allowing them to properly schedule maintenance and better manage their resources. One of the key differentiators in our marketing strategy is to emphasize the "no up-front cost" subscription feature because we provide all of the monitoring sensors as part of the subscription service, thereby eliminating a capital expenditure to the business's balance sheet. Management will emphasize speed in penetrating selected markets and implementing advertising and public relations campaigns. Financial results will be compiled and reported weekly so that gross and net margins can be reviewed and benchmarked against the competition. Marketing will be continually monitored and adjusted as needed to maximize market penetration and profitability. Cost control and brand management will be critical to the overall strategy.

Large untapped markets in Asia-Pacific and Middle East could offer growth opportunities to market players. The condition-based monitoring market in Asia-Pacific is displaying strong growth due to continuous infrastructure development and business expansions, especially in emerging countries, mainly China and India. The deregulation policy and a substantial increase in foreign direct investments (FDIs) in Asian countries also triggered the establishment of new businesses across many industries in the Asia-Pacific region. Moreover, the countries in the Middle East, primarily Saudi Arabia and Qatar, are also increasing the use of condition-based monitoring in the oil and gas sector.

    Filed Pursuant to Rule 424(b)(3)

Table of Contents

Recent Developments

On July 12, 2023, the Board appointed Mr. Michael J. Portera as a director and Chief Financial Officer of the Company.

Risks and Uncertainties facing the Company

As an early-stage company with a limited operating history, the Company has experienced losses since its inception. The Company's independent auditors have issued a report questioning the Company's ability to continue as a going concern. That is, the Company needs to create a source of revenue or locate additional financing in order to continue its developmental plans. As a development stage company, management of the Company has experience in developing technology similar to that planned by the Company but limitation in marketing and distributing such services and products on a broad scale.

One of the biggest challenges facing the Company is the ability to increase its sales revenue and raise adequate capital to develop and execute project opportunities.

Due to financial constraints, the Company has to date conducted limited operations. If the Company were unable to develop strong and reliable sources of funding for future growth opportunities, it is unlikely that the Company could develop its operations to return revenue sufficient to further develop its business plan. Moreover, the above assumes that the Company's efforts are met with customer satisfaction in the marketplace and exhibit steady adoption of its solutions amongst the potential base of customers, neither of which are currently known or guaranteed.

Due to these and other factors, the Company's need for additional capital, the Company's independent auditors have issued a report raising substantial doubt of the Company's ability to continue as a going concern.

Trading Market

Currently, there is no trading market for the securities of the Company. The Company intends to initially apply for admission to quotation of its securities on the OTC Bulletin Board as soon as possible, which may be while this offering is still in process. There can be no assurance that the Company will qualify for quotation of its securities on the OTC Bulletin Board. See "RISK FACTORS" and "DESCRIPTION OF SECURITIES".

    Filed Pursuant to Rule 424(b)(3)

Table of Contents

    Filed Pursuant to Rule 424(b)(3)

The Issuer Nexscient, Inc.

Securities being Up to 4,000,000 shares of Common Stock is being offered for offered sale by the Company, this collectively represents approximately 16.7% of the currently issued and outstanding shares of the Company's Common Stock, if the offering is fully subscribed. Our Common Stock is described in further detail in the section of this prospectus titled "DESCRIPTION OF SECURITIES."

Per Share $0.75 Offering Price

Duration of The Shares are offered for a period of one hundred and eighty Offering (180) days from the effective date of this Prospectus, unless extended by our Board of Directors.

Common stock There are 19,955,980 shares of Common Stock issued and outstanding outstanding. before the Offering Assuming we sell all of the shares of common stock in this Offering, there will be 23,955,980 shares of Common Stock Common stock issued and outstanding. outstanding after the Offering

Net Proceeds to We will receive net proceeds of $3,000,000 if the offering is the Company fully subscribed for all 4,000,000 shares of Common Stock at an offering price of $0.75 per Share. The full subscription price will be payable at the time of subscription and accordingly, funds received from subscribers in this Offering will be released to the Company when subscriptions are received and accepted. No assurance can be given that the net proceeds from the total number of shares offered hereby or any lesser net amount will be sufficient to accomplish our goals. If proceeds from this offering are insufficient, we may be required to seek additional capital. No assurance can be given that we will be able to obtain such additional capital, or even if available, that such additional capital will be available on terms acceptable to us.

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

Table of Contents

    Filed Pursuant to Rule 424(b)(3)

An investment in our Common Stock involves a high degree of risk. You should carefully consider the risks described below and the other information in this Prospectus before investing in our Common Stock. If any of these risks actually occur, our business, financial condition and results of operations could be materially and adversely affected and we may not be able to achieve our goals, the value of our securities could decline and you could lose some or all of your investment. Currently, shares of our Common Stock are not publicly traded. In the event that shares of our Common Stock become publicly traded, the trading price of our Common Stock could decline due to any of these risks, and you may lose all or part of your investment. In the event our Common Stock fails to become publicly traded, you may lose all or part of your investment. Additional risks not presently known to us or that we currently believe are immaterial may also significantly impair our business operations. Some statements in this prospectus, including statements in the following risk factors, constitute forward-looking statements. Please refer to the section titled "Cautionary Statement Regarding Forward-Looking Statements."

    Filed Pursuant to Rule 424(b)(3)

Investing in the Company is a highly speculative investment and could result in the loss of your entire investment.

A purchase of the offered securities is significantly speculative and involves significant risks. The offered securities should not be purchased by any person who cannot afford the loss of his or her entire purchase price. The business objectives of the Company are also speculative, and we may be unable to satisfy those objectives. The stockholders of the Company may be unable to realize a substantial return on their purchase of the offered securities, or any return whatsoever, and may lose their entire investment in the Company. For this reason, each prospective purchaser of the offered securities should read this prospectus and all of its exhibits carefully and consult with their attorney, business advisor and/or investment advisor.

The offering price of the offered securities has been arbitrarily determined by the Company and such offering price should not be used by an investor as an indicator of the fair market value of the offered securities.

Currently there is no public market for the Company's common stock. The offering price for the offered Shares has been arbitrarily determined by the Company and does not necessarily bear any direct relationship to the assets, operations, book, or other established criteria of value of the Company. Thus, an investor should be aware that the offering price does not reflect the fair market price of the offered securities.

As there is no minimum for our offering, if only a few persons purchase shares, they could lose their investment.

Since there is no minimum with respect to the number of securities to be sold directly by the Company in this Offering, if only a few Shares are sold, we may not have enough capital to sustain our business. In such an event, it is highly likely that any investment would be lost. As such, proceeds from this Offering may not be sufficient to meet the objectives we state in this Prospectus, other corporate milestones that we may set, or to avoid a "going concern" modification in future reports of our auditors as to uncertainty with respect to our ability to continue as a going concern. If we fail to raise sufficient capital, we expect to have to significantly decrease operating expenses, which will curtail the growth of our business.

The Company's management has full discretion in allocating net proceeds from the Offering.

We have allocated the net proceeds of the Offering in the sum of $3,000,000 (assuming the sale of all 4,000,000 shares of Common Stock) to working capital and operational expenses of the Company. As to such funds, investors will be relying on the judgment and discretion of the Company's management without specific information as to the uses, which are proposed to be made of such funds. Further, we may use any portion of the net proceeds of the Offering to acquire and/or invest in businesses related to the business of the Company (see "Use of Proceeds").

Investors in the offering will experience immediate dilution of the value of their shares.

Purchasers of the Shares will experience immediate dilution in the value of their Shares. Dilution represents the difference between the price per share paid by investors and the net tangible book value per share immediately after completion of the Offering (see "Dilution"). Net tangible book value per share is the net tangible assets of the Company (total assets less total liabilities less intangible assets), divided by the number of shares of common stock outstanding. As of June 30, 2023, the Company's net tangible book value before the Offering was $0.01 per share. Thus, if at some other time, shares had been sold by the Company at a price less than the $0.75 paid by purchasers of the Shares or had been issued by the Company for services or as other non-cash consideration, then the value of such investor Shares immediately after purchase would be less than the purchase price. The Company has issued shares prior to the date of this Prospectus at a price less than $0.75. In addition to the dilution described above, further dilution may result if additional shares of Common Stock are sold or issued in the future, including shares issued in connection with any subsequent financing or initial public offering.

    Filed Pursuant to Rule 424(b)(3)

Table of Contents

There is no firm commitment underwriting for the Offering.

We do not have a firm commitment underwriting for the Offering. The Company is offering its Shares for sale through its officers and directors on a "self-underwritten", "best efforts" basis without compensation. Accordingly, there is no assurance that we will sell the maximum Shares offered or any amount. If all of the Shares offered hereby are not sold, the Company will be limited in its ability to conduct its business.

    Filed Pursuant to Rule 424(b)(3)

We have a limited history of operations and unless we are able to successfully execute our business plan, our business and operating results will suffer, resulting in the complete failure of our business.

Nexscient, Inc. is a start-up company with limited assets and limited operating history. As such, we face the risks and problems associated with any business in its early stages with a limited operating history on which an evaluation of its prospects can be made. The likelihood of our success must be considered in light of the risks, problems, expenses and delays frequently encountered in connection with the formation of a new business in general, as well as the highly competitive environment in which the business is operating. To address these risks, we must, among other things, continue to respond to competitive developments, attract, retain and motivate qualified personnel, commercialize products, and implement and successfully execute our marketing strategy and advertising sales strategy. There can be no assurance that we will be successful in addressing such risks.

Our ability to operate the business successfully is dependent, in part, on a variety of factors, including our ability to expand our operations into new geographic areas as well as into existing and/or new market niches within our industry. In addition, the rate of growth may be dependent upon our ability to identify and negotiate favorable deals with strategic partners that will assist the Company in the development, marketing and sales of its products and services. There can be no assurance regarding whether or when we will implement the business plan successfully or that we will achieve profitability.

The Company has limited operating history of its own, and as such, any prospective investor can only assess the Company's profitability or performance on a limited basis to date.

Because the Company is an early-stage company with limited operating history, it is impossible for an investor to assess the performance of the Company or to determine whether the Company will meet its projected business plan. The Company has limited financial results upon which an investor may judge its potential. As a development-stage company, the Company may in the future experience under-capitalization, shortages, setbacks and many of the problems, delays and expenses encountered by any early-stage business. An investor will be required to make an investment decision based solely on the Company management's history and its projected operations in light of the risks, expenses and uncertainties that may be encountered by engaging in the Company's industry.

The Company has no revenues to date.

The Company has generated no revenues to date. Most of management's time, and the Company's limited resources have been spent on research and development of the Company's condition monitoring and predictive analytics platform and developing its business strategy. Most of the activity has been centered in the following areas: researching potential opportunities, preparing a business model, hiring software development consultants and programmers, working with software developers and programmers, working with engineers and manufacturers of sensors and related hardware apparatus, selecting professional advisors, bookkeeping, accounting, corporate record keeping, seeking capital for the Company, and preparing this registration statement.

The proposed operations of the Company are speculative; there are no assurances that we will receive any revenue.

The success of the proposed business plan of the Company will depend to a great extent on the operations, financial condition, and management of the Company. Although the Company has a business plan and intends to execute its overall business strategy, limited operations have been conducted to date and the proposed operations of the Company remain speculative. Technology development generally may continue for years before any revenue is realized or generated, if at all.

    Filed Pursuant to Rule 424(b)(3)

Table of Contents

Our current research and development efforts may not produce successful products or enhancements to our platform that result in significant revenue, cost savings or other benefits in the near future, if at all.

We must continue to dedicate significant financial and other resources to our research and development efforts if we are to maintain our competitive position. However, developing products and enhancements to our platform is expensive and time consuming, and there is no assurance that such activities will result in significant new marketable products or enhancements to our platform, design improvements, cost savings, revenue, or other expected benefits. If we spend significant resources on research and development and are unable to generate an adequate return on our investment, our business and results of operations may be materially and adversely affected.

The Company depends on its management team and employees to operate its business effectively.

The Company's future success is dependent in large part upon its ability to understand and develop the business plan and to attract and retain highly skilled management, operational and executive personnel. In particular, due to the relatively early stage of the Company's business, its future success is highly dependent on its officers, to provide the necessary experience and background to execute the Company's business plan. We presently expect each of our officers and directors to devote such amount of time as they reasonably believe is necessary to our business; our officers are currently working full time for the Company. We do not know if we would be able to replace the key executives and personnel with equally competent people in the event their services become unavailable (see "Management"). The loss of any officer's services could impede, particularly initially as the Company builds a record and reputation, its ability to develop its objectives, particularly in its ability to develop, commercialize and further its business and products.

The Company's business also depends on its ability to attract and retain talented software developers, engineers, product marketing and sales professionals. Any loss of key members of the team and the customer relationship associated with the member can impact the business significantly.

The Company expects to incur additional expenses and may ultimately never be profitable.

The Company is a development-stage company and it has limited operations to date. The Company will need to continue to generate revenue to achieve and maintain profitability. To become profitable, the Company must successfully develop its product sales and operate its business. These processes involve many factors that are beyond the Company's control, including the type of competition that the Company may encounter. Ultimately, in spite of the Company's best or reasonable efforts, the Company may never actually generate revenues sufficient to cover operating expenses or become profitable.

Costs associated with our business, including software development and programming costs are not fixed and might increase, creating uncertainty about our ability to meet our plan of operations.

We have not established long-term contracts with our consultants or other third-party suppliers we intend to rely on. The lack of long-term contracts could result in an increase in what we pay these individuals for their services. An increase in the development costs will reduce our margins and might make our projects uneconomical, leading to the failure of our business.

We are in the development stage and have conducted no market research on the viability of our products or services. There is no guarantee that we will be able to sell enough of our products or services to generate a profit, and failure to become profitable will result in the failure of our business.

The market for our products and services is limited in scope and there is no assurance that our products or services will generate market acceptance and result in revenue. We are developing our products and services with no market research and there is no assurance that we will be able to respond to the rapidly evolving markets in the industrial automation market. The inability to sell our products or services will result in the failure of our business.

No assurance of market acceptance.

Even if the Company successfully markets, sells, and distributes its technology, products and services, there can be no assurance that the market reception will be positive for the Company or its offerings. The widespread adoption and use of the Company's condition monitoring products and services will represent fundamental change in the industrial automation industry. As with any new technology, there is a substantial risk that potential customers may not accept the potential benefits of the Company's products or services. Market acceptance of Company's products will depend, in large part, upon the ability of Company to demonstrate the performance advantages and cost-effectiveness of its products over competing products. There can be no assurance that Company will be able to market its technology successfully on a widespread basis or that any of Company's current or future products or services will be accepted in the marketplace. Furthermore, Company intends to develop products and systems and sell them at a price assumed by Company sufficient to generate a profit. Even if Company's products and services are accepted in the industry, the market for its products may not be able to support Company's pricing structure.

10

Table of Contents

If the prices we charge for our services are unacceptable to our customers, our operating results will be harmed.

As the market for our services matures, or as new or existing competitors introduce new products or services that compete with ours, we may experience pricing pressure and be unable to renew our agreements with existing customers or attract new customers at prices that are consistent with our pricing model and operating budget. If this were to occur, it is possible that we would have to change our pricing model or reduce our prices, which could harm our revenue, gross margin, and operating results.

If the Company is unable to develop and introduce new products and improvements, the Company may be unable to compete in the marketplace.

The market for the Company's condition monitoring products and services is characterized by evolving industry requirements. Accordingly, the Company's future performance depends on a number of factors, including its ability to identify emerging technological trends in its target markets, to develop and maintain competitive products, to enhance its products by adding innovative features that differentiate the Company's products from those of its competitors, and to manufacture and bring products to market quickly at cost-effective prices. There can be no assurance, however, that the Company will successfully complete the development of any products, that such products will achieve market acceptance that such products will receive regulatory approvals where required, that any required regulatory approvals will be received in a timely manner, or that such products can be produced at competitive prices, or at all. In the event that its products are not timely developed, do not gain market acceptance or cannot be manufactured at competitive prices, the Company's business could be materially adversely affected.

Rapid growth will place a significant strain on our managerial, operational, and financial resources.

If we grow as planned, our growth will place a significant strain on our managerial, operational, and financial resources. To accommodate this growth, we must implement new or upgraded operating and financial systems, procedures and controls. We may not succeed in these efforts. Our failure to expand and integrate these areas in an efficient manner could have a material adverse effect on our business, financial condition, and results of operations. To develop our products and achieve success, we may need to identify, recruit, hire, and train a significant number of employees, particularly employees with relevant technical, marketing and sales backgrounds. These individuals are in high demand. We may not be able to attract such personnel. This could have a material adverse effect on the Company's business, financial condition, and results of operations.

The Company's growth strategy through acquisitions may present additional risks.

From time-to-time Nexscient may undertake acquisitions consistent with its stated growth strategy. The successful implementation of acquisitions will depend on a range of factors including funding arrangements, geographic issues, staff continuity, compatibility of equipment and infrastructure and regulatory requirements. To the extent that acquisitions are not successfully integrated with the Company's then existing businesses, the financial position and performance of the Company could be adversely affected. Depending on various factors affecting our business at the time of any future acquisition such as the Company's share price, its financial position and performance and the nature of the acquisition, management may decide that it is in the best interests of the Company and its shareholders to fund the acquisition through the issue of further shares. If this were to occur, it may result in dilution of the ownership interests of its shareholders.

We may need to acquire licensing rights to certain proprietary technologies.

The Company may acquire licensing rights to certain technologies protected by patents and patents pending as part of its product development business plan. Our success will depend in significant part on our ability to obtain and maintain meaningful licenses for such patented and proprietary technologies. Patent law relating to the scope of claims in the technology fields in which we will license is still evolving. The degree of future protection for our licensed proprietary rights is uncertain. We will rely on license agreements to protect a significant part of the licensed intellectual property and to enhance our competitive position. While, we presently do not hold any licenses to patents or technologies pending patent applications, there is no assurance that will be able to obtain such licenses on terms acceptable to the Company. If we fail to obtain licenses for proprietary technologies, our ability to be commercially competitive will be materially impaired.

Production and manufacturing of our Nodes will be outsourced to a third-party contract manufacturer. We are also exploring other potential joint venture options for sourcing Nodes. If we don't secure such contract manufacturer or establish a joint venture arrangement with a supplier to produce and deliver Nodes in a timely manner for any reason, our business, prospects, financial condition and results of operation could be materially harmed.

11

Table of Contents

While we initially intend to integrate nodes purchased from a third-party supplier, we plan to design and integrate our nodes at some point in the future. When we do, we expect to outsource the manufacturing of the Nexscient Nodes to a third-party contract manufacturer, which we may heavily rely upon. We are also exploring other potential joint venturing options with suppliers of nodes, in addition to the contract manufacturer. Collaboration with third parties, including joint ventures, for the manufacturing of Nodes is subject to risks that may be outside of our control. While we have a preliminary verbal understanding with a third-party contract manufacturer and joint venture partner, we have not entered into a legally binding definitive agreement with either the contract manufacturer or such joint venture partner. Failure to reach a memorandum of understanding and cooperation agreement or pursue other commercial arrangements (such as contract manufacturing or sale agreement) on terms acceptable to the Company at any time before any definitive agreements are signed may limit or have a material adverse effect on the Company and its ability to offer its services.

In addition, we may experience delays if such third-party contract manufacturing or joint venture partner does not meet agreed upon timelines or experiences capacity constraints. There is risk of potential disputes with business partners, and the Company could be affected by adverse publicity related to its business partners, whether or not such publicity is related to their collaboration with the Company. Our ability to successfully build a premium brand could also be adversely affected by perceptions if the quality of the third-contract manufacturing partners or joint venture's products not related to the Company's products are questioned. Furthermore, there can be no assurance that the Company will successfully ensure its manufacturing partners or joint ventures maintain appropriate quality standards, with any failure to do so adversely affecting quality, function, and customers' perceptions of the Company's products and services.

If we experience delays, disputes or other difficulties with third-party manufacturers or joint ventures partners that the Company outsources orders to, there can be no assurance that it would be able to engage other third parties or to establish or expand its own production capacity to meet the needs of its customers in a timely manner or on acceptable terms, or at all. The expense and time required to complete any transition, and to assure that Nexscient Nodes manufactured at facilities of new manufacturers comply with the Company's design standards and other requirements may be greater than anticipated. Any of the foregoing could adversely affect our business, results of operations, financial condition and prospects.

To date, we have not generated revenues from operations, and we may have additional capital requirements to continue our operations, but they might not be available to us on favorable terms or at all, and if unavailable our ability to run our business will be impaired.

As of the date of this registration statement, we have limited working capital. As a result, it is impossible to expand our operations and we are totally dependent upon this Offering to sustain and grow our business. Although this registration statement contemplates raising $3,000,000, there is no assurance that this amount can be raised. If we were to only receive the minimum amount for this Offering, we would not have sufficient capital to fully implement our business strategy and would have to stagger our development. This Offering is being conducted on a "best efforts/no minimum" basis, meaning that no aggregate minimum offering amount is required to be raised by us in this Offering in order for the Offering to proceed. Assuming the sale of all 4,000,000 shares of common stock hereunder, the proceeds will be utilized over the next twelve months as specified in "Use of Proceeds." We will require additional capital and resources to implement the growth strategies set forth in this registration statement. Adequate funds for the Company's future operating or capital needs, whether from additional financing, collaborative arrangements with joint venture partners, or other sources, may not be available when needed or on favorable terms, which would severely limit the company's growth. If we are unable to generate sufficient revenues to cover operating expenses or raise additional funds, we are unlikely establish or maintain our business operations. We currently have no other plans or arrangements to raise capital for our business except for this Offering.

The Company's success is dependent on current management, who may be unable to devote sufficient time to the development of the Company's business plan, which could cause the business to fail.

The Company is heavily dependent on the management experience of our officers and directors. Currently there are no employment contracts by and between any officer/director/employee of the Company. If the Company lost any of its officers or directors, it would negatively impact and delay operations and there is no assurance that suitable replacements could be found. Currently, our officers are devoted full-time to the Company, but may not be able to continue to devote their full-time to the development of the Company's business plan unless this Offering is successful. If management is required to find outside employment, they may not have sufficient time to devote to the Company and we would be unable to develop our business plan, resulting in the failure of our business.

Some of our officers and directors presently have additional interest or affiliation to other businesses, and accordingly, may have conflicts of interest in their determination as to how much time to devote to our affairs.

Some of our officers and directors will allocate their time to other businesses thereby causing conflicts of interest in their determination as to how much time to devote to our affairs. This conflict of interest could have a negative impact on our ability to conduct our business.

12

Table of Contents

The Company has a correspondingly small financial and accounting organization. Being a public company may strain the Company's resources, divert management's attention and affect its ability to attract and retain qualified officers and directors.

The Company is an early-stage company with no developed finance and accounting organization and the rigorous demands of being a public company require a structured and developed finance and accounting group. Once it becomes a public reporting company, the Company will become subject to the reporting requirements of the Securities Act of 1933 and Securities Exchange Act of 1934, under which we intend to register in the future and regulations promulgated thereunder, which entail significant accounting, legal and financial compliance costs which may be prohibitive to the Company as it develops its business plan, services and scope. These costs have made, and will continue to make, some activities more difficult, time consuming or costly and may place significant strain on its personnel, systems and resources.

The Securities Exchange Act requires, among other things, that companies maintain effective disclosure controls and procedures and internal control over financial reporting. In order to maintain the requisite disclosure controls and procedures and internal control over financial reporting, significant resources and management oversight are required. As a result, management's attention may be diverted from other business concerns, which could have a material adverse effect on the development of the Company's business, financial condition and results of operations.

These rules and regulations may also make it difficult and expensive for the Company to obtain director and officer liability insurance. If the Company is unable to obtain adequate director and officer insurance, its ability to recruit and retain qualified officers and directors, especially those directors who may be deemed independent, will be significantly curtailed.

The Company's independent auditors have issued a report raising a substantial doubt of the Company's ability to continue as a going concern.

In their audited financial report, the Company's independent auditors have issued added an explanatory paragraph that unless the Company is able to generate sufficient cash flows from operations and/or obtain additional financing, there is a substantial doubt as to its ability to continue as a going concern. The Company anticipates that it would need substantial capital over the next 12 months to continue as a going concern to expand its operations in accordance with its current business plan.

The Company may not be able to continue as a going concern.

The ability of the Company to continue as a going concern is dependent on the Company's ability to fund future operations through additional financing from investors and/or lenders or through the sale of its securities or through development of its operations. Due to these and other factors, there is substantial doubt of the Company's ability to continue as a going concern.

We will incur increased costs and demands upon management as a result of complying with the laws and regulations affecting public companies, which could harm our operating results.

As a public company, we will incur significant additional legal, accounting and other expenses that we did not incur as a private company, including costs associated with public company reporting requirements. We also will incur costs associated with current corporate governance requirements, including requirements under Section 404 and other provisions of the Sarbanes-Oxley Act, as well as rules implemented by the Securities and Exchange Commission, or SEC, and the exchange on which we list our shares of common stock issued in this Offering. The expenses incurred by public companies for reporting and corporate governance purposes have increased dramatically in recent years. We expect these rules and regulations to substantially increase our legal and financial compliance costs and to make some activities more time consuming and costly. We are unable to currently estimate these costs with any degree of certainty. We also expect these new rules and regulations may make it more difficult and more expensive for us to obtain director and officer liability insurance, and we may be required to accept reduced policy limits and coverage or incur substantially higher costs to obtain the same or similar coverage previously available. As a result, it may be more difficult for us to attract and retain qualified individuals to serve on our board of directors or as our executive officers. Currently we do not have a system of checks and balances in place covering our financial operations and investors will bear the economic risk associated with the lack such oversight.

Because we do not have an audit committee, shareholders will have to rely on the directors, who are not independent, to perform these functions.

We do not have an audit or compensation committee comprised of independent directors. These functions are performed by the board of directors as a whole. Most members of the Board of Directors are not independent directors. Thus, there is a potential conflict in that the board members are also engaged in management and participates in decisions concerning management compensation and audit issues that may affect management performance.

13

Table of Contents

Early failures would impair our ability to attract additional capital.

Our business model contemplates success from the development and deployment of the Company's SaaS-delivered condition monitoring solutions. That is, we are anticipating revenue from these services to support the Company's operations. In the event that our product and service offerings are not profitable, we will need to raise additional capital from outside investment. There are no guarantees that we will be able to raise such capital, or that if we are able to, that it will be on favorable terms. Early failures are likely to make such additional financing more "expensive" because investors are not likely to be willing to pay for "past mistakes."

Government regulation could negatively impact the business.

The Company's business segments may be subject to various government regulations in the jurisdictions in which they operate. Due to the potential wide scope of the Company's operations, the Company could be subject to regulation by various political and regulatory entities, including various local and municipal agencies and government sub-divisions. The Company may incur increased costs necessary to comply with existing and newly adopted laws and regulations or penalties for any failure to comply. The Company's operations could be adversely affected, directly or indirectly, by existing or future laws and regulations relating to its business or industry.

The Company's election not to opt out of JOBS Act extended accounting transition period may not make its financial statements easily comparable to other companies.

Pursuant to the JOBS Act of 2012, as an emerging growth company the Company can elect to opt out of the extended transition period for any new or revised accounting standards that may be issued by the PCAOB or the SEC. The Company has elected not to opt out of such extended transition period which means that when a standard is issued or revised and it has different application dates for public or private companies, the Company, as an emerging growth company, can adopt the standard for the private company. This may make comparison of the Company's financial statements with any other public company which is not either an emerging growth company nor an emerging growth company which has opted out of using the extended transition period difficult or impossible as possible different or revised standards may be used.

The recently enacted JOBS Act will also allow the Company to postpone the date by which it must comply with certain laws and regulations intended to protect investors and to reduce the amount of information provided in reports filed with the SEC.

The recently enacted JOBS Act is intended to reduce the regulatory burden on "emerging growth companies. The Company meets the definition of an emerging growth company and so long as it qualifies as an "emerging growth company," it will, among other things: be exempt from the provisions of Section 404(b) of the Sarbanes-Oxley Act requiring that its independent registered public accounting firm provide an attestation report on the effectiveness of its internal control over financial reporting; be exempt from the "say on pay" provisions (requiring a non-binding shareholder vote to approve compensation of certain executive officers) and the "say on golden parachute" provisions (requiring a non-binding shareholder vote to approve golden parachute arrangements for certain executive officers in connection with mergers and certain other business combinations) of the Dodd-Frank Act and certain disclosure requirements of the Dodd-Frank Act relating to compensation of its chief executive officer; be permitted to omit the detailed compensation discussion and analysis from proxy statements and reports filed under the Securities Exchange Act of 1934 and instead provide a reduced level of disclosure concerning executive compensation; and be exempt from any rules that may be adopted by the Public Company Accounting Oversight Board requiring mandatory audit firm rotation or a supplement to the auditor's report on the financial statements.

Although the Company is still evaluating the JOBS Act, it currently intends to take advantage of some or all of the reduced regulatory and reporting requirements that will be available to it so long as it qualifies as an "emerging growth company". The Company has elected not to opt out of the extension of time to comply with new or revised financial accounting standards available under Section 102(b) of the JOBS Act. Among other things, this means that the Company's independent registered public accounting firm will not be required to provide an attestation report on the effectiveness of the Company's internal control over financial reporting so long as it qualifies as an emerging growth company, which may increase the risk that weaknesses or deficiencies in the internal control over financial reporting go undetected. Likewise, so long as it qualifies as an emerging growth company, the Company may elect not to provide certain information, including certain financial information and certain information regarding compensation of executive officers that would otherwise have been required to provide in filings with the SEC, which may make it more difficult for investors and securities analysts to evaluate the Company. As a result, investor confidence in the Company and the market price of its common stock may be adversely affected.

14

Table of Contents

If we are unable to sell additional products, subscriptions, and services, as well as renewals of our subscriptions and services, to our customers, our future revenue and operating results will be harmed.

As existing customers that purchase our platform subscriptions have limited contractual obligation to renew their subscriptions and support services after the initial contract period, and given our limited operating history, we may not be able to accurately predict our retention rates. Our customers' retention rates may decline or fluctuate as a result of a number of factors, including the level of their satisfaction with our platform, our customer support, customer budgets and the pricing of our platform compared with the products and services offered by our competitors. If our customers renew their subscriptions, they may renew for shorter contract lengths or on other terms that are less economically beneficial to us. We cannot assure you that our customers will renew their subscriptions, and if our customers do not renew their subscriptions or renew them on less favorable terms, our revenue may grow more slowly than expected, not grow at all, or even decline.

We also depend on our installed customer base for future support and maintenance of revenues. We offer our service and support agreements for terms that generally range between one and three years. If customers choose not to renew their support and maintenance agreements or seek to renegotiate the terms of their service and support agreements prior to renewing such agreements, our revenue may grow more slowly than expected, not grow at all, or even decline.

If we are unable to retain our customers, renew and expand our relationships with them, and add new customers, we may not be able to sustain revenue growth and we may not achieve or maintain profitability in the future.

We are a relatively new company with limited operating history. Although we anticipate rapid growth based on our industry experience, we may not experience growth due to a myriad of factors and any success that we may experience will depend, in large part, on our ability to, among other things:

? maintain, renew, and expand our customer base; ? win new customers to our solutions; ? increase revenues from existing customers through increased use of our products, subscriptions, and services within their organizations; ? improve the capabilities of our products and subscriptions through research and development; ? continue to develop our AI, IIOT and cloud-based, analytics solutions; ? maintain the rate at which customers purchase our subscriptions and support; ? continue to successfully expand our business domestically and internationally; and ? successfully compete with other companies.

If we are unable to maintain consistent or increasing revenue growth or if our revenues decline, it may be difficult to achieve and maintain profitability and our business and financial results could be adversely affected.

If we are unable to increase sales to large organizations while mitigating the risks associated with serving such customers, our business, financial position, and results of operations may suffer.

Our growth strategy is dependent, in part, upon increasing sales of our solutions to commercial enterprises. Sales to commercial customers involve risks that may not be present (or that are present to a lesser extent) with sales to retail customers. These risks include:

    Filed Pursuant to Rule 424(b)(3)

Fluctuating economic conditions make it difficult to predict revenue for a particular period, and a shortfall in revenue may harm our business and operating results.

Our revenue depends significantly on general economic conditions and the demand for services in the industrial automation market. Economic weakness, customer financial difficulties, and constrained spending on equipment condition monitoring may result in decreased revenue and earnings. Such factors could make it difficult to accurately forecast our sales and operating results and could negatively affect our ability to provide accurate forecasts to our contract manufacturers and manage our inventory purchases, contract manufacturer relationships and other costs and expenses. General economic weakness may lead to longer collection cycles for payments due from our customers, an increase in customer bad debt, restructuring initiatives and associated expenses, and impairment of investments. Furthermore, the continued uncertainty in worldwide credit markets may adversely impact the ability of our customers to adequately fund their expected capital expenditures, which could lead to delays or cancellations of planned purchases of our platform.

15

Table of Contents

Uncertainty about future economic conditions also makes it difficult to forecast operating results and to make decisions about future investments. Future or continued economic weakness for us or our customers, failure of our customers and markets to recover from such weakness, customer financial difficulties, and reductions in spending on equipment condition monitoring services could have a material adverse effect on demand for our platform and consequently on our business, financial condition, and results of operations.

Claims by others that we infringe their proprietary technology or other rights could harm our business.

Technology companies frequently enter into litigation based on allegations of patent infringement or other violations of intellectual property rights. In addition, patent holding companies seek to monetize patents they have purchased or otherwise obtained. As we face increasing competition and gain an increasingly higher profile, the possibility of intellectual property rights claims against us grows. From time to time, third parties may assert, and we expect that third parties will assert, claims of infringement of intellectual property rights against us. Third parties may in the future also assert claims against our customers or channel partners, whom our standard license and other agreements obligate us to indemnify against claims that our products infringe the intellectual property rights of third parties. While we intend to increase the size of our patent portfolio, many of our competitors and others may now and in the future have significantly larger and more mature patent portfolios than we have. In addition, future litigation may involve patent holding companies or other patent owners who have no relevant product offerings or revenue and against whom our own patents may therefore provide little or no deterrence or protection. Any claim of intellectual property infringement by a third party, even a claim without merit, could cause us to incur substantial costs defending against such claim, could distract our management from our business and could require us to cease use of such intellectual property.

Although third parties may offer a license to their technology or other intellectual property, the terms of any offered license may not be acceptable, and the failure to obtain a license or the costs associated with any license could cause our business, financial condition, and results of operations to be materially and adversely affected. We may also be subject to additional fees or be required to obtain new licenses if any of our licensors allege that we have not properly paid for such licenses or that we have improperly used the technologies under such licenses. In addition, some licenses may be non-exclusive, and therefore our competitors may have access to the same technology licensed to us. If a third party does not offer us a license to its technology or other intellectual property on reasonable terms, or at all, we could be enjoined from continued use of such intellectual property. As a result, we may be required to develop alternative, non-infringing technology, which could require significant time (during which we could be unable to continue to offer our affected products, subscriptions, or services), effort, and expense and may ultimately not be successful. Furthermore, a successful claimant could secure a judgment, or we may agree to a settlement that prevents us from distributing certain products, providing certain subscriptions, or performing certain services or that requires us to pay substantial damages, royalties, or other fees. Any of these events could harm our business, financial condition, and results of operations.

The Company is not aware of any material violation or infringement of the intellectual property rights of others. Nevertheless, there can be no assurance that in its development of protocols, logos, and methods, Nexscient may inadvertently infringe the intellectual property rights of others, or others may assert infringement claims against the Company. Such claims against the Company, even if untrue or baseless, could result in significant egal and other costs and may be a distraction to its management. Adverse determinations in such litigation could result in loss of proprietary rights or subject Nexscient to significant liabilities. As a result, the Company's financial and operating results may be adversely affected.

If organizations do not adopt cloud-based SaaS-delivered monitoring solutions, our ability to grow our business and results of operations may be adversely affected.

We believe our future success will depend in large part on the growth, if any, in the market for cloud-based SaaS-delivered condition monitoring solutions. The use of SaaS solutions to manage and automate condition monitoring of equipment is at an early stage and rapidly evolving. As such, it is difficult to predict its potential growth, if any, customer adoption and retention rates, customer demand for our solutions, or the success of existing competitive products. Any expansion in our market depends on a number of factors, including the cost, performance, and perceived value associated with our solutions and those of our competitors. If our solutions do not achieve widespread adoption or there is a reduction in demand for our solutions due to a lack of customer acceptance, technological challenges, competing products, privacy concerns, decreases in corporate spending, weakening economic conditions or otherwise, it could result in early terminations, reduced customer retention rates, or decreased revenue, any of which would adversely affect our business, results of operations, and financial results. We do not know whether the trend in adoption of cloud-based SaaS-delivered condition monitoring solutions we have experienced in the past will continue in the future. Furthermore, if we or other SaaS condition monitoring providers experience security incidents, loss or disclosure of customer data, disruptions in delivery, or other problems, the market for SaaS solutions, including our condition monitoring solutions, may be negatively affected. You should consider our business and prospects in light of the risks and difficulties we encounter in this new and evolving market.

16

Table of Contents

The Company faces market risk from other players in the industry.

We expect our greatest competition to be from existing analytical test equipment, computerized maintenance management systems, and related companies in the market today. These industry segments are highly competitive and includes numerous manufactures, distributors, marketers that actively compete for the business of consumers both in the United States and abroad. Additionally, there are several other companies currently marketing similar monitoring services and related company products, many of which have established market presence both domestically and internationally. Some or all of these companies have greater financial resources than those available to the Company and have established market positions which the Company may be unable to effectively compete with. As a result, the Company's ability to remain competitive depends in part upon the successful introduction and consumer acceptance of its products and services. The principal competitive factors affecting the market for our products include product performance, reliability, timeliness, scalability, ease of use, price, and distribution capabilities. There can be no assurance that the Company will be able to compete successfully against current and future competitors based on these and other factors. Any failure to adapt to these changing technologies may have a material adverse effect on the Company's business, financial condition, and results of operations.

We will operate in a competitive industry.

The growth in the industrial automation industry may result in potential competitors to the Company entering the market. Many of our potential competitors may be large, well-financed and established companies that have greater financial and marketing resources than does the Company. Our ability to compete effectively is dependent upon, among other things, our ability to form strategic development and marketing relationships with major companies that participate in markets relevant to the Company's products. No assurance can be given that we will be successful in these efforts. We plan to offer our resulting products and services in several distinct markets, all of which contain potential competitors, which may be large, well-financed and established companies that have greater financial and marketing resources than does the Company. There are several purveyors of condition monitoring solutions offering many products on the market today. Our ability to compete effectively is dependent upon, among other things, our ability to develop and market our products and services to customers in markets relevant to our solutions. No assurance can be given that we will be successful in these efforts.

We face intense competition and could lose market share to our competitors, which could adversely affect our business, financial condition, and results of operations.

The market for industrial automation and condition-based monitoring products and services is intensely competitive and characterized by rapid changes in technology, customer requirements, industry standards, and frequent new product introductions and improvements. We anticipate continued challenges from current competitors, which in many cases are more established and enjoy greater resources than us, as well as by new entrants into the industry. If we are unable to anticipate or effectively react to these competitive challenges, our competitive position could weaken, and we could experience a decline in our growth rate or revenue that could adversely affect our business and results of operations.

Our competitors and potential competitors include condition monitoring equipment vendors of greater size such as Fluke, Emerson, and Augury that may emulate or integrate certain features similar to ours into their own products; test equipment vendors that offer products or features that claim to perform similar functions to our platform; small and large companies, including new market entrants, that offer niche monitoring solutions that compete with some of the features present in our solutions; and other providers of condition-based monitoring services. Other equipment providers offer, and may continue to introduce, remote monitoring features that compete with our platform, either in stand-alone products or as additional services in their network infrastructure offerings. Many of our existing competitors have, and some of our potential competitors could have, substantial competitive advantages such as:

    Filed Pursuant to Rule 424(b)(3)

17

Table of Contents

In addition, some of our competitors have substantially broader product offerings and may be able to leverage their relationships with distribution partners and customers based on other products or incorporate functionality into existing products to gain business in a manner that discourages users from purchasing our products, subscriptions, and services, including by selling at zero or negative margins, product bundling or offering closed technology platforms. Potential customers may also prefer to purchase from their existing suppliers rather than a new supplier regardless of product performance or features. As a result, even if the features of our platform are superior, customers may not purchase our products. In addition, new innovative start-up companies, and larger companies that are making significant investments in research and development, may invent similar or superior products and technologies that compete with our platform. Our current and potential competitors may also establish cooperative relationships among themselves or with third parties that may further enhance their resources. Further, as our customers refresh the condition monitoring products bought in prior years, they may seek to consolidate vendors, which may result in current customers choosing to purchase products from our competitors on an ongoing basis.

Some of our competitors have made or could make acquisitions of businesses that allow them to offer more competitive and comprehensive solutions. As a result of such acquisitions, our current or potential competitors may accelerate the adoption of new technologies that better address end-customer needs, devote greater resources to bring these products and services to market, initiate or withstand substantial price competition, or develop and expand their product and service offerings more quickly than we do. These competitive pressures in our market or our failure to compete effectively may result in price reductions, fewer orders, reduced revenue and gross margins, and loss of market share. If we are unable to compete successfully, or if competing successfully requires us to take costly actions in response to the actions of our competitors, our business, financial condition, and results of operations could be adversely affected.

Real or perceived defects, errors or vulnerabilities in our products or services, the misconfiguration of our products, the failure of our products or services to identify incipient issues, or the failure of customers to take action on issues identified by our products or services could harm our reputation and adversely impact our business, financial position and results of operations.

Because our products and services are complex, they have contained and may contain design or manufacturing defects or errors that are not detected until after their deployment. Our products also provide our customers with the ability to customize a multitude of settings, and it is possible that a customer could misconfigure our products or otherwise fail to configure our products in an optimal manner. Such defects and misconfigurations of our products could cause our products or services to be vulnerable to missed identification of incipient issues, cause equipment to fail, or temporarily interrupt the operations of our customers. In addition, because the techniques used to detect, analyze and send notifications are still developing and generally are not recognized until sufficient data has been accrued, there is a risk that an undetected issue could emerge that our products and services are unable to detect or prevent. In addition, defects or errors in our subscription updates or our products could result in a failure of our subscriptions to effectively update customers' hardware and cloud-based products. Our data centers and networks may experience technical failures and downtime, may fail to distribute appropriate updates, or may fail to meet the increased requirements of a growing installed customer base, any of which could temporarily or permanently expose our customers' equipment, leaving their them unmonitored, which could lead to eventual failure. Similarly, if we inadvertently update our products with an erroneous configuration or untested detection content, invalid detections or product downtime could occur. Any of these situations could result in negative publicity to us, damage to our reputation, declining sales, increased expenses, and customer relations issues, and therefore adversely impact our business, financial position and results of operations.

In addition, we cannot assure you that any limitation of liability provisions in our customer agreements, contracts with third-party vendors and service providers or other contracts would be enforceable or adequate or would otherwise protect us from any liabilities or damages with respect to any particular claim relating to equipment failure or other condition-related matter. While our insurance policies expect to include liability coverage for certain of these matters, if we experienced a widespread incident that impacted a significant number of our customers to whom we owe indemnity obligations, we could be subject to indemnity claims or other damages that exceed our insurance coverage. We also cannot be certain that our insurance coverage will be adequate for such liabilities actually incurred, that insurance will continue to be available to us on economically reasonable terms, or at all, or that any future claim will not be excluded or otherwise be denied coverage by any insurer. The successful assertion of one or more large claims against us that exceed available insurance coverage, or the occurrence of changes in our insurance policies, including premium increases or the imposition of large deductible or co-insurance requirements, could have a material adverse effect on our business, including our financial condition, operating results, and reputation.

18

Table of Contents

Any real or perceived defects, errors or vulnerabilities in our products and services, or any other failure of our products and services to detect an incipient issue, could result in:

? a loss of existing or potential customers or channel partners; ? delayed or lost revenue and harm to our financial condition and results of operations; ? a delay in attaining, or the failure to attain, market acceptance; ? the expenditure of significant financial and product development resources in efforts to analyze, correct, eliminate, or work around errors or defects, or to identify and ramp up production with alternative third-party manufacturers; ? an increase in warranty and other claims, or an increase in the cost of servicing warranty and other claims, either of which would adversely affect our gross margins; ? harm to our reputation or brand; and ? claims and litigation, regulatory inquiries, or investigations, enforcement actions, and other claims and liabilities, all of which may be costly and burdensome and further harm our reputation.

If we do not accurately anticipate and respond promptly to changes in our customers' technologies, business plans or equipment-monitoring needs, our competitive position and prospects could be harmed.

The industrial automation market has grown quickly and is expected to continue to evolve rapidly. Moreover, many of our customers operate in markets characterized by rapidly changing technologies and business plans, which require them to adapt to increasingly complex manufacturing environments, incorporating a variety of hardware, software applications, operating systems and networking protocols. As their technologies and business plans grow more complex, we expect these customers to face an increasing number of equipment failures. We face significant challenges in ensuring that our platform effectively identifies and responds to these incipient issues without disrupting our customers' operations or performance.

We have identified a number of new products and enhancements to that we believe are important to our success in the industrial automation market, including our predictive maintenance platform and remote monitoring solutions. There can be no assurance that we will be successful in developing and marketing, on a timely basis, such new products or enhancements or that our new products or enhancements will adequately address the changing needs of the marketplace. We may experience unanticipated delays in the availability of new products and enhancements to our platform and fail to meet customer expectations with respect to the timing of such availability. If we do not quickly respond to the rapidly changing and rigorous needs of our customers by developing, releasing and making available on a timely basis new products and enhancements to our platform, such as our threat intelligence platform and enhancements to our monitoring solutions, that can adequately respond to incipient equipment issues and our customers' needs, our competitive position and business prospects will be harmed. Furthermore, from time to time, we or our competitors may announce new products with capabilities or technologies that could have the potential to replace or shorten the life cycles of our existing products. There can be no assurance that announcements of new products will not cause customers to defer purchasing our existing products.

Additionally, the process of developing new technology is expensive, complex, and uncertain. The success of new products and enhancements depends on several factors, including appropriate component costs, timely completion and introduction, differentiation of new products and enhancements from those of our competitors, and market acceptance. To maintain our competitive position, we must continue to commit significant resources to developing new products or enhancements to our platform before knowing whether these investments will be cost-effective or achieve the intended results. There can be no assurance that we will successfully identify new product opportunities, develop, and bring new products or enhancements to market in a timely manner, or achieve market acceptance of our platform, or that products and technologies developed by others will not render our platform obsolete or noncompetitive. If we expend significant resources on researching and developing products or enhancements to our platform and such products or enhancements are not successful, our business, financial position and results of operations may be adversely affected.

War, terrorism, other acts of violence or natural or manmade disasters such as a global pandemic may affect the markets in which the Company operates, the Company's customers, the Company's delivery of products and customer service, and could have a material adverse impact on our business, results of operations, or financial condition.

The Company's business may be adversely affected by instability, disruption, or destruction in a geographic region in which it operates, regardless of cause, including war, terrorism, riot, civil insurrection or social unrest, and natural or manmade disasters, including famine, food, fire, earthquake, storm or pandemic events and spread of disease (including the recent outbreak of the coronavirus commonly referred to as "COVID- 19"). Such events may cause customers to suspend their decisions on using the Company's products and services and give rise to sudden significant changes in regional and global economic conditions and cycles that could interfere with purchases of goods or services. These events also pose significant risks to the Company's personnel and operations, which could materially adversely affect the Company's financial results.

Any significant disruption to communications and travel, including travel restrictions and other potential protective quarantine measures against COVID-19 by governmental agencies, could make it difficult for the Company to deliver goods services to its customers. War, riots, or other disasters may increase the need for our products and demand may make it difficult for use to provide products to customers. Further, travel restrictions and protective measures against pandemics, like COVID-19, could cause the Company to incur additional unexpected labor costs and expenses or could restrain the Company's ability to retain the highly skilled personnel the Company needs for its operations. The extent to which health concerns, like COVID-19, impacts the Company's business, sales and results of operations will depend on future developments, which are highly uncertain and cannot be predicted.

19

Table of Contents

    Filed Pursuant to Rule 424(b)(3)

There is presently no market for the Company's common stock.

A market does not presently exist for the Company's securities (the "Securities"), and no assurances can be given that a market will ever develop. Consequently, holders of the Securities offered hereby may not be able to liquidate their investment in the Company in a timely manner or at any time, and such Securities will not be readily acceptable as collateral for loans. Although we may endeavor to establish a trading market for the Company's securities at an unspecified future date, no assurances can be given that we will be successful in our efforts. Further, even if we establish a trading market, no assurances can be given as to the timing of such event or whether the market, if established, will be sufficiently liquid to enable the investor to liquidate his investment in the Company. Finally, if a market is developed for the Company's securities through a public offering, the holders of the Securities offered hereby, as a condition to such offering, may be required to enter into an agreement not to sell or otherwise transfer their stock for a significant period of time following the public offering (see "Description of Securities").

We do not expect to pay dividends in the foreseeable future.

We do not intend to declare dividends for the foreseeable future, as we anticipate that we will reinvest any future earnings in the development and growth of our business. Therefore, investors will not receive any funds unless they sell their common stock, and stockholders may be unable to sell their Shares on favorable terms or at all. We cannot assure you of a positive return on investment or that you will not lose the entire amount of your investment in our common stock.

The officers and directors of the Company have controlling interest in the Company.

Currently there are issued and outstanding 19,955,980 shares of Common Stock of which 12,273,000 shares of Common Stock are issued to the officers and directors of the Company. The holders of the Common Stock are entitled to one (1) vote per share so that presently, management control shares of Common Stock that are entitled to 12,273,000 votes or 61.50% of the issued and outstanding voting shares. At the completion of this Offering, assuming the sale of all 4,000,000 shares of Common Stock being offered hereby there will be issued and outstanding 23,955,980 shares of Common Stock, of which management will then have approximately 51.23% of such voting power. Additionally, should the Company issue additional shares of Common Stock the purchasers in this Offering would be further diluted in voting control (see "Management," "Principal Shareholders" and "Description of Securities").

We may in the future issue additional shares of our common stock which would reduce investors' ownership interests in the Company, and which may dilute our share value.

Our Certificate of Incorporation authorize the issuance of 75,000,000 shares of Common Stock, par value $0.001 per share and 10,000,000 shares of authorized but undesignated shares of Preferred Stock, par value $0.001 per share. The future issuance of all or part of our remaining authorized Common Stock or the designation and subsequent issuance of any Preferred Stock may result in substantial dilution to our then existing stockholders. We may value any stock issued in the future on an arbitrary basis. The issuance of our stock for future services or acquisitions or other corporate actions may have the effect of diluting the value of the shares held by our investors and might have an adverse effect on any trading market for our stock.

An active trading market for our common stock may never develop or be sustained.

We cannot assure you that an active trading market for our Common Stock will develop in the future or, if developed, that any market will be sustained. Accordingly, you may be required to hold your Shares indefinitely or to sell them at a price that does not meet your expectations, if at all.

20

Table of Contents

The Company's stock price may be volatile.

The market price of the Company's common stock is likely to be highly volatile and could fluctuate widely in price in response to various potential factors, many of which will be beyond the Company's control, including the following:

? Competition; ? Additions or departures of key personnel; ? The Company's ability to execute its business plan; ? Operating results that fall below expectations; ? Loss of any strategic relationship; ? Industry developments; ? Economic and other external factors; and ? Period-to-period fluctuations in the Company's financial results.

In addition, the securities markets have from time-to-time experienced significant price and volume fluctuations that are unrelated to the operating performance of particular companies. These market fluctuations may also materially and adversely affect the market price of the Company's common stock.

The Company's stock may be considered a penny stock and any investment in the Company's stock will be considered a high-risk investment and subject to restrictions on marketability.

If the Shares commence trading, the trading price of the Company's common stock may be below $5.00 per share. If the price of the common stock is below such level, trading in its common stock would be subject to the requirements of certain rules promulgated under the Securities Exchange Act of 1934, as amended. These rules require additional disclosure by broker-dealers in connection with any trades generally involving any non-NASDAQ equity security that has a market price of less than $5.00 per share, subject to certain exceptions. Such rules require the delivery, before any penny stock transaction, of a disclosure schedule explaining the penny stock market and the risks associated therewith, and impose various sales practice requirements on broker-dealers who sell penny stocks to persons other than established customers and accredited investors (generally institutions). For these types of transactions, the broker-dealer must determine the suitability of the penny stock for the purchaser and receive the purchaser's written consent to the transactions before sale. The additional burdens imposed upon broker-dealers by such requirements may discourage broker-dealers from effecting transactions in the Company's common stock which could impact the liquidity of the Company's common stock.

FINRA sales practice requirements may limit a stockholder's ability to buy and sell our stock.

The Financial Industry Regulatory Authority ("FINRA") has adopted rules that relate to the application of the SEC's penny stock rules in trading our securities and require that a broker/dealer have reasonable grounds for believing that the investment is suitable for that customer, prior to recommending the investment. Prior to recommending speculative, low-priced securities to their non-institutional customers, broker/dealers must make reasonable efforts to obtain information about the customer's financial status, tax status, investment objectives and other information.

Under interpretations of these rules, FINRA believes that there is a high probability that speculative, low-priced securities will not be suitable for at least some customers. FINRA's requirements make it more difficult for broker/dealers to recommend that their customers buy our common stock, which may have the effect of reducing the level of trading activity and liquidity of our common stock. Further, many brokers charge higher transactional fees for penny stock transactions. As a result, fewer broker/dealers may be willing to make a market in our common stock, reducing a shareholder's ability to resell shares of our common stock.

There has been no prior public market for the Company's securities and the lack of such a market may make resale of the stock difficult.

No prior public market has existed for the Company's Securities and the Company cannot assure any investor that a market will develop subsequent to this offering. An investor must be fully aware of the long-term nature of an investment in the Company. The Company intends to apply for quotation of its common stock on the OTC Bulletin Board as soon as possible, which may be while this offering is still in process. To qualify for quotation on the OTC Bulletin Board, an equity security must have one registered broker-dealer, known as the market maker, willing to list bid or sale quotations and to sponsor the company listing (currently, the Company does not have an arrangement with any such market maker to qualify the Company's securities for quotation on the OTC Bulletin Board). Moreover, the Company does not know if it will be successful in such application for quotation on the OTC bulletin board, how long such application will take, or, that if successful, that a market for the common stock will ever develop or continue on the OTC Bulletin Board. If for any reason the common stock is not listed on the OTC Bulletin Board or a public trading market does not otherwise develop, investors in the offering may have difficulty selling their common stock should they desire to do so. If the Company is not successful in its application for quotation on the OTC Bulletin Board, it will apply to have its securities quoted by the OTC Markets Group's Pink Open Market., real-time quotation service for over-the-counter equities.

Shares of common stock in the Company are subject to resale restrictions imposed by Rule 144 of the Securities and Exchange Commission.

The shares of common stock held by current shareholders are "restricted securities" subject to the limitations of Rule 144 under the Securities Act. In general, securities can be sold pursuant to Rule 144 after being fully-paid and held for more than 12 months (6 months if registered under the Exchange Act). Unregistered shares of the Company's common stock held by current shareholders are subject to Rule 144 resale restrictions; provided, however, investors participating in the Offering are not subject to such resale limitations.

21

Table of Contents

    Filed Pursuant to Rule 424(b)(3)

This prospectus contains forwardlooking statements that are based on our management's beliefs and assumptions and on information currently available to us. All statements other than statements of historical facts are forwardlooking statements. The forwardlooking statements are contained principally in, but not limited to, the sections entitled "Prospectus Summary," "Risk Factors," "Management's Discussion and Analysis of Financial Condition and Results of Operations" and "Business." These statements relate to future events or to our future financial performance and involve known and unknown risks, uncertainties and other factors that may cause our actual results, levels of activity, performance or achievements to be materially different from any future results, levels of activity, performance or achievements expressed or implied by these forwardlooking statements. Forwardlooking statements include, but are not limited to, statements about:

? our goals and strategies; ? our future business development, financial condition and results of operations; ? expected changes in our revenue, costs or expenditures; ? growth of and competition trends in our industry; ? our expectations regarding demand for, and market acceptance of, our products; ? our expectations regarding our relationships with investors, institutional funding partners and other parties with whom we collaborate; ? our expectation regarding the use of proceeds from this offering; ? fluctuations in general economic and business conditions in the markets in which we operate; and ? relevant government policies and regulations relating to our industry.

In some cases, you can identify forwardlooking statements by terms such as "may," "could," "will," "should," "would," "expect," "plan," "intend," "anticipate," "believe," "estimate," "predict," "potential," "project" or "continue" or the negative of these terms or other comparable terminology. These statements are only predictions. You should not place undue reliance on forwardlooking statements because they involve known and unknown risks, uncertainties and other factors, which are, in some cases, beyond our control and which could materially affect results. Factors that may cause actual results to differ materially from current expectations include, among other things, those listed under the heading "Risk Factors". If one or more of these risks or uncertainties occur, or if our underlying assumptions prove to be incorrect, actual events or results may vary significantly from those implied or projected by the forwardlooking statements. No forwardlooking statement is a guarantee of future performance.

The forwardlooking statements made in this prospectus relate only to events or information as of the date on which the statements are made in this prospectus. Although we will become a public company after this offering and have ongoing disclosure obligations under United States federal securities laws, we do not intend to update or otherwise revise the forwardlooking statements in this prospectus, whether as a result of new information, future events or otherwise.

    Filed Pursuant to Rule 424(b)(3)

As a result of there being no established public market for our shares, the offering price and other terms and conditions relative to our shares have been arbitrarily determined by the Company and do not bear any relationship to assets, earnings, book value, or any other objective criteria of value. In determining the number of shares to be offered and the Offering price, we took into consideration our capital structure and the amount of money we would need to implement our business plan. Accordingly, the Offering price should not be considered an indication of the actual value of our securities. In addition, no investment banker, appraiser, or other independent third party has been consulted concerning the offering price for the shares or the fairness of the offering price used for the shares.

    Filed Pursuant to Rule 424(b)(3)

Our offering is being made in a direct public offering without the involvement of underwriters or broker-dealers. We intend to disburse the proceeds from this offering in the priority set forth below within the first 12 months after successful completion of this offering.

Not taking into account any possible additional funding or revenues, we intend to use the proceeds from this offering as follows. The following chart indicates the approximate amount of funds that we will allocate to each item, but does not indicate the total fee/cost of each item. The amount of proceeds we allocate to each item is dependent upon the amount of proceeds we receive from this offering:

22

Table of Contents

If we sell all of the Shares being offered, our net proceeds will be $3,000,000. If the Offering is fully subscribed, the proceeds will be applied in the manner described below. If less than the full numbers of shares are subscribed, the proceeds will be applied in the order of priority listed. If we are only to receive between $0 and $750,000, we would need to amend our business plan. The following table sets forth a breakdown of the estimated use of the net proceeds as we currently expect to use them, assuming the sale of 25%, 50%, 75% and 100% of the Shares offered for sale in this Offering:

    Filed Pursuant to Rule 424(b)(3)

The above figures represent only estimated costs. As indicated in the table above, if we sell only 25%, or 50%, or 75% of the Shares offered for sale in this offering, we would expect to use the resulting net proceeds for the same purposes as we would use the net proceeds from a sale of 100% of the Shares, and in approximately the same proportions. However, the lower our net proceeds, the less we would expect to use the funds in the expenditure caries.

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

In the event we do not sell all of the Shares being offered, we may seek additional financing to support the intended use of proceeds discussed above. If we secure additional equity funding, investors in this offering would be diluted. In all events, there can be no assurance that additional financing would be available when needed and, if available, on terms acceptable to us.

23

Table of Contents

    Filed Pursuant to Rule 424(b)(3)

We have not paid any dividends on our common stock since inception and we currently expect that, in the foreseeable future, all earnings (if any) will be retained for the development of our business and no dividends will be declared or paid. Any future dividends will be subject to the discretion of our board of directors and will depend upon, among other things, our earnings (if any), operating results, financial condition and capital requirements, general business conditions and other pertinent facts.

    Filed Pursuant to Rule 424(b)(3)

As of November 6, 2023, Nexscient, Inc. has issued and outstanding 19,955,980 shares of Common Stock. The Company is registering an additional 4,000,000 shares of its Common Stock for sale at the price of $0.75 per share. There is no arrangement to address the possible effect of the offering on the price of the stock. In connection with the Company's selling efforts in the offering, our officers and directors will not register as broker-dealers pursuant to Section 15 of the Exchange Act, but rather will rely upon the "safe harbor" provisions of SEC Rule 3a4-1, promulgated under the Securities Exchange Act of 1934, as amended (the "Exchange Act"). Generally speaking, Rule 3a4-1 provides an exemption from the broker-dealer registration requirements of the Exchange Act for persons associated with an issuer that participate in the sale of the securities of such issuer.

Our officers and directors meet the conditions of the Rule 3a4-1 exemption, as: (1) they are not subject to any statutory disqualification, as that term is defined in Section 3(a)(39) of the Exchange Act; (2) they will not be compensated in connection with their participation in the direct public offering or resale offering by the payment of commissions or other remuneration based either directly or indirectly on transactions in our securities; and (3) they will not be associated persons of a broker or dealer at the time of their participation in the direct public offering and resale offering. Further, our officers and directors: (1) at the end of the offerings, will continue to primarily perform substantial duties for the Company or on its behalf otherwise than in connection with transactions in securities; (2) are not, nor have been within the preceding 12 months, a broker or dealer, and they are not, nor have they been within the preceding 12 months, an associated person of a broker or dealer; and (3) they have not participated in another offering of securities pursuant to the Exchange Act Rule 3a4-1 in the past 12 months and they have not and will not participate in selling an offering of securities for any issuer more than once every 12 months other than in reliance on the Exchange Act Rule 3a4-1(a)(4)(i) or (iii).

In order to comply with the applicable securities laws of certain states, the securities will be offered or sold in those states only if they have been registered or qualified for sale, an exemption from such registration is available, or if qualification requirement is available and with which the Company has complied. In addition, and without limiting the foregoing, the Company will be subject to applicable provisions, rules and regulations under the Exchange Act with regard to security transactions during the period of time when this Registration Statement is effective.

Offering Period and Expiration Date

This offering will start on the date of this Prospectus and continue for a period of up to 180 days, unless extended by our board of directors for an additional 90 days.

Concurrent Offering

The Company will be offering shares of the Company's Common Stock under the direct public offering at the same time that the Selling Shareholders may be offering shares of the Company's Common Stock under the resale offering. The Selling Shareholders do not include any of our officers and directors.

Procedures for Subscribing

If you decide to subscribe for any shares in this offering, you must:

(1) execute and deliver a Subscription Agreement; and

    Filed Pursuant to Rule 424(b)(3)

24

Table of Contents

The Subscription Agreement requires you to disclose your name, address, social security number, telephone number, number of shares you are purchasing, and the price you are paying for your shares.

All subscriptions must be funded by wire transfer or by check made payable to "Nexscient, Inc."

Acceptance of Subscriptions

Upon the Company's acceptance of a Subscription Agreement and receipt of full payment, the Company shall countersign the Subscription Agreement and issue a stock certificate along with a copy of the Subscription Agreement.

Right to Reject Subscriptions

We have the right to accept or reject subscriptions in whole or in part, for any reason or for no reason. All monies from rejected subscriptions will be returned immediately by us to the subscriber, without interest or deductions. Subscriptions for securities will be accepted or rejected within 48 hours after we receive them.

No Minimum Subscription

There is no minimum number of shares that must be sold under the offering. As such, there is no guarantee that the Company will raise any funds from the offering.

Penny Stock Regulation

Our Common Shares are not quoted on any stock exchange or quotation system. The SEC has adopted rules that regulate broker-dealer practices in connection with transactions in penny stocks. Penny stocks are generally equity securities with a price of less than $5.00 (other than securities registered on certain national securities exchanges or quoted on the NASDAQ system, provided that current price and volume information with respect to transactions in such securities is provided by the exchange system).

The penny stock rules require a broker-dealer, prior to a transaction in a penny stock not otherwise exempt from those rules, to deliver a standardized risk disclosure document prepared by the SEC, that:

    Filed Pursuant to Rule 424(b)(3)

The broker-dealer also must provide the customer with the following, prior to proceeding with any transaction in a penny stock:

? bid and offer quotations for the penny stock; ? details of the compensation of the broker-dealer and its salesperson in the transaction; ? the number of shares to which such bid and ask prices apply, or other comparable information relating to the depth and liquidity of the market for such stock; and, ? monthly account statements showing the market value of each penny stock held in the customer's account.

25

Table of Contents

In addition, the penny stock rules require that prior to a transaction in a penny stock not otherwise exempt from those rules, the broker-dealer must make a special written determination that the penny stock is a suitable investment for the purchaser and receive the purchaser's written acknowledgment of the receipt of a risk disclosure statement and a signed and dated copy of a written suitability statement. These disclosure requirements will have the effect of reducing the trading activity in the secondary market for our stock because it will be subject to these penny stock rules. Therefore, stockholders may have difficulty selling those securities.

Registration Rights

We have not granted registration rights to any persons.

    Filed Pursuant to Rule 424(b)(3)

Net tangible book value per share represents the amount of the Company's tangible assets less total liabilities, divided by 19,955,980 shares of Common Stock outstanding as of June 30, 2023 pursuant to the financials enclosed herein. Net tangible book value dilution per share represents the difference between the amount per share paid by purchasers of the Shares in this offering assuming the offering price of $0.75 per share of Common Stock and the pro forma net tangible book value per share of Common Stock immediately after completion of the offering.

After giving effect to the sale of the 4,000,000 shares offered by the Company hereunder, at an Offering Price of $0.75 per share the pro forma net tangible book value of the Company at June 30, 2023, would have been $0.152 per share, representing an immediate increase in tangible book value of $0.143 per share to existing shareholders and an immediate dilution of $0.598 per share to purchasers of the Shares.

The following table illustrates the foregoing information with respect to new investors on a per share basis:

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

Our executive offices are located at 2029 Century Park East, Suite 400, Los Angeles, CA 90067. We signed an office service agreement with Regus Management Group, LLC for mailbox plus virtual office and workstation. However, once we expand our business to a significant degree, we will have to lease office space. We do not foresee any significant difficulties in obtaining any required office space. We do not currently own any real property.

    Filed Pursuant to Rule 424(b)(3)

Common Stock and Preferred Stock

Our Amended and Restated Certificate of Incorporation authorize us to issue up to eighty-five million (85,000,000) shares, consisting of: (i) seventy-five million (75,000,000) shares of Common Stock, par value $0.001 per share (the "Common Stock"); and (ii) 10,000,000 shares of blank check Preferred Stock, par value $0.001 per share (the "Preferred Stock").

Our Certificate of incorporation authorize our board, without stockholder approval, to issue up to 10,000,000 shares of Preferred Stock in one or more series, to determine the designations and the powers, preferences and rights and the qualifications, limitations and restrictions thereof, including the dividend rights, conversion or exchange rights, voting rights (including the number of votes per share), redemption rights and terms, liquidation preferences, sinking fund provisions and the number of shares constituting the series. Our board of directors has the discretion to issue Preferred Stock with voting and other rights that could adversely affect the voting power and other rights of the holders of Common Stock and which could have the effect of making it more difficult for a third party to acquire, or of discouraging a third party from attempting to acquire, a majority of our outstanding voting stock.

26

Table of Contents

The following statements relating to the capital stock set forth the material terms of the securities of the Company. Reference is also made to the more detailed provisions of the certificate of incorporation and the by-laws, copies of which are filed as exhibits to this registration statement.

Voting Rights

Except as otherwise required by law or as may be provided by the resolutions of the board of directors authorizing the issuance of Common Stock, all rights to vote and all voting power shall be vested in the holders of Common Stock. Each share of Common Stock shall entitle the holder thereof to one vote.

No Cumulative Voting

Except as may be provided by the resolutions of the board of directors authorizing the issuance of Common Stock, cumulative voting by any shareholder is expressly denied.

No Preemptive Rights

Preemptive rights shall not exist with respect to shares of Common Stock or securities convertible into shares of Common Stock of the Company.

Dividends

We have not paid any cash dividends on our Common Stock since inception and presently anticipate that all earnings, if any, will be retained for development of our business and that no dividends on our Common Stock will be declared in the foreseeable future. Any future dividends will be subject to the discretion of our Board of Directors and will depend upon, among other things, future earnings, operating and financial condition, capital requirements, general business conditions and other pertinent facts. Therefore, there can be no assurance that any dividends on our Common Stock will be paid in the future.

Rights upon Liquidation, Dissolution or Winding-Up of the Company

Upon any liquidation, dissolution or winding-up of the Company, whether voluntary or involuntary, the remaining net assets of the Company shall be distributed pro rata to the holders of the Common Stock.

Warrants and Options

The Company has not issued any warrants or options.

Holders

As of November 6, 2023, we have 19,955,980 issued and outstanding shares of Common Stock, which are held by 73 shareholders of record.

Securities Authorized for Issuance Under Equity Compensation Plans

None.

Transfer Agent and Registrar

Nexscient, Inc. has appointed VStock Transfer, LLC as its transfer agent. VStock's address is 18 Lafayette Place, Woodmere, NY 11598. The transfer agent is responsible for all record-keeping and administrative functions in connection with the common shares.

27

Table of Contents

No Public Market for Common Stock

There is currently no public trading market for our Common Stock and no such market may ever develop. While we intend to seek and obtain quotation of our Common Stock for trading on the OTC Markets ("OTCQB"), there is no assurance that our application will be approved. An application for quotation on the OTCQB must be submitted by one or more market makers who: 1) are approved by the Financial Industry Regulatory Authority ("FINRA"); 2) who agree to sponsor the security; and 3) who demonstrate compliance with SEC Rule 15(c)2-11 before initiating a quote in a security on the OTCQB. In order for a security to be eligible for quotation by a market maker on the OTCQB, the security must be registered with the SEC and the company must be current in its required filings with the SEC. There are no listing requirements for the OTCQB and accordingly no financial or minimum bid price requirements. We intend to cause a market maker to submit an application for quotation to the OTCQB upon the effectiveness of this Registration Statement of which this Prospectus forms a part. However, we can provide no assurance that our shares will be traded on the bulletin board or, if traded, that a public market will materialize.

Admission to Quotation on the OTC Bulletin Board

If the Company meets the qualifications, it intends to apply for quotation of its securities on the OTC Bulletin Board. The OTC Bulletin Board differs from national and regional stock exchanges in that it (1) is not situated in a single location but operates through communication of bids, offers and confirmations between broker-dealers and (2) securities admitted to quotation are offered by one or more broker-dealers rather than the "specialist" common to stock exchanges. To qualify for quotation on the OTC Bulletin Board, an equity security must have one registered broker-dealer, known as the market maker, willing to list bid or sale quotations and to sponsor the company listing. In addition, the Company must make available adequate current public information as required by applicable rules and regulations.

In certain cases, the Company may elect to have its securities initially quoted in the Pink Sheets published by Pink OTC Markets Inc. In general, there is greater liquidity for traded securities on the OTC Bulletin Board, and less through quotation on the Pink Sheets. It is not possible to predict where, if at all, the securities of the Company will be traded following the effectiveness of this registration statement.

Penny Stock Regulation

Penny stocks generally are equity securities with a price of less than $5.00 per share other than securities registered on national securities exchanges or listed on the NASDAQ Stock Market, provided that current price and volume information with respect to transactions in such securities are provided by the exchange or system. The penny stock rules impose additional sales practice requirements on broker-dealers who sell such securities to persons other than established customers and accredited investors (generally those with assets in excess of $1,000,000 or annual income exceeding $200,000, or $300,000 together with their spouse). For transactions covered by these rules, the broker-dealer must make a special suitability determination for the purchase of such securities and have received the purchaser's written consent to the transaction prior to the purchase. Additionally, for any transaction involving a penny stock, unless exempt, the rules require the delivery, prior to the transaction, of a disclosure schedule prescribed by the SEC relating to the penny stock market. The broker-dealer also must disclose the commissions payable to both the broker-dealer and the registered representative and current quotations for the securities. Finally, monthly statements must be sent disclosing recent price information on the limited market in penny stocks. Because of these penny stock rules, broker-dealers may be restricted in their ability to sell the Company's common stock. The foregoing required penny stock restrictions will not apply to the Company's common stock if such stock reaches and maintains a market price of $5.00 per share or greater.

Additional Information

We refer you to our Certificate of Incorporation, Bylaws, and the applicable provisions of the Delaware Revised Statues for a more complete description of the rights and liabilities of holders of our securities.

28

Table of Contents

    Filed Pursuant to Rule 424(b)(3)

THE FOLLOWING DISCUSSION AND ANALYSIS SHOULD BE READ TOGETHER WITH THE CONSOLIDATED FINANCIAL STATEMENTS OF THE COMPANY AND THE NOTES TO CONSOLIDATED FINANCIAL STATEMENTS INCLUDED ELSEWHERE IN THIS REGISTRATION STATEMENT ON FORM S-1. THIS DISCUSSION SUMMARIZES THE SIGNIFICANT FACTORS AFFECTING OUR OPERATING RESULTS, FINANCIAL CONDITIONS AND LIQUIDITY AND CASH-FLOW SINCE INCEPTION.

    Filed Pursuant to Rule 424(b)(3)

The Company Overview

Nexscient, Inc. is early-stage company engaged in the business of developing a Software as a Service (Saas) platform for commercialization that intends to exploit Industrial Internet-of-Things (IIoT), Artificial Intelligence (AI), and Cloud-computing technologies to deliver an innovative solution for manufacturers and continuous production facilities in the industrial automation sector that helps reduce equipment failures, avoid unscheduled downtimes, decrease equipment maintenance costs, and improve overall equipment efficiencies. The platform is currently under development.

Corporate History and General Information about the Company

Nexscient, Inc. was incorporated in the State of Delaware on March 14, 2023. Our fiscal year end is June 30. We are a development stage enterprise. Our principal office is located at 2029 Century Park East, Suite 400, Los Angeles, CA 90067. Our telephone number is (310) 494-6620 and our e-mail contact is [email protected]. Our website can be viewed at nexscient.com.

Addressing the shortcomings of most existing condition-based monitoring products on the market today, Nexscient is taking a unique approach by developing a remote, continuous monitoring solution as a subscription-based service -- one that not only will offer all of the benefits of condition-based monitoring diagnostic system through vibration and acoustic analysis, but also will offer those benefits with (i) no upfront capital expense of equipment and software purchases; (ii) no need to update and maintain and update purchased diagnostic equipment and software, (iii) no requirement for specialized training of maintenance personnel; and (iv) no need for licensing, maintaining, and updating software. From a financial perspective, our solution is expected to be more affordable because it does not require upfront investment and shifts what would be a capital expenditure to an operating expense for the customer. For the Company, our business model provides a pathway to profitability through recurring stream of revenues that can be realized through a growing base of subscribers and subscriptions.

Business and Market Summary

Nexscient represents the next-generation, wireless condition monitoring solution that is robust, secure, and scalable, offering manufacturers and continuous-process facilities a powerful new tool for not only reducing maintenance costs and protecting against potentially adverse conditions due to unexpected machine failures, but also improving production schedules, product quality and yield, and overall equipment efficiencies. Having instant access to accurate and timely information provides plant managers with a notable advantage in making front-end decisions that can improve return on investment. Through its anticipated subscription-based service, Nexscient expects to offer increased visibility, analytics, and continuous connectivity that not only provides an immediate solution to avert sudden machine failures, but also enables actionable insights into machine health and recommends adjustments for optimal performance. We intend to generate revenues initially from subscription fees and may generate additional revenues from premium service offerings as well as consulting services that may be offered directly to customers.

Operational & Financial Benefits

By leveraging the power of low-power sensor, edge processing, secure wireless connectivity, and Cloud computing technologies, we intend to develop an easy-to-use and affordable solution that helps continuous process, industrial facilities improve uptime and reliability, and optimize total cost of operations and maintenance. Continuous condition monitoring can help manufacturers automate the entire orchestration of events-from sensing performance data, updating critical systems and predicting breakdowns to alerting appropriate personnel and triggering schedule repairs-with regard to equipment maintenance. This makes continuous condition monitoring a compelling proposition for modern industrial facilities seeking to improve equipment productivity and cost competitiveness.

29

Table of Contents

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

According to the Deloitte Analytics Institute1 and various industry benchmarks, on average, predictive maintenance increases productivity by 25%, reduces breakdowns by 70% and lowers maintenance costs by 25%. Operational and financial benefits that can be further realized from using the Nexscient System for continuous condition monitoring include:

    Filed Pursuant to Rule 424(b)(3)

Additional benefits of condition monitoring for industrial equipment include:

? Decrease average equipment repair time; ? Reduce need for stocking spare parts inventory; ? Increase in Overall Equipment Effectiveness (OEE) (availability, performance, quality); ? Reduce maintenance costs through efficient scheduling of repairs; ? Reduce chances of collateral damage or catastrophic failure; ? Increase production through greater machine availability; ? Extend equipment and bearing service life; ? Improve product quality; and ? Improve employee safety.

Apart from these quantifiable benefits in relation to equipment performance, Nexscient is expected to deliver multiple intangible benefits. When implemented, the Nexscient system is expected to foster smooth running of factory operations and optimized production, by minimizing plant interruptions on account of machinery-related delays. Some of the other qualitative gains that may be derived include higher customer satisfaction, superior capacity management and better supply chain relationships.

The Industry/Marketplace

The maintenance of manufacturing equipment such as motors, pumps, compressors, and other industrial machinery is experiencing a major shift as new maintenance methods are increasingly being adopted across the industrial sector. The emergence of 'Industry 4.0' and Industrial Automation is pushing companies to adopt IIoT and AI into their maintenance practices to achieve better outcomes from their operations.

_____________________

1"Taking pro-active measures based on advanced data analytics to predict and avoid machine failure", Predictive Maintenance | Position Paper -Deloitte Analytics Institute, 2017

30

Table of Contents

Properly managing machine health plays an increasingly important role for continuous process, asset-intensive manufacturers in reducing operational expenditure, achieving superior cost efficiencies and resource utilization, and is becoming the top driver for many companies to remain competitive. Efficient machine maintenance practices go a long way in improving factory floor operations and reducing unforeseen expenditures.

Typically, manufacturers allocate 40% of their operating budgets toward running critical equipment, with an additional 5-8% earmarked for maintenance of the same equipment. Any unexpected equipment failure, not only increases the cost of operations, but also adversely affects asset utilization levels and ultimately impacts productivity.

Furthermore, the amount of money that is locked up in spare parts and inventory for repairs is in the tens of millions of dollars, because these parts often have such unexpected failures. For example, an auto assembly factory can experience the ill effects of downtime misfortunes adding up to $22,000 per minute or approximately $1.3 million every hour2. Likewise, an average manufacturing plant can have downtime costs extending in the vicinity of 5-20%.

The global predictive maintenance market is expected to grow from $5.66 billion in 2021 to $64.25 billion by 2030, witnessing a Compound Annual Growth Rate (CAGR) of 27.4% from 2022 to 2030, according to a market research report published by Next Move Strategy Consulting3. The major factors fueling the market growth include the increasing use of emerging technologies to gain valuable insights, and growing need to reduce maintenance cost and downtime.

The global predictive maintenance market is driven by rising demand for smart factories and is expected to register significant growth due to technological advancement such as wireless technology and remote monitoring. Remote monitoring is the most preferred monitoring process in continuous-process facilities that work continuously and are highly prone to flaws because it enables the operator to accurately collect data, which can be communicated immediately to all the concerned personnel.

Trends

The increasing advancements in efficiency and accuracy of machine condition monitoring equipment is resulting in growing demand for this equipment in several industries, as it maximizes machine productivity. Through effective condition monitoring, it is possible to virtually eliminate plant downtime resulting from unexpected machine failure. Condition monitoring facilitates planning of repairs during non-peak production hours. As an outcome of machine maintenance planning, the actual repair/maintenance work is more cost effective than the traditional way. Often, the overall effect of improved maintenance improves product quality.

Target Industries

Manufacturers and continuous process facilities using condition-based monitoring can be found in industries such as (i) automotive manufacturing, (ii) chemicals, (iii) metals and mining, (iv) oil & gas, (v) power & utilities and others, including (vi) food & beverage, (vii) cement, (viii) paper & pulp, (ix) pharmaceuticals, and (x) semiconductor & electronics. Many of these industries are under continuous pressure to improve performance in a competitive and cost-sensitive environment. Preventing machine downtime in production lines is a top priority. Ends users in these industries are increasingly adopting condition-based monitoring to help improve their competitive standing.

______________________________

2According to a research study conducted by Nielsen Research in 2006 following survey of 101 manufacturing executives in the automotive industry. https://news.thomasnet.com/companystory/downtime-costs-auto-industry-22k-minute-survey-481017

3Globe Newswire https://www.globenewswire.com/en/news-release/2022/08/24/2503654/0/en/Global-Predictive-Maintenance-Market-to-Generate-USD-64-25-Billion-by-2030-States-a-New-Report-by-Next-Move-Strategy-Consulting.html

31

Table of Contents

Geographic Locations

North America dominated the market in 2022, accounting for over 36% share of the global revenue4. The U.S. and Canada are slated to provide promising growth opportunities against bullish demand from power generation, aerospace, oil & gas, marine, and food & beverages industries.

The trend for vibration monitoring has become pronounced for oil condition monitoring in the oil and gas platform machinery lubricants. The rapid growth in the energy sector as well as technological advancements in manufacturing sector spurred the demand for condition-based monitoring in other countries. Also, the rising need for effective scheduling of machine maintenance as well as prediction of equipment failure across major industries, namely manufacturing, oil and gas and construction, are the major factors behind North America's largest market share. Manufacturers and continuous process facilities using condition-based monitoring can also be found in (i) Asia Pacific, (ii) Europe, (iii) Latin America, and (iv) Middle East/North Africa.

Drivers

Now-a-days smart factories hold huge potential for innovation. Some of the biggest challenges that the firms face today are resource and energy inefficiency, high labor cost, increasing capital, operational cost, and demographic change. Hence, more and more companies are implementing plant automation solutions to ensure regular monitoring of plant operations and processes, and thereby propelling the growth of the market.

Condition-based monitoring offers the flexibility required to accommodate a wide range of production processes and interfaces for smooth information exchange between the plant control system, process visualization unit and operator. The need for technology advancements and demand for effective and efficient operation in the smart factories increase the use of machine condition monitoring equipment.

Restraints

High capital expenditure and maintenance requirement is one of the key restraints impacting the condition-based monitoring market. The procurement, installation, operation, and maintenance cost of condition-based monitoring equipment, and other expensive monitoring systems, affects the overall spending. High capital requirement for such equipment would further hamper market growth. In spite of these restraints, condition monitoring still stands out as a superior way of driving efficient predictive maintenance, since it can boost the plant production capacity while driving down operating costs over the long term.

Opportunities

Large untapped markets in Asia-Pacific and Middle East could offer growth opportunities to market players. The condition-based monitoring market in Asia-Pacific is displaying strong growth due to continuous infrastructure development and business expansions, especially in emerging countries, mainly China and India. The deregulation policy and a substantial increase in foreign direct investments (FDIs) in Asian countries also triggered the establishment of new businesses across many industries in Asia-Pacific region. Moreover, the countries in the Middle East, primarily Saudi Arabia and Qatar, are also increasing the use of condition-based monitoring in the oil & gas sector.

Competition

We intend to compete with an array of established and emerging vendors of condition-based monitoring products and services and IIOT-equipped devices. As organizations increasingly embrace predictive maintenance, IIoT and other new industrial automation technologies, an increasing number of companies offering machine monitoring products and services could result to fill the growing demand. The introduction of new technologies and market entrants will continue to fuel an intense competitive environment as companies seek solutions to predicting equipment failures and maintaining equipment performance. Our competitors include condition-based monitoring equipment vendors, diversified diagnostic equipment and services vendors, and providers of machine monitoring products that compete with some of the features present in our solution such as Fluke, Emerson Electric Co. (NYSE: EMR), and Augury, Inc. We compete based on several factors, including product functionality; scope of offerings; performance; brand, reputation, and customer satisfaction; ease of implementation, use and service; price, scalability, reliability, and security. We believe that we will compete favorably with respect to these factors and will become well positioned as an emerging provider of predictive maintenance solution, data analysis, and professional services.

Purchase of Nodes

Management is in advanced discussions with a developer of nodes specifically designed for condition-based monitoring that substantially meet our technical requirements (the "Generic Nodes"). Management believes that by initially purchasing and integrating Generic Nodes, the cost and risk associated with the design and manufacture its own nodes will be significantly reduced allowing it to focus its resources on the development of the software required for its SaaS platform. While we're in the process of discussing a potential partnership with a Generic Nodes supplier, we have yet to finalize any purchase or enter into a binding agreement.

Contract Manufacturers, Joint Venture Partners & Suppliers

We ultimately expect to design and develop our own Nexscient Nodes and outsource the manufacturing of such Nodes to third-party contract manufacturers or joint venture partners. Over the long term, management believes that strategic partnerships with suppliers and contract manufacturers will be a major component of the Company's operating strategy and path to success. Currently, the Company has no existing agreements in place with such suppliers, joint venture partners, or contract manufacturers.

______________________

4"Machine Condition Monitoring Market Size, Share & Trends Analysis Report, 2023 - 2030", Grand View Research, 2022, https://www.grandviewresearch.com/industry-analysis/machine-condition-monitoring-market-report

32

Table of Contents

    Filed Pursuant to Rule 424(b)(3)

We are developing a Software as a Service (SaaS) platform that intends to exploit Industrial Internet-of-Things (IIoT), Artificial Intelligence (AI)/Machine Learning (ML), and Cloud-computing technologies to deliver an innovative solution for manufacturers and continuous production facilities in the industrial automation sector that helps reduce equipment failures, avoid unscheduled downtimes, decrease equipment maintenance costs, and improve overall equipment efficiencies. As of the date of this Prospectus, we are in the pre-development phase.

Industrial Internet of Things (IIoT)

The Internet of Things (IoT) refers to the network of physical objects or "things" embedded with sensors, software, and other technologies, interconnected through various communication protocols, networks, and cloud-based platforms. These interconnected objects collect and exchange data, enabling them to interact with the external environment or other systems in an intelligent manner. The Industrial Internet of Things (IIoT) is a transformative manufacturing strategy that integrates advanced digital technologies into the industrial sector to enhance operational efficiencies, improve performance, and create new revenue models. IIoT is an extension of the Internet of Things (IoT) paradigm, specifically tailored to industrial contexts, encompassing sectors including manufacturing, energy, oil and gas, and transportation.

Artificial Intelligence (AI)& Machine Learning (ML)

Artificial Intelligence (AI) is a branch of computer science focused on creating systems capable of performing tasks that would typically require human intelligence. These tasks include, but are not limited to, problem-solving, understanding natural language, perception (such as vision or speech recognition), and decision-making. AI systems are designed to mimic or simulate human cognitive functions, and they can operate either based on predefined rules (via algorithms) or by learning from data. Machine Learning is a subset of AI that provides systems the ability to learn and improve from experience without being explicitly programmed. In essence, ML focuses on the development of algorithms that can process vast amounts of data, derive patterns from this data, and then make decisions or predictions based on it.

Cloud Computing

Cloud computing is a technology paradigm that provides scalable, on-demand computing resources, delivered as a service over the internet. Instead of owning and maintaining physical data centers and servers, businesses can rent access to anything from applications to storage from a cloud service provider. This offers flexibility, cost-effectiveness, and the ability to scale services according to the need of the user. In the case of Nexscient, we intend to leverage cloud computing to offer Software as a Service (SaaS) to deliver our software solution over the Internet on a subscription basis, which will be hosted and maintained "in the cloud," thus eliminating the need for users to install or maintain the software locally.

Nexscient System

Nexscient intends to leverage the latest IIoT technology with edge processing, machine-learning/AI algorithms, and Cloud computing infrastructure to collect, diagnose and transmit critical information about machine health and performance. Designed as a scalable, stand-alone service, Nexscient does not depend on integration with any control or IT system (i.e., SCADA, CMMS, MES, ERP, etc.)* for its data source.

We have engaged an outsourced, third-party software development firm that is currently in the process of developing the Nexscient SaaS platform. When complete, the Nexscient predictive maintenance platform intends to offer a simple, cost-effective solution for continuous monitoring of rotating machinery. Nexscient strives to become the next-generation, wireless condition monitoring solution that is robust, secure and scalable, offering manufacturers and continuous-process facilities a powerful new tool for, not only reducing maintenance costs and protecting against potentially adverse conditions due to unexpected machine failures, but also improving production schedules, product yield and overall quality. Having instant access to accurate real-time data provides plant managers with a notable advantage in making front-end decisions that can improve return on investment.

    Filed Pursuant to Rule 424(b)(3)

Figure: Fundamental processes in the Nexscient Predictive Maintenance System

________________________________

*SCADA: Supervisory Control and Data Acquisition; CMMS: Computerized Maintenance Management System; MES: Manufacturing Execution Systems; and ERP: Enterprise Resource Planning.

33

Table of Contents

Collect: Nexscient Nodes externally attach to the outer casing of the equipment being monitored and data is collected via three on-board sensors: acoustic, vibration and temperature. Collected data is processed and wirelessly transmitted to a secure gateway, which makes the information available in the Cloud for analysis and viewing via a Web browser or mobile device.

Analyze: Our Cloud-based software uses rule-based logic, which incorporates domain-level expertise to effect immediate actionable insights and corrective recommendations without the reliance upon a large historical data set. Raw signal and temperature data collected from the Nexscient Nodes is stored in the Cloud and made available on demand for deeper analysis and engineering assessments, if desired.

Diagnose: In conjunction, our advanced machine learning/AI algorithms and analytics combine streaming data with historical information to learn, diagnose, and deliver long-term assessments, such as root cause analysis and estimate remaining useful life.

Execute: Resulting actionable outcomes are pushed to personnel and made available for viewing in an intuitive user interface accessible through any secure Web browser from anywhere in the world.

High-Performance Sensors

All rotating machinery exhibit physical and audible operating characteristics based on the type of equipment, i.e., pump, motor, compressor, fan, gearbox, etc. Nexscient Nodes collect data using the three on-board sensors, including acoustic, vibration and temperature, to diagnose potential problems before they occur.

Acoustic

Acoustic monitoring is highly accurate and provides an early indicator of potential issues. Not only can it identify potential failures extremely early, but it can also narrow down and specifically pinpoint which parts are in danger of failing. Because our sensors capture readings in the ultrasonic acoustic spectrum, they are able to detect ultrasonic frequencies generated by friction, a defect symptom, which is an indication of poor lubrication or bearing wear. Other symptoms may include rubbing and skidding of rolling elements against the bearing raceway, or impacting due to mechanical flaws or contaminated lubricant. Lubrication issues and bearing wear represent upwards of 80% of the issues encountered with rotating machinery. Because ultrasonic monitoring encompasses both sonic and electrical elements of machinery, it is capable of detecting not only mechanical failures but electric failures as well. Ultrasonic detectors can also be useful for identifying defect symptoms arising from misalignment, imbalance, or worn shaft couplings.

Vibration

Vibration sensors measure the radial, axial and horizontal displacement of the rotating machine. Our embedded 3-axis accelerometer, which detect vibration from all directions with one sensor, captures readings in the requisite frequency range. It checks for any unusual physical vibrations, which can serve as an early indicator of misalignment or motion that is too fast or too slow. A number of problems can cause anomalies in the vibration pattern, including but not limited to the slowing down or stopping of moving parts, bearings rubbing against each other in an unusual manner, and any internal imbalances or misalignments.

Temperature

Temperature sensors are typically used to detect heat caused by friction. They complement the acoustic and vibration sensors to collaborate vibration-detected degradation. The temperature trend will actually be a measure of the temperature inside the accelerometer. Although this is not the absolute temperature of the bearing, it is a relative temperature of the bearing casing the accelerometer is mounted on and can be trended over time or alarmed for changes in the bearing temperature. Wear and tear or problems with lubrication will often cause high vibration and high temperature in the bearing. There is a relatively good correlation between the overall vibration trend and the temperature trends providing supporting data on bearing condition and performance.

34

Table of Contents

Nexscient System Components

The Nexscient System is comprised of three primary components (Sensors, Cloud, Apps) that work together to produce an integrated subscription-based service (SaaS model) for customers seeking an affordable yet effective predictive maintenance solution.

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

Sensors

One key feature of the Nexscient System is its wireless sensors nodes, called Nexscient Nodes. These autonomous data collection beacons simply mount on existing machinery, seamlessly connect to our Cloud-based monitoring service, and wirelessly transmit collected data for analysis and diagnosis.

Data Collection

Each Nexscient Node incorporates three sensors, acoustic, 3-axial vibration, and temperature, to collect data. Since Nexscient Nodes are externally mounted on the equipment, there is no integration required, thereby bypassing the hassle and expense of integrating with any data network.

Cloud

Nexscient monitors assets continuously 24 hours a day, 7 days a week. Our Cloud-based services and Web apps are designed to meet the needs of managers who need a quick snapshot or engineers who want sophisticated tools and analysis features. Mobile apps (iPhone and iPad) are expected to match all of the functionality of the Web version.

Secure Wireless Connectivity

Deployment is virtually plug 'n play, as each Nexscient Node takes only a few minutes to self-configure with the gateway before beginning to collect data. Each Nexscient Node utilizes Wirepas wireless mesh networking protocol using to send data to the Nexscient gateway. Client certificates are used to identify the device on the server and AES-256 ciphers are supported for communications.

AI Analytics

Our platform design incorporates a combination of rule-based logic and machine learning/AI to achieve a short- and long-term view of the machine's health. We intend to use machine learning/AI analytics to carefully monitor, diagnose and relay changes to a machine's health status to designate personnel at the first sign of developing issues along with actionable insights. Our continuous machine monitoring service, once developed, will not only send notification alerts with detailed malfunction analysis, but will also recommend corrective actions.

35

Table of Contents

    Filed Pursuant to Rule 424(b)(3)

Nexscient intends to exploit the latest state-of-the-art IIoT, Cloud computing, and edge processing technology to enable data collection and transmission, driving machine learning/AI analytics to deliver real-time insights for predictive maintenance solutions. Nexscient's scalable platform will be extended to address more complex implementations and realizing greater value offered automatically detecting failures in equipment and common sub-assemblies spanning the entire manufacturing process. Nexscient's SaaS platform is currently under development.

Nexscient System Architecture Stack

The Nexscient SaaS platform intends to use state-of-the-art IoT architecture designed for redundancy, flexibility and scalability. Our platform represents a secure end-to-end Industrial IoT solution that takes a holistic approach on multiple levels by fusing together important features across four layers: Infrastructure, Data Management, Analytics, and Security.

The infrastructure layer refers to the connectivity networks of the Nexscient IIoT solution over which the data is securely transmitted/received. The data management layer represents the data acquisition and aggregation processes where edge processing generates meaningful results, which are passed on to the Cloud for further processing and analysis. The analytics layer refers to the software backend where data is ingested, analyzed, and interpreted at scale to generate insights. The security layer is an overarching layer with continuous processes ensuring sufficient security levels are in place on all levels.

INFRASTRUCTURE LAYER

The infrastructure layer includes the Nexscient Nodes with sensors, which capture data and communicate with a gateway via Wirepas mesh networking protocol. Collected data is pre-processed and stored, before it is transported from the gateway to the Nexscient Cloud platform, where further processing and analysis happens.

Sensors

The primary components of the Nexscient system are the Nexscient Node sensors, which collect various raw data into a data logger. These sensors collect real-time data that contains information, which provides us with an understanding of the machine's health and performance conditions. By monitoring these conditions in real time, we can analyze and predict alert situations, which can be communicated to designate personnel for further action. Each Nexscient Node includes an acoustic, vibration and temperature sensor.

Acoustic Ultrasonic Sensor

The embedded MEMS ultrasonic acoustic detector measures sound pressure waves in the 0-40 kHz frequency range. The waves act upon a resonant sensor to create a small electrical charge. The charge is amplified, measured, and converted to a corresponding audible frequency that is recorded to the data collector's memory. The signals monitored by an ultrasonic device are expressed as data using the unit decibels per microvolt (dBuV). Ultrasonic detectors are capable of accurately interpreting the sounds created by under-lubrication, over-lubrication, and early signs of wear. Ultrasound is produced by friction, impact, turbulence, and electrical discharge. Friction and impact are the by-products of mechanical equipment. For example, a roller bearing will produce friction as the shaft and balls roll around the center. If there is too much friction, however, problems begin to occur on the equipment due to imbalance, or the bearing might seize, thereby shutting down equipment altogether. Ultrasonic sensors offer a fast and effective means of determining such conditions in moving, mechanical components such as bearings, gearboxes, motors, compressors, etc.

According to NASA research5, "Ultrasonic monitoring of bearings provides the earliest warning of bearing failure. They noted that an increase in amplitude of a monitored ultrasonic frequency of 12 decibels over baseline would indicate the initial (incipient) stages of bearing failure. This change is detected long before it is indicated by changes in vibration or temperature."

Vibration Sensors

Vibration sensors can detect vibration from all directions with one sensor, measures the vibrations, which occur while the equipment is in motion. Our vibration sensor consists of a tri-axial MEMS accelerometer with a frequency range up to 6.3kHz (+/-3dB) with a 2,6667 Hz sampling rate. They check for any unusual acoustics or physical vibrations, which can serve as an early indicator of misalignment or motion that is too fast or too slow. It usually involves measuring the Root Mean Square (RMS) vibration of the bearing housing or some other point on the machine with the transducer located as close to the bearing as possible.

In machines where there is little vibration other than from the bearings, the spikiness of the vibration signal indicated by the Crest Factor (Peak-to-RMS ratio) may imply incipient defects, whereas the high energy level given by the RMS level may indicate severe defects. In some situations, the Crest Factor of the vibration is capable of giving an earlier warning of bearing defects. A number of problems can cause anomalies in the vibration pattern, including but not limited to the slowing down or stopping of moving parts, bearings rubbing against each other in an unusual manner, and any internal imbalances or misalignments.

______________________________

5Engineering Acoustics and Structural Acoustics and Vibration: Vibration and Acoustic Monitoring of Machinery and Structures, Robert D. Finch, Cochair Department of Mechanical Engineering, University of Houston, Houston, Texas 77204-4792

36

Table of Contents

Temperature Sensor

Temperature sensors are typically used to detect heat caused by friction. We use a thermistor with a range of -40 to 85oC and accuracy +/- 1oC (0 to 70oC). It complements the acoustic and vibration sensors to collaborate vibration-detected degradation. The temperature trend will actually be a measure of the temperature inside the accelerometer. Although this is not the absolute temperature of the bearing, it is a relative temperature of the bearing casing the accelerometer is mounted on and can be trended over time or alarmed for changes in the bearing temperature. Wear and tear or problems with lubrication will often cause high vibration and high temperature in the bearing. There is a relatively good correlation between the overall vibration trend and the temperature trends providing supporting data on bearing condition and performance.

Secure Connectivity

Each Nexscient Node is a fully wireless device that has no cables or external antenna. It uses Wirepas mesh networking protocol to send acoustic, vibration and temperature data to the Nexscient Cloud. Nexscient Nodes connect to the Cloud using TLS 1.2 over a TCP or cellular connection. Client certificates are used to identify the device on the server and AES-256 ciphers are supported for communications.

Industrial Compliance

Nexscient Nodes were specifically designed for industrial environments made from materials chosen to handle exposure to a wide range of chemicals and temperatures while providing a significant level of ingress protection in dirty environments. Nexscient Nodes are suitable for indoor or outdoor use (IP67) and certified for use in Class 1 Div. 2 environments and certified for FCC, CE, UL60079, and CSA 60079.

DATA MANAGEMENT LAYER

Data management layer provides a centralized secure layer where we effect data acquisition, aggregation, and processing.

Data Acquisition

At the core of our data acquisition system, collected data from the sensors is converted to discrete levels that can be interpreted by the processor and stored for analysis. We take advantage of libraries that abstract hardware interfaces, which enable us to work with sensors in a more straightforward way by collecting information the sensors provide to our application instead of on the low-level details of working directly with hardware.

Edge Processing

Because sensor data can easily consume network bandwidth and potentially cause latency issues, we perform edge processing on the collected data as a way to lessen the burden on the core infrastructure. With this approach, we preprocess the data, generate meaningful results, and pass only those on to the Cloud for further processing and analysis. For example, rather than passing on raw vibration data for the pumps, we aggregate and convert the data, analyze it, and send only projections as to when each device will fail or need service.

ANALYTICS LAYER

The analytics layer reads the data digested by the Data Management layer. Our solution employs rule-based logic and AI analytics to accurately evaluate current technical condition of the machines and to predict their failures. The analytics layer also processes and displays the information collected via the sensors. It includes analytics tools, AI and machine learning, and visualization capabilities.

37

Table of Contents

Rule-Based Logic

Continuous diagnostics relies on sensors to continuously collect data about equipment and send alerts according to predefined rules, i.e., when a specified threshold has been reached. With rule-based logic, we use pre-defined rules, such as "if-this-then-that", which describe certain machine behaviors and inter-dependencies between the various system components, to trigger certain events. Rule-based logic delivers immediate measurable benefits without the need for a large historical data set or advanced machine learning/AI algorithms and data science at the outset. Our solution offers quick results and forms a steppingstone into advanced analytics as data is collected over time - advanced analytics with predictive alerts and automated root cause analysis can be applied at a later phase once sufficient historical data has been collected to accurately identify issues before they occur.

Machine Learning/AI

Machine learning and AI tools are applied to acoustic, vibration and temperature data to push the boundaries of production floor efficiency. Advanced machine learning/AI algorithms learn a machine's normal data behavior and use this as a baseline to identify and alert deviations in real-time. These algorithms look at collected historical data combined with tailored machine-learning algorithms, to run different scenarios and predict what will go wrong and when. We use two approaches to AI and machine learning for predictive analytics - supervised and unsupervised machine learning - each is relevant for a different scenario and depends on the availability of sufficient historical training data and the frequency of asset failure.

Anomaly Analysis

Anomaly Analytics uses machine learning to understand behavioral patterns within time series data, to identify anomalies and to continuously forecast future values. Our alerts operate in real time and offer context - correlating each incident to similar anomalies, relevant factors and the potential root cause.

Regression Analysis

We use regression models to predict metrics such as Remaining Useful Life - the amount of time an asset will remain operational before its next failure - while iteratively trialing and selecting the most appropriate algorithms to use.

Root Cause Analysis

By implementing Automated Root Cause Analysis, there is accurate visibility into early causes of process inefficiencies, with a low number of alerts and false positives. By fusing historical and real-time machine data, machine-learning algorithms trace correlations between the consolidated data and the process inefficiencies. Then, root causes are ranked by likelihood level, delivering production teams with prioritized suggestions to quickly mitigate machine failure that may impact production yield and quality. Automated Root Cause Analysis generates actionable insights, enabling plant managers to reduce unplanned downtime, increase production throughput and maintain schedules.

Data Visualization

Nexscient presents a user-friendly interface with real-time dashboards and interactive data visualizations designed to facilitate major takeaway points. We incorporate point and click data exploration and rich analysis tools to get quicker and accurate interpretations. Our automatic work order generator produces easy-to-understand instructions for inspections and follow-up recommendations.

Automatic Work Orders

User requirements for events and notifications vary based on an application's criticality, the user's role, and personal preference. Nexscient offers a flexible and versatile notifications service that generates work orders specifically describing developing issues along with recommended actions or maintenance procedures. These real-time alerts and reports are sent via push notifications, emails and/or text messages. Optionally, by leveraging its REST API interface, Nexscient can also be optionally integrated with existing CMMS or ERP systems to natively generate and send work orders through the respective system.

Real-Time Dashboard

Leveraging a powerful, yet simple and intuitive Web-based user interface, users can view the dashboard to visualize and analyze machine performance. Visual indicators and alerts are provided in the context of the production process and enable users to quickly pinpoint the root cause and determine the required maintenance action.

38

Table of Contents

Rich Analysis Tools

For deeper analysis, Nexscient plans to offer rich analysis tools for power-users:

? Explore trend, waveform, and spectrum graphs on any browser; ? Analyze spectra with harmonic cursors and sidebands; ? Trend broadband features, like RMS or peak-to-peak; ? Trend narrowband features, like forcing frequencies and bearing tones; ? Configure F-max, lines of resolution, windowing, and averaging metrics; ? Configure bearing tones from our database of bearings; and ? View demodulated and enveloped spectra to catch bearing and other high-frequency issues.

SECURITY LAYER

Security spans all layers, guaranteeing protection of data, plus management, monitoring, orchestration, and provisioning to allow rapid scaling on an ongoing basis. All of the data paths between sensors, the Cloud and apps are authenticated and fully encrypted; connection requests are always initiated by the sensors to prevent inbound threats. From pre-to post-development, our secure software development lifecycle (SDLC) provides best-in-class level of security.

Security Automation and Orchestration

We build in-house tools and capabilities that automatically combat threats - quickly and at scale. These tools respond for us when possible, allowing us to focus on improving our defenses.

Proactive Security

We safeguard data with continuous delivery and code-level security insights. We use static and dynamic code analysis, including process gates to prevent introducing vulnerabilities into the production environment.

Information Classification

To determine the right level of protection, we first classify information before any ingestion takes place. We classify all data, provide clear visibility of threats, maintain highly restricted access and isolate live data from other environments. Once data ingestion begins, we encrypt information while it's in transit and at rest.

Access and Authentication

Based on National Institute of Standards and Technology (NIST) requirements, users only receive the level of access necessary to perform their jobs. Data access control includes passwords, cryptographic keys and multi-factor authentication devices.

Access Zone Security

Our networks use a tiered classification framework to provide data separation. Each client-protected data enclave is a fully security-hardened stack that includes endpoint and network threat prevention, application firewalls and vulnerability scanning.

39

Table of Contents

    Filed Pursuant to Rule 424(b)(3)

We believe our service will be viewed by businesses as a cost-effective way to reduce maintenance costs while increasing productivity, giving them advance warning of potential machine failure allowing them to properly schedule maintenance and better manage their resources. One of the key differentiators in our marketing strategy is to emphasize the "no up-front cost" subscription feature because we provide all of the monitoring sensors as part of the subscription service, thereby eliminating a capital expenditure to the business's balance sheet.

Management will emphasize speed in penetrating selected markets and implementing advertising and public relations campaigns. Financial results will be compiled and reported weekly so that gross and net margins can be reviewed and benchmarked. Marketing will be continually monitored and adjusted as needed to maximize market penetration and profitability. Cost control and brand management will be critical to the overall strategy.

Brand Development

We will focus our marketing efforts on increasing the strength of the 'NEXSCIENT' brand, communicating product advantages and business benefits, generating leads for our sales teams and channel partners while driving product adoption. We will deliver targeted content to demonstrate our predictive maintenance platform and use digital advertising methods to deliver opportunities to our sales teams. We will engage with existing customers to provide education and awareness to promote expanded use of our solution. We will work with our own researchers, as well as the broader data science community, to gather important information about potential opportunities and customer leads through an online community, social media, and traditional public relations.

Differentiate us from our competitors

The Nexscient system has powerful capabilities, quick to set up, easy to use, does not require up-front costs, special training, is compatible with most rotating machines in use today, and works right out-of-the-box without the need for any system integration. We plan to establish our service as a cost efficient, machine-monitoring solution for our target markets.

Build a relationship-oriented business

For future clients, such as channel partners and OEMs, relationships will be important. We will become a revenue-generating partner for them, not just a vendor, making these market segments increasingly receptive to our offerings. We must effectively convey the potential monetary value of the relationship, as well as the intrinsic value in being able to offer no upfront cost, ease of deployment, and powerful predictive capabilities to their end-users.

Focus on target markets

We plan to focus our sales and marketing efforts strategically in order to succeed in our target markets. As a start-up company, we believe direct and channel sales will give us the quickest launch and penetration while immediately generating revenues to sustain our company's growth and expansion into other markets.

Fulfill the promise

We can't just market and sell our products, service and support; we must actually deliver as well. We need to make sure we have the technological knowledge we claim to have, while keeping up with evolving technologies to advance the capabilities of our newest products and services.

    Filed Pursuant to Rule 424(b)(3)

Our most important marketing goal as a start-up is to establish product and brand awareness with customers in each target market. The way we go about this task will vary from one target market segment to another.

Direct Sales

We will be marketing to businesses through traditional sales efforts, such as advertising in trade journals and publications and establishing a presence at select trade shows geared towards businesses in our market segment. For the larger companies we target, we will offer the free use of our service for a limited time, to prove their efficacy in controlling maintenance costs and averting potential equipment failures, in order to penetrate and gain market share in this segment. We believe once reliability engineers and senior management of these businesses experience the rapid installation of the system, which is virtually plug-n-play and requires no integration with existing IT systems; experience the easy-to-understand tools and user interface without specialized training; and feel more in control of the health and performance of their equipment while realizing notable savings in equipment maintenance costs; all with no upfront costs, they will understand the value of Nexscient.

40

Table of Contents

Channel Partners

We will focus our efforts to partner with condition-based monitoring test equipment and analysis software suppliers. We will emphasize our products' potential as an additional source of revenue for them with recurring monthly revenues; this should make our product very desirable as part of their product lines. By solidifying these partnership agreements, we will also enable cross-marketing back into the consumer market through their sales forces' efforts and their advertising, increasing our sales efforts nationwide without the expense of additional personnel to cover the entire U.S. We believe that once partnered with these companies, our channel market partners (resellers) will advertise the Nexscient system as new features in their traditional outlets, primarily print advertising and in-house POS material, in order to increase mutual sales and brand awareness, benefiting both organizations.

OEMs

Another marketing strategy is to position Nexscient as a strategic ally with original equipment manufacturers of industrial equipment, such as motors, pumps, and compressors. By building a business based on long-standing relationships, we build defenses against competition through the demonstrated efficacy of our products, and our partners' loyalties.

    Filed Pursuant to Rule 424(b)(3)

The key to selling Nexscient products and services is the ability to identify a singular market and its unique needs, develop channels to these markets, to configure the Nexscient System, and market that particular feature set to that market. This strategy has the distinct advantage, critical with a potentially complex product, of a focused and simple sales message.

Direct Sales

We believe Nexscient services will benefit any manufacturer or continuous process plant that seeks actionable insights on maintenance and repair issues for their machines and equipment on a real-time basis. The keys to success in this segment are threefold:

    Filed Pursuant to Rule 424(b)(3)

The company will market its products to customer segments that require remote, continuous machine monitoring solution (highlighting its machine learning/AI capabilities) in a monthly subscription service. Other features will be specific to each customer segment. The company will spend substantial marketing efforts in determining which set of features are the most attractive to each customer segment. Offering customized quality product to each customer segment at a competitive price level will be one of the marketing goals of Nexscient.

Channel Partners

The sales through channel partners segment are anticipated to be strong for several reasons. By positioning our product to sensor manufacturers, testing equipment suppliers, and software analysis companies as an ancillary item to help them market their own products, we will effectively increase our sales force substantially, without the expenses of payroll, benefits, etc., because their sales force(s) will sell our products to their respective companies. This would also positively impact branding, making our name more commonplace in all the markets discussed herein. By securing alliances in this market, we also position ourselves as the leader in this new technology and its associated applications. This will foster confidence in the Nexscient product, increase sales dramatically and help our Company break into the global market.

41

Table of Contents

OEMs

As the market of industrial equipment manufacturers grows more competitive each year, this segment is continuously looking to add new technologies and systems to draw consumers to their specific and sometimes proprietary products and services. This natural synergy between our product's capabilities and this market segment's needs should prove to have a large and positive impact on the awareness of the Nexscient name and products, as well as increasing revenues through positioning our products with the leaders of this market segment. It is our understanding that many manufacturers of motors, blowers, compressors, and pumps, among others, will be incorporating IoT technologies, such as that in our Nexscient Nodes, into their products over the next five years. This will prove invaluable for Nexscient, as we position ourselves as the preferred supplier of remote, continuous monitoring technologies to OEMs.

Service and Support

We believe, as a value-add, we must be able to sell a support option in order to accommodate certain customers. The Nexscient System, while very easy to install and facilitate, will be better received if we offer (fee-based) consulting services for our larger clients, such as our channel sales partners and large corporate accounts. Simplifying the understanding and implementation of our system will help encourage the daily use and sales efforts of our product, while generating additional revenues for Nexscient, our channel market resellers while increasing the ROI for our investor/partner(s).

    Filed Pursuant to Rule 424(b)(3)

We intend to retain and public relations and marketing firm to coordinate the marketing, advertising, and promotion strategy, which will include print advertising in popular industry journals and attending trade shows for Condition-Based Monitoring, Vibration Analysis, and Predictive Maintenance, to name a few. Nexscient will utilize five primary promotion programs:

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

Website & Online Strategy

The Nexscient website will be the virtual business card and portfolio for the company, as well as its online "corporate home" for business-to-business marketing and investor relations. It will showcase our products and services, as well as hosting a portfolio of case studies and whitepapers. The website needs to be simple to navigate, yet well designed and flexible, to accommodate changes in our online needs. The key to the online strategy will be combining a very well-designed front end, with a back end capable of recording leads, processing online demos and information requests, offering online manuals, and running online marketing program for channel partners.

The Nexscient website is developed with few technical resources; a simple hosting provider will host the site and provide the technical back end. The design, updates and maintenance of the site will be done by contracted Web designers, for a more professional image of our company, freeing up senior management to focus on company growth and product development. As the website rolls out future developments such as new products, product add-ons and software updates, ancillary products, newsletters, and downloadable market research reports. We may need to contract further technical resources to build the trackable download information with the capabilities of transmitting and organizing extensive information.

42

Table of Contents

    Filed Pursuant to Rule 424(b)(3)

Nexscient subscription requirements will vary depending on the size of the facility and number of machines. Each Nexscient deployment will include a gateway, Nexscient Nodes and unlimited number of accounts to our Nexscient Cloud service. Depending on the number of assets to be monitored, a Nexscient network could include tens to hundreds to several hundred Nexscient Nodes; the price will vary based on the subscription package selected, number of Nexscient Nodes installed, and the number of machines being monitored.

Nexscient expects to offer the lowest cost structure in the industry, but premium pricing based on its uniquely rich feature set and quality service. The company expects it will be the pricing leader, manage the Nexscient brand for this identification and strive to maintain this leadership once obtained. We plan to organize focus groups to determine the best feature set and pricing for the present Nexscient service. The pricing schedule for its subscription offerings has not yet been determined.

Purchase Decision Factors

The primary purchase decision factors in predictive maintenance market are price, accessibility, and ease of use. Based on the Company's review of the existing market of prospective customers, we have identified significant brand loyalty by businesses in this industry. Once an individual has acclimated to the Nexscient system and realized the immediate benefits of the system, we believe they will be reluctant to switch to another service.

Powerful branding and advertising, emphasizing our competitive pricing structure, will create a significant barrier to competitors taking our customers. Becoming a market leader will strengthen the company's branding position and also make it more difficult for the competition. Management feels the primary competition will be other well-branded companies, which have deep advertising pockets, competitive products, and an established brand. Many of the major test instrumentation companies are moving into the remote, condition-based monitoring space because they have the infrastructure to support it and the brand to promote it. They will have the initial advantage in branding and marketing muscle, but they lack the nimble and spry nature of a start-up, such as Nexscient. We believe the marketplace is big enough to support all this competition and then some.

    Filed Pursuant to Rule 424(b)(3)

The increased visibility, analytics, and continuous connectivity afforded by Nexscient does not just offer a short-term solution for monitoring equipment for immediate problems, but rather, it enables continuous improvement by providing continuous process facilities with forward-looking capabilities necessary to solve future problems before they arise-compounding the value of the monitoring service over time. Many manufacturers with aged machines are challenged with the expense or feasibility of retrofitting their old equipment with modern sensors. Furthermore, outdated expensive hardware can lead to inefficient performance of the overall predictive maintenance program.

Even if industrial enterprises were to overcome such challenges, they would still have to incur an up-front capital expenditure to purchase the hardware, license the software, and train their personnel to ensure the data being captured is applied and interpreted correctly. With Nexscient, there will be no requirement to purchase any hardware or software, integration to existing IT systems is optional, and specialized training for personnel is not necessary. The key advantages of Nexscient System include:

No Upfront Cost; Low Cost of Entry

Unlike most other continuous monitoring systems on the market today, each subscription to the Nexscient monitoring system includes the sensors nodes used to remotely collect the data from the machines being monitored. Depending on the selected subscription plan and the number of machines to be monitored, Nexscient Nodes are provided as part of the subscription contract.

Quick Installation; Virtually Plug 'n Play

Due to the significantly quicker and less complicated installation process, the Nexscient system is anticipated to take less time to get up and running than alternative legacy monitoring systems. Setup is effectively plug 'n play, taking only a few minutes to install and commence monitoring.

43

Table of Contents

No Integration Required; Autonomous and Cloud-Based

Nexscient does not require integration with control systems or IT networks, thereby bypassing the hassle and expense of integration. If integration is desired, the Nexscient gateway will provide for integration via REST API.

Predictive Analytics; Rule-Based Expert System + AI Algorithms

Proprietary rule-based logic immediately diagnoses incipient problems while at the same time our machine learning/AI algorithms ingest data over time to construct a comprehensive profile for machine health and performance which allows for longer term analysis and planning of machine maintenance, helps reduce machine downtime, increases mean time between failures, and reduces costs of unnecessary preventative maintenance and spare parts inventory.

Remote Access; Continuous Connectivity

Visibility to the operational status of machine components allows plant managers to monitor and diagnose systems quickly as well as identify and resolve problems before the impact on machine availability and productivity. Continuous communication with the monitored equipment allows for a more streamlined process for data collection by replacing manual, route-based patrol thereby increasing efficiencies and leading to better machine health and performance.

Intellectual Property

To protect our unpatented proprietary technologies and processes, we rely on trade secret laws and confidentiality agreements with our employee(s), consultants, channel partners and vendors. At present our only intellectual property is our trademark for "Nexscient" Serial Number 97925547 registered with the USPTO and the Nexscient Predictive Maintenance Platform, which is still in development. The company will rely on provisional patents in the near term, filing for full patent protection, as necessary.

The duration of our trademark registration will vary from country to country, if we register such outside the United States. However, trademarks are generally valid and may be renewed indefinitely as long as they are in use and/or their registrations are properly maintained.

Subsidiaries

The Company has no subsidiaries.

Employees

We currently employ three full-time employees, which include the President & Chief Executive Officer, Chief Financial Officer, and Chief Operating Officer of the Company, all of which have responsibility for all segments of our business. Additionally, we have two contracted consultants.

Jumpstart Our Business Startups Act

In April, 2012, the Jumpstart Our Business Startups Act ("JOBS Act") was enacted into law. The JOBS Act provides, among other things:

    Filed Pursuant to Rule 424(b)(3)

44

Table of Contents

In general, under the JOBS Act, a company is an emerging growth company if its initial public offering ("IPO") of common equity securities was effected after December 8, 2011 and the company had less than $1 billion of total annual gross revenues during its last completed fiscal year. A company will no longer qualify as an emerging growth company after the earliest of:

    Filed Pursuant to Rule 424(b)(3)

The JOBS Act provides additional new guidelines and exemptions for non-reporting companies and for non-public offerings. Those exemptions that impact the Company are discussed below.

Financial Disclosure. The financial disclosure in a registration statement filed by an emerging growth company pursuant to the Securities Act of 1933 will differ from registration statements filed by other companies as follows:

(i) audited financial statements required for only two fiscal years; (ii) selected financial data required for only the fiscal years that were audited; (iii) executive compensation only needs to be presented in the limited format now required for smaller reporting companies.

(A smaller reporting company is one with a public float of less than $75 million as of the last day of its most recently completed second fiscal quarter).

However, the requirements for financial disclosure provided by Regulation S-K promulgated by the Rules and Regulations of the SEC already provide certain of these exemptions for smaller reporting companies. The Company is a smaller reporting company. Currently a smaller reporting company is not required to file as part of its registration statement selected financial data and only needs audited financial statements for its two most current fiscal years and no tabular disclosure of contractual obligations.

The JOBS Act also exempts the Company's independent registered public accounting firm from complying with any rules adopted by the Public Company Accounting Oversight Board ("PCAOB") after the date of the JOBS Act's enactment, except as otherwise required by SEC rule.

The JOBS Act also exempts an emerging growth company from any requirement adopted by the PCAOB for mandatory rotation of the Company's accounting firm or for a supplemental auditor report about the audit.

Internal Control Attestation. The JOBS Act also provides an exemption from the requirement of the Company's independent registered public accounting firm to file a report on the Company's internal control over financial reporting, although management of the Company is still required to file its report on the adequacy of the Company's internal control over financial reporting.

Section 102(a) of the JOBS Act exempts emerging growth companies from the requirements in 14A(e) of the Securities Exchange Act of 1934 for companies with a class of securities registered under the 1934 Act to hold shareholder votes for executive compensation and golden parachutes.

45

Table of Contents

Other Items of the JOBS Act. The JOBS Act also provides that an emerging growth company can communicate with potential investors that are qualified institutional buyers or institutions that are accredited to determine interest in a contemplated offering either prior to or after the date of filing the respective registration statement. The Act also permits research reports by a broker or dealer about an emerging growth company regardless if such report provides sufficient information for an investment decision. In addition, the JOBS Act precludes the SEC and FINRA from adopting certain restrictive rules or regulations regarding brokers, dealers and potential investors, communications with management and distribution of a research reports on the emerging growth company IPO.

Section 106 of the JOBS Act permits emerging growth companies to submit 1933 Act registration statements on a confidential basis provided that the registration statement and all amendments are publicly filed at least 21 days before the issuer conducts any road show. This is intended to allow the emerging growth company to explore the IPO option without disclosing to the market the fact that it is seeking to go public or disclosing the information contained in its registration statement until the company is ready to conduct a roadshow.

Election to Opt Out of Transition Period. Section 102(b)(1) of the JOBS Act exempts emerging growth companies from being required to comply with new or revised financial accounting standards until private companies (that is, those that have not had a 1933 Act registration statement declared effective or do not have a class of securities registered under the 1934 Act) are required to comply with the new or revised financial accounting standard.

The JOBS Act provides a company can elect to opt out of the extended transition period and comply with the requirements that apply to non-emerging growth companies but any such an election to opt out is irrevocable. The Company has elected not to opt out of the transition period.

    Filed Pursuant to Rule 424(b)(3)

We know of no material, existing or pending legal proceedings against our Company, nor are we involved as a plaintiff in any material proceeding or pending litigation. There are no proceedings in which our directors, officers or any affiliates, or any registered or beneficial shareholder, is an adverse party or has a material interest adverse to our interest.

46

Table of Contents

    Filed Pursuant to Rule 424(b)(3)

The following discussion of our financial condition and results of operations should be read in conjunction with the financial statements and related notes to the financial statements included elsewhere in this Registration Statement. Some of the statements under "Management's Discussion and Analysis," "Description of Business" and elsewhere herein may include forward-looking statements which reflect our current views with respect to future events and financial performance. These statements include forward-looking statements both with respect to us specifically and the renewable energy industry in general. Statements which include the words "expect," "intend," "plan," "believe," "project," "anticipate," "will," and similar statements of a future or forward-looking nature identify forward-looking statements for purposes of the federal securities laws or otherwise. The safe harbor provisions of the federal securities laws do not apply to any forward-looking statements contained in this Registration Statement. All forward-looking statements address such matters that involve risks and uncertainties. Accordingly, there are or will be important factors that could cause our actual results to differ materially from those indicated in these statements. We undertake no obligation to publicly update or review any forward-looking statements, whether as a result of new information, future developments or otherwise. If one or more of these or other risks or uncertainties materialize, or if our underlying assumptions prove to be incorrect, actual results may vary materially from what we projected. Any forward-looking statements you read herein reflect our current views with respect to future events and are subject to these and other risks, uncertainties and assumptions relating to our written and oral forward-looking statements attributable to us or individuals acting on our behalf and such statements are expressly qualified in their entirety by this paragraph.

The Company is an early-stage company and was incorporated in the State of Delaware on March 14, 2023. During the fiscal year ended June 30, 2023, the Company generated no revenues and incurred operating losses of $93,766 as part of its operating activities.

We believe that our current cash and cash equivalents, anticipated cash flow from operations and the proceeds from the sale of shares being offered hereunder will only be sufficient to meet our anticipated cash needs for the next 12-48 months. Our management has determined that the maximum amount of funds received from this Offering would be sufficient to cover our intended plan of operations contemplated for the next 48 months.

Results of Operations

From March 14, 2023 (inception) to Year Ended June 30, 2023

Revenues

We are in our development stage and have not generated any revenue from March 14, 2023 (inception) to year ended June 30, 2023.

Operating Expenses

We incurred total operating expenses of $93,766 from March 14, 2023 (inception) to year ended June 30, 2023. All of these expenses are related to development costs and general and administrative expenses, which included professional fees of $67,752 relating to consulting, legal and accounting costs incurred, including fees as part of the formation process of the Company. There is no historical financial data for the Company.

Net Loss

We incurred a net loss of $93,766 from March 14, 2023 (date of inception) to year ended June 30, 2023.

Liquidity and Capital Resources

As at June 30, 2023, the Company has a working capital surplus of $173,099, a net loss of $93,766 and has no revenues to cover its operating costs. We have $202,459 cash on hand and our anticipated burn rate is approximately $61,500 per month. Presently, our operations are being funded by funds previously raised and we believe our currently available capital resources would be sufficient to sustain our operations for a minimum of three (3) months. The Company intends to fund future operations through equity or debt financing arrangements. The ability of the Company to realize its business plan is dependent upon, among other things, obtaining additional financing to continue operations, and development of its business plan. In response to these requirements, management intends to raise additional funds through public or private placement offerings. These factors, among others, raise substantial doubt about the Company's ability to continue as a going concern. The accompanying financial statements do not include any adjustments that might result from the outcome of this uncertainty.

47

Table of Contents

We are currently in development of our software platform. We believe we will require a minimum of $738,000 to proceed with our business plan and remain in operation for at least the next 12 months, see Cash Requirements. As the platform comes online and starts to generate revenue, we will be hiring additional staff which will increase our monthly capital requirements, however, we believe the revenue generated from our operations should cover any additional expenditures.

Beginning October 2023, and continuing for the next twelve months, our plan of operations as presented below includes estimates for our proposed milestones, any one of which may be subject to delays resulting in overall setback of our development timeline. If we are unable to raise the maximum amount in this Offering, we will have to scale back our development and operational efforts, which may curtail the achievement of the proposed milestones, commensurate with the amount raised.

Month 1-2: Pre-launch Preparation (Estimated Expense: $35,000 - $45,000)

Define Technical and Functional Requirements: Determine the core features and functionality required for the initial release; Prioritize features based on customer needs.

Retain Outsourced Software Development Firm: A dedicated team of developers, designers, testers, and customer support representatives to provide the initial development of the Nexscient platform.

Budget Allocation and Roadmap: Allocate budget resources for development, marketing, and ongoing operations. Establish key milestones for achievement in the design, development, and deployment.

Month 3-4: Development and Pilot Program (Estimated Expense: $95,000 - $110,000)

Commence Product Development: Begin building the Minimum Viable Product (MVP) based on the defined specifications and established roadmap. Implement agile development methodologies for flexibility and continuous improvement.

Sensor Node Integration: Design and integrate interface for establishing connections with sensor nodes. Sensor nodes will transmit collected data to the system in real-time and at specified intervals. The system must provide authentication mechanisms to ensure only authorized sensors can send data. Data collected from sensors should include time-stamped acoustic, vibration, temperature information.

Feature Prioritization: Prioritize features based on feature specifications and technical requirements, competitive advantage, and resource availability. Create a detailed product roadmap.

System Reports: Build functionality into user interface to generate custom reports based on selected time periods and sensor types. Reports will include visualizations such as graphs, charts, and tables to represent data trends. Users should have the option to export reports in formats such as PDF or CSV or HTML.

Notifications: Notifications will be triggered by certain threshold-triggered events, system updates, and user configurations. Users will have the option to set custom triggers for notifications; notifications will provide concise and relevant information, including sensor details, event description and timestamp.

Continuous Testing: Conduct rigorous testing, including unit testing, integration testing, and user acceptance testing (UAT). Address any issues promptly.

Pilot Program: Deploy a pilot program with a select group of industrial customers. Gather feedback and iterate on the product.

Month 5-6: User Onboarding and Beta Testing (Estimated Expense: $55,000 - $85,000)

Beta Release: Launch a closed beta version of the software to a limited group of customers. Invite a select group of industrial customers to participate in beta testing. Gather valuable feedback to identify and fix any issues and refine the product based on input.

Documentation and Training: Develop comprehensive user documentation and training materials for both customers and internal teams.

Pricing and Packaging: Finalize subscription pricing models and packaging options. Prepare for billing and payment processing.

48

Table of Contents

Quality Assurance: Conduct thorough testing to ensure the product is stable, secure, and user-friendly.

Month 7-8: Marketing and Sales (Estimated Expense: $35,000 - $65,000)

Content Creation: Develop marketing materials, including website content, blog posts, demo videos, and case studies.

Marketing Strategy: Launch a marketing campaign targeting industrial customers through digital channels, industry events, and partnerships. Consider webinars, social media promotions, and email marketing.

Sales Strategy: Identify and work with channel partners. Develop and train sales personnel on the product's features and benefits. Develop sales collateral and pricing strategies. Equip the sales team with product knowledge and sales materials to effectively communicate the value proposition.

Early Access Program: Offer early access to interested customers at a discounted subscription rates to generate initial revenue and gather more feedback.

Month 9-10: Deployment (Estimated Expense: $90,000 - $120,000)

Beta Launch: Open the software to a wider group of customers, including early beta testers and selected leads.

Customer Onboarding: Develop an onboarding program to ensure customers can easily adopt the software.

Full Product Release: Launch the SaaS application to the public, with a focus on the identified industrial customer segments.

Monitoring and Support: Implement tools for monitoring customer usage and feedback. Provide dedicated customer support.

Customer Support: Scale up customer support operations to handle inquiries and issues effectively. Implement a ticketing system for tracking and resolution.

Month 11-12: Growth and Optimization (Estimated Expense: $50,000 - $75,000)

Monitor Performance Metrics: Continuously monitor key performance indicators (KPIs) such as customer acquisition cost (CAC), customer lifetime value (CLV), and churn rate to refine the strategy. Continue collecting and analyzing customer feedback to drive product improvements. Based on user feedback and data analytics, release updates and improvements to the software.

Reporting and Analysis: Regularly assess the performance against objectives and adjust strategies as needed.

Customer Engagement: Nurture customer relationships through engagement initiatives, including webinars, newsletters, and forums.

Customer Retention: Implement strategies to retain and upsell existing customers, including regular feature updates and customer support.

Cash Flow from Operating Activities

From March 14, 2023 (inception) to year ended June 30, 2023, the cash flows used in the Company's operating activities was $16,381.

Cash Flow from Investing Activities

From March 14, 2023 (inception) to year ended June 30, 2023, the net cash used in investing activities by the Company was $0.

Subsequent Event

On October 2, 2023, we entered into a Software Development Agreement with CORSAC Technologies Corporation, a non-related party, for the software development of the Nexscient SaaS platform. Pursuant to the agreement, the cost of the initial software development version is estimated to range between approximately $68,000 to $95,000.

Recent Developments

Since commencement of the agreement, CORSAC has completed two key milestones in the development schedule, expending more than 420 man-hours on software development. The milestones met to date include: the architecture and implementation of the foundational apparatus for establishing and managing account and user registration, authentication and administration; and established the configuration, authentication and administration protocol for integrating the sensor nodes. In the coming weeks, we anticipate that CORSAC will complete the configurations that provide logic and endpoint to customize notification settings, subscriptions set-up, payment management, and various components of the frontend user interface design.

Furthermore, the Company purchased additional gateway equipment from Treon for further testing and development, and is likely to make additional purchases in the coming weeks.

Company management also continues to have dialogue with factory operators for the purpose of hosting a pilot study of the Nexscient predictive maintenance system in their facility. One such factory is a manufacturer and supplier of noodles for one of the nation's largest fast-casual Asian food chains. No agreement has been reached yet.

49

Table of Contents

Cash Flow from Financing Activities

From March 14, 2023 (inception) to year ended June 30, 2023, the net cash provided by financing activities by the Company was $218,840. The cash provided by financing activities is related to increases in proceeds received from sales of our common stock and advances from related party.

Going Concern

We have not attained profitable operations and are dependent upon obtaining financing to pursue any extensive activities. For these reasons, our auditors stated in their report on our audited financial statements that they have substantial doubt that we will be able to continue as a going concern.

Contractual Obligations

We are a smaller reporting company as defined by Rule 12b-2 of the Securities Exchange Act of 1934 and are not required to provide the information under this item.

Future Financings

We will continue to rely on equity sales of our common shares and debt proceeds in order to continue to fund our business operations. Issuances of additional shares will result in dilution to existing stockholders. There is no assurance that we will achieve any additional sales of the equity securities or arrange for debt or other financing to fund our operations and other activities.

Expected Purchase or Sale of Significant Equipment

We do not anticipate the purchase or sale of any significant equipment, as such items are not required by us at this time or in the next twelve months.

Off-Balance Sheet Arrangements

We have no significant off-balance sheet arrangements that have or are reasonably likely to have a current or future effect on our financial condition, changes in financial condition, revenues or expenses, results of operations, liquidity, capital expenditures or capital resources that are material to stockholders.

Disagreements with Accountants on Accounting and Financial Disclosure

Other than the disclosure of uncertainty regarding the ability for us to continue as a going concern which was included in our accountant's report on the financial statements for the period from March 14, 2023 (inception) to year ended June 30, 2023; dbbmckennon's report on the financial statements of the Company for the years ended June 30, 2023 did not contain an adverse opinion or a disclaimer of opinion, nor were they qualified or modified as to uncertainty, audit scope, or accounting principles.

In connection with the audit of the financial statements of the Company from March 14, 2023 (inception) to year ended June 30, 2023, there were no disagreements on any matter of accounting principles or practices, financial statement disclosures, or auditing scope or procedures, which disagreements if not resolved to their satisfaction would have caused them to make reference in connection with dbbmckennon's opinion to the subject matter of the disagreement.

In connection with the audited financial statements of the Company from March 14, 2023 (inception) to year ended June 30, 2023, there have been no reportable events with the Company as set forth in Item 304(a)(1)(v) of Regulation S-K.

Critical Accounting Policies

Critical Accounting Policies described in the Notes to the Financial Statements, page F-7.

50

Table of Contents

Cash Requirements

We anticipate that our current cash and cash equivalents, anticipated cash flow from operations and the proceeds from the sale of 25% to 100% of the amount of shares being offered hereunder will be sufficient to meet our anticipated cash needs for the next 48 months. If we are able to sell only 75%, 50% or 25% of our offered shares, we anticipate that we will only be able to meet our anticipated cash needs for the next 36 months, 24 months or 12 months, respectively. There is no minimum number of shares that must be sold and there is no guarantee that the Company will raise any funds from the Offering.

We estimate that our maximum and minimum amount of expenses over the next 12 months will be approximately $960,000 and $738,000, respectively, as described in the table below. These estimates may change significantly depending on the nature of our future business activities and our ability to raise additional capital from shareholders or other sources. Some of these estimates will be paid for out of the proceeds of this offering, assuming we are successful in raising any such proceeds.

    Filed Pursuant to Rule 424(b)(3)

The foregoing chart sets forth estimates of the Company's total maximum and minimum operational expenses for the initial 12-month period following effectiveness of this Offering. The minimum expenses represent development costs and basic G&A expenses associated with minimal rents and office expenses, working capital for professional fees associated with project development expenses and general legal, accounting and consultant expenses. The amounts are not limited to proceeds received under this offering, if any, and therefore in order to reach our targets, we will need additional funds in the form of financing or revenues.

    Filed Pursuant to Rule 424(b)(3)

Identification of Directors and Executive Officers

The following table sets forth the names and ages of our current directors and executive officers:

    Filed Pursuant to Rule 424(b)(3)

Term of Office

Should a vacancy exist, the Company's Board of Directors has the power to nominate and appoint a director or directors to fill such vacancy, and each shall hold office until the next annual meeting of stockholders and until his/her successor shall have been duly elected and qualified.

51

Table of Contents

Background and Business Experience

Fred E. Tannous, MSEE, MBA- Director, President & Chief Executive Officer, Treasurer and Secretary

Since founding Nexscient, Inc. in March, 2023, as President and Chief Executive Officer, Mr. Tannous is responsible for overseeing all aspects of its vision, strategy, and product development. Mr. Tannous has over thirty-five years of experience in finance, engineering and new business development and previously consulted to several Fortune 500 companies as well as launching several of his own start-ups. Some of the companies that he founded and operated include Cryptonic Ventures (January 2021-March 2023), a blockchain-based videogame developer; Promise Nutritionals, Inc., (June 2020 - August 2021), a retail purveyor of wellness products under the brand name Promise Guru®; and OverNear/Rowl, Inc. (June 2011- March 2015), a location-based mobile messaging platform and mobile application. Over the past fifteen years, he has worked extensively with development stage and emerging companies to improve performance, enhance enterprise value and maximize returns. As a principal of Rothswell Financial, Inc. (2015-Present), Mr. Tannous has also helped effect transactions valued at more than $1.2 billion in companies across several industries, including mobile and wireless communications and networking technology sectors. One of his previous start-up companies partnered with Los Alamos National Laboratories to commercialize a declassified military technology for continuous remote sensing and monitoring applications. Drawing on his previous public company experience, Mr. Tannous co-founded and was the Chief Executive Officer of Health Sciences Group (2000-2005), an innovative life sciences company, where he was instrumental in successfully taking it public by effecting a self-underwritten public offering (IPO) of its equity securities and growing its market value to more than $100 million. Prior, Mr. Tannous held the position of Senior Analyst at corporate treasury for Hughes Aircraft Company, a government contractor, before transitioning to the position of Manager of Investments & Acquisitions at DIRECTV, where he worked with the CFO in financial operations and was responsible for valuing, structuring and executing strategic investments and overseeing the company's portfolio having a market valuation of over $1 billion. As Chief Financial Officer of Colorado Casino Resorts, Inc. (1996-1999), a gaming and hospitality concern, Mr. Tannous was instrumental in obtaining its listing and trading on NASDAQ and raising over $65 million in combined private equity and debt financing to expand its operations. Mr. Tannous started his career as an electrical engineer at Hughes Aircraft, where he worked on advanced radar signal and data processing techniques for electronic counter-counter-measures used in radar systems onboard F-14, F-15 and F-18/A fighter aircraft. He has co-authored several papers on proprietary and unconventional methods for detecting and countering radar jamming. Mr. Tannous holds a Master of Business Administration (MBA) in Finance and Banking from the University of Chicago (Booth) Graduate School of Business (1994) as well as a Master of Science (1990) and a Bachelor of Science (1988) in Electrical Engineering from the University of Southern California. Mr. Tannous is a member of the Association for the Advancement of Artificial Intelligence and the Association for Computing Machinery.

Tarek N. Shoufani- Director, Chief Operating Officer

Mr. Shoufani has over twenty-five years of experience at the forefront of new and innovative technology sectors where he has focused on implementing corporate strategy into daily operations to meet key objectives. Since 2006, as Managing Director of SinoAmerican Global Fund, Mr. Shoufani is involved in various stages of the Fund's portfolio companies spanning across a broad spectrum of industries globally. Mr. Shoufani brings extensive management experience in the technology industry as well as valuable know-how and expertise in market development and finance structuring within various industry sectors throughout the Americas, Asia, Europe, and Middle East. While working with IZP (2012-2015), a leading global big data company in Shenzhen, China, Mr. Shoufani was instrumental in helping expand their financial and logistical transactions segment across Asia-Pacific, Latin America, Europe and Middle East. As a key liaison with MPR Tech (2010-2012), China's equivalent to eBay, Mr. Shoufani worked with management to streamline online auction management operations and improve top line revenues while helping realize savings in operating expenses. As a key member of 4PX (2007-2010), an e-commerce solutions provider based in Shanghai, China, Mr. Shoufani worked with designers and engineers to implement custom supply chain systems and software services that delivered efficiencies across multiple levels including installation, training, maintenance, and security. Mr. Shoufani holds a Bachelor of Arts (BA) from University of California in Business Economics and Marketing, and is fluent in English, Arabic and French.

Michael J. Portera - Director, Chief Financial Officer

Mr. Portera joined the Company as a Director and Chief Financial Officer on July 12, 2023. With over forty years of experience in finance, sales, and business development, he is responsible for overseeing the financial operations of the Company, liaising with investment banks and financial institutions on fundraising initiatives, advising on merger and acquisition transactions, and implementing industry best practices for the Company's finances and overall financial health. Over the past fifteen years, as a consultant, Mr. Portera has worked with seasoned executives, entrepreneurs, and start-up businesses to successfully consummate thousands of transactions on a global basis, including serving as Treasurer of OverNear/Rowl, Inc. (September 2019 - September 2023), a location-based mobile messaging platform and mobile application. As a former Managing Director with NYPPEX Private Markets (2000-2011), he assisted accredited investors achieve liquidity for over half a billion dollars in illiquid securities in secondary markets with venture capital and private equity funds and was instrumental in raising capital for founders and management teams of early-stage startups. Previously, as Senior Vice President of Investments at Gilford Securities (1995-1999), Mr. Portera worked with Fortune 500 CEOs, Forbes 400 members, and high-net-worth individuals and institutions in various financings and investment-related initiatives. Over the course of his early career as a registered representative, Mr. Portera held senior-level positions at several investment banking firms, including Smith Barney (1992-1995), UBS (1988-1992), and Drexel Burnham Lambert (1983-1987). Early in his career, as a Certified Public Accountant (CPA), Mr. Portera served as a senior auditor at Deloitte & Touche in New York City. Mr. Portera holds a Bachelor of Science (BS) in Economics with a concentration in Accounting from the Wharton School at the University of Pennsylvania (1980).

52

Table of Contents

Eric Manlunas - Director

Mr. Manlunas joined the Nexscient Board of Directors in March, 2023. He has over thirty years of experience in various aspects of financing and building new enterprise and is a valuable member of our Board due to his depth of operating, strategic, and transactional experience. As a recognized business leader, Mr. Manlunas excels in demanding and fluid environments, often across multiple markets, continents, and cultures. Over the past twenty years, as founder and Managing Partner of Wavemaker Partners (2003 - Present), a cross-border venture capital firm with offices in Los Angeles and Singapore, Mr. Manlunas has been part of over 450 investments in early-stage businesses. He is adept at assimilating high levels of complexity, balancing competing factors, and quickly forming sensible and workable strategies to achieve stability and deliver sustainable outcomes. Prior to becoming a venture capitalist, from 1999 to 2003, Mr. Manlunas founded, built and successfully sold two businesses, an e-commerce and Internet Service Provider, to strategic buyers. During the early part of his career, he started as a consultant with Arthur Andersen's Retail Management Group. Mr. Manlunas holds a Master of Business Administration (MBA) from Pepperdine University (1995) and earned a Bachelor of Arts (BA) in Communications from Florida International University (1990).

Term of Office

Each director serves for a term of one year and until his successor is elected at the Annual Shareholders' Meeting and is qualified, subject to removal by the shareholders. Each officer serves for a term of one year and until his successor is elected at a meeting of the Board of Directors and is qualified.

Employees

We have three executive officers. These individuals are not obligated to devote any specific number of hours to our matters and intend to devote only as much time as they deem necessary to our affairs. Our officers are devoted full time to the Company; the amount of time they will devote in any time period will vary based on the stage of the business and progress the company is making. Accordingly, once we are beyond the developmental phase our management will spend more time on our affairs.

Limitation of Liability and Indemnification Matters

Insofar as indemnification for liabilities arising under the Securities Act may be permitted to directors, officers and controlling persons of the registrant pursuant to the foregoing provisions, or otherwise, we have been advised that in the opinion of the Securities and Exchange Commission such indemnification is against public policy as expressed in the Securities Act, and is, therefore, unenforceable.

Identification of Significant Employees

We have no significant employees other than the aforementioned Officers and Directors.

Family Relationship

Tarek N. Shoufani is the brother-in-law of Fred E. Tannous. Other than the foregoing, we currently do not have any officers or directors of our Company who are related to each other.

Involvement in Certain Legal Proceedings

During the past ten years no director, executive officer, promoter or control person of the Company has been involved in the following:

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

53

Table of Contents

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

i. Any Federal or State securities or commodities law or regulation; or ii. Any law or regulation respecting financial institutions or insurance companies including, but not limited to, a temporary or permanent injunction, order of disgorgement or restitution, civil money penalty or temporary or permanent cease-and-desist order, or removal or prohibition order; or iii. Any law or regulation prohibiting mail or wire fraud or fraud in connection with any business entity; or

    Filed Pursuant to Rule 424(b)(3)

Independence of Directors

The Board of Directors is currently composed of four members. Mr. Fred E. Tannous, Mr. Tarek N. Shoufani, Mr. Michael J. Portera, and Mr. Eric Manlunas. Messrs. Tannous, Shoufani and Portera do not qualify as independent Directors in accordance with the published listing requirements of the NASDAQ Global Market as they each hold officer positions. Mr. Eric Manlunas does qualify as an independent director as he is not an officer of the Company. The NASDAQ independence definition includes a series of objective tests, such as that the Director is not, and has not been for at least three years, one of the Company's employees and that neither the Director, nor any of his family members has engaged in various types of business dealings with us. In addition, the Board of Directors has not made a subjective determination as to each Director that no relationships exist which, in the opinion of the Board of Directors, would interfere with the exercise of independent judgment in carrying out the responsibilities of a Director, though such subjective determination is required by the NASDAQ rules. Had the Board of Directors made these determinations, the Board of Directors would have reviewed and discussed information provided by the Directors and the Company with regard to each Director's business and personal activities and relationships as they may relate to the Company and its management.

54

Table of Contents

Committees

We do not currently have an audit, compensation or nominating committee. The Board of Directors as a whole currently acts as our audit, compensation and nominating committees. We intend to establish an audit, compensation and nominating committee of our Board of Directors once we expand the Board to include one or more independent directors and intend to adopt a charter for each committee.

Our audit committee shall be primarily responsible for reviewing the services performed by our independent auditors, evaluating our accounting policies and our system of internal controls. Our compensation committee shall assist the Board in reviewing and approving the compensation structure, including all forms of compensation, relating to our directors and executive officers and periodically reviewing and approving any long-term incentive compensation or equity plans, programs or similar arrangements. Our nominating committee shall assist the Board in selecting individuals qualified to become our directors and in determining the composition of the Board and its committees.

Compliance with Section 16(a) of the Exchange Act

Section 16(a) of the Securities Exchange Act of 1934 requires our directors and executive officers and persons who beneficially own more than ten percent of a registered class of our equity securities to file with the SEC initial reports of ownership and reports of change in ownership of our common stock and other equity securities. Officers, directors and greater than ten percent stockholders are required by SEC regulations to furnish us with copies of all Section 16(a) forms they file. Since inception, we have not had a class of equity securities registered under the Securities Exchange Act of 1934, as amended. Hence, compliance with Section 16(a) thereof by our officers and directors is not required.

Risk Oversight

Effective risk oversight is an important priority of the Board of Directors. Because risks are considered in virtually every business decision, the Board of Directors discusses risk throughout the year generally or in connection with specific proposed actions. The Board of Directors' approach to risk oversight includes understanding the critical risks in the Company's business and strategy, evaluating the Company's risk management processes, allocating responsibilities for risk oversight among the full Board of Directors, and fostering an appropriate culture of integrity and compliance with legal responsibilities.

Corporate Governance

The Company promotes accountability for adherence to honest and ethical conduct; endeavors to provide full, fair, accurate, timely and understandable disclosure in reports and documents that the Company files with the SEC and in other public communications made by the Company; and strives to be compliant with applicable governmental laws, rules and regulations. The Company has not formally adopted a written code of business conduct and ethics that governs the Company's employees, officers and Directors as the Company is not required to do so.

In lieu of an Audit Committee, the Company's Board of Directors is responsible for reviewing and making recommendations concerning the selection of outside auditors, reviewing the scope, results and effectiveness of the annual audit of the Company's financial statements and other services provided by the Company's independent public accountants. The Board of Directors reviews the Company's internal accounting controls, practices and policies.

Code of Ethics

Our Board of Directors has not adopted a code of ethics. We anticipate that we will adopt a code of ethics when we increase either the number of our directors or the number of our employees.

55

Table of Contents

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

Narrative Disclosure to Summary Compensation Table

There are no formal contracts in place for employment of any officers. In addition to the foregoing, there are no employment contracts, compensatory plans or arrangements, including payments to be received from the Company with respect to any executive officer, that would result in payments to such person because of his resignation, retirement or other termination of employment with the Company, or its subsidiaries, any change in control, or a change in the person's responsibilities following a change in control of the Company.

Outstanding Equity Awards at Fiscal Year-End

There are no current outstanding equity awards to our executive officers.

Long-Term Incentive Plans

There are no arrangements or plans in which we provide pension, retirement or similar benefits for directors or executive officers.

Compensation of Directors

Our directors receive no annual salary or bonus for their service as members of the Company's board of directors.

Security Holders Recommendations to Board of Directors

Shareholders can direct communications to our Chief Executive Officer, Fred E. Tannous, at our executive offices. However, while we appreciate all comments from shareholders, we may not be able to individually respond to all communications. We attempt to address shareholder questions and concerns in our press releases and documents filed with the SEC so that all shareholders have access to information about us at the same time. Mr. Tannous collects and evaluates all shareholder communications. All communications addressed to our directors and executive officers will be reviewed by those parties unless the communication is clearly frivolous.

56

Table of Contents

SECURITY OWNERSHIP OF CERTAIN BENEFICIAL OWNERS AND MANAGEMENT

The following table sets forth certain information concerning the number of shares of our common stock owned beneficially as of November 6, 2023, by: (i) each of our directors; (ii) each of our named executive officers; and (iii) each person or group known by us to beneficially own more than 5% of our outstanding shares of common stock. Unless otherwise indicated, the shareholders listed below possess sole voting and investment power with respect to the shares they own. Unless otherwise specified, the address of each of the persons set forth below is care of the Company at the address 2029 Century Park East, Suite 400, Los Angeles, CA 90067.

Beneficial ownership has been determined in accordance with Rule 13d-3 under the Exchange Act. Under this rule, certain shares may be deemed to be beneficially owned by more than one person (if, for example, persons share the power to vote or the power to dispose of the shares). In addition, shares are deemed to be beneficially owned by a person if the person has the right to acquire shares (for example, upon exercise of an option or warrant) within 60 days of the date as of which the information is provided. In computing the percentage ownership of any person, the amount of shares is deemed to include the amount of shares beneficially owned by such person by reason of such acquisition rights. As a result, the percentage of outstanding shares of any person as shown in the following table does not necessarily reflect the person's actual voting power at any particular date.

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

Changes in Control

There are no present arrangements or pledges of the Company's securities, which may result in a change in control of the Company.

57

Table of Contents

    Filed Pursuant to Rule 424(b)(3)

Related Party Transactions

Related party transactions are measured at the exchange amount, which is the amount of consideration established and agreed to by the related parties. Related parties are natural persons or other entities that have the ability, directly, or indirectly, to control another party or exercise significant influence over the party in making financial and operating decisions. Related parties include other parties that are subject to common control or that are subject to common significant influences.

After the date of incorporation, 10,000,000 shares were issued to directors and officers at par value in exchange for concept and services for the Company valued at $10,000: Fred E. Tannous, founder, Director, President & CEO, Secretary, Treasurer: 6,000,000 shares; Tarek N. Shoufani, Director, Chief Operating Officer: 3,000,000 shares; and Eric Manlunas, Director: 1,000,000 shares. In addition, founder stock in the amount of 525,000 shares was issued to advisors at par value in exchange for services valued at $525: Dr. Leroy B. Pascal: 150,000 shares; Koji Kawana: 130,000 shares; Edwin Medley Payne: 100,000 shares; Dominique Laurin: 100,000 shares; and Salvatore Russo: 45,000 shares.

During the period ended June 30, 2023, there were expenses incurred on behalf of the Company by Fred E. Tannous, Director, President & CEO, Secretary and Treasurer totaling an amount of $19,860 which is included in accounts payable. As of June 30, 2023, included in advances from a related party is $500 due to this officer.

During the period ended June 30, 2023, there were cash expenses of $3,500 incurred for bookkeeping transactions between the Company and David E. Tannous, brother of our CEO, Fred E. Tannous. In addition, the Company issued 250,000 shares of its common stock, with a fair market value of $2,500, for bookkeeping services.

On April 26, 2023, pursuant to a unanimous written consent of the Board of Directors and Common Stock Subscription Agreement, the Company issued 123,000 shares of its common stock to our Director, Eric Manlunas, in exchange for a cash investment of $9,840.

On May 17, 2023, pursuant to a unanimous written consent of the Board of Directors and a Board Member Consulting Agreement, the Company issued 225,000 shares, with a fair value of $18,000 to Eric Manlunas, a Director of the Company, in exchange for consulting services.

On June 1, 2023, the Company entered into a Consulting Agreement with MJP Consulting, LLC ("MJP), a company owned by Michael J. Portera, whereby MJP was retained to provide market research and business, consulting and advisory services as reasonably requested by the Company in the various aspects regarding financial and operational issues of the Company. Consultant fee totaled $18,000, paid in two equal installments. Subsequently, the Board appointed Mr. Portera as a Director and Chief Financial Officer of the Company.

Other than the foregoing, none of the directors or executive officers of the Company, nor any person who owned of record or was known to own beneficially more than 5% of the Company's outstanding shares of its Common Stock, nor any associate or affiliate of such persons or companies, has any material interest, direct or indirect, in any transaction that has occurred during the past fiscal year, or in any proposed transaction, which has materially affected or will affect the Company.

With regard to any future related party transaction, we plan to fully disclose any and all related party transactions in the following manner:

? Disclosing such transactions in reports where required; ? Disclosing in any and all filings with the SEC, where required; ? Obtaining disinterested directors' consent; and ? Obtaining shareholder consent where required.

58

Table of Contents

Review, Approval or Ratification of Transactions with Related Persons

Given our small size and limited financial resources, we have not adopted formal policies and procedures for the review, approval or ratification of transactions, such as those described above, with our executive officers, Directors and significant stockholders. However, all of the transactions described above were approved and ratified by our Board of Directors. In connection with the approval of the transactions described above, our Board of Directors, took into account several factors, including their fiduciary duties to the Company; the relationships of the related parties described above to the Company; the material facts underlying each transaction; the anticipated benefits to the Company and related costs associated with such benefits; whether comparable products or services were available; and the terms the Company could receive from an unrelated third party.

We intend to establish formal policies and procedures in the future, once we have sufficient resources and have appointed additional Directors, so that such transactions will be subject to the review, approval or ratification of our Board of Directors, or an appropriate committee thereof. With regard to any future related party transaction, we plan to fully disclose any and all related party transactions in the following manner:

? Disclosing such transactions in reports where required; ? Disclosing in any and all filings with the SEC, where required; ? Obtaining disinterested directors' consent; and ? Obtaining shareholder consent where required.

Director Independence

Quotations for the Company's common stock are entered on the Over-the-Counter Bulletin Board inter-dealer quotation system, which does not have director independence requirements. For purposes of determining director independence, the Company applied the definitions set out in NASDAQ Rule 4200(a)(15). Under NASDAQ Rule 4200(a)(15), a director is not considered to be independent if he or she is also an executive officer or employee of the corporation. As a result, the Company has one independent director, Eric Manlunas, as our other directors, Fred E. Tannous, Michael Portera, and Tarek Shoufani, are each also an executive officer of the Company.

    Filed Pursuant to Rule 424(b)(3)

Lockett + Horwitz, a Professional Law Corporation of Foothill Ranch, California is acting as our counsel in connection with the registration of our securities under the Securities Act, and as such, will pass upon the validity of the securities offered in this offering.

    Filed Pursuant to Rule 424(b)(3)

The financial statements of our Company appearing elsewhere in this prospectus have been included herein in reliance upon the report of dbbmckennon, an independent registered public accounting firm, appearing elsewhere herein (which contains an explanatory paragraph describing conditions that raise substantial doubt about our ability to continue as a going concern as described in Note to the financial statements), and upon the authority of said firm as experts in accounting and auditing.

59

Table of Contents

COMMISSION POSITION ON INDEMNIFICATION FOR SECURITIES ACT LIABILITIES

Our Certificate of Incorporation and Delaware law provide that none of our officers or directors will be personally liable to the Company or its stockholders for any damages as a result of any act or failure to act in his or her capacity as an officer or director unless it is proven that:

    Filed Pursuant to Rule 424(b)(3)

These provisions eliminate our rights and those of our stockholders to recover damages from an officer or director for his or her breach of a fiduciary duty unless such breach involved intentional misconduct, fraud or a knowing violation of law. The limitations summarized above, however, do not affect our ability or that of our stockholders to seek non-monetary remedies, such as an injunction or rescission, against an officer or director for his or her acts or failure to act.

Insofar as indemnification for liabilities arising under the Securities Act may be permitted to our directors, officers and other persons pursuant to the foregoing provisions, we have been advised that in the opinion of the Securities and Exchange Commission, such indemnification is against public policy as expressed in the Securities Act and is therefore unenforceable.

    Filed Pursuant to Rule 424(b)(3)

This prospectus, which constitutes a part of the registration statement, does not contain all of the information set forth in the registration statement and the exhibits thereto. Statements contained in this prospectus as to the contents of any contract or other document that is filed as an exhibit to the registration statement are not necessarily complete and each such statement is qualified in all respects by reference to the full text of such contract or document. For further information with respect to us and the common stock, reference is hereby made to the registration statement and the exhibits thereto, which may be inspected and copied at the principal office of the SEC, 100 F Street NE, Washington, D.C. 20549, and copies of all or any part thereof may be obtained at prescribed rates from the Commission's Public Reference Section at such addresses. Also, the SEC maintains a World Wide Web site on the Internet at http://www.sec.govthat contains reports and other information regarding registrants that file electronically with the SEC. We also make available free of charge our annual, quarterly and current reports, and other information upon request. To request such materials, please contact Mr. Fred E. Tannous, President & Chief Executive Officer.

60

Table of Contents

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

Report of Independent Registered Public Accounting Firm (PCAOB ID F-2 3501) Balance Sheet as of June 30, 2023 F-3 Statement of Operations for the period March 14, 2023 to June 30, 2023 F-4 Statement of Stockholders' Equity for the period March 14, 2023 to June F-5 30, 2023 Statement of Cash Flows for the period March 14, 2023 to June 30, 2023 F-6 Notes to Financial Statements F-7

F-1

Table of Contents

    Filed Pursuant to Rule 424(b)(3)

To the Board of Directors of Nexscient Inc.

Opinion on the Financial Statements

We have audited the accompanying balance sheet of Nexscient Inc. (the "Company") as of June 30, 2023, and the related statements of operations, stockholders' equity, and cash flows for the period from March 14, 2023 (Inception) to June 30, 2023 and the related notes (collectively referred to as the financial statements). In our opinion, the financial statements present fairly, in all material respects, the financial position of the Company as of June 30, 2023, and the results of their operations and their cash flows for the period then ended, in conformity with accounting principles generally accepted in the United States of America.

Going Concern

The accompanying financial statements have been prepared assuming the Company will continue as a going concern. As discussed in Note 3 to the financial statements, the Company has not generated revenues and incurred losses from Inception, which raises substantial doubt about its ability to continue as a going concern. Management's plans in regard to these matters are also described in Note 3. The financial statements do not include any adjustments that might result from the outcome of this uncertainty.

Basis for Opinion

These financial statements are the responsibility of the Company's management. Our responsibility is to express an opinion on the Company's financial statements based on our audit. We are a public accounting firm registered with the Public Company Accounting Oversight Board (United States) (PCAOB) and are required to be independent with respect to the Company in accordance with the U.S. federal securities laws and the applicable rules and regulations of the Securities and Exchange Commission and the PCAOB.

We conducted our audit in accordance with the standards of the PCAOB. Those standards require that we plan and perform the audit to obtain reasonable assurance about whether the financial statements are free of material misstatement, whether due to error or fraud. The Company is not required to have, nor were we engaged to perform, an audit of its internal control over financial reporting. As part of our audit, we are required to obtain an understanding of internal control over financial reporting, but not for the purpose of expressing an opinion on the effectiveness of the Company's internal control over financial reporting. Accordingly, we express no such opinion.

Our audit included performing procedures to assess the risks of material misstatement of the financial statements, whether due to error or fraud, and performing procedures that respond to those risks. Such procedures included examining, on a test basis, evidence regarding the amounts and disclosures in the financial statements. Our audit also included evaluating the accounting principles used and significant estimates made by management, as well as evaluating the overall presentation of the financial statements. We believe that our audit provides a reasonable basis for our opinion.

/s/ dbbmckennon

We have served as the Company's auditor since 2023.

Newport Beach, California

September 15, 2023

F-2

Table of Contents

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

LIABILITIES AND STOCKOLDERS' EQUITY Current liabilities Accounts payable - related party $ 28,860 Advances from related party 500 TOTAL LIABILITIES $ 29,360

STOCKHOLDERS' EQUITY

Preferred Stock 10,000,000 shares authorized, $0.001 par value, 0 shares issued and outstanding at June 30, 2023 $ - Common Stock 75,000,000 shares authorized, $0.001 par value, 16,528,000 shares issued and outstanding at June 30, 2023 16,528 Additional paid-in capital 404,837 Subscriptions receivable (154,500) Accumulated deficit (93,766) TOTAL STOCKHOLDERS' EQUITY 173,099

TOTAL LIABILITIES AND STOCKHOLDERS' EQUITY $ 202,459

The accompanying notes are an integral part of these financial statements

F-3

Table of Contents

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

OPERATING EXPENSES Research and development 3,141 General and administrative 90,625 TOTAL OPERATING EXPENSES 93,766

NET LOSS $ (93,766) BASIC AND DILUTED LOSS PER COMMON SHARE $ (0.01) WEIGHTED AVERAGE NUMBEROF COMMON SHARES OUTSTANDING - BASIC AND DILUTED 12,220,670

The accompanying notes are an integral part of these financial statements

F-4

Table of Contents

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

The accompanying notes are an integral part of these financial statements

F-5

Table of Contents

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

CASH FLOWS FROM FINANCING ACTIVITIES Advances from related party 500 Proceeds from shares issued for cash 218,340 NET CASH PROVIDED BY FINANCING ACTIVITIES 218,840

NET INCREASE IN CASH 202,459 CASH AT BEGINNING OF THE PERIOD - CASH AT END OF THE PERIOD $ 202,459

Non-cash investing and financing activities: Shares issued for subscriptions receivable $ 154,500

    Filed Pursuant to Rule 424(b)(3)

F-6

Table of Contents

NEXSCIENT INC.

NOTES TO FINANCIAL STATEMENTS

NOTE 1 - ORGANIZATION AND DESCRIPTION OF BUSINESS

Nexscient, Inc. (the "Company") was incorporated in the State of Delaware on March 14, 2023. The Company is developing a subscription-based, condition monitoring solution for maintaining and protecting industrial equipment. The Company's objective is to exploit Industrial Internet-of-Things (IIoT), artificial intelligence (AI), and Cloud-computing technologies to offer a continuous, remote machine health monitoring service that provides actionable insights to manufacturers and continuous process facilities seeking an effective yet affordable predictive maintenance solution to help reduce equipment failures, avoid unscheduled downtimes, decrease equipment maintenance costs, and improve overall equipment efficiencies. The Company's head office in Los Angeles, CA.

NOTE 2 - SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES

This summary of significant accounting policies is presented to assist in understanding the financial statements. The financial statements and notes are representations of the Company's management, who are responsible for their integrity and objectivity. These accounting policies conform to the United States of America ("US GAAP") and have been consistently applied in the preparation of the financial statements.

Use of Estimates

In preparing financial statements in conformity with US GAAP, management makes estimates and assumptions that affect the reported amounts of assets and liabilities and disclosures of contingent assets and liabilities at the dates of the financial statements, as well as the reported amounts of revenues and expenses during the reporting periods. Management makes these estimates using the best information available at the time the estimates are made. However, actual results could differ materially from those estimates. Current estimates relate to the fair value of the Company's common stock issued for services.

Concentrations of Credit Risk

The Company maintains its cash with a major financial institution located in the United States of America which it believes to be credit worthy. Balances are insured by the Federal Deposit Insurance Corporation up to $250,000. At times, the Company may maintain balances in excess of the federally insured limits.

Cash

The Company considers all highly liquid investments with original maturities of three months or less to be cash equivalents.

Fair Value of Financial Instruments

Accounting Standards Codification ("ASC") 820 "Fair Value Measurements and Disclosures", defines fair value, establishes a three-level valuation hierarchy for disclosures of fair value measurement and provides disclosure requirements for fair value measures. The three levels are defined as follows:

    Filed Pursuant to Rule 424(b)(3)

For cash, accounts payable, and advances from related party, it is management's opinion that the carrying values are a reasonable estimate of fair value because of the short period of time between the origination of such instruments and their expected realization.

F-7

Table of Contents

Revenue Recognition

The Company will account for revenue under ASC 606, "Revenue from Contracts with Customers". The Company will determine revenue recognition through the following steps:

? Identification of a contract with a customer; ? Identification of the performance obligations in the contract; ? Determination of the transaction price; ? Allocation of the transaction price to the performance obligations in the contract; and ? Recognition of revenue when or as the performance obligations are satisfied

Revenue is recognized when control of the promised goods or services is transferred to customers, in an amount that reflects the consideration the Company expects to be entitled to in exchange for those goods or services.

To date, no revenues have been generated.

Research and Development

Research and development costs include costs to develop and refine technological processes used to carry out business operations. Research and development costs charged to expense for the period ended June 30, 2023 were $3,141.

Stock-Based Compensation

Stock-based compensation is accounted for in accordance with ASC Topic 718-10 "Compensation-Stock Compensation" ("ASC 718-10"). The Company measures all equity-based awards granted to employees, independent contractors and advisors based on the fair value on the date of the grant and recognizes compensation expense for those awards over the requisite service period, which is generally the vesting period of the respective award.

The Company classifies equity-based compensation expense in its statement of operations in the same manner in which the award recipient's payroll or contractor costs are classified or in which the award recipient's service payments are classified.

Income Taxes

The Company uses the asset and liability method of accounting for income taxes pursuant to ASC 740 "Income Taxes". ASC 740 requires an asset and liability approach for financial accounting and reporting for income taxes and allows recognition and measurement of deferred tax assets based upon the likelihood of realization of tax benefits in future years. Under the asset and liability approach, deferred taxes are provided for the net tax effects of temporary differences between the carrying amounts of assets and liabilities for financial reporting purposes and the amounts used for income tax purposes. Valuation allowances are provided for deferred tax assets if it is more likely than not these items will either expire before the Company is able to realize their benefits, or that future deductibility is uncertain. The provision for income taxes represents current taxes payable net of the change during the period in deferred tax assets and liabilities.

Earnings (Loss) per Share

Basic earnings (loss) per share is computed by dividing income (loss) available to common shareholders by the weighted-average number of common shares outstanding during the period. Diluted earnings (loss) per share reflects the actual weighted average of common shares issued and outstanding during the period, adjusted for potentially dilutive securities outstanding. Potentially dilutive securities are excluded from the computation of the diluted net earnings (loss) per share if their inclusion would be anti-dilutive. The Company had no dilutive securities for the period ended June 30, 2023.

F-8

Table of Contents

Recently Issued Accounting Pronouncements

Management does not believe that any other recently issued, but not yet effective, accounting standards could have a material effect on the accompanying financial statements. As new accounting pronouncements are issued, the Company will adopt those that are applicable under the circumstances.

NOTE 3 - GOING CONCERN

The financial statements have been prepared on a going concern basis which assumes the Company will be able to realize its assets and discharge its liabilities in the normal course of business for the foreseeable future.

The Company has generated no revenues and incurred losses since inception, resulting in an accumulated deficit of $93,766 as of June 30, 2023 and further losses are anticipated in the development of the Company's business. Accordingly, there is substantial doubt about the Company's ability to continue as a going concern.

The ability to continue as a going concern is dependent upon the Company generating profitable operations in the future and/or to obtain the necessary financing to meet its obligations and repay its liabilities arising from normal business operations when they come due. Management intends to finance operating costs over the next twelve months with existing cash on hand, loans from directors, private placement of common stock, and/or a registered offering of its common stock.

NOTE 4 - RELATED PARTY TRANSACTIONS

Related party transactions are measured at the exchange amount, which is the amount of consideration established and agreed to by the related parties. Related parties are natural persons or other entities that have the ability, directly, or indirectly, to control another party or exercise significant influence over the party in making financial and operating decisions. Related parties include other parties that are subject to common control or that are subject to common significant influences.

See Note 5 for stock issued for services and sold for cash to founders, officers and directors, and advisors.

On June 1, 2023, the Company entered into a Consulting Agreement with MJP Consulting, LLC ("MJP), owned by Michael J. Portera, whereby MJP was retained to provide market research and business, consulting and advisory services as reasonably requested by the Company in the various aspects regarding financial and operational issues of the Company. Consultant fee totaled $18,000, paid in two equal installments. Subsequently, the Board appointed Mr. Portera as a Director and Chief Financial Officer of the Company.

NOTE 5 - STOCKHOLDERS' EQUITY

At June 30, 2023, the Company's authorized capital consists of eighty-five million (85,000,000) shares, comprised of: (i) seventy-five million (75,000,000) shares of Common Stock, par value $0.001 per share (the "Common Stock"); and (ii) 10,000,000 shares of blank check Preferred Stock, par value $0.001 per share (the "Preferred Stock").

On March 17, 2023, the Company issued a total of 10,525,000 founder shares of its common stock to related parties, including officers and directors, and advisors in consideration for various pre-incorporation services rendered to the Company relating to the development of the its strategy, market research, marketing strategy and branding, and other. Management determined the fair value of stock issued to be $10,525, or $0.001 per share, using a market approach that considered infancy of the Company and an early cash investment at $0.01 per share discussed below.

During the period from Inception to June 30, 2023, the Company issued 1,350,000 shares of common stock for various services including product development, board of director services, and accounting services. Of these amounts, 475,000 were to related parties that included a director and a relative of the Company's Chief Executive Officer. The shares issued were valued from $0.01 to $0.08 based on the value of shares being sold for cash at the time of issuance to investors, which was deemed to be the market value. Total stock-based compensation for shares issued for services was $38,000.

A total of $48,525 stock-based compensation was recognized during the period ended June 30, 2023 and is included in general and administrative in the accompanying statement of operations.

On April 19, 2023, the Company issued 1,000,000 shares of its common stock to an early investor in exchange for a cash investment of $10,000, or $0.01 per share.

F-9

Table of Contents

On April 26, 2023, the Company issued 123,000 shares of its common stock to a Director, in exchange for a cash investment of $9,840, or $0.08 per share.

During the period from May 10, 2023 to June 30, 2023, the Company conducted a private placement offering whereby a total of 3,530,000 shares of common stock were issued at a price of $0.10 per share for a total value of $353,000. As at June 30, 2023, $154,500 of the subscriptions remained receivable. Such subscription receivable was received in full subsequent to June 30, 2023.

NOTE 6 - INCOME TAXES

For the periods ended December 31, 2022 and 2021, the Company did not record a current or deferred income tax expense or benefit due to current losses incurred by the Company.

Deferred taxes are recognized for temporary differences between the basis of assets and liabilities for financial statement and income tax purposes. Deferred tax assets of the Company, amounted to approximately $15,000 as of June 30, 2023, and consists primarily of net operating loss carryforwards totaling approximately $53,000. The net operating loss carryforwards are available to be utilized against future taxable income indefinitely. In assessing deferred tax assets, management considers whether it is more likely than not that some portion or all of the deferred income tax assets will not be realized. The ultimate realization of deferred tax assets is dependent upon the generation of future taxable income. Management considers the scheduled projected future taxable income, and tax planning strategies in making this assessment. Accordingly, the Company recognized a full valuation allowance on deferred tax assets. Deferred tax assets were calculated using the Company's combined effective tax rate, which is estimated to be approximately 28%, which is reduced to 0% for the period ended June 30, 2023 due to the full valuation allowance.

The Company has evaluated its income tax positions and has determined that it does not have any uncertain tax positions. The Company will recognize interest and penalties related to any uncertain tax positions through its income tax expense.

The Company is subject to taxation in the U.S. and state jurisdictions. The Company is not presently subject to any income tax audit in any taxing jurisdiction. The Company has not yet filed any tax returns and accordingly, all tax periods remain open to examination.

NOTE 7 - SUBSEQUENT EVENTS

Subsequent to June 30, 2023, the Company issued an additional 1,927,980 shares as part of its private placement offering for total cash proceeds of $192,798.

On July 12, 2023, at a special meeting of the Board of Directors, the Board appointed Michael J. Portera as a Director and Chief Financial Officer, and Company issued 1,500,000 shares of its restricted common stock, having a fair value of $150,000, based on its latest private placement offering price at $0.10 per share.

Management has evaluated subsequent events through September 15, 2023, the date the financial statements were available to be issued. Based on this evaluation, no material events were identified which require adjustment or disclosure in these financial statements, other than described above.

F-10

Table of Contents

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

Until _____________, all dealers that effect transactions in these securities, whether or not participating in this offering, may be required to deliver a Prospectus. This is in addition to the dealers' obligation to deliver a Prospectus when acting as underwriters and with respect to their unsold allotments or subscriptions.

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

Our existing shareholders (the "Selling Shareholders") are offering for resale, 7,682,980 shares of Common Stock. Our Common Stock is presently not traded on any market or securities exchange. The 7,682,980 shares of our Common Stock can be sold by the Selling Shareholders at a fixed price of $0.75 per share until our shares are quoted on the OTC Bulletin Board and thereafter at prevailing market prices or privately negotiated prices. There can be no assurance that a market maker will agree to file the necessary documents with the Financial Industry Regulatory Authority ("FINRA"), which operates the OTC Electronic Bulletin Board, nor can there be any assurance that such an application for quotation will be approved. We have agreed to bear the expenses relating to the registration of the shares for the Selling Shareholders.

61

Table of Contents

Each of the selling shareholders have been advised that they will be affected by the applicable provisions of the Securities Exchange Act of 1934, including, without limitation, Regulation M, which may limit the timing of purchases and sales of any of the securities by the selling shareholders or any such other person. We have instructed our selling shareholders that they may not purchase any of our securities while they are selling shares under this registration statement. Additionally, we have included the foregoing language in the Selling Shareholder Prospectus.

The Selling Shareholders and any broker or dealer participating in the sale of shares on behalf of the Selling Shareholders may be deemed to be "underwriters" within the meaning of the Securities Act of 1933, in which case any profit on the sale of shares by them or commissions received by such broker or dealer may be deemed to be underwriting compensation under the Securities Act of 1933.

This Prospectus covers the resale offering by the Selling Shareholders of 7,682,980 shares of Common Stock. The Company is concurrently conducting a primary offering for 4,000,000 shares, which is covered in a separate public offering prospectus.

THE PURCHASE OF THE SECURITIES OFFERED THROUGH THIS PROSPECTUS INVOLVES A HIGH DEGREE OF RISK. YOU SHOULD CAREFULLY READ AND CONSIDER THE SECTION OF THIS PROSPECTUS ENTITLED "RISK FACTORS" BEFORE BUYING ANY SHARES OF NEXSCIENT, INC. COMMON STOCK.

NEITHER THE SECURITIES AND EXCHANGE COMMISSION NOR ANY STATE SECURITIES COMMISSION HAS APPROVED OR DISAPPROVED OF THESE SECURITIES OR PASSED UPON THE ADEQUACY OR ACCURACY OF THIS PROSPECTUS. ANY REPRESENTATION TO THE CONTRARY IS A CRIMINAL OFFENSE.

You should rely only on the information contained in this Prospectus and in any Prospectus supplement we may file after the date of this Prospectus. We have not authorized anyone to provide you with different information. If anyone provides you with different or inconsistent information, you should not rely on it. We will not make an offer to sell these securities in any jurisdiction where an offer or sale is not permitted. The information contained in this Prospectus is accurate only as of the date of this Prospectus, regardless of the time of delivery of this Prospectus or of any sale of our securities.

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

62

Table of Contents

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

63

Table of Contents

You should rely only on the information contained or incorporated by reference to this Prospectus in deciding whether to purchase our Common Stock. We have not authorized anyone to provide you with information different from that contained or incorporated by reference to this Prospectus. Under no circumstances should the delivery to you of this Prospectus or any sale made pursuant to this Prospectus create any implication that the information contained in this Prospectus is correct as of any time after the date of this Prospectus. To the extent that any facts or events arising after the date of this Prospectus, individually or in the aggregate, represent a fundamental change in the information presented in this Prospectus, this Prospectus will be updated to the extent required by law.

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

Securities being Up to 7,682,980 shares of Common Stock. Our Common Stock is offered described in further detail in the section of this Prospectus titled "DESCRIPTION OF SECURITIES - Common Stock."

Number of shares 19,955,980 shares of Common Stock issued and outstanding as outstanding before of September 15, 2023. the offering

Net Proceeds to the We will not receive proceeds from the resale of shares by Company the Selling Shareholders.

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

We will not receive any of the proceeds from the sale of our common shares by the Selling Shareholders. The Selling Shareholders will receive all of the net proceeds from the sales of common shares offered by them under this Prospectus.

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

The persons listed in the following table plan to offer the shares shown opposite their respective names by means of this Prospectus. The owners of the shares to be sold by means of this Prospectus are referred to as the "Selling Shareholders". These shares will be sold at a fixed price of $0.75 per share until our shares are quoted on the OTCQB and thereafter at prevailing market prices or privately negotiated prices.

The following table sets forth the name of the Selling Shareholders, the number of shares of Common Stock beneficially owned by each of the Selling Shareholders as of September 15, 2023 and the number of shares of Common Stock being offered by the Selling Shareholders. The Selling Shareholders may offer all or part of the shares for resale from time to time, however, the Selling Shareholders are under no obligation to sell all or any portion of such shares nor are the Selling Shareholders obligated to sell any shares immediately upon effectiveness of this Prospectus.

64

Table of Contents

    Filed Pursuant to Rule 424(b)(3)

65

Table of Contents

James McMiller 25,000 25,000 25,000 0.10 % Leonard Panzer 25,000 25,000 25,000 0.10 % Marcos Hume 25,000 25,000 25,000 0.10 % Maria Danko 25,000 25,000 25,000 0.10 % Michael and Amy Gusick 25,000 25,000 25,000 0.10 % Paolo Sandejas 25,000 25,000 25,000 0.10 % Remeliza Ticsay 25,000 25,000 25,000 0.10 % Reynaldo Cuerdo Jr 25,000 25,000 25,000 0.10 % Robert Ticsay 25,000 25,000 25,000 0.10 % Santiago Enrique Sandejas 25,000 25,000 25,000 0.10 % Stephen Salzstein 25,000 25,000 25,000 0.10 % The Tomorrow Group, LLC 25,000 25,000 25,000 0.10 % Emile F. Tannous 25,000 25,000 25,000 0.10 % Alexander F. Tannous 25,000 25,000 25,000 0.10 % Thomas Keneipp 25,000 25,000 25,000 0.10 %

TOTALS 7,682,980 7,682,980 7,682,980 32.07 %

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

66

Table of Contents

    Filed Pursuant to Rule 424(b)(3)

The Selling Shareholders and any of their pledgees, donees, transferees, assignees and successors-in-interest may, from time to time, sell any or all of their shares of common stock on any stock exchange, market or trading facility on which the shares are traded or quoted or in private transactions. These sales may be at fixed or negotiated prices. The Selling Shareholders may use any one or more of the following methods when selling shares:

    Filed Pursuant to Rule 424(b)(3)

The Selling Shareholders may also sell shares under Rule 144 under the Securities Act, if available, rather than under this prospectus.

Broker-dealers engaged by the Selling Shareholders may arrange for other brokers-dealers to participate in sales. Broker-dealers may receive commissions or discounts from the Selling Shareholders (or, if any broker-dealer acts as agent for the purchaser of shares, from the purchaser) in amounts to be negotiated. The Selling Shareholders do not expect these commissions and discounts to exceed what is customary in the types of transactions involved.

The Selling Shareholders may from time to time pledge or grant a security interest in some or all of the Shares owned by them and, if they default in the performance of their secured obligations, the pledgees or secured parties may offer and sell shares of common stock from time to time under this prospectus, or under an amendment to this prospectus under Rule 424(b)(3) or other applicable provision of the Securities Act of 1933 amending the list of selling shareholders to include the pledgee, transferee or other successors in interest as selling shareholders under this prospectus.

Upon the Company being notified in writing by a Selling Shareholder that any material arrangement has been entered into with a broker-dealer for the sale of common stock through a block trade, special offering, exchange distribution or secondary distribution or a purchase by a broker or dealer, a supplement to this prospectus will be filed, if required, pursuant to Rule 424(b) under the Securities Act, disclosing (i) the name of each such Selling Shareholders and of the participating broker-dealer(s), (ii) the number of shares involved, (iii) the price at which such the shares of common stock were sold, (iv) the commissions paid or discounts or concessions allowed to such broker-dealer(s), where applicable, (v) that such broker-dealer(s) did not conduct any investigation to verify the information set out or incorporated by reference in this prospectus, and (vi) other facts material to the transaction. In addition, upon the Company being notified in writing by a Selling Shareholder that a donee or pledgee intends to sell more than 5,000 shares of common stock, a supplement to this prospectus will be filed if then required in accordance with applicable securities law.

67

Table of Contents

The Selling Shareholders also may transfer the shares of common stock in other circumstances, in which case the transferees, pledgees or other successors in interest will be the selling beneficial owners for purposes of this prospectus.

The Selling Shareholders and any broker-dealer participating in the distribution of the Selling Shareholder Shares may be deemed to be "underwriters" within the meaning of the Securities Act, and any commission paid, or any discounts or concessions allowed to, any such broker-dealer may be deemed to be underwriting commissions or discounts under the Securities Act. At the time a particular offering of the Selling Shareholder Shares is made, a prospectus supplement, if required, will be distributed which will set forth the aggregate amount of Selling Shareholder Shares being offered and the terms of the offering, including the name or names of any broker-dealers or agents, any discounts, commissions, and other terms constituting compensation from the Selling Shareholders and any discounts, commissions, or concessions allowed or reallowed or paid to broker-dealers.

Under the securities laws of some states, the Selling Shareholder Shares may be sold in such states only through registered or licensed brokers or dealers. In addition, in some states the Selling Shareholder Shares may not be sold unless such shares have been registered or qualified for sale in such state or an exemption from registration or qualification is available and is complied with.

There can be no assurance that any Selling Shareholder will sell any or all of the Selling Shareholder shares registered pursuant to the registration statement, of which this prospectus forms a part.

The Selling Shareholders and any other person participating in such distribution will be subject to applicable provisions of the Exchange Act and the rules and regulations thereunder, including, without limitation, Regulation M of the Exchange Act, which may limit the timing of purchases and sales of any of the Selling Shareholder Shares by the Selling Shareholders and any other participating person. Regulation M may also restrict the ability of any person engaged in the distribution of the Selling Shareholder Shares to engage in market-making activities with respect to the Selling Shareholder Shares. All of the foregoing may affect the marketability of the Selling Shareholder Shares and the ability of any person or entity to engage in market-making activities with respect to the Selling Shareholder Shares.

Once sold under the registration statement of which this prospectus forms a part, the Selling Shareholder Shares will be freely tradeable in the hands of persons other than our affiliates.

    Filed Pursuant to Rule 424(b)(3)

68

Table of Contents

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

    Filed Pursuant to Rule 424(b)(3)

Until ______, all dealers that effect transactions in these securities, whether or not participating in this offering, may be required to deliver a Prospectus. This is in addition to the dealers' obligation to deliver a Prospectus when acting as underwriters and with respect to their unsold allotments or subscriptions.

COMTEX_443469158/2255/2023-11-14T16:00:04

(c) 1995-2023 Cybernet Data Systems, Inc. All Rights Reserved

Web sites - Information Technology & Internet - Consumer Infoline
October 5, 2023 5835 mots
New Gold Reports Strong Third Quarter Operational Results

News Today New Gold Reports Strong Third Quarter Operational Results October 5, 2023 Provides Notice of Release of Third Quarter Financial Results ... Voir l'article

Ce document référence un lien URL de site non hébergé par Cision.

Ghanaian Chronicle (Accra, Ghana)
Thursday, November 23, 2023 2959 mots, p. NA

Feature: Can We Survive The 'Attack' Of Big Tech?

'Every morning a lion wakes up, it knows it must run faster than the slowest gazelle, or it will starve to death...It doesn't matter whether you are a lion or a gazelle, you better be running'

First used by Dan Montano in The Economist, but popularised by Thomas Friedman in The World is Flat.

If, 20 years ago, you asked me whether big technology (or big tech) companies were a threat to journalism, my answer would have been an emphatic yes. After all, these companies do our job without our job description. They also disrupt the media space while taking little responsibility for content.

Perhaps I should explain that there is a slight difference in form, but not always in substance, between big tech and big search engines.

While big tech could sometimes be a dominant player in information technology hardware, like Samsung, or in e-commerce, like Amazon, search engines are software monsters although both core hardware and software providers in this field have the capacity as we have seen, for forward or backward linkages.

I will focus more on search engines, at least a few in the big league that have significantly disrupted our work, for good or ill.

I'm sure you know them - Google, Facebook, X (formerly Twitter), Yahoo, YouTube, Baidu and so on. Please don't add MySpace to this list; it died before they could write our obituary.

The buzz-word these days, is 'sustainability.' What does it mean? One of the most practical definitions I have seen is, 'sustainability consists of fulfilling the needs of the current generation without compromising the needs of future generations.'

As to whether big tech poses an existential threat to the survival of the Nigerian media and the way out, if indeed such a threat exists, we shall see soon enough.

How media earns

Traditional media's two basic sources of revenue are advertising and circulation or subscription sales. On the face of it, the fear of a journalistic doomsday appears justified in light of catastrophic declines in revenues from these two major sources of media income.

The relationship between big tech and traditional news media is already complex enough. But I can assure you that the impact of big tech on the media as we know it is just beginning. The Reuters Institute has already predicted this year to be the breakthrough year for artificial intelligence and its application for journalism.

The institute rightly said the arrival of ChatGPT has transformed the debate over whether AI is here to stay or not. In its journal, Journalism, Media, and Technology Trends and Predictions 2023, the Institute said about ChatGPT, 'Its speed and capabilities are awe-inspiring and frightening at the same time.

While the underlying models have been around for some time, ChatGPT has turned these into an accessible prototype that gives a real sense of where AI may be heading. It can tell jokes (but has been trained not to tell racist or sexist ones), come up with plots for a film or book, write computer code.'

In case you missed it, AI even mocked our industry in the report by summarising the challenges facing local news media in 50 words! Here's the QandA:

'NI: Can you summarise the challenges facing local media in 50 words.

ChatGPT: The challenges facing local media include the decline of print media and advertising revenues, competition from online news sources, and the impact of COVID-19 pandemic on local businesses, which are the major sources of advertising revenue. These challenges have made it difficult for local news outlets to sustain their operations and continue to provide important coverage and information to their communities.'

More news outlets, including News24 of South Africa, are training their systems with the voices of their popular anchors with astonishing accuracy.

Big Tech: Archenemy, Frenemy, or Friend?

Big tech may be playing more actively in our industry than us, taking an increasing share of our money and maybe our jobs without being responsible - both in proprietorship and accountability - for the information it disseminates. It has exploited its unmatched reach, ability to use algorithms to tailor content to suit consumers, and real-time engagement advantage to retain consumers. But as they say, there are two sides to a coin.

Positive Impact:

Increased Exposure:

Big tech platforms provide news media companies with a vast audience. Articles and videos can be shared and spread rapidly on these platforms, leading to increased visibility and traffic for news outlets.

New Revenue Streams:

Some tech platforms have revenue-sharing agreements with news media companies. For example, YouTube shares ad revenue with news organisations that post videos on its platform, once you reach a certain threshold.

Better Analytics:

Tech platforms provide news media companies with sophisticated analytic tools that allow them to better understand their audiences and tailor content to user preferences.

Engagement Opportunities:

Social media platforms allow news outlets to interact with their audience in a way that wasn't possible before. They can receive immediate feedback, address concerns, and build communities around their content.

Negative Impact:

Ad Revenue Competition:

Big tech companies have diverted advertising revenues away from traditional media outlets. They offer targeted advertising based on vast amounts of data, which is often more appealing to advertisers. I was scandalised during the recent general elections in Nigeria that folks who had built their careers in the mainstream and whom we were banking on left us high and dry, with the excuse that their principals wanted minimum use of legacy media platforms! But I understood, even if I did so with a heavy heart! Why? A BBC online report www.bbc.co.uk/bitesize/guides/zd9bd6f/revision/7said, 'Politicians are investing heavily in the use of websites, blogs, podcasts and social networking websites like Facebook and Twitter as a way of reaching voters.'

'During the 2019 election campaign,' the BBC report continued, 'the Conservatives spent one million pounds on Facebook alone, at a point, running 2,500 adverts.'

Let's look at some more numbers: Google earned about $3bn from sales to China-based advertisers in 2018; Google UK earned APS3.34bn in 18 months ending December 2021 as total revenue in the UK market; in 2022 Google's share of UK digital advert market was 38 percent of all adverts valued at APS5.72bn.

If the UK media is complaining, what should we do? I'm sure you already know that on revenue from traffic, for example, while you can get as much as $2 in CPM from traffic from the UK or the US, the best you can hope to get from local traffic, that is, traffic from Nigeria, for example, regardless of the size, is probably 80cents per 1K! Sure, this example is related to revenue from traffic; but the ratio, even for advertising is not significantly different.

Spread of Misinformation:

The ease of sharing on social media platforms can contribute to the spread of misinformation. This not only misleads the public but also undermines trust in news media.

Algorithmic Control:

The algorithms used by tech platforms control what content is seen and what is buried. This can lead to a loss of control for news media over how and to whom their content is distributed. In an article by Kanchan Srivastava, published on February 27, 2023, entitled, 'Surviving the algorithm: News publishers walk the tightrope as Google 'updates' hit hard,' the author quoted a respondent as saying, 'Google has released major algo updates in 2022, which impacted search traffic across publishers.' Publishers didn't find two major updates last year by the big tech funny at all.

Dependency:

News media companies may become dependent on these platforms for traffic and revenue, which can be risky given the changing algorithms and policies.

Potential for Censorship:

Big tech companies have the power to censor or prioritise certain types of news content based on their own policies or external pressures, which can impact the democratic discourse.

Data Privacy Concerns:

There are concerns about how big tech companies handle user data, and these concerns extend to the partnerships between tech platforms and news media companies.

Dilution of Brand Identity:

Being lumped together with a multitude of other content producers on a single platform can dilute a news outlet's brand identity.

Room for redress

Complaints about discriminatory business or editorial practices from Nigeria and a number other developing countries are hardly treated with seriousness

All About Algorithm, the Devil?

Not all the challenges summarised by AI were brought upon the traditional media by big tech. Nor are we here solely because of Google's malicious fiddling with its algo. We in the traditional media space share in the blame for what took our industry from distress to life support.

I will tweak HBS Professor Clayton Christensen a bit by saying for a long time, we were innovating our products in response to technological shifts, with very little attention to our business models, or if you'll pardon my drift, what E. Jerome McCarthy described in his book, Basic Marketing: A Managerial Approach, as the 7Ps of marketing - Product, Promotion, Price, Place, People, Process and Physical Evidence.

Nothing depicts this more tellingly than media organisations' need to reconsider obsolete editorial culture and imbibe new ones, especially in the areas of collaboration, audience-centered production, and creating an audience community.

To be able to compete favourably, media houses may have to take another look at the redundancy levels in-house. Reuters Institute predicted that more newspapers would stop daily print production due to rising print costs and the weakening of distribution networks. It also predicted a further spate of venerable titles switching to an online-only model. They are happening before our own eyes.

Let me be local. In LEADERSHIP the average production costs of our major consumables - newsprint, plates, ink, energy - have risen, with the most significant rise being in energy cost, which increased by 40 percent in one year, while our advert rates have remained largely constant.

Survival in the media industry used to depend on rivalry in the media; now it depends on collaboration. Recent collaborative works on the Pandora Papers, BureauLocal, and the #CoronaVirusFacts have shown that media organisations can work with colleagues across boundaries to share resources for the common good.

In 2020, Aliaa El-Shabassy, a teaching assistant at Cairo University, listed six reader needs outlined by the BBC for media organisations that want to stay ahead and compete with tech platforms. Why should other media companies listen to the BBC's advice? Well, its global reach in 2020 was 468.2m people a week!

El-Shabassy wrote, 'During Corona's peak when audiences needed a trustworthy source to rely on, BBC News scored the highest reach among other international media organisations. Moreover, according to the annual Global Audience Measure, a total of 151 million users per week are accessing BBC's news and entertainment content digitally.'

Six reader needs that any Media Practitioner must be aware of, according to the BBC are:

Update me - which means in the era of information overload, your audience should know in a new light what they already know about.

Give me perspective - it is a newsroom's own goal to believe that perspective can only be shaped by the newsroom. Your audience can provide perspective.

Educate me - everyone wants to learn about an exciting new thing. Once you provide diverse content with curiosity value, your audience will be eager to find more from you.

Keep me on trend - audiences want to be kept trending. Perhaps that was why the BBC reached a record number of people during COVID-19.

Amuse me - one of the reasons tech platforms prioritise user-generated content (remember Facebook's pivot to video) over professionally produced content is that they have better entertainment value to attract adverts. The simple truth is that if you make your audience smile, they will most likely come back. It doesn't always have to be serious! The more entertaining yet informative your content is, the more your institution is likely to grow.

Inspire me - inspiring stories attract younger audiences more than others and younger audiences source content through tech platforms more. Do the math!

Big Stick for Big Tech

Yet, big tech can't get off lightly. In 2021, and despite heavy criticism, the Australian government pioneered a new media bargaining code that compels tech platforms to negotiate payment to local news media outlets for using their content.

Initially criticised as a form of subsidy from big tech to big media, significantly because of the role played by media mogul Rupert Murdoch, the law has been hugely successful. Both big and small media outlets have benefitted from the law while the country's journalism practice has also been revitalised, leading to the creation of new journalism jobs.

In an article published in 2022 by Brookings, Dr. Courtney Radsch, Fellow, Institute for Technology, Law and Policy, UCLA, wrote that Australia's big tech regulatory efforts were developed around three thrusts: taxation, competition/antitrust, and intellectual property.

The bargaining code therefore allows publishers to collectively bargain without violating antitrust laws; requires tech platforms to negotiate with publishers for the use of news snippets; also requires them to pay licensing fees to publishers; and taxes digital advertising and uses the revenue to subsidise news outlets.

The EU, US and India have since adopted their own media bargaining code and the idea of compelling big tech to pay for news they don't produce but use and sell is gaining momentum, has been gaining global support since Australia took the bull by the horns.

I'm aware that the Newspaper Proprietor's Association of Nigeria (NPAN) set up a committee in July to examine the possibility of collective bargaining with big tech.

Staying in business

Understanding that consumers hold all - or most - of the aces, is the first step towards sustainability. For perspective, a paper entitled, 'The Newspaper: Emerging Trends, Opportunities, and Strategies for Survival and Sustainability,' by Frank Aigbogun presented at a retreat for NPAN on July 18, 2023, said between 2010 and 2015, audience time spent spend on online media consumption soared to 150%. In that time, audience time spent on television decreased to -8%; radio, -15%; magazine, -23%; and newspaper, -31%.

The reality of digital media is that evolution has brought about new competition and fresh opportunities. Solutions journalism, citizens journalism, and a deeper interface between journalism and technology are the order of the day. There was a time when we consumed music via turntables, stereos with records, and then cassettes and then compact discs. Album sales are no longer used to measure the success of a body of work.

Now it is streaming, the playground of big tech companies such as Apple Music, Spotify, Amazon Music, TIDAL, Pandora, etc. If technology did not pose an existential threat to the music industry, I do not think big tech would end journalism.

Reuters Institute said, 'Better data connections have opened up possibilities beyond just text and pictures and smartphone adoption has accelerated the use of visual journalism, vertical video, and podcasts.'

Good content should not be free. What technology is doing, therefore, is to offer traditional media the opportunity to reach more people and make a profit.

Through the use of content and tech-led innovation, a growing list of brands are expanding into broadcast and streaming TV to grow and engage their audiences, and bring in new revenue streams. This involves the use of new formats, new technology, and new products to broaden and retain the audience base.

In addition, feedback tools, such as engagement matrices, are being used to 'galvanise the industry on loyalty' (according to the Financial Times, which now uses the RFV - Recency, Frequency, and Volume of reading its digital content).

Traditional media organisations in Nigeria also need to rethink their business models, from content to distribution and personnel costs. One of the ways some media organisations are going about change in business model is by targeting niche markets, while others invest in research, education and learning.

Other ideas you may find useful in turning an existential threat to an opportunity for sustainable growth, are:

Diversify:Think about Julius Berger (a Nigerian construction giant) now into massive production and export of cashew nuts! Think about games, films, books, special events and publications, etc

Preserve your candle:Don't give content free and still not collect and deploy customer data. Know your audiences and cultivate them

Re-purpose content

Review your systems and processes regularly and take tough decisions

Be ethical

Invest in talent

Keep running!

Let me return to the first sentence of this presentation. Yes, big tech poses a threat because of the opaque relationship it has with traditional media. However, is this threat going to pull the plug on journalism? I'll say no. I'll be the first to admit that the prevailing mood in the media industry is one of uncertainty.

To be certain, nothing will bring back the days when advertisement and circulation were enough to successfully run a media organisation. Also, because the media is a kind of cultural sector that does not necessarily respond to the principles of demand and supply, media organisations that fail to swim with the tide will continue to struggle or pack up altogether.

If we invest in what feels relevant and useful to consumers, then we have nothing to worry about because technology will help us know exactly how to adapt and reach our target audience.

What we should worry about instead is how to retain the ethics of our practice in the face of robotic and artificial media which might just overpower the audiences we share.

Remember: whether you're a lion or a gazelle, you better be running!

Note(s):

ISSN: 0855-1677

EDGAR Online-Prospectus and Proxies
Friday, October 6, 2023 58061 mots, p. NA
Aussi paru dans

26 avril 2023 | - | EDGAR Online-8-K Glimpse

S-1/A: LUDWIG ENTERPRISES, INC.

(EDGAR Online via COMTEX) -- As filed with the Securities and Exchange Commission on October 5 , 2023

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

If any of the securities being registered on this form are to be offered on a delayed or continuous basis pursuant to If any of the securities being registered on this Form are to be offered on a delayed or continuous basis pursuant to Rule 415 under the Securities Act, check the following box. ?

If this Form is filed to register additional securities for an offering pursuant to Rule 462(b) under the Securities Act, check the following box and list the Securities Act registration statement number of the earlier effective registration statement for the same offering. ?

If this Form is a post-effective amendment filed pursuant to Rule 462(c) under the Securities Act, check the following box and list the Securities Act registration statement number of the earlier effective registration statement for the same offering. ?

If this Form is a post-effective amendment filed pursuant to Rule 462(d) under the Securities Act, check the following box and list the Securities Act registration statement number of the earlier effective registration statement for the same offering. ?

Indicate by check mark whether the registrant is a large accelerated filer, an accelerated filer, a non-accelerated filer, a smaller reporting company or an emerging growth company. See the definitions of "large accelerated filer," "accelerated filer," "smaller reporting company" and "emerging growth company" in Rule 12b-2 of the Exchange Act.

Large accelerated filer ? Accelerated filer ? Non-accelerated filer ? Smaller reporting company ? Emerging growth company ?

If an emerging growth company, indicate by check mark if the registrant has elected not to use the extended transition period for complying with any new or revised financial accounting standards provided to Section 7(a)(2)(B) of the Securities Act. ?

The registrant hereby amends this registration statement on such date or dates as may be necessary to delay its effective date until the registrant shall file a further amendment which specifically states that this registration statement shall thereafter become effective in accordance with Section 8(a) of the Securities Act of 1933 or until the registration statement shall become effective on such date as the Commission, acting pursuant to Section 8(a) may determine.

The information in this preliminary prospectus is not complete and may be changed. These securities may not be sold until the registration statement filed with the Securities and Exchange Commission is effective. This preliminary prospectus is not an offer to sell these securities and we are not soliciting an offer to buy these securities in any jurisdiction where the offer or sale is not permitted.

Preliminary Prospectus Subject to Completion, dated October 5 , 2023

[[Image Removed: Icon& #10;& #10;Description automatically generated]]

    Registration No. 333-271439

This prospectus relates to the sale of 47,000,000 shares of common stock, par value $0.001 (the "Offered Shares"), of Ludwig Enterprises, Inc. (the "Company," "we" or "us"), by the Company on a best-efforts basis (the "Offering"). The Company anticipates that the public offering price will be $[0.75-1.25] per share. The Offering (which will commence upon effectiveness of the registration statement of which this prospectus is a part) terminates on __________, 2024. The Company is offering the shares on a self-underwritten, "best-efforts" basis directly through its President, Anne B. Blackstone. The total proceeds from the Offering will not be escrowed or segregated but will be available to the Company immediately. There is no minimum amount of common shares required to be purchased, and, therefore, the total proceeds received by the Company might not be enough to sustain continued operations, or a market may not develop. For more information, see the sections titled "Plan of Distribution" and "Use of Proceeds" herein.

Upon the effectiveness of this Offering, a total of $940,000 of principal amount convertible notes (the "Convertible Notes") will, by their terms, be eligible for conversion into shares of common stock (the shares of common stock issued upon conversion of the Convertible Notes are referred to as the "Conversion Shares"), at the election of their respective holders, at a price equal to 80% of the offering price for all of the Offered Shares, or $[0.60-1.00] per Conversion Share. (See "Use of Proceeds" and "Plan of Distribution").

Our common stock is quoted on the OTC PINK market operated by OTC Markets Group, Inc., under the symbol LUDG. As of October 4, 2023 , the last reported sale price for our common stock was $0.179 per share. Prior to this Offering, there has been a limited market for the securities of the Company. While our common stock is quoted on the OTC PINK marketplace, there has been limited trading volume. There is no guarantee that an active trading market for our common stock will develop. We are not a "blank check company," and we have no plans or intentions to engage in a business combination following this Offering.

This Offering is highly speculative, and the Offered Shares involve a high degree of risk, including the superior voting rights of our outstanding shares of Convertible Preferred Stock, and should be considered only by persons who can afford the loss of their entire investments. See "Risk Factors," beginning on page 5.

Each share of our Convertible Preferred Stock (1) is convertible into 100 shares of our common stock at any time, (2) votes on all matters as a class with the holders of our common stock and (3) is entitled to 100 votes per share. The holders of our Convertible Preferred Stock will, therefore, be able to control the management and affairs of our company, as well as matters requiring the approval by our shareholders, including the election of directors, any merger, consolidation or sale of all or substantially all of our assets, and any other significant corporate transaction. (See "Description of Securities-Convertible Preferred Stock" and "Security Ownership of Certain Beneficial Owners and Management").

We are an "emerging growth company" under applicable U.S. Securities and Exchange Commission ("SEC") rules and will be subject to reduced public company reporting requirements.

NEITHER THE SECURITIES AND EXCHANGE COMMISSION NOR ANY STATE SECURITIES COMMISSION HAS APPROVED OR DISAPPROVED OF THESE SECURITIES OR DETERMINED IF THIS PROSPECTUS IS TRUTHFUL OR COMPLETE. ANY REPRESENTATION TO THE CONTRARY IS A CRIMINAL OFFENSE.

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

You should rely only on the information contained in this prospectus and in any free writing prospectus. We have not authorized anyone to provide you with information different from that contained in this prospectus. We are offering to sell, and seeking offers to buy, shares of our common stock only in jurisdictions where offers and sales are permitted. The information in this prospectus is accurate only as of the date of this prospectus, regardless of the time of delivery of this prospectus or any sale of shares of our common stock.

We have not done anything that would permit this Offering or possession or distribution of this prospectus in any jurisdiction where action for that purpose is required, other than in the United States. Persons outside the United States who come into possession of this prospectus must inform themselves about and to observe any restrictions as to this Offering and the distribution of this prospectus applicable to that jurisdiction.

    Registration No. 333-271439

Unless otherwise indicated, information contained in this prospectus concerning our industry and the markets in which we operate is based on information from independent industry and research organizations, other third-party sources and management estimates. Management estimates are derived from publicly available information released by independent industry analysts and third-party sources, as well as data from our internal research, and are based on assumptions made by us upon reviewing such data and our knowledge of such industry and markets which we believe to be reasonable. Although we believe the data from these third-party sources is reliable, we have not independently verified any third-party information. In addition, projections, assumptions and estimates of the future performance of the industry in which we operate and our future performance are necessarily subject to uncertainty and risk due to a variety of factors, including those described in "Risk Factors" and "Information Regarding Forward-Looking Statements." These and other factors could cause results to differ materially from those expressed in the estimates made by the independent parties and by us.

    Registration No. 333-271439

    Registration No. 333-271439

As this is a summary, it does not contain all of the information that you should consider in making an investment decision. You should read the entire prospectus carefully, including the information under the sections entitled "Risk Factors," "Management's Discussion and Analysis of Financial Condition and Results of Operations" and our financial statements and the related notes thereto included in this prospectus, before investing. This prospectus includes forward-looking statements that involve risks and uncertainties. See "Information Regarding Forward-Looking Statements." Unless the context otherwise requires, we use the terms "Ludwig," the "Company," "we," "us" and "our" in this prospectus to refer to Ludwig Enterprises, Inc. and its wholly-owned subsidiaries mRNAforLife, Inc., Precision Genomics, Inc. and Exousia Ai, Inc.

The Company

Overview. We are an innovative genomics technology and health related company that is developing mRNA genetic testing kits that use "inflammatory genetic markers" to assess the presence of disease and monitor treatment responses [in a person], and nutritional supplements that may modulate and/or reduce inflammatory genetic markers associated with certain diseases.

Inflammatory genetic markers are biological molecules that indicate the presence (or absence) of inflammatory disease activity. These inflammatory molecules, called cytokine and chemokines, mediate the biological response of tissues within the body to harmful agents, such as bacteria, viruses, damaged cells or toxic irritants. These inflammatory molecules are produced by messenger RNA (mRNA) and are signals that are sent between cells. Messenger RNA transfers information from DNA to the cell machinery that makes proteins. Examples of such inflammatory molecules include, but are not limited to, nuclear factorE2, superoxide dismutase, TNF-? and NF-?B, IFN-?, and IL-6.

Leveraging our proprietary mRNA genetic testing kits, we can collect buccal cheek swabs from an individual and isolate the individual's mRNA from these swabs. Next, we use a Thermo Fisher Scientific Quant Studio Real-Time Polymerase Chain Reaction system to measure levels of specific mRNA-produced inflammatory molecules within the individual.) We believe these measurements could be used to detect genetic biomarkers for inflammatory driven diseases or to monitor treatment responses for conditions such as heart disease, preeclampsia, and cancer. Once we identify involved inflammatory genetic markers, our proprietary natural nutritional anti-inflammatory supplements may be able to modulate a person's previously measured inflammatory index or even potentially control further inflammatory reactions and continued disease development. We believe our genetic tools will have the potential to not only achieve early detection of diseases, but also to evaluate and support customized treatments that may improve patient outcomes. (See "Business").

Our Products. We intend to launch and market our proprietary mRNA genetic testing kits and supplements into the U.S. marketplace by the end of the third quarter 2023.

Test Kits. The My RNA for Life Home Test Kit is a home testing kit containing a flocked swab designed to collect cheek cells, and a collection tube containing a molecular medium inside to stabilize and preserve human nucleic acids such as DNA and RNA. [Once the buccal cheek swab sample is collected and stored in the collection tube, the testing kit is then sent to a third-party laboratory for analysis.] The Company is also developing proprietary technology to properly store swab samples and isolated mRNA samples for future analysis.

Our testing kits are considered a Laboratory Developed Test ("LDT"). LDT's are classified as medical devices but do not generally require U.S. Food and Drug Administration ("FDA") clearance, approval or premarket review. (See "Business").

Supplement. The My RNA for Life Genetic Centric Supplement (NuGenea(TM)) is a preventive natural nutritional anti-inflammatory formulation that utilizes compounds that have the potential to modulate expression of the genes that produce the inflammatory molecules that cause inflammation. The focus of the unique NuGenea(TM) formula of ingredients is the potential modulation and/or reduction of the inflammatory genetic markers associated with chronic disease.

The FDA does not approve dietary supplements and supplements are regulated as food, not as drugs. Companies are required to submit a premarket safety notification to the FDA at least 75 days before marketing dietary supplements containing certain "new dietary ingredients" (that were not marketed in the U.S. before Oct. 15, 1994). Because our supplement does not contain any such ingredients, we will not be required to submit a premarket safety notification. (See "Business").

2023 Plans. We hope to launch our supplement during the fourth quarter of 2023. We will focus our efforts in launching into the wellness clinic space. Patients and clients in this space are seeking ways, in general, to reduce inflammation in their bodies. We believe we can be part of that armamentarium with our supplement. There is no assurance that we will be successful in this regard. We plan to launch our inflammation home test kit during the 4th quarter of 2023. This will be direct to consumer and to wellness clinics. We will use advertisement in journals, internet and through educational literature.

Challenges to Our Plans. The primary challenges we face in establishing our business are our history of recurring net losses, our management's limited experience in commercializing products, and that fact that we have not yet established sales, marketing, large scale manufacturing or distribution capabilities. We must obtain capital, including from this offering, with which to begin the full-scale commercialization of our products. There is no assurance that we will obtain sufficient capital. (See "Risk Factors" and "Business").

In addition, the market into which we intend to sell our supplement is very crowded and filled with supplements targeted for the anti-inflammatory marketplace. There is no guarantee we can establish ourselves within this category. Further, most other companies in this space are well-established brands offered by some of the most notable companies. We are a start-up with no existing presence nor relationships. Also, we have only one product SKU, while most of our competitors have many SKU's and have large areas of shelf space in retail environments. Further, we plan to initially offer only one product will find it very challenging to get shelf space thereby limiting our opportunity and sales. We cannot assure our investors our product launch will be a success.

    Registration No. 333-271439

The use of home testing kits to assess inflammation may not be perceived as needed in the market, especially one not paid by insurance. Relying on customers to pay out of pocket for this tool is potentially a very large impediment to product use and acceptance. The Company does not currently plan to seek insurance coverage for use of the home testing kits.

Launching a marketing campaign for our products will be costly without any assurance the products will be purchased, used and accepted. As a start up with limited capital, there may not be enough time or capital to see this product through to market acceptance.

Selected Risks Associated with Our Business

Investing in our common stock involves a high degree of risk. You should carefully consider all the information in this prospectus prior to investing in our common stock. These risks are discussed more fully in the section entitled "Risk Factors" immediately following this prospectus summary. These risks and uncertainties include, but are not limited to, the following:

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

? we are dependent upon our sole officer and director for future success;

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

Corporate Information

The Company was originally organized as a Kentucky corporation on February 11, 1988. On February 8, 2006, we formed a wholly owned subsidiary, Ludwig Enterprises, Inc., a Nevada corporation. On March 28, 2006, Ludwig Enterprises, Inc., the Kentucky corporation, merged with and into Ludwig Enterprises, Inc., the Nevada corporation, with the Company, Ludwig Enterprises, Inc., the Nevada corporation, being the surviving entity.

Our principal executive offices, and those of our subsidiaries, are located at 1749 Victorian Avenue, #C-350, Sparks, Nevada 89431. Our phone number is (786) 235-9026. Our corporate website is located at www.ludwigent.com. Information on our website is not part of this prospectus.

The Offering

    Registration No. 333-271439

Securities being offered 47,000,000 shares of common stock by us:

Shares of common stock 152,408,220 shares(1) outstanding prior to the Offering:

Shares of common stock to 199,408,220 shares be outstanding after the Offering:

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

The following tables summarize certain financial data regarding our business and should be read in conjunction with our financial statements and related notes contained elsewhere in this prospectus and the information under "Management's Discussion and Analysis of Financial Condition and Results of Operations," as well as our financial statements and related notes appearing elsewhere in this prospectus.

We derived the summary financial information from our unaudited financial statements and related notes for the six months ended June 30, 2023 and 2022, and our audited financial statements and related notes for the years ended December 31, 2022 and 2021, appearing elsewhere in this prospectus.

All financial statements included in this prospectus are prepared and presented in accordance with generally accepted accounting principles in the United States. The financial statements contained elsewhere fully represent our financial condition and operations; however, they are not indicative of our future performance.

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

An investment in our shares of common stock involves significant risks. Before making an investment in our shares of common stock, you should carefully consider the risks and uncertainties discussed below under "Information Regarding Forward-Looking Statements," and the specific risks set forth herein. Any of the following risks could have a material adverse effect on our business, financial condition and results of operations. Additional risks and uncertainties not currently known to us or that we currently deem to be immaterial may also materially and adversely affect our business, prospects, financial condition, results of operations, cash flows and ability to pay dividends. In any such case, the market price of our shares of common stock could decline, and you may lose all or part of your investment.

Risks Related to the Company

We are an early-stage genomics technology and health related Company without any products or services currently available for sale and we may not be able to successfully develop or bring products or services to market.

We have several product and service candidates, including our proprietary mRNA genetic program and nutraceutical supplement, we hope to bring to market by the fourth quarter of 2023; however, there is no assurance that we will succeed in bringing any of our product and service candidates to market or that such product candidates, or any of our other operations, will generate any revenue. If we cannot develop a marketable product or generate sufficient revenues, we may be required to suspend or cease operations.

    Registration No. 333-271439

The report of our independent auditors on our financial statements for the year ended December 31, 2022, indicates uncertainty concerning our ability to continue as a going concern and this may impair our ability to raise capital to fund our business.

The report of our independent auditors indicates uncertainty concerning our ability to continue as a going concern and this may impair our ability to raise capital to fund our business. In its opinion on our financial statements for the years ended December 31, 2022 and 2021, our independent auditors raised substantial doubt about our ability to continue as a going concern. We cannot assure you that this will not impair our ability to raise capital on attractive terms. Additionally, we cannot assure you that we will ever achieve significant revenues and therefore remain a going concern. Our financial statements do not include any adjustments that might result from the outcome of this uncertainty.

The obtainment of additional financing, the successful development of our contemplated plan of operations, and its transition, ultimately, to the attainment of profitable operations are necessary for us to continue operations. These conditions and the ability to successfully resolve these factors over the next twelve months raise substantial doubt about our ability to continue as a going concern.

We have incurred significant losses in prior periods, and losses in the future could cause the quoted price of our common stock to decline or have a material adverse effect on our financial condition, our ability to pay our debts as they become due, and on our cash flows.

To date, we have not generated revenues from our operations, and we have incurred significant losses in prior periods. For the six months ended June 30, 2023 and 2022, we incurred a net loss of $1,559,276 (unaudited) and $87,502 (unaudited), respectively, and, as of June 30, 2023, we had an accumulated deficit of $3,345,208 (unaudited). For the years ended December 31, 2022 and 2021, we incurred a net loss of $965,150 and $137,467, respectively, and, as of such dates, we had an accumulated deficit of $1,785,932 and $820,782, respectively.

The time required for us to become profitable is highly uncertain, and we cannot assure you that we will achieve or sustain profitability or generate sufficient cash flow from operations to meet our planned capital expenditures, working capital and debt service requirements. If required, our ability to obtain additional financing from other sources also depends on many factors beyond our control, including the state of the capital markets and the prospects for our business. The necessary additional financing may not be available to us or may be available only on terms that would result in further dilution to the current owners of our common stock. We expect we will require significant capital in connection with our efforts, and we will be required to continue to make significant investments to further develop and expand our business. In particular, we expect to continue to expend substantial financial and other resources on further research studies, marketing and advertising as part of our strategy to develop and increase our business-to-business ("B2B") and business-to-consumer ("B2C") channels, as well as on research and development activities regarding our proprietary mRNA genetic methodologies. The sales, marketing and advertising expenses that we will incur will typically be expensed immediately. In addition, to the extent that our business ramps up as we expect, we will need to increase our headcount significantly in the coming years.

We intend to seek interim short-term financing to assure full legal compliance with our Securities and Exchange Commission ("SEC") filings, and to bring on the necessary personnel to begin its future development activities. Our working capital needs will be met largely from the sale of debt and public equity securities, including in this Offering, until such time that funds provided by operations, if ever, are sufficient to fund working capital requirements. The accompanying financial statements do not include any adjustments relating to the recoverability or classification of recorded assets and liabilities that might result should the Company be unable to continue as a going concern.

We will require additional capital to fund our operations and if we do not obtain additional capital, we may be required to scale back, delay or cease our operations.

Our business does not presently generate the cash needed to finance our current and anticipated operations and we need to obtain additional financing to finance our operations, until such time that we are able to conduct profitable revenue generating activities.

Through the date of this prospectus, we have obtained approximately $1.3 million in loans to meet our ongoing expenses, including professional fees and day-to-day operating expenses. We cannot assure you that adequate financing will be available on acceptable terms, if at all. Our failure to raise additional financing, including through this Offering, in a timely manner would adversely affect our ability to pursue our business plan and could cause us to delay launching our league and our proposed business plan.

    Registration No. 333-271439

The Company has product candidates with very complex and different sales and marketing channels, the development of which will put significant burdens on us and which we may not be able to develop as effectively as competitors.

We will have very different sales and marketing channels if the products in our pipeline are to reach customers in their respective markets - either B2C or B2B channels - requiring us to develop distinct sales, marketing, and distribution methods. In particular, the B2C channels have different customers and distribution channels as B2B channels. Building, managing and maintaining such a sales and marketing infrastructure may require us to hire experts in the field, implement complex systems, establish collaborations with third parties effectively across various geographies and understand disparate regulatory regimes. Our ability to effectively engage in these steps is untested, making it impossible for us to accurately predict the level of success we will achieve.

We have yet to establish sales, marketing or distribution capabilities, and if we are unable to establish these capabilities, we may not be successful in commercializing our product candidates if they are approved.

We have not yet established a sales, marketing or product distribution infrastructure for our product and service candidates, which are still in various stages of development. To achieve commercial success for any product for which we obtain marketing approval, we will need to establish a sales and marketing organization within the United States and, potentially, also develop a strategy for sales outside of the United States. We intend to outsource the manufacturing and distribution, and failure to obtain contracts with such third parties on terms acceptable to us, or at all, may significantly delay our product and service candidates market rollout. In addition, as we begin to commercialize our products, we will need to hire, develop, train personnel with expertise in marketing and selling products in each of those markets.

Our revenue and results of operations may vary on a quarterly and annual basis.

Our revenue and results of operations could vary significantly from period-to-period and may fail to match expectations as a result of a variety of factors, some of which are outside of our control, including general market conditions and macroeconomic factors. We have not yet generated revenues and we cannot accurately estimate future revenue and operating expenses based on historical performance. Our quarterly operating results may vary significantly based on many factors, including:

? Fluctuating demand for our potential products;

? Announcements or implementation by our competitors of new products;

    Registration No. 333-271439

? Timing and amounts relating to the expansion of our operations;

? Our ability to enter into, renegotiate or renew key agreements;

? Timing and amounts relating to the expansion of our operations; or

    Registration No. 333-271439

As a result of the potential variations in our revenue and results of operations, period-to-period comparisons may not be meaningful and the results of any one period should not be relied on as an indication of future performance. We may also be unable to, or may elect not to, adjust spending quickly enough to offset any unexpected revenue shortfall. In addition, our results of operations may not meet the expectations of investors or public market analysts who follow the Company, which may adversely impact our stock price. We expect to make significant operating and capital expenditures in connection with the development of our plan of business. If these increased capital expenditures are not accompanied by increased revenue in the same quarter, our quarterly revenue and results of operations would be adversely affected.

If we fail to effectively manage our growth, our business will be harmed.

Currently, our three executive officers perform all required corporate functions, including product development activities. As we continue preparing for our service and product candidates to enter the market, we will, as availability of capital permits, begin to hire personnel necessary to support our operations. The skills we seek are typically in high demand and we may have difficulty identifying, hiring, integrating, motivating and retaining additional employees, consultants, and contract personnel. Also, our management may need to divert a disproportionate amount of our attention away from our day-to-day activities and devote a substantial amount of time to simultaneously manage rightsizing and growth activities. We may not be able to effectively manage changes in the size of our operations, which may result in weaknesses in our infrastructure, give rise to operational mistakes, loss of business opportunities, loss of employees and reduced productivity among remaining employees.

Should we secure adequate capital, whether through this offering or otherwise, we intend to hire a Marketing and Sales Officer to implement plans for product distribution and channel placement. Regional distributors will be engaged to place product into their current customers (retail) and (Physician offices). In addition, we intend to hire a Chief Financial Officer who has the financial experience in managing product launches and in developing financial models to assist in the stewarding of the capital during this period of market entrance and beyond. Further, we intend to hire a Medical Educator to write educational materials to educate and inform our potential customers on the use of our supplement.

Any future growth could require significant capital expenditures and may divert financial resources from other projects, such as the development of product candidates. If our management is unable to effectively manage our rightsizing efforts while scaling the Company, our expenses may increase more than expected, our ability to generate and/or grow revenues could be reduced, and we may not be able to implement our business strategy. Our future financial performance and our ability to commercialize our product candidates and compete effectively will depend, in part, on our ability to effectively manage the size of our organization. We cannot assure you that we will be able to accomplish these tasks or effectively manage our growth.

    Registration No. 333-271439

We are dependent upon our executive officers for future success.

Our future success to a significant extent depends on the continued services of our executive officers, Marvin S. Hausman, M.D., Anne B. Blackstone and Thomas Terwilliger. The departure of one or more of these persons could materially adversely affect our ability to implement our business strategy. Currently, we do not maintain, for our benefit, any key man life insurance on any of our executive officers; we have, however, entered into employment agreements with Dr. Hausman, Ms. Blackstone and Mr. Terwilliger. (See "Management").

If we are unable to recruit and retain key personnel, our business may be harmed.

If we are unable to attract and retain key personnel, our business may be harmed. Our failure to enable the effective transfer of knowledge and facilitate smooth transitions with regard to our key employees could adversely affect our long-term strategic planning and execution.

Our financial success is dependent to a significant degree upon the efforts of our executive officers. Our future success and viability will depend to a significant extent upon its ability to attract and retain qualified personnel in all areas of its business, especially its sales, science, and financial management teams. If we were to be unable to retain these key members of our respective teams, we would need to replace them with qualified individuals in a timely manner or our business, results of operations and financial condition could be adversely impacted.

Significant disruptions of information technology systems or security breaches could adversely affect our operations.

We are increasingly dependent upon information technology systems, infrastructure and data to operate our business ourselves and on vendors who operate aspects of our technology infrastructure for us. In the ordinary course of business, through the use of our product and service candidates, we will collect, store and transmit large amounts of confidential information (including, among other things, trade secrets or other intellectual property, proprietary business information and personal patient information). It is critical that we do so in a secure manner to maintain the confidentiality and integrity of such confidential information.

Attacks on information technology systems are increasing in their frequency, levels of persistence, sophistication and intensity, and they are being conducted by increasingly sophisticated and organized groups that include state actors, criminal organizations and individuals who can bring significant resources and expertise to bear. Public reports indicate that state actors have specifically targeted companies developing COVID-19 vaccines with the intent of stealing trade secrets or disabling information technology systems associated with vaccine development and we may be unable to defend against these state actors who have significantly more resources at their disposal than we do.

Our information technology systems, and those of third-party vendors with whom we contract are also vulnerable to service interruptions, security breaches from inadvertent or intentional actions by our employees, third-party vendors, and/or business partners, or from cyber-attacks by malicious third parties. Cyber-attacks could include the deployment of harmful malware, ransomware, denial-of-service attacks, social engineering and other means to affect service reliability, and could threaten the confidentiality, integrity, and availability of information. For example, interruption of our information technology systems or technology infrastructure may cause delays in producing results for patients that utilize our products and/or services.

Significant disruptions of our information technology systems, or those of our third-party vendors, or security breaches could adversely affect our business operations and/or result in the loss, adulteration, misappropriation and/or unauthorized access, use or disclosure of, or the prevention of access to, confidential information, including, among other things, trade secrets or other intellectual property, proprietary business information and personal information, and could result in financial, legal, business, and reputational harm to us.

Any such breach or interruption could compromise our networks, and the information stored there could be inaccessible or could be accessed by unauthorized parties, publicly disclosed, lost or stolen. Any such interruption in access, improper access, disclosure or other loss of information could result in legal claims or proceedings, liability under laws that protect the privacy of personal information, such as the federal Health Insurance Portability and Accountability Act ("HIPAA"), and regulatory penalties. Unauthorized access, loss or dissemination could also disrupt our operations, including our ability to perform tests, provide test results, bill facilities or patients, process claims and appeals, provide customer assistance services, conduct research and development activities, collect, process and prepare Company financial information, provide information about our current and future solutions and other patient and clinician education and outreach efforts through our website, and manage the administrative aspects of our business and damage our reputation, any of which could adversely affect our business. Any such breach could also result in the compromise of our trade secrets and other proprietary information, which could adversely affect our competitive position.

    Registration No. 333-271439

Any failure or perceived failure by us or any third-party collaborators, service providers, contractors or consultants to comply with our privacy, confidentiality, data security or similar obligations to third parties, or any data security incidents or other security breaches that result in the unauthorized access, release or transfer of sensitive information, including personally identifiable information, may result in governmental investigations, enforcement actions, regulatory fines, litigation or public statements against us, could cause third parties to lose trust in us or could result in claims by third parties asserting that we have breached our privacy, confidentiality, data security, or similar obligations, any of which could have a material adverse effect on our reputation, business, financial condition, or results of operations. Moreover, data security incidents and other security breaches can be difficult to detect, and any delay in identifying them may lead to increased harm. While we have implemented data security measures intended to protect our information technology systems and infrastructure, there can be no assurance that such measures will successfully prevent service interruptions or data security incidents.

We process, store and use certain personal information, which subjects us to privacy laws and standards, governmental regulation and other legal obligations related to privacy, and our actual or perceived failure to comply with these privacy laws and standards, regulations, and obligations could subject us to fines, sanctions or litigation, and could potentially damage our brand and reputation and adversely affect our business, financial condition and results of operations.

We depend on information technology networks and systems to process, transmit and store electronic information and to communicate among our locations around the United States and with customers. We collect, use and disclose personal information, such as names, addresses, phone numbers and email addresses. We collect, store and use sensitive or confidential transaction and account information of consumers. As a result, we are or may be subject to a variety of state, national and international laws and regulations that apply to the collection, use, retention, protection, disclosure, transfer and other processing of personal data, potentially including the Fair Credit Reporting Act, the General Data Protection Regulation ("GDPR") and California Consumer Privacy Act ("CCPA"). These laws and regulations are evolving, with new or modified laws and regulations proposed and implemented frequently and existing laws and regulations subject to new or different interpretations. For example, the GDPR introduced new data protection requirements in the EU and imposes substantial fines for breaches of the data protection rules. Compared to the previous EU data protection laws, the GDPR notably has a greater extra territorial reach and has a significant impact on data controllers and data processors, which either have an establishment in the EU, or offer goods or services to EU data subjects or monitor EU data subjects' behavior within the EU. The GDPR regime imposes more stringent operational requirements on both data controllers and data processors, and introduces significant penalties for non-compliance with fines of up to 4% of total annual worldwide turnover or EUR20.0 million (whichever is higher), depending on the type and severity of the breach.

In addition, the CCPA expands the rights of California residents to access and require deletion of their personal information, opt out of certain personal information sharing and receive detailed information about how their personal information is used. The CCPA imposes a number of privacy and security obligations on companies who collect, use, disclose, or otherwise process personal information of California residents, which may result in civil penalties for violations and private rights of action in case of data breaches. The CCPA provides for civil penalties for violations, which could result in statutory penalties of up to $2,500 per violation, or up to $7,500 per violation if the violation is intentional. Other states have adopted, or are considering enacting, similar laws. Any failure or alleged failure to comply with privacy or data protection laws could lead to government enforcement actions and significant penalties against us, and could materially and adversely affect our reputation, business, financial condition, cash flows and results of operations. Compliance with any of the foregoing laws and regulations can be costly, can delay or impede the development of new products, and may require us to change the way we operate.

Additionally, the California Privacy Rights Act ("CPRA"), which took effect on January 1, 2023 and significantly expands the CCPA, imposes additional data protection obligations on companies doing business in California, including additional consumer rights processes and opt outs for certain uses of sensitive data and sharing of personal data as well as an expanded definition of "sale" to include sharing of personal information, and data minimization and data retention requirements. The CPRA also establishes a new enforcement agency, the California Privacy Protection Agency, which may take a more active role in enforcement. Other states have and are likely to continue to implement their own privacy statutes in the near term. The effects of the CCPA, CPRA and other similar state regulations are potentially significant and may require us to modify our data collection or processing practices and policies and to incur substantial costs and expenses in an effort to comply and increase our potential exposure to regulatory enforcement and/or litigation. Any of the foregoing could materially and adversely affect our business, results of operations and financial condition.

We may also be subject to or affected by evolving federal, state and foreign data protection laws and regulations, such as laws and regulations that address privacy and data security. In the United States, federal, state, and local governments have enacted numerous data privacy and security laws, including data breach notification laws, personal data privacy laws, and consumer protection laws (e.g. Section 5 of the Federal Trade Commission Act). For example, HIPAA as amended by the Health Information Technology for Economic and Clinical Health Act, imposes specific requirements relating to the privacy, security, and transmission of individually identifiable health information. We may obtain health information or other personal information from third parties, including research institutions from which we obtain clinical trial data, that are subject to privacy and security requirements under HIPAA. While we do not believe that we are currently acting as a covered entity or business associate under HIPAA and thus are not directly regulated under HIPAA, any person may be prosecuted under HIPAA's criminal provisions if it knowingly receives individually identifiable health information from a HIPAA-covered healthcare provider or research institution that has not satisfied HIPAA requirements for disclosure of individually identifiable health information under aiding-and-abetting or conspiracy principles.

    Registration No. 333-271439

The interpretation and application of many privacy and data protection laws are uncertain. Anticipated further evolution of regulations on this topic may substantially increase the penalties to which we could be subject to in the event of any non-compliance. These laws may be interpreted and applied in a manner that is inconsistent with our existing data management practices or the features of our products. If so, in addition to the possibility of negative publicity, fines, lawsuits and other claims and penalties, we could be required to fundamentally change our business activities and practices or modify our products, which could harm our business.

We seek to comply with privacy related industry standards and are subject to the terms of our own privacy policies and privacy related obligations to third parties. We strive to comply with all applicable laws, policies, legal obligations and industry codes of conduct relating to privacy and data security protection to the extent possible. However, these obligations may be interpreted and applied in a manner that is inconsistent from one jurisdiction to another and may conflict with other rules or regulations, making enforcement, and thus compliance requirements, ambiguous, uncertain, and potentially inconsistent. Additionally, laws, regulations, and standards covering marketing and advertising activities conducted by telephone, email, mobile devices, and the internet may be applicable to our business, such as the Telephone Consumer Protection Act (as implemented by the Telemarketing Sales Rule), the CAN SPAM Act of 2003, and similar state consumer protection laws. Any failure or perceived failure by us to comply with our privacy policies, privacy related obligations to agents, clients or other third parties, or our privacy related legal obligations, any marketing or advertising related laws, regulations, or standards, or any compromise of security that results in the unauthorized access to or unintended release of personal information or other agent or client data, may result in governmental enforcement actions, litigation, or public statements against us by consumer advocacy groups or others. Any of these events could cause us to incur significant costs in investigating and defending such claims and, if found liable, pay significant damages. Further, these proceedings and any subsequent adverse outcomes may cause our agents and clients to lose trust in us, which could have a material adverse effect on our reputation and business.

We are also subject to laws and regulations that involve electronic contracts and other communications; consumer protection; and online payment services. These laws and regulations are constantly evolving and can be subject to significant change. For example, many states have ordinances in place allowing individuals with certain criminal backgrounds to become tenants. State ordinances vary from state to state, and the types of criminal backgrounds that will clear a background check are not uniform on a national scale. As a result, the application, interpretation, and enforcement of these laws and regulations are often uncertain and may be interpreted and applied inconsistently. Additionally, as we depend on third parties for key services, we rely on such third-party service providers' compliance with laws and regulations regarding privacy, data protection, consumer protection, and other matters relating to our customers.

Any significant change to applicable laws, regulations or industry practices regarding the use or disclosure of personal information, or regarding the manner in which the express or implied consent of agents and their clients for the use and disclosure of personal information is obtained, could require us to modify our platform and its features, possibly in a material manner and subject us to increased compliance costs, which may limit our ability to innovate, improve and expand our platform and its features that make use of the personal information that our agents and their clients voluntarily share. Our customers operate independent of our platform as well and are responsible for their own data privacy compliance in certain respects. Additionally, we provide training and our platform provides tools and security controls to assist our agents with their data privacy compliance to the extent they store relevant data on our platform. However, if a customer or tenant on our platform were to be subject to a claim for breach of data privacy laws, we could possibly be found liable for their claims due to our relationship, which can require us to take more costly data security and compliance measures or to develop more complex systems.

Our business plan is not based on independent market studies.

We have not commissioned any independent market studies concerning our plans of operations. Rather, our plans for implementing our business strategy and achieving profitability are based on the experience, judgment and assumptions of our management. If these assumptions prove to be incorrect, we may not be successful in our business operations.

Our Board of Directors may change our policies without stockholder approval.

Our policies, including any policies with respect to investments, leverage, financing, growth, debt and capitalization, will be determined by our Board of Directors or officers to whom our Board of Directors delegate such authority. Our Board of Directors will also establish the amount of any dividends or other distributions that we may pay to our stockholders. Our Board of Directors or officers to which such decisions are delegated will have the ability to amend or revise these and our other policies at any time without stockholder vote. Accordingly, our stockholders will not be entitled to approve changes in our policies, which policy changes may have a material adverse effect on our financial condition and results of operations.

    Registration No. 333-271439

Our limited operating history makes it difficult for you to evaluate our prospects and future performance.

Our business operations have only a limited history upon which an evaluation of our prospects and future performance can be made. The Company's operations are subject to all business risks associated with development stage enterprises. The likelihood of the Company's success must be considered in light of the problems, expenses, difficulties, complications and delays frequently encountered in connection with the establishment and expansion of a business, operation in a competitive industry and the necessary continued development of advertising and other marketing strategies. We believe it is likely that we will continue to sustain losses throughout the next twelve months. We cannot assure you that we will ever operate profitably.

Our limited operating history makes it difficult for us to estimate correctly our future operating expenses and anticipated revenue sources, which could lead to cash shortfalls.

We have a limited operating history, and as a result our historical financial and other operating data may be of limited value in estimating future operating revenue, revenue sources and expenses. Our budgeted expense levels are based in part on our expectations concerning future revenue and future revenue sources. The amount and sources of these revenues will depend on the success of our ability to establish the commercial viability of our new products, to sustain our marketing efforts, the perception of our products by customers and users, and other factors that are difficult to forecast accurately.

Because we do not have an audit committee, stockholders will have to rely on the directors, who are not independent, to perform these functions.

We do not have an audit or compensation committee comprised of independent directors. These functions are performed by the board of directors as a whole. Our sole director is not an independent director. Thus, there is a potential conflict in that this director is also engaged in management and participate in decisions concerning management compensation and audit issues that may affect management performance.

There are limitations of director liability and indemnification of directors, officers and employees.

Pursuant to Section 78.7502 of the Nevada Revised Statutes, we have the power to indemnify any person made a party to any lawsuit by reason of being a director or officer of the Company, or serving at the request of the corporation as a director, officer, employee or agent of another corporation, partnership, joint venture, trust or other enterprise against expenses (including attorneys' fees), judgments, fines and amounts paid in settlement actually and reasonably incurred by him in connection with such action, suit or proceeding if he acted in good faith and in a manner he reasonably believed to be in or not opposed to the best interests of the corporation, and, with respect to any criminal action or proceeding, had no reasonable cause to believe his conduct was unlawful. Our Articles of Incorporation provide that the Company shall indemnify its directors and officers to the fullest extent permitted by Nevada law.

These limitations of liability do not apply to liabilities arising under the federal or state securities laws and do not affect the availability of equitable remedies such as injunctive relief or rescission. Our corporate bylaws provide that we will indemnify our directors, officers and employees to the fullest extent permitted by law. Our bylaws also provide that we are obligated to advance expenses incurred by a director or officer in advance of the final disposition of any action or proceeding. We believe that these bylaw provisions are necessary to attract and retain qualified persons as directors and officers. The limitation of liability in our Articles of Incorporation and bylaws may discourage stockholders from bringing a lawsuit against directors for breach of their fiduciary duties. They may also reduce the likelihood of derivative litigation against directors and officers, even though an action, if successful, might provide a benefit to us and our stockholders. Our results of operations and financial condition may be harmed to the extent we pay the costs of settlement and damage awards against directors and officers pursuant to these indemnification provisions.

We are an emerging growth company and a smaller reporting company and intend to take advantage of reduced disclosure requirements applicable to emerging growth companies, which could make the common stock less attractive to investors.

We are an "emerging growth company" ("EGC") as defined in the Jumpstart Our Business Startups Act of 2012. we will remain an EGC until the earliest to occur of (i) the last day of the fiscal year in which it has total annual gross revenue of $1.235 billion or more; (ii) the last day of the fiscal year following the fifth anniversary of the date of the first sale of common stock pursuant to the registration statement; (iii) the date on which it has issued more than $1.0 billion in non-convertible debt securities during the prior three-year period; or (iv) the date it qualifies as a "large accelerated filer" under the rules of the SEC, which means the market value of the common stock held by non-affiliates exceeds $700 million as of the last business day of its most recently completed second fiscal quarter after it has been a reporting Company in the United States for at least 12 months. For so long as we remain an EGC, we are permitted to and intend to rely upon exemptions from certain disclosure requirements that are applicable to other public companies that are not EGCs. These exemptions include not being required to comply with the auditor attestation requirements of Section 404 of the Sarbanes-Oxley Act and reduced disclosure about our executive compensation arrangements.

We may choose to take advantage of some but not all of these reduced burdens. We have taken advantage of reduced reporting requirements in this prospectus. Accordingly, the information contained herein may be different from the information you receive from other public companies in which you hold stock. In addition, Section 107 of the Jumpstart Our Business Startups Act (the "JOBS Act") provides that an EGC may take advantage of an extended transition period for complying with new or revised accounting standards, delaying the adoption of these accounting standards until they would apply to private companies. We have elected to avail ourselves of the extended transition period for complying with new or revised financial accounting standards. As a result of our accounting standards election, we will not be subject to the same implementation timing for new or revised accounting standards as other public companies that are not EGC's which may make comparison of our financials to those of other public companies more difficult.

    Registration No. 333-271439

We are also a smaller reporting Company, as defined in Rule 405 promulgated under the Securities Act ("SRC"). As an SRC, the Company intends to utilize certain reduced disclosure requirements, including publishing two years of audited financial statements instead of three years, as required for companies that do not qualify as an SRC. The Company will remain an SRC until the last day of the fiscal year in which it had (i) a public float that exceeded $250 million or (ii) annual revenues of more than $100 million and a public float that exceeded $700 million. To the extent the Company takes advantage of such reduced disclosure obligations, it may make comparison of its financial statements to those of other public companies difficult or impossible.

After the Company ceases to be an SRC, it is expected to incur additional management time and cost to comply with the more stringent reporting requirements applicable to companies that are accelerated filers or large accelerated filers, including complying with the auditor attestation requirements of Section 404 of SOX.

Risks Related to Our Business

We use RNA-based molecular biology in our products and services pipeline and the successful commercialization of these products will depend on public perceptions of RNA-based products.

The successful commercialization of our product candidates depends, in part, on public acceptance of modern biotechnology techniques and the use of RNA to identify differentially expressed genes ("DEGs") involved in the inflammatory process associated with the development of chronic diseases. Negative public perceptions about RNA and molecular regulation of gene expression can also affect the regulatory environment in the jurisdictions in which we are targeting the sale of our products and the commercialization of our product candidates. Any increase in such negative perceptions or any restrictive government regulations in response to RNA-based products could have a negative effect on our business and may delay or impair the sale of our products or the development or commercialization of our product candidates. Public pressure may lead to increased regulation and legislation for products produced using biotechnology and this could adversely affect our ability to sell our product or commercialize our product candidates.

If the U. S. Food and Drug Administration (the "FDA") were to begin actively regulating our tests, we could incur substantial costs and delays associated with trying to obtain premarket clearance or approval and incur costs associated with complying with post-market controls.

We intend to launch and market each of our proprietary testing products as a laboratory-developed test ("LDT"). We believe each of our proprietary testing products that we will offer are LDTs. The FDA generally considers an LDT to be a test that is developed, validated and performed within a single laboratory. The FDA sometimes determines that a test that is being offered by a laboratory as an LDT is not an LDT under the FDA's interpretation of that term but is an in vitro diagnostic ("IVD") medical device in commercial distribution, and therefore must comply with the regulations that apply to IVDs, including the need for successfully completing the FDA review process. If the FDA were to conclude that our proprietary testing product is not an LDT, we would be subject to extensive regulation as a medical device.

Moreover, even for tests that are deemed to be LDTs, the FDA has historically taken the position that it has the authority to regulate such tests as IVDs under the Federal Food, Drug, and Cosmetic Act, or FDC Act, although it has generally exercised enforcement discretion with regard to LDTs. This means that even though the FDA believes it can impose regulatory requirements on LDTs, such as requirements to obtain premarket approval, de novo authorization or clearance of LDTs, it has generally chosen not to enforce those requirements. The regulatory environment for LDTs has changed over time. For example, in 2020, the Department of Health and Human Services, or HHS, directed the FDA to stop regulating LDTs, but in 2021, HHS reversed its policy. Thereafter, the FDA resumed requiring submission of emergency use authorization, or EUA, requests, for COVID-19 LDTs, but has not indicated an intent to change its policy of enforcement discretion with respect to other, non-COVID, LDTs. Various bills have been introduced in Congress seeking to substantially revamp the regulation of both LDTs and IVDs. For example, the VALID Act, introduced in June 2021, would clarify and enhance the FDA's authority to regulate LDTs, while the VITAL Act, introduced in May 2021, would assign oversight of LDTs exclusively to the Centers for Medicare and Medicaid Services, or CMS.

Neither the VALID Act nor the VITAL Act has been enacted into law as of the date of this prospectus. Although the VALID Act was favorably voted upon in June 2022 by the Senate Health, Education, Labor and Pensions Committee as part of the FDA Safety and Landmark Advancements bill, it was not included in the version of that legislation that was enacted by Congress and signed into law. Congress may, through the enactment of other legislation during the current session of Congress or the subsequent Congress, enact VALID or establish new regulatory requirements for LDTs through other legislation.

    Registration No. 333-271439

In the meantime, the regulation by the FDA of LDTs remains uncertain. The FDA may, if Congress does not enact new legislation, seek to establish new requirements for LDTs. If the FDA premarket clearance, approval or authorization is required by FDA for any of our future proprietary testing products, or for any components or materials we use in our tests, such as the component used to collect samples from patients, we may be forced to stop selling our tests or we may be required to modify claims for or make other changes to our tests while we work to obtain FDA clearance, approval or de novo authorization. Our business would be adversely affected while such review is ongoing and if we are ultimately unable to obtain premarket clearance, approval or de novo authorization. For example, the regulatory premarket clearance, approval or de novo authorization process may involve, among other things, successfully completing analytical, pre-clinical and/or clinical studies beyond the studies we have already performed or plans to perform for our LDT. These studies may be extensive and costly and may take a substantial period of time to complete. Any such studies may fail to generate data that meets the FDA's requirements. The studies may also not be conducted in a manner that meets the FDA's requirements, and therefore could not be used in support of the marketing application. We would also need to submit a premarket notification, or 510(k), a request for de novo authorization, or a PMA application to the FDA and to include information (e.g., clinical and other data) supporting our LDT. Completing such studies requires the expenditure of time, attention and financial and other resources, and may not yield the desired results, which may delay, limit or prevent regulatory clearances, approvals or de novo authorizations. There can be no assurance that the submission of such an application will result in a timely response by the FDA or a favorable outcome that will allow the test to be marketed.

Certain types of standalone diagnostics software are subject to FDA regulation as a medical device (specifically, software as a medical device or "SaMD"). Some types of SaMD are subject to premarket authorization requirements. If the FDA were to conclude that the proprietary mRNA technology we have developed to predict presence of inflammatory-driven diseases and monitor patient treatment responses through artificial intelligence is required to obtain premarket authorization for the software used to analyze the mRNA genetic score, our ability to offer the test as an LDT could be delayed or prevented, which would adversely affect our business.

In addition, we may require cooperation in our filings for FDA clearance, approval or de novo authorization from third-party manufacturers of the components of our tests.

We cannot assure investors that any of our tests for which we decide to pursue or are required to obtain premarket clearance, approval or de novo authorization by the FDA will be cleared, approved or authorized on a timely basis, if at all. In addition, if a test has been cleared, approved or authorized, certain kinds of changes that we may make, e.g., to improve the test, or because of issues with suppliers of the components of the test or modification by a supplier to a component upon which our test approval relies, may result in the need for the test to obtain new clearance, approval or authorization from the FDA before we can implement them, which could increase the time and expense involved in implementing such changes commercially. Ongoing compliance with FDA regulations, such as the Quality System Regulation, labeling requirements, Medical Device Reports, and recall reporting, would increase the cost of conducting our business and subject us to heightened regulation by the FDA. We will be subject to periodic inspection by the FDA to ascertain whether our facility does comply with applicable requirements. The penalties for failure to comply with these and other requirements may include Warning Letters, product seizure, injunctions, civil penalties, criminal penalties, mandatory customer notification, and recalls, any of which may adversely impact our business and results of operations.

Furthermore, the FDA or the Federal Trade Commission ("FTC"), as well as state consumer protection agencies and competitors, may object to the materials and methods we use to promote the use of our current tests or other LDTs we may develop in the future, including with respect to the product claims in our promotional materials, and may initiate enforcement actions against us. Enforcement actions by these agencies may include, among others, injunctions, civil penalties, and equitable monetary relief.

For more information, see "Business - Laboratory Developed Test (LDT)" below.

We are in competition with companies that are larger, more established and better capitalized than are we.

The medical testing products industry is highly competitive, rapidly evolving and subject to constant change. The number of competitors in our industry is substantial. We expect that if our products establish a market niche, competition will arise from a variety of sources, including from large healthcare companies to other smaller national and regional healthcare companies.

Many of our potential competitors possess:

? greater financial, technical, personnel, promotional and marketing resources;

? longer operating histories;

? greater name recognition; and

? larger consumer bases.

We cannot assure you that we will be able to compete effectively in our extremely competitive industry.

    Registration No. 333-271439

We sell our nutraceutical supplement in highly competitive markets, which results in pressure on our profit margins and limits our ability to maintain or increase the market share of our services.

The nutraceutical, retail pharmacy and compounding pharmacy industries are subject to significant competition and pricing pressures. We will experience significant competitive pricing pressures as well as competitive products. While we believe that the products we offer are uniquely competitive against those offered by other supplement and nutraceutical companies, several significant competitors offer products with prices that may match or are lower than ours.

It is possible that one or more of our competitors could develop a significant research advantage over us that allows them to provide superior products or pricing, which could put us at a competitive disadvantage. Continued pricing pressure or improvements in research and shifts in customer preferences away from natural supplements could adversely impact our customer base or pricing structure and have a material and adverse effect on our business, financial condition, results of operations and cash flows.

Adverse publicity or consumer perception of our My RNA for Life(TM) Genetic Centric Supplement and any similar products distributed by others could harm our reputation and adversely affect our sales and revenues.

We are highly dependent upon positive consumer perceptions of the safety and quality of our My RNA for Life(TM) Genetic Centric Supplement as well as similar products distributed by other wellness, nutraceutical and food-supplement companies. Consumer perception of wellness supplements and our products, in particular, can be substantially influenced by scientific research or findings, national media attention and other publicity about product use. Adverse publicity from these sources regarding the safety, quality or efficacy of nutritional supplements and our products could harm our reputation and results of operations. The mere publication of news articles or reports asserting that such products may be harmful or questioning their efficacy could have a material adverse effect on our business, financial condition and results of operations, regardless of whether such news articles or reports are scientifically supported or whether the claimed harmful effects would be present at the dosages recommended for such products.

Our mRNA product candidates are based on innovative technologies and any product candidates we develop may be more complex and more difficult to manufacture than initially anticipated. We may encounter difficulties with manufacturing processes, manufacturing at higher volumes, product releases, product shelf life and storage, supply chain management, or shipping for any of our products. If we or any of our third-party vendors encounter such difficulties, our ability to supply commercial product or material for clinical studies could be delayed or stopped.

Our subsidiary, Precision Genomics, Inc., has developed medical artificial intelligence ("AI") technology that uses RNA-based inflammatory genetic markers to assist in disease diagnosis, monitoring and assessment of pre- and post-treatment patient responses. The manufacturing processes for our product candidates using our mRNA genomic technology are innovative and complex. There are no mRNA alternatives currently manufactured at commercial scale for our program. Due to the nature of this technology and our limited experience at commercial scale production, we could encounter difficulties with manufacturing processes, manufacturing at higher volumes, product releases, product shelf life and storage, supply chain management, or shipping.

Due to the nature of our products and manufacturing platform, there may also be a high degree of technological change that can negatively impact product comparability during and after clinical development. Furthermore, technology changes may drive the need for changes in, modification to, or the sourcing of new manufacturing infrastructure or may adversely affect third-party relationships.

The process to generate mRNA product candidates is complex and, if not developed and manufactured under well-controlled conditions, can adversely impact pharmacological activity and may result in one or more of our product candidates' failure. To date, we have not completed the development of our product candidates and there is not assurance that, once developed, that any of our products will be accepted by our targeted customers. If we do not successfully develop and commercialize our products based upon this technological approach, we may not become profitable and our results of operations may be adversely affected.

If we fail to develop and maintain satisfactory relationships with physicians and/or wellness centers that may recommend our nutraceutical supplement, our business may be adversely affected.

Our B2B approach will focus on engaging wellness center physicians as well as medical facilities and pharmacies. Our products encourage or require our customers to use these providers that we will market to. A key component of our "My RNA For Life" program is to increase the number of providers who may recommend our program or nutraceutical supplement to potential customers.

In any particular market, providers could refuse to engage with us, demand higher payments, or take other actions that could result in higher costs for us, less desirable products for customers and members or difficulty meeting regulatory or accreditation requirements. In some markets, some providers, particularly hospitals, physician specialty groups, physician/hospital organizations, or multi-specialty physician groups, may have significant market positions and negotiating power. If these providers refuse to contract with us, use their market position to negotiate unfavorable engagements with us or place us at a competitive disadvantage, or do not enter into contracts with us that encourage the usage of our "My RNA For Life" program, our ability to market products or to be profitable in those areas may be adversely affected. The market to engage physician and wellness practices, as well as medical facilities and pharmacies, is, and is expected to remain, highly competitive, and the performance of our B2B approach to market and distribute our "My RNA For Life" program and our nutraceutical supplement may be adversely impacted if we are unable to attract or maintain satisfactory relationships with physicians other medical professionals.

    Registration No. 333-271439

The materials used in our diagnostic tests processes and those used to manufacture RNA-based products and our derivative products, such as mRNA genetic microarrays, may become difficult to obtain in the quality or quantity required for our business plans or at the prices that are currently projected.

Many of our processes and products rely on materials purchased from third parties and should these materials increase in prices, have supply constraints, or become unavailable, it could impact our ability to develop products or bring them to market either on time, at competitive prices or at all. For example, some of our protein diagnostic tests that we use to identify inflammatory related diseases, such as our "ELISA" (as defined below) and Apoptotic Index(TM) technology, may use compounds that are sourced from suppliers in China. Further, mRNA panels used in our diagnostic tests are produced by a third-party. Should these particular components that are sourced and/or produced by third parties become unavailable, it could impair the effectiveness, yield or availability of some of our available laboratory tests.

Single or limited sources for some materials may impact our ability to secure supply for our nutraceutical supplement.

Our dependence on single-source, limited-source or preferred suppliers exposes us to certain risks, such as:

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

Should any of the above risks, or should any consequences of unpredictable risks, come to fruition, such events could have a material adverse effect on operations.

We rely on highly specialized equipment and consumables for the production of RNA and our derivative products, such as mRNA, and any disruption to the supply chain or any malfunction of that equipment may adversely impact our operations.

The equipment and consumables used to produce RNA and our derivative mRNA products are currently supply constrained across all suppliers, which may cause delays in development, testing or marketing of our human health products and may require us to ultimately increase prices should our products become available to consumers.

Additionally, we will be dependent on a number of equipment providers and third-party contract manufacturing organizations ("CMOs") who are also implementing innovative technology. For instance, we will use medical AI technology that uses mRNA-based genetic markers to measure the presence of inflammatory driven diseases and monitor patient treatment responses. This AI technology is run on a third-party equipment, which is located in a CLIA and CAP (as defined above) certified laboratory. If such equipment malfunctions or if we encounter unexpected performance issues, we could encounter delays or interruptions to clinical and commercial supply.

Delay or unavailability of products, services, or equipment provided by suppliers could require us to change the design of our research, development, and manufacturing processes based on the functions, limitations, features, and specifications of the replacement items or seek out a new supplier to provide these items. Additionally, as we grow, our existing suppliers may not be able to meet our increasing demand, and additional suppliers may need to be found. We may not be able to secure suppliers who provide lab supplies at, or equipment and services to, the specification, quantity, and quality levels that we demand (or at all) or be able to negotiate acceptable fees and terms of services with such suppliers.

    Registration No. 333-271439

If we are unable to develop and later market our products under development in a timely manner or at all, or if competitors develop or introduce similar products that achieve commercialization before our products enter the market, the demand for our products may decrease or the products could become obsolete.

Our products will compete in extremely competitive markets, where competitors may already be well established. We expect that competitors will continue to innovate and to develop and introduce similar products that could be competitive in both price and performance. Competitors may succeed in developing or introducing similar products earlier than, obtaining regulatory approvals and clearances for such products before our products are approved and cleared, or developing more effective products. In addition, competitors may have products, which may achieve commercialization before our products enter the market.

If the products we sell do not have the healthful effects intended, our business may suffer.

In general, our My RNA for Life(TM) Genetic Centric Supplement contain food and nutritional supplements which do not currently require approval from the FDA or other regulatory agencies prior to sale. Many of our products contain innovative ingredients or combinations of ingredients. There is minimal long-term experience with human or other animal consumption of certain of these ingredients or combinations thereof in concentrated form. Our products could have certain side effects if not taken as directed or if taken by a consumer that has certain medical conditions. Furthermore, there can be no assurance that any of the products, even when used as directed, will have the effects intended or will not have harmful side effects. Should our products cause unwanted side effects or not have the results intended, it could have a material adverse effect on our business, financial condition and results of operations.

Our marketing strategies for our products may not be successful.

We will be required to attract customers to our products, all of which will be new upon their introduction. Should our marketing strategies fail to establish sales of our products, our operations will be adversely affected.

Our business may be affected by litigation and government investigations.

We may from time to time receive inquiries and subpoenas and other types of information requests from government authorities and others and we may become subject to claims and other actions related to our business activities. While the ultimate outcome of investigations, inquiries, information requests and legal proceedings is difficult to predict, defense of litigation claims can be expensive, time-consuming, and distracting, and adverse resolutions or settlements of those matters may result in, among other things, modification of our business practices, costs and significant payments, any of which could have a material adverse effect on our business, financial condition, results of operations and prospects.

There will be no third-party oversight over the manufacturer of our products.

We intend for our products to be manufactured in an FDA-approved facility. While these facilities are inspected by the FDA, FDA inspections may not be conducted on a regular basis. Further we will not employ an independent third party to inspect regularly any such facility nor will our management regularly visit such facility to conduct a quality control review. As such, there is a risk that the quality of our products may decline. Any decline, or perception of decline, in the quality of our products can adversely affect our reputation, and consequently adversely affect our results of operations and revenue.

Our insurance coverage may not be sufficient to cover our legal claims or other losses that we may incur in the future.

We are also a smaller reporting Company, as defined in Rule 405 promulgated under the Securities Act ("SRC"). As an SRC, the Company intends to utilize certain reduced disclosure requirements, including publishing two years of audited financial statements instead of three years, as required for companies that do not qualify as an SRC. The Company will remain an SRC until the last day of the fiscal year in which it had (i) a public float that exceeded $250 million or (ii) annual revenues of more than $100 million and a public float that exceeded $700 million. To the extent the Company takes advantage of such reduced disclosure obligations, it may make comparison of its financial statements to those of other public companies difficult or impossible.

After the Company ceases to be an SRC, it is expected to incur additional management time and cost to comply with the more stringent reporting requirements applicable to companies that are accelerated filers or large accelerated filers, including complying with the auditor attestation requirements of Section 404 of SOX.

Our intellectual property rights are valuable, and any inability to protect them could reduce the value of our products and brand.

We have invested, and will continue to invest, resources to protect our brands and intellectual property rights. However, we may be unable or unwilling to strictly enforce our intellectual property rights, including our patents and trademarks, from infringement. Our failure to enforce our intellectual property rights could diminish the value of our brands and product offerings and harm our business and future growth prospects.

    Registration No. 333-271439

If we are unable to obtain and maintain protection of our intellectual property, which are costly to maintain, the value of our products may be adversely affected.

Our industry is characterized by vigorous pursuit and protection of intellectual property rights, which has resulted in protracted and expensive litigation for several companies. Third parties may assert claims of misappropriation of trade secrets or infringement of intellectual property rights against us or against our end customers or partners for which we may be liable.

As our business expands, the number of products and competitors in our markets can be expected to increase and product overlaps to occur, and infringement claims may increase in number and significance. Intellectual property lawsuits are subject to inherent uncertainties due to the complexity of the technical issues involved, and we cannot be certain that we would be successful in defending ourselves against intellectual property claims. Further, many potential litigants have the capability to dedicate substantially greater resources than we can to enforce their intellectual property rights and to defend claims that may be brought against them. Furthermore, a successful claimant could secure a judgment that requires us to pay substantial damages or prevents us from distributing products or performing certain services.

We attempt to protect our intellectual property position, in part, by filing patent applications related to our proprietary technology, inventions and improvements that are important to our business. However, our patent and trademark positions are not likely by itself to prevent others from commercializing products that compete directly with our products. In addition, the patents and trademarks owned by us or issued to us could be challenged, invalidated, or held to be unenforceable. We also note that any patent granted may not provide a competitive advantage to us. Our competitors may independently develop technologies that are substantially similar or superior to our technologies. Further, third parties may design around our patented or proprietary products and technologies.

We rely on certain trade secrets and we may not be able to adequately protect our trade secrets even with contracts with our personnel and third parties. Also, any third party could independently develop and have the right to use, our trade secret, know-how and other proprietary information. If we are unable to protect our intellectual property rights, our business, prospects, financial condition and results of operations could suffer materially.

We may not be successful in registering and enforcing our trademarks.

As we apply to register our unregistered trademarks in the United States and other countries, our applications may not be allowed for registration in a timely fashion or at all, and our registered trademarks may not be maintained or enforced. Trademark enforcement is always uncertain, since proving infringement requires a showing of consumer confusion in addition to use by the defendant of a similar or identical trademark. In addition, opposition or cancellation proceedings may be filed against our trademark applications and registrations, and our trademarks may not survive such proceedings. In certain countries outside of the United States, trademark registration is required to enforce trademark rights. If we do not secure registrations for our trademarks, we may encounter more difficulty in enforcing them against third parties than we otherwise would.

Risks Related to an Investment in Our Securities

Persons who purchase shares of our common stock may lose their money without us ever being able to develop a market.

In the event that no market to purchase our common shares is ever created, it is likely that the entire investment of a purchaser in our common stock would be lost.

The outstanding shares of our convertible preferred stock (the "Convertible Preferred Stock") will, for the foreseeable future, preclude current and future owners of our common stock from influencing any corporate decision.

The Convertible Preferred Stock has the following voting rights: each share of Convertible Preferred Stock shall vote on all matters as a class with the holders of common stock and each share of Convertible Preferred Stock shall be entitled to the number of votes equal to the "conversion rate," or one hundred (100) votes per share of Convertible Preferred Stock. These holders of Convertible Preferred Stock will, therefore, be able to control the management and affairs of the Company, as well as matters requiring the approval by our stockholders, including the election of directors, any merger, consolidation or sale of all or substantially all of our assets, and any other significant corporate transaction. (See "Security Ownership of Certain Beneficial Owners and Management").

The conversion of our outstanding shares of Convertible Preferred Stock and Convertible Notes will, if and when converted, result in significant ownership dilution to holders of our common stock, including holders of Offered Shares.

The 7,000,000 outstanding shares of Convertible Preferred Stock are convertible, at any time, into a total of 700,000,000 shares of our common stock. (See "Description of Securities--Convertible Preferred Stock" and "Security Ownership of Certain Beneficial Owners and Management"). The Convertible Notes are also convertible at the election of their respective holders, at a price equal to 80% of the offering price for all of the Offered Shares, or $ [0.60-1.00] per Conversion Share, for a total of up to [1,566,667-940,000] shares of our common stock.

    Registration No. 333-271439

If and when the shares underlying the Convertible Preferred Stock and Convertible Notes are converted, the then-holders of our common stock, including purchasers of the Offered Shares, may experience immediate and substantial dilution in their respective ownership percentages.

Investors in this Offering will experience immediate and substantial dilution in net tangible book value.

If you purchase Offered Shares in this Offering, your investment will be diluted to the extent of the difference between your purchase price per Offered Share and the net tangible book value of our common stock after this Offering. Our net tangible book value as of December 31, 2022, was $(826,167), or $(0.00) per share.

As a result of the Offered Shares in this Offering, investors in this Offering may incur immediate dilution of $[0.87-0.96] based on the $[0.75-1.25] offering price. Investors in this Offering will pay a price per share that substantially exceeds the book value of our assets after subtracting our liabilities. See "Dilution" for a more complete description of how the value of your investment will be diluted upon the completion of this Offering.

In addition, we have 7,000,000 shares of Convertible Preferred Stock outstanding, which may be converted into a total of 700,000,000 shares of our common stock. To the extent that the Convertible Preferred Stock is converted, there may be further dilution.

We have outstanding indebtedness pursuant to the Convertible Notes, and default on such Convertible Notes may adversely affect our financial condition and ability to operate our business.

If the holders of the Convertible Notes determine not to convert the Convertible Notes into shares of our common stock, we may be unable to discharge such obligations when due. In such circumstance, we would be in default on each of the Convertible Notes, which would have a severe material adverse effect on our ability to operate our business. None of the Convertible Notes is due until October 1, 2023.

In addition, we may need additional financing to support our business and pursue our growth strategy, including for pursuing our future planned studies. Our ability to obtain additional financing, if and when required, will depend on investor demand, our operating performance, the condition of the capital markets and other factors. We cannot assure you that additional financing will be available to us on favorable terms when required, or at all. If we raise additional funds through the issuance of equity, equity-linked or debt securities, those securities may have rights, preferences or privileges senior to those of our common stock, and, in the case of equity and equity-linked securities, our existing shareholder may experience dilution.

We may seek capital that may result in stockholder dilution or that may have rights senior to those of our common stock.

From time to time, we may seek to obtain additional capital, either through equity, equity linked or debt securities. The decision to obtain additional capital will depend on, among other factors, our business plans, operating performance and condition of the capital markets. If we raise additional funds through the issuance of equity, equity linked or debt securities, those securities may have rights, preferences or privileges senior to the rights of our common stock, which could negatively affect the market price of our common stock or cause our stockholders to experience dilution.

Given that we do not have committed sources of financing, we may attempt to raise capital by selling shares, possibly at a deep discount to market. These actions may result in dilution of the ownership interests and voting power of existing stockholders, further dilute common stock book value, and may delay, defer or prevent a change of control.

Future issuances of debt securities and equity securities could negatively affect the market price of shares of our common stock and, in the case of equity securities, may be dilutive to existing stockholders.

In the future, we may issue debt or equity securities or incur other financial obligations, including stock dividends. Upon liquidation, it is possible that holders of our debt securities and other loans and preferred stock would receive a distribution of our available assets before common stockholders. We are not required to offer any such additional debt or equity securities to existing stockholders on a preemptive basis. Therefore, additional common stock issuances, directly or through convertible or exchangeable securities, warrants or options, would dilute the holdings of our existing common stockholders and such issuances, or the perception of such issuances, could reduce the market price of shares of our common stock.

    Registration No. 333-271439

We do not intend to pay dividends on our common stock.

We intend to retain earnings, if any, to provide funds for the implementation of our business strategy. We do not intend to declare or pay any dividends in the foreseeable future. Therefore, there can be no assurance that holders of our common stock will receive cash, stock or other dividends on their shares of our common stock, until we have funds which our Board of Directors determines can be allocated to dividends. Further, our common stock may be less valuable because a return on your investment will only occur if our stock price appreciates.

We have broad discretion in the use of the net proceeds from this Offering and may not use them effectively.

Our management will have broad discretion in the application of the net proceeds from this Offering, including for any of the purposes described in the section entitled "Use of Proceeds," and you will not have the opportunity as part of your investment decision to assess whether the net proceeds will be used appropriately. Because of the number and variability of factors that will determine our use of the net proceeds from this Offering, their ultimate use may vary substantially from their currently intended use. Furthermore, our management will have broad discretion in the application of the net proceeds, and investors will be relying on our judgment regarding the application of the net proceeds of this Offering.

The failure by our management to apply these funds effectively could harm our business. Pending their use, we may invest the net proceeds from this Offering in short-term, investment-grade, interest-bearing securities. These investments may not yield a favorable return to our stockholders. If we do not invest or apply the net proceeds from this Offering in ways that enhance stockholder value, we may fail to achieve expected financial results, which could cause our stock price to decline.

Because our common stock is considered a "penny stock," any investment in our common stock is considered to be a high risk investment and is subject to restrictions on marketability.

Our common stock is considered a "penny stock" because it is quoted on the OTC Pink and it trades for less than $5.00 per share. The OTC Pink is generally regarded as a less efficient trading market than the Nasdaq Capital ("Nasdaq") or Global Markets or the New York Stock Exchange. The SEC has rules that regulate broker dealer practices in connection with transactions in "penny stocks."

Penny stocks generally are equity securities with a price of less than $5.00 per share (other than securities registered on certain national securities exchanges or quoted on the Nasdaq system, provided that current price and volume information with respect to transactions in such securities is provided by the exchange or system). The penny stock rules require a broker dealer, prior to a transaction in a penny stock not otherwise exempt from those rules, to deliver a standardized risk disclosure document prepared by the SEC, which specifies information about penny stocks and the nature and significance of risks of the penny stock market. The broker dealer also must provide the customer with bid and offer quotations for the penny stock, the compensation of the broker dealer and any salesperson in the transaction, and monthly account statements indicating the market value of each penny stock held in the customer's account. In addition, the penny stock rules require that, prior to effecting a transaction in a penny stock not otherwise exempt from those rules, the broker dealer must make a special written determination that the penny stock is a suitable investment for the purchaser and receive the purchaser's written agreement to the transaction. These disclosure requirements may have the effect of reducing the trading activity in the secondary market for our common stock. Since our common stock is subject to the regulations applicable to penny stocks, the market liquidity for our common stock could be adversely affected because the regulations on penny stocks could limit the ability of broker dealers to sell our common stock and thus your ability to sell our common stock in the secondary market in the future.

We can provide no assurance that our common stock will be quoted or listed on any trading platform of higher quality than the OTC Pink, including the OTCQB, NYSE American or any exchange, even if eligible, in the future.

It is possible that our common stock will continue to experience volatility in its trading volume and its market price.

Our common stock is quoted in the over-the-counter market under the symbol "LUDG" on the OTC Pink. For over the past five years, our common stock has experienced both volume and price volatility. The market for low-priced securities is generally less liquid and more volatile than securities traded on national stock markets. Wide fluctuations in market prices are not uncommon.

The price of our common stock may be subject to wide fluctuations in response to factors such as the following, some of which are beyond our control:

? quarterly variations in our operating results;

? operating results that vary from the expectations of investors;

    Registration No. 333-271439

    Registration No. 333-271439

? changes in our capital structure;

? announcements of innovations or new products by us or our competitors;

    Registration No. 333-271439

    Registration No. 333-271439

? lack of success in the expansion of our business operations;

    Registration No. 333-271439

? additions or departures of key personnel;

? asset impairment;

? temporary or permanent inability to offer products or services; and

? rumors or public speculation about any of the above factors.

If our quarterly operating results fall below the expectations of investors or securities analysts, the price of our common stock could decline substantially. Furthermore, any quarterly fluctuations in our operating results may, in turn, cause the price of our stock to fluctuate substantially. We believe that quarterly comparisons of our financial results are not necessarily meaningful and should not be relied upon as an indication of our future performance.

In the past, following periods of volatility in the market price of a company's securities, securities class-action litigation often has been instituted against that company. Such litigation, if instituted against us, could cause us to incur substantial costs to defend such claims and divert management's attention and resources.

Our internal controls may be inadequate, which could cause our financial reporting to be unreliable and lead to misinformation being disseminated to the public.

Our management is responsible for establishing and maintaining adequate internal control over our financial reporting. As defined in Exchange Act Rule 13a 15(f), internal control over financial reporting is a process designed by, or under the supervision of, the principal executive and principal financial officer and effected by the Board of Directors, management and other personnel, to provide reasonable assurance regarding the reliability of financial reporting and the preparation of financial statements for external purposes in accordance with generally accepted accounting principles and includes those policies and procedures that:

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

Our internal controls may be inadequate or ineffective, which could cause financial reporting to be unreliable and lead to misinformation being disseminated to the public. Investors relying upon this misinformation may make an uninformed investment decision.

Failure to achieve and maintain an effective internal control environment could cause us to face regulatory action and also cause investors to lose confidence in our reported financial information, either of which could have a material adverse effect on the Company's business, financial condition, results of operations and future prospects.

    Registration No. 333-271439

However, our auditors will not be required to formally attest to the effectiveness of our internal control over financial reporting pursuant to Section 404 until we are no longer an EGC if we take advantage of the exemptions available to us through the JOBS Act.

The costs of being a public company could result in us being unable to continue as a going concern.

As a public Company, we are required to comply with numerous financial reporting and legal requirements, including those pertaining to audits and internal control. The costs of maintaining public company reporting requirements could be significant and may preclude us from seeking financing or equity investment on terms acceptable to us and our stockholders. We estimate these costs to be approximately $75,000 per year and may be higher if our business volume or business activity increases significantly.

To the extent that funds generated from any private placements, public offerings and/or bank financing are insufficient, we will have to raise additional working capital and no assurance can be given that additional financing will be available, or, if available, will be on acceptable terms. The recent interest rate hikes and the present conditions and state of the United States and global economies make it difficult to predict whether and/or when and to what extent a recession has occurred or will occur in the near future. These conditions potentially raise substantial doubt about our ability to continue as a going concern. If adequate working capital is not available, we may be forced to discontinue operations, which would cause investors to lose their entire investment.

Risks Related to Our Organization and Structure

Our holding Company structure makes us dependent on our subsidiaries for our cash flow and could serve to subordinate the rights of our stockholders to the rights of creditors of our subsidiaries, in the event of an insolvency or liquidation of any such subsidiary.

The Company acts as a holding company and, accordingly, substantially all of our operations are conducted through our subsidiaries. Such subsidiaries will be separate and distinct legal entities. As a result, substantially all of our cash flow will depend upon the earnings of our subsidiaries. In addition, we will depend on the distribution of earnings, loans or other payments by our subsidiaries. No subsidiary will have any obligation to provide the Company with funds for our payment obligations. If there is an insolvency, liquidation or other reorganization of any of our subsidiaries, our stockholders will have no right to proceed against their assets. Creditors of those subsidiaries will be entitled to payment in full from the sale or other disposal of the assets of those subsidiaries before the Company, as a stockholder, would be entitled to receive any distribution from that sale or disposal.

Risks Relating to This Offering

FINRA sales practice requirements may limit a stockholder's ability to buy and sell our common stock.

The Financial Industry Regulatory Authority ("FINRA") has adopted rules that require that in recommending an investment to a customer, a broker dealer must have reasonable grounds for believing that the investment is suitable for that customer. Prior to recommending speculative low-priced securities to their non institutional customers, broker dealers must make reasonable efforts to obtain information about the customer's financial status, tax status, investment objectives and other information. Under interpretations of these rules, FINRA believes that there is a high probability that speculative low-priced securities will not be suitable for at least some customers. FINRA requirements make it more difficult for broker dealers to recommend that their customers buy our common stock, which may have the effect of reducing the level of trading activity in our common stock. As a result, fewer broker dealers may be willing to make a market in our common stock, reducing a stockholder's ability to resell shares of our common stock.

State securities laws may limit secondary trading, which may restrict the states in which you can sell the shares offered by this prospectus.

If you purchase Offered Shares in this Offering, you may not be able to resell the shares in any state, unless and until the shares of our common stock are qualified for secondary trading under the applicable securities laws of such state or there is confirmation that an exemption, such as listing in certain recognized securities manuals, is available for secondary trading in such state. There can be no assurance that we will be successful in registering or qualifying our common stock for secondary trading, or identifying an available exemption for secondary trading in our common stock in every state. If we fail to register or qualify, or to obtain or verify an exemption for the secondary trading of, our common stock in any particular state, our common stock could not be offered or sold to, or purchased by, a resident of that state. In the event that a significant number of states refuse to permit secondary trading in our common stock, the market for our common stock will be limited which could drive down the market price of our common stock and reduce the liquidity of the shares of our common stock and a stockholder's ability to resell shares of our common stock at all or at current market prices, which could increase a stockholder's risk of losing some or all of his, her or its investment.

    Registration No. 333-271439

There has been no independent valuation of the stock, which means that the stock may be worth less than the purchase price.

The Offering price of the Offered Shares has been determined by us without independent valuation of the Offered Shares. We established the offering price based on management's estimate of the value of the Offered Shares. This valuation is highly speculative and arbitrary. There is no relation to the market value, book value, or any other established criteria. We did not obtain an independent appraisal opinion on the valuation of the Offered Shares. The Offered Shares may have a value significantly less than the offering price and the Offered Shares may never obtain a value equal to or greater than the offering price.

Our common stock is thinly traded and experiences wide share price fluctuations, low share prices and minimal liquidity.

The trading price of our common stock is volatile with wide fluctuations in response to several factors, including, without limitation, potential investors' anticipated feeling regarding our results of operations, increased competition and our ability or inability to generate future revenues. In addition, the trading price of our common stock may be affected by factors that are unrelated or disproportionate to our operating performance. The trading price of our common stock might be affected by general economic, political and market conditions, such as recessions, interest rates, commodity prices or international currency fluctuations. Additionally, stocks traded on the OTC PINK market are usually thinly traded, highly volatile and not followed by analysts. These factors, which are not under our control, may have a material effect on the trading price of our common stock.

Because this Offering does not have a minimum offering amount, we may not raise enough funds to continue operations.

Because the terms of this Offering lack a minimum offering amount, no minimum amount of funds are assured, and we may only receive proceeds sufficient to fund operations for a short amount of time. We may, then, have to cease operations, and investors could then lose their entire investments.

Because this Offering is a self-underwritten "best effort" basis offering, we may not raise enough capital to fund our business goals and/or objectives.

This prospectus relates to the sale of 47,000,000 Offered Shares at a price of $___[0.75-1.25] per share. This Offering terminates one year from the date of this prospectus. We are offering the Offered Shares on a self-underwritten "best-efforts" basis directly through our President, Anne B. Blackstone. There is no minimum amount of Offered Shares required to be purchased, and the total proceeds received by us might not be enough to execute our business plan, or a market may not ever develop for our common stock. No commission or other compensation related to the sale of the shares will be paid. For more information, see the sections titled "Plan of Distribution" and "Use of Proceeds" herein.

    Registration No. 333-271439

This prospectus relates to the sale of 47,000,000 Offered Shares at a price of $___[0.75-1.25] per share. This Offering terminates one year from the date of this prospectus. We are offering the Offered Shares on a self-underwritten "best-efforts" basis directly through our President, Anne B. Blackstone. There is no minimum amount of Offered Shares required to be purchased, and the total proceeds received by us might not be enough to execute our business plan, or a market may not ever develop for our common stock. No commission or other compensation related to the sale of the shares will be paid. For more information, see the sections titled "Plan of Distribution" and "Use of Proceeds" herein.

    Registration No. 333-271439

We estimate the net proceeds to us from this offering will be approximately $__[35,250,000-58,750,000] based on the initial offering price of $___[0.75-1.25] per share, prior to deducting estimated offering expenses payable by us in the approximate amount of $50,000.

We anticipate that the net cash proceeds of this Offering will be used primarily to execute our business plan and will include expenditures for equipment, marketing, staffing, legal expenses, accounting expense, company awareness, research and clinical trials, debt repayment and the exercise of an option to buy back certain shares of our common stock. Additionally, net cash proceeds will be used for paying general and administrative expenses associated with this Offering and paying general and administrative expenses associated with being a public company, including accounting, auditing, transfer agent, EDGAR filing and legal expenses. The precise amounts that we will devote to our programs will vary depending on numerous factors, including, but not limited to, the progress and results of our research and assessments as to the market for our products that are in development. In the event that we sell less than the maximum Offered Shares offered in this Offering, our first priorities are to pay fees associated with product development and their market introduction.

    Registration No. 333-271439

The table below sets forth the estimated proceeds we would derive from this Offering, assuming the sale of 25%, 50%, 75% and 100% of the Offered Shares at a per share price of $1.00, which represents the midpoint of the offering price range herein.

    Registration No. 333-271439

The table below sets forth the manner in which we intend to apply the net proceeds derived by us in this Offering, assuming the sale of 25%, 50%, 75% and 100% of the Offered Shares. All amounts set forth below are estimates. Following the table below, there is a narrative that describes how we intend to use the proceeds from this Offering. We urge you to read such narrative, in conjunction with the table below.

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

(3) The Convertible Notes (as defined above) were issued as follows:

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

With proceeds from this Offering, we intend to purchase Thermofisher sequencing equipment, an Automated Liquid Handler (Eppendorf), a Maxwell RNA extractor and a King Fisher Extractor (if necessary, we would lease such equipment). This equipment allows for the extraction and sequencing of mRNA from samples provided. With the purchase of this equipment and related lab items, over the next year, we expect to analyze approximately 3,000 mRNA samples obtained from patients with various chronic inflammatory diseases, choose the most significant mRNA diagnostic genes and organize an antibody research lab to target the chosen genes. Our plan is to develop specific antibodies that bind to these genes and market them to biotech- and pharma-companies to treat chronic inflammatory diseases, such as cancer, diabetes and heart disease. We believe that our planned clinical studies will provide the needed therapeutic data to support our plan to develop these specific antibodies.

With proceeds from this Offering, we intend to conduct three separate clinical trials, which are detailed below.

    Registration No. 333-271439

This study is a standard-of-care study with BCG immunotherapy, an approved FDA drug. Therefore, it is anticipated that evaluation and treatment of patients enrolled would be covered under existing medical and surgical insurance. The costs to evaluate the 300 patients with our mRNA technology and Elisa protein saliva and urine costs is expected to be approximately $180,000, to apply machine learning (AI) statistical costs are expected to be approximately $300,000 and to retain a Clinical Research Organization (CRO) is expected to be approximately $600,000. We expect that the total cost of this clinical study will be approximately $1,250,000.

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

Currently, we are organizing cheek swab samples that have already been collected. The immediate goal is to isolate mRNA genetic samples and analyze them to identify inflammatory markers specific to cardiovascular diseases. The cost of collecting 300 samples is $300 per sample, or approximately $90,000. Prior to commencing this clinical study, a clinical protocol must be written (we expect that our Chief Executive Officer, Marvin S. Hausman, M.D., will author the necessary protocol) and IRB approval obtained. This clinical trial is for 100 patients, with anticipated expenses for controls, laboratory tests and a CRO to perform the study are expected to be at least $15,000 per patient. At a cost of approximately $300,000, machine learning (AI) statistical analysis will be used to analyze all clinical lab results and develop indices that assess the severity of the state of disease for each patient and also allow assessment of disease response to treatment. We expect that the total cost of this clinical study will be approximately $2,000,000.

We intend to deploy a direct-to-consumer marketing campaign, as well as a physician awareness program using continuous medical education on the area in which our product may be useful, i.e., inflammation. We intend to engage an outside medical education firm to assist in the production of such programs. We plan to hire a Chief Compliance Officer to lead and monitor such programs. In addition, we intend to retain outside parties to implement a company awareness that would serve to increase our company's visibility within its target markets, as well as within the investment community. Our management believes that building investor awareness of our company is an important aspect of any company that seeks to uplist its stock to a higher quality market, to benefit its shareholders.

As we expand our operations with proceeds from this Offering, it will be necessary to hire key personnel, including a Chief Marketing Officer, a Chief Financial Officer and a Chief Compliance Officer, as well as ancillary support staff (e.g., warehouse, staff accountants, bookkeeper, marketing analyst, sales representatives, bio-analytics specialist).

Should we not be successful in selling all of the Offered Shares, we would be required to prioritize our expenditures. Our management has determined that expenditures for clinical trials and marketing would be the last expenditure items to be reduced. The remaining expenditure items would be adjusted by our management, in light of the circumstances existing at the time such decisions are to be made. Our expected use of net proceeds from this Offering represents our current intentions based upon our present plans and business condition. As of the date of this prospectus, we cannot predict with complete certainty all of the particular uses for the net proceeds to be received upon the completion of this Offering or the actual amounts that we will spend on the uses set forth above.

The amounts and timing of our actual expenditures will depend on numerous factors, including the progress of our business growth strategy and the scale achieved by our sales and marketing team, as well as the amount of cash used in our operations. We therefore cannot estimate with certainty the amount of net proceeds to be used for the purposes described above. We may find it necessary or advisable to use the net proceeds for other purposes, and we will have broad discretion in the application of the net proceeds.

    Registration No. 333-271439

The Offered Shares covered by this prospectus at a price of $___[0.75-1.25] per share until our shares are either listed on a national securities exchange or quoted on the OTC Bulletin Board, OTCQX, or OTCQB, and thereafter at prevailing market prices or privately negotiated prices. In determining the public offering price of the Primary Offering shares, we considered several factors including:

? Our start up status;

? General economic conditions and political events;

    Registration No. 333-271439

? Our future prospects; and

? Our capital structure.

Therefore, the public offering price of the Offered Shares does not necessarily bear any relationship to established valuation criteria and may not be indicative of prices that may prevail at any time or from time to time in the public market for our common stock. You cannot be sure that a public market for any of our securities will develop and continue or that the securities will ever trade at a price at or higher than the offering price in this Offering. Such offering price does not have any relationship to any established criteria of value, such as book value or earnings per share. Because we have no significant operating history, the price of our common stock is not based on past earnings, nor is the price of our common stock indicative of the current market value of the assets owned by us. No valuation or appraisal has been prepared for our business and potential business expansion. You cannot be sure that the trading price for our common stock will ever trade at a price at or higher than the offering price of the Offered Shares in this Offering.

    Registration No. 333-271439

We have not declared or paid any cash dividends on our capital stock since our inception. We intend to retain future earnings, if any, to finance the operation and expansion of our business and do not anticipate paying any cash dividends in the foreseeable future. Declaration or payment of dividends, if any, in the future, will be at the discretion of our board of directors and will depend on our then current financial condition, results of operations, capital requirements and other factors deemed relevant by the There are no contractual restrictions on our ability to declare or pay dividends. Consequently, you will only realize an economic gain on your investment in our common stock if the price appreciates. You should not purchase our common stock expecting to receive cash dividends. Since we do not anticipate paying dividends, and if we are not successful in establishing an orderly public trading market for our shares, then you may not have any manner to liquidate or receive any payment on your investment. Therefore, our failure to pay dividends may cause you to not see any return on your investment even if we are successful in our business operations. In addition, because we may not pay dividends in the foreseeable future, we may have trouble raising additional funds which could affect our ability to expand our business operations.

    Registration No. 333-271439

Market Information

Our common stock is currently quoted on the OTC PINK tier of the OTC Markets under the symbol "LUDG." The market price of our common stock is subject to significant fluctuations in response to variations in our quarterly operating results, general trends in the market and other factors, over many of which we have little or no control. In addition, broad market fluctuations, as well as general economic, business and political conditions, may adversely affect the market for our common stock, regardless of our actual or projected performance.

    Registration No. 333-271439

The following table reflects the high and low closing price for our common stock for the periods indicated. The information was obtained from the OTC Markets Group, Inc. and reflects inter-dealer prices, without retail mark up, markdown or commission, and may not necessarily represent actual transactions.

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

On September 15, 2023, the closing price of our common stock was $0.164.

Shareholders of Record

We have 582 shareholders of record of our common stock as of September ___, 2023.

    Registration No. 333-271439

Information included or incorporated by reference in this prospectus may contain forward-looking statements. This information may involve known and unknown risks, uncertainties and other factors which may cause our actual results, performance or achievements to be materially different from the future results, performance or achievements expressed or implied by any forward-looking statements. Forward looking statements, which involve assumptions and describe our future plans, strategies and expectations, are generally identifiable by use of the words "may," "should," "expect," "anticipate," "estimate," "believe," "intend" or "project" or the negative of these words or other variations on these words or comparable terminology.

This prospectus contains forward looking statements, including statements regarding, among other things, (a) our projected sales and profitability, (b) our production and technology, (c) the regulation to which we are subject, (d) anticipated trends in our industry and(e) our needs for working capital. These statements may be found under "Management's Discussion and Analysis or Plan of Operations" and "Business," as well as in this prospectus generally. Actual events or results may differ materially from those discussed in forward-looking statements as a result of various factors, including, without limitation, the risks outlined under "Risk Factors" and matters described in this prospectus generally. In light of these risks and uncertainties, there can be no assurance that the forward looking statements contained in this prospectus will in fact occur.

Except as otherwise required by applicable laws, we undertake no obligation to publicly update or revise any forward-looking statements or the risk factors described in the prospectus, whether as a result of new information, future events, changed circumstances or any other reason after the date of this prospectus.

    Registration No. 333-271439

Ownership Dilution

The information under "Investment Dilution" below does not take into account the potential conversion of the outstanding shares of Convertible Preferred Stock into a total of 700,000,000 shares of our common stock. The conversion of the Convertible Preferred Stock, which could occur at any time would cause holders of our common stock, including the Offered Shares, to incur significant dilution in their ownership of the Company. (See "Risk Factors--Risks Related to a Purchase of the Offered Shares," "Description of Securities--Convertible Preferred Stock" and "Security Ownership of Certain Beneficial Owners and Management").

In addition, should all of the Convertible Notes be converted by their respective holders into a total of up to [1,566,667-940,00] shares of our common stock, holders of our common stock, including the Offered Shares, could incur further dilution in their ownership of the Company. (See "Risk Factors--Risks Related to a Purchase of the Offered Shares," "Description of Securities--Convertible Promissory Notes" and "Security Ownership of Certain Beneficial Owners and Management").

Investment Dilution

Dilution in net tangible book value per share to purchasers of our common stock in this Offering represents the difference between the amount per share paid by purchasers of the Offered Shares in this Offering and the net tangible book value per share immediately after completion of this Offering. In this Offering, dilution is attributable primarily to our negative net tangible book value per share.

    Registration No. 333-271439

If you purchase Offered Shares in this Offering, your investment will be diluted to the extent of the difference between your purchase price per Offered Share and the net tangible book value of our common stock after this Offering. Our net tangible book value as of June 30, 2023, was $(997,345) (unaudited), or $(0.00) (unaudited) per share. Net tangible book value per share is equal to total assets minus the sum of total liabilities and intangible assets divided by the total number of shares outstanding.

The tables below illustrate the dilution to purchasers of Offered Shares in this Offering, on a pro forma basis, assuming 100%, 75%, 50% and 25% of the Offered Shares are sold at a per share price of $1.00, which represents the midpoint of the offering price range herein.

Percentage of Offered Shares Sold 100% 75% 50% 25% Offering price per share 1.00 1.00 1.00 1.00 Net tangible book value per share as of June 30, 2023 (0.00) (0.00) (0.00) (0.00) Increase per share attributable to investors 0.04 0.07 0.10 0.13 Pro forma net tangible book value per share after offering 0.04 0.07 0.10 0.13 Dilution per share to investors 0.96 0.93 0.9 0.87

    Registration No. 333-271439

You should read the following discussion and analysis of our financial condition and results of our operations together with our consolidated financial statements and the notes thereto appearing elsewhere in this prospectus. This discussion contains forward-looking statements reflecting our current expectations, whose actual outcomes involve risks and uncertainties. Actual results and the timing of events may differ materially from those stated in or implied by these forward-looking statements due to a number of factors, including those discussed in the sections entitled "Risk Factors," "Cautionary Statement Regarding Forward Looking Statements" and elsewhere in this prospectus. Please see the notes to our Financial Statements for information about our Critical Accounting Policies and Recently Issued Accounting Pronouncements.

Forward looking Statements

There are "forward looking statements" contained herein. All statements that express expectations, estimates, forecasts or projections are forward-looking statements. In addition, other written or oral statements which constitute forward-looking statements may be made by us or on our behalf. Words such as "expect," "anticipate," "intend," "plan," "believe," "seek," "estimate," "project," "forecast," "may," "should," and variations of such words and similar expressions are intended to identify such forward looking statements. These statements are not guarantees of future performance and involve risks, uncertainties and assumptions which are difficult to predict. Therefore, actual outcomes and results may differ materially from what is expressed or forecasted in or suggested by such forward-looking statements. We undertake no obligation to update or revise any of the forward-looking statements after the date of this quarterly report to conform forward-looking statements to actual results. Important factors on which such statements are based are assumptions concerning uncertainties, including but not limited to, uncertainties associated with the following:

    Registration No. 333-271439

? Our failure to earn revenues or profits;

? Inadequate capital to continue business;

? Volatility or decline of our stock price;

? Potential fluctuation in quarterly results;

? Rapid and significant changes in markets;

? Litigation with or legal claims and allegations by outside parties; and

? Insufficient revenues to cover operating costs.

    Registration No. 333-271439

The following discussion should be read in conjunction with the financial statements and the notes thereto which are included in this quarterly report. This discussion contains forward-looking statements that involve risks, uncertainties and assumptions. Our actual results may differ substantially from those anticipated in any forward-looking statements included in this discussion as a result of various factors.

Overview

We are an innovative technology and health related Company that is developing products that use mRNA-based genetic markers with the potential to measure the presence of inflammation, and, as a result, inflammatory driven diseases and monitor patient response to treatment. Advancements in medical technology have awarded us with cutting edge genetic tools, unheard of even a generation ago. These genetic tools have the potential to not only achieve early detection of diseases but also to support customized treatments that may improve patient outcomes. The Company is at the forefront of this new era of medicine with development of products that will embody our proprietary mRNA genomic technology that has the potential of detecting genetic biomarkers for inflammatory driven diseases, including, but not limited to, heart disease, diabetes, preeclampsia, cancer and "long COVID".

Our subsidiary, Precision Genomics, Inc., has developed medical machine learning, artificial intelligence ("AI") technology that uses measurements of mRNA genetic biomarkers to potentially predict the presence of inflammation, and, as a result, inflammatory driven diseases and monitor patient response to treatment. Precision Genomics' proprietary technology uses unique mRNA language to capture a snapshot of disease and the body's response to treatment. This genomic technology is applicable to chronic inflammatory driven diseases, including, but not limited to, cancer, heart disease, diabetes, preeclampsia and "long COVID".

Effects of COVID 19 on The Company

The COVID-19 pandemic did not have a discernable negative impact on the Company, due to our lack of capital with which we operate. Overall, the Company is not of a size that required us to implement "companywide" policies in response to the COVID-19 pandemic.

Current Financial Condition Summary

We have not yet derived revenues from our operations.

We had a net loss of $1,559,276 (unaudited) for the six months ended June 30, 2023. Additionally, we had net cash used in operating activities of $500,425 (unaudited) for the six months ended June 30, 2023. At June 30, 2023, we had a working capital deficit of $997,345 (unaudited), an accumulated deficit of $3,345,208 (unaudited) and a stockholders' deficit of $997,345 (unaudited), which could have a material impact on our ability to obtain needed capital.

    Registration No. 333-271439

Results of Operations

Six Months Ended June 30, 2023, compared to the Six Months Ended June 30, 2022. For the six months ended June 30, 2023 and 2022, we had no revenue, respectively. We expect that revenues from sales of our planned products will begin late in the third quarter or early in the fourth quarter of 2023.

Operating Expenses. Total operating expenses for the six months ended June 30, 2023 and 2022, were $1,078,466 (unaudited) and $128,772 (unaudited), respectively. Included in operating expenses for the six months ended June 30, 2023, are $684,256 (unaudited) of general and administrative expenses and $394,210 (unaudited) of research and development expenses.

The increase in operating expenses during the six months ended June 30, 2023, was primarily due to a significant increase in our activities relating to our planned products, including the payment of product study expenses, as well as the payment of monthly fees to our key consultants and fees for professional services, including accounting and legal.

Research and Development Expenses. Total research and development ("R&D") expenses for the six months ended June 30, 2023, was $394,210 (unaudited), as compared to $45,245 (unaudited) for the six months ended June 30, 2022. R&D consisted primarily of the expensing of 1,000,000 shares of common stock, having a fair value of $370,000 related to the acquisition of a licensing agreement. The Company believed this license was going to be the basis for future research and development activities.

General and Administrative Expenses. The increase of $600,729 (unaudited) in general and administrative expenses for the six months ended June 30, 2023, as compared to the six months ended June 30, 2022, was primarily due to the significant increase in our activities relating to our planned products, including the payment of product study expenses, as well as the payment of monthly fees to our key consultants and fees for professional services, including accounting and legal. Should we be able to obtain capital in this offering or otherwise, as we continue to expand our business activities, we expect that our general and administrative expenses for all of 2023 will be in excess of those incurred during prior periods.

Other Income/Expense. Total other expense for the six months ended June 30, 2023 and 2022, were $480,810 (unaudited) and $147,822 (unaudited), respectively. The increase in total other expense during the six months ended June 30, 2023, was primarily due to a significant increase in amortization of debt discount associated with our obtaining loans convertible into shares of our common stock.

Amortization of Debt Discount. Due to our obtaining $830,000 in convertible debt during the last half of 2022, which was offset by the conversion of $692,857 in convertible debt during the six months ended June 30, 2023, for the six months ended June 30, 2023, we incurred amortization of debt discount expense of $372,781 (unaudited), which represented a significant increase from the $183,489 (unaudited) in amortization of debt discount expense incurred for the six months ended June 30, 2022. We are unable to predict with any certainty our amortization of debt discount expense for all of 2023.

Interest Expense. Our interest expense for the six months ended June 30, 2023, was slightly lower than for the six months ended June 30, 2022, $5,172 (unaudited) versus $8,808 (unaudited). We anticipate that our interest expense for all of 2023 will be higher, but are unable to make any prediction in this regard.

Net Loss. We incurred a net loss of $1,559,276 (unaudited) for the six months ended June 30, 2023, as compared to a net loss of $276,594 (unaudited) for the six months ended June 30, 2022. The increase in net loss for the six months ended June 30, 2023, as compared to the six months ended June 30, 2022, was primarily due to an increase of $949,694 (unaudited) in operating expenses and an increase of $189,292 (unaudited) in amortization of debt discount. Should we be able to obtain capital in this offering or otherwise, as we continue to expand our business activities, we expect that our operating expenses for all of 2023 will be in excess of those incurred during prior periods. However, we are unable to predict our actual operating expenses for all of 2023, due to the uncertainty surrounding our ability to obtain capital.

Year Ended December 31, 2022, compared to the Year Ended December 31, 2021. For the years ended December 31, 2022 and 2021, we had no revenue, respectively. We expect that revenues from sales of our planned products will begin during the third quarter of 2023.

Operating Expenses. Total operating expenses for the years ended December 31, 2022 and 2021, were $560,505 and $45,723, respectively. The increase in operating expenses during the year ended December 31, 2022, was primarily due to a significant increase in our activities relating to our planned products, including the payment of product study expenses, as well as the payment of monthly fees to our key consultants and fees for professional services, including accounting and legal.

General and Administrative Expenses. The increase of $401,537 in general and administrative expenses for the year ended December 31, 2022, as compared to the year ended December 31, 2021, was primarily due to the significant increase in our activities relating to our planned products, including the payment of product study expenses, as well as the payment of monthly fees to our key consultants and fees for professional services, including accounting and legal. Should we be able to obtain capital in this offering or otherwise, as we continue to expand our business activities, we expect that our general and administrative expenses for all of 2023 will be in excess of those incurred during the year ended December 31, 2022.

Research and Development. The $113,245 in research and development expenses for the year ended December 31, 2022, were incurred due to our determining to make expenditures in the development of our planned products, including the payment of product study-relate expenses. While we expect to continue to incur research and development expenses, we are unable to predict the level of such expenditures, due to the uncertainty of the level of funding that will be available to us.

Other Income/Expense. Total other expense for the years ended December 31, 2022 and 2021, were $404,645 and $91,744, respectively. The increase in total other expense during the year ended December 31, 2022, was primarily due to a significant increase in amortization of debt discount associated with our obtaining loans convertible into shares of our common stock.

Amortization of Debt Discount. Due to our obtaining $830,000 in convertible debt during the year ended December 31, 2022, we incurred amortization of debt discount expense of $435,052, which represented a significant increase from the $79,792 in amortization of debt discount expense incurred for the year ended December 31, 2021. We are unable to predict with any certainty our amortization of debt discount expense for all of 2023.

Interest Expense. While interest expense for the year ended December 31, 2022, was only slightly higher than for the year ended December 31, 2021, $14,068 versus $11,952, we anticipate that our interest expense for all of 2023 will be higher, but are unable to make any prediction in this regard.

Gain on Debt Extinguishment. For the year ended December 31, 2022, we experienced a $44,475 gain on debt extinguishment. We had no such event during the year ended December 31, 2021.

Net Loss. We incurred a net loss of $965,150 for the year ended December 31, 2022, as compared to a net loss of $137,467 for the year ended December 31, 2021. The increase in net loss for the year ended December 31, 2022, as compared to the year ended December 31, 2021, was primarily due to an increase of $514,782 in operating expenses and an increase of $355,260 in amortization of debt discount. Should we be able to obtain capital in this offering or otherwise, as we continue to expand our business activities, we expect that our operating expenses for all of 2023 will be in excess of those incurred during the year ended December 31, 2022. However, we are unable to predict our actual operating expenses for all of 2023, due to the uncertainty surrounding our ability to obtain capital.

    Registration No. 333-271439

Liquidity and Capital Resources

June 30, 2023. At June 30, 2023, we had $85,770 (unaudited) in cash and a working capital deficit of $997,345 (unaudited), compared to $516,195 in cash and a working capital deficit of $826,167 at December 31, 2022. The Company has sufficient working capital to fund current operating expenses at least through the fourth quarter of 2023. To the extent the Company requires additional funds beyond the fourth quarter of 2023 and more than 12 months from the date hereof, we will need to obtain additional debt or equity-based capital from third parties, including in this Offering, to implement our full business plans. There is no assurance that we will be successful in obtaining such additional capital.

December 31, 2022. At December 31, 2022, the Company had $516,195 in cash and a working capital deficit of $826,167, compared to $125,000 in cash and a working capital deficit of $57,717 at December 31, 2021. The Company has sufficient working capital to fund current operating expenses at least through the second quarter of 2023. To the extent the Company requires additional funds beyond the second quarter of 2023 and more than 12 months from the date hereof, we will need to obtain additional debt or equity-based capital from third parties, including in this Offering, to implement our full business plans. There is no assurance that we will be successful in obtaining such additional capital.

Cash Flows

Six Months Ended June 30, 2023 and 2022.

Net Cash Used in Operating Activities. Net cash used in operating activities was $500,425 (unaudited) during the six months ended June 30, 2023, compared to $64,071 (unaudited) used during the six months ended June 30, 2022. This increase in the use of cash is primarily attributable to our significant increase in business activity during the 2023 period.

Net Cash Used in Investing Activities. Net cash used in investing activities was $-0- (unaudited) during the six months ended June 30, 2023, compared to $-0- (unaudited) during the six months ended June 30, 2022.

Net Cash Provided by Financing Activities. Net cash provided by financing activities was $70,000 (unaudited)of net cash during the six months ended June 30, 2023, as compared to $75,000 (unaudited) provided during the six months ended June 30, 2022. All of the cash provided by financing activities was proceeds from convertible promissory notes issued.

During the six months ended June 30, 2023, $692,857 in principal amount of outstanding convertible notes were paid by the issuance of a total of 6,298,703 shares of our common stock at a conversion price of $0.11 per share.

Years Ended December 31, 2022 and 2021.

Net Cash Used in Operating Activities. Net cash used in operating activities was $444,805 during the year ended December 31, 2022, compared to $45,723 used during the year ended December 31, 2021. This increase in the use of cash is primarily attributable to our significant increase in business activity during 2022.

Net Cash Used in Investing Activities. Net cash used in investing activities was $-0- during the year ended December 31, 2022, compared to $-0- during the year ended December 31, 2021.

Net Cash Provided by Financing Activities. Net cash provided by financing activities was $836,000 of net cash during the year ended December 31, 2022, as compared to $166,500 provided during the year ended December 31, 2021. All of the cash provided by financing activities was proceeds from convertible promissory notes issued.

Convertible Promissory Notes

The table below sets forth information with respect to the Convertible Notes as of the date of this prospectus. None of the Convertible Notes contains restrictive covenants with respect to the conduct of our business. In addition to the terms set forth in the table below, each of the Convertible Notes (a) may be prepaid by the Company at any time without penalty, (b) would be in default should the Company (i) fail to make any required payment when due, following a five-day cure period, or (ii) file for bankruptcy protection, (iii) become the subject of an involuntary bankruptcy proceeding and such proceeding shall not have been dismissed within 30 days or (iv) there shall have been appointed a receiver of the Company and such appointment shall remain beyond 120 days, (c) require the Company to register the shares of common stock underlying the Convertible Notes in the Registration Statement of which this prospectus forms a part, and (d) no conversion of a Convertible Note shall be permitted should any such conversion cause the converting holder's ownership of Company common stock to exceed 4.99%.

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

Going Concern

The consolidated financial statements included with this prospectus have been prepared on a going concern basis, which contemplates the realization of assets and the satisfaction of liabilities in the normal course of business. As reflected in the financial statements, we had a working capital deficit of $826,167 at December 31, 2022, and had a net loss of $1,559,276 (unaudited) for the six months ended June 30, 2023, which raises substantial doubt as to the Company's ability to continue as a going concern for a period of one year from the issuance of the financial statements.

Off Balance Sheet Arrangements

At June 30, 2023, we did not have any off balance sheet arrangements that we believe have or are reasonably likely to have a current or future effect on our financial condition, changes in financial condition, revenue or expenses, results of operations, liquidity, capital expenditures or capital resources that are material to investors.

Critical Accounting Policies

Our accounting policies are more fully described in our financial statements, beginning on page F-1. The preparation of financial statements in conformity with generally accepted accounting principles in the United States requires management to make estimates and assumptions that affect the amounts reported in the financial statements and accompanying notes. Although these estimates are based on our best knowledge of current and anticipated events, actual results could differ from the estimates.

We have identified the following accounting policies as those that require significant judgments, assumptions and estimates and that have a significant impact on our financial condition and results of operations. These policies are considered critical because they may result in fluctuations in our reported results from period to period, due to the significant judgments, estimates and assumptions about complex and inherently uncertain matters and because the use of different judgments, assumptions or estimates could have a material impact on our financial condition or results of operations. We evaluate our critical accounting estimates and judgments required by our policies on an ongoing basis and update them as appropriate based on changing conditions.

Fair Value of Financial Instruments. The Company accounts for financial instruments under Financial Accounting Standards Board ("FASB") ASC 820, Fair Value Measurements. ASC 820 provides a framework for measuring fair value and requires disclosures regarding fair value measurements. Fair value is defined as the price that would be received to sell an asset or paid to transfer a liability in an orderly transaction between market participants at the measurement date, based on the Company's principal or, in absence of a principal, most advantageous market for the specific asset or liability.

    Registration No. 333-271439

The Company uses a three-tier fair value hierarchy to classify and disclose all assets and liabilities measured at fair value on a recurring basis, as well as assets and liabilities measured at fair value on a non-recurring basis, in periods subsequent to their initial measurement. The hierarchy requires the Company to use observable inputs when available, and to minimize the use of unobservable inputs, when determining fair value.

The three tiers are defined as follows:

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

The determination of fair value and the assessment of a measurement's placement within the hierarchy requires judgment. Level 3 valuations often involve a higher degree of judgment and complexity. Level 3 valuations may require the use of various cost, market, or income valuation methodologies applied to unobservable management estimates and assumptions. Management's assumptions could vary depending on the asset or liability valued and the valuation method used. Such assumptions could include estimates of prices, earnings, costs, actions of market participants, market factors, or the weighting of various valuation methods. The Company may also engage external advisors to assist us in determining fair value, as appropriate.

Derivative Liabilities. The Company analyzes all financial instruments with features of both liabilities and equity under FASB ASC Topic No. 480, ("ASC 480"), "Distinguishing Liabilities from Equity" and FASB ASC Topic No. 815, ("ASC 815") "Derivatives and Hedging". Derivative liabilities are adjusted to reflect fair value at each reporting period, with any increase or decrease in the fair value recorded in the results of operations (other income/expense) as change in fair value of derivative liabilities. The Company uses a binomial pricing model to determine fair value of these instruments.

Beneficial Conversion Features. For instruments that are not considered liabilities under ASC 480 or ASC 815, the Company applies ASC 470-20 to convertible securities with beneficial conversion features that must be settled in stock. ASC 470-20 requires that the beneficial conversion feature be valued at the commitment date as the difference between the effective conversion price and the fair market value of the common stock (whereby the conversion price is lower than the fair market value) into which the security is convertible, multiplied by the number of shares into which the security is convertible limited to the amount of the loan. This amount is recorded as a debt discount and amortized to interest expense in the Consolidated Statements of Operations.

Debt Discount. For certain notes issued, the Company may provide the debt holder with an original issue discount. The original issue discount is recorded as a debt discount, reducing the face amount of the note, and is amortized to interest expense over the life of the debt, in the Consolidated Statements of Operations.

Research and Development. The Company accounts for research and development costs in accordance with ASC subtopic 730-10, Research and Development ("ASC 730-10").

    Registration No. 333-271439

Under ASC 730-10, all research and development costs must be charged to expense as incurred. Accordingly, internal research and development costs are expensed as incurred. Third-party research and development costs are expensed when the contracted work has been performed or as milestone results have been achieved as defined under the applicable agreement. Company-sponsored research and development costs related to both present and future products are expensed in the period incurred.

Stock-based Compensation. The Company accounts for our stock-based compensation under ASC 718 "Compensation - Stock Compensation" using the fair value-based method. Under this method, compensation cost is measured at the grant date based on the value of the award and is recognized over the service period, which is usually the vesting period. This guidance establishes standards for the accounting for transactions in which an entity exchanges it equity instruments for goods or services. It also addresses transactions in which an entity incurs liabilities in exchange for goods or services that are based on the fair value of the entity's equity instruments or that may be settled by the issuance of those equity instruments.

The Company uses the fair value method for equity instruments granted to non-employees and use the Black-Scholes model for measuring the fair value of options.

The fair value of stock-based compensation is determined as of the date of the grant or the date at which the performance of the services is completed (measurement date) and is recognized over the vesting periods.

When determining fair value, the Company considers the following assumptions in the Black-Scholes model:

? Exercise price, ? Expected dividends, ? Expected volatility, ? Risk-free interest rate; and ? Expected life of option

Recent Accounting Standards. Changes to accounting principles are established by the FASB in the form of Accounting Standards Updates ("ASU's") to the FASB's Codification. We consider the applicability and impact of all ASU's on our financial position, results of operations, stockholders' deficit, cash flows, or presentation thereof. Management has evaluated all recent accounting pronouncements as issued by the FASB in the form of Accounting Standards Updates ("ASU") through the date these financial statements were available to be issued and found the following recent accounting pronouncements issued, but not yet effective accounting pronouncements, are not expected to have a material impact on the financial statements of the Company.

    Registration No. 333-271439

In August 2020, FASB issued ASU 2020-06, Accounting for Convertible Instruments and Contracts in an Entity; Own Equity ("ASU 2020-06"), as part of its overall simplification initiative to reduce costs and complexity of applying accounting standards while maintaining or improving the usefulness of the information provided to users of financial statements. Among other changes, the new guidance removes from GAAP separation models for convertible debt that require the convertible debt to be separated into a debt and equity component, unless the conversion feature is required to be bifurcated and accounted for as a derivative or the debt is issued at a substantial premium. As a result, after adopting the guidance, entities will no longer separately present such embedded conversion features in equity and will instead account for the convertible debt wholly as debt. The new guidance also requires use of the "if-converted" method when calculating the dilutive impact of convertible debt on earnings per share, which is consistent with the Company's current accounting treatment under the current guidance. The guidance is effective for financial statements issued for fiscal years beginning after December 15, 2023, and interim periods within those fiscal years, with early adoption permitted, but only at the beginning of the fiscal year.

We do not expect the adoption of this pronouncement will have a material effect on the Company's financial statements.

    Registration No. 333-271439

Background

The Company was originally organized as a Kentucky corporation on February 11, 1988, as Ludwig Enterprises, Inc. On February 8, 2006, we formed a wholly owned subsidiary, Ludwig Enterprises, Inc., a Nevada corporation. On March 28, 2006, Ludwig Enterprises, Inc., the Kentucky corporation, merged with and into Ludwig Enterprises, Inc., the Nevada corporation, with the Company, Ludwig Enterprises, Inc., the Nevada corporation, being the surviving entity.

During the history of the Company, it has, variously, been involved in the radio paging industry and the broadcasting industry as it relates to "specialized programming" utilizing surplus spectra existing on existing FCC-licensed spectrum. In April 2019, the Company acquired Direct Mortgage Investors, Inc. ("DMI"), a residential mortgage broker. However, due to ongoing disputes between the former owner of DMI and his then-wife, this acquisition was rescinded in September 2021, and the parties returned to status quo ante.

Shortly after the DMI rescission transaction, our management became aware of the potential an mRNA-based business model could provide our company and investigated the opportunity for our company. It was in late 2021 that our mRNA-based business plan gained clarity, after our then-management had learned of its specific potential. At that time, our then-management determined to take initial steps towards achieving our current objectives. Beginning in early 2022, the Company has actively pursued our business plan, putting into action our strategies, including the conceiving and development of our first products. To that end, in the second quarter of 2022, we formed mRNAforLife, Inc. as a wholly-owned subsidiary to operate our supplements business, and, in the third quarter of 2022, we formed Precision Genomics, Inc. as a wholly-owned subsidiary to operate the business surrounding our testing kits and any future related products.

In June 2023, we formed Exousia Ai, Inc. ("EXO") as a wholly-owned subsidiary. EXO was formed to focus on studying the expression of differentially expressed mRNA genes in various chronic inflammatory diseases. No activities will be undertaken in this regard, unless we obtain additional capital, of which there is no assurance.

Our principal executive offices, and those of our subsidiaries, are located at 1749 Victorian Avenue, #C-350, Sparks, Nevada 89431. Our phone number is (786) 235-9026. Our corporate website is located at www.ludwigent.com. Information on our website is not part of this prospectus.

    Registration No. 333-271439

Our Focus

We are an innovative genomic technology and health related Company that is developing products that use inflammatory genetic markers to potentially assess the occurrence of inflammation, and, as a result, inflammation related diseases and monitor treatment responses. Advancements in genomic technology have awarded us with cutting edge genetic tools, unheard of even a generation ago. These genetic tools, coupled with our proprietary mRNA technology, have the potential to achieve early detection of inflammatory driven diseases, and support customized treatments that may improve patient outcomes.

The immune system and inflammatory processes are involved in not just a few select disorders, but a wide variety of physical health problems that dominate the occurrences of many diseases and worldwide morbidity and mortality. Chronic inflammatory diseases have been recognized as the most significant cause of death in the world today, with more than 50% of all deaths being attributable to inflammation-related diseases, according to [ Furman D, et al. Chronic inflammation in the Etiology of Disease Across The Life Span. Nat Med. 2019 Dec; 25(12): 1822-1832.]

These diseases include but are not limited to heart disease, stroke, cancer, diabetes mellitus, arthritis, autoimmune and neurodegenerative disorders. Furthermore, chronic inflammation has also been linked to mental issues such as depression, according to a study published at the Am J. Psychiatry journal (Frank P, et al. Association Between Systemic Inflammation and Individual Symptoms of Depression: A Pooled Analysis of 15 Population-Based Cohort Studies. Am J Psychiatry. Published online October 14, 2021. doi: 10.1176/appi.ajp.2021.20121776). The risk of developing chronic inflammation may be traced back to early development, and its effects can persist throughout the life span to affect adulthood health and the risk of mortality. With this perspective, the Company's genomic technology intends to offer promising avenues for future research and medical care intervention.

Through our subsidiary, Precision Genomics, Inc., we have developed proprietary medical machine learning artificial intelligence ("AI") technology that uses mRNA inflammatory language to potentially capture an inflammatory snapshot of disease and the body's response to treatment.

Recent Developments

OTCQB Application. In a January 12, 2023, press release, we announced our intention to apply to OTC Markets for listing on its OTCQB market platform. Such application has been prepared and will be submitted shortly after the effective date of the Registration Statement of which this prospectus forms a part.

Sales and Marketing Consulting Agreement. In a February 14, 2023, press release, we announced that we had entered into a sales and marketing consulting agreement with The Fannon Group. Effective September 5, 2023, our company and The Fannon Group terminated the consulting agreement. Pursuant to the termination agreement, we issued 210,000 shares of our common stock to The Fannon Group in payment of the terminated remainder of the agreement. We terminated The Fannon Group agreement in conjunction with our adding two executive officers, after determining The Fannon Group's involvement in our planned sales and marketing would no longer be necessary.

Program to Support Ketamine Clinics. In a March 7, 2023, press release, we announced that we had entered into an agreement with Dr. Kim Farahay and Dr. Jeff Lee to provide them with our products for use in their Ketamine-centered treatment of patients with Treatment Resistant Depression. At such time as we begin to produce our products, we will begin to execute sales under this agreement.

New Partnerships. In a March 16, 2023, press release, we announced that we had entered into early-stage discussions with a foreign developer of nutraceutical products and with an organization to conduct a diabetes clinical study using our company's products. These discussions are currently ongoing and are expected to remain in an "early-stage," until such time as we possess sufficient capital with which to support more substantial involvement by our company.

Cross-Listing on Canadian Stock Exchange. In press releases on March 21, 2023, and March 23, 2023, we announced our intention to cross-list onto the Canadian Stock Exchange and our entering into a consulting agreement with Ontario, Canada-based Summit Bancorp related to such efforts. Our stated intentions with respect to such cross-listing onto the Canadian Stock Exchange continue to be a part of our overall strategy of enhancing shareholder liquidity. In light of current stock market conditions, we have not established a specific time for pursuing such cross-listing.

Plans Within Hair Loss Market. In a May 3, 2023, press release, we announced our plan to launch a new nutraceutical product in the hair loss market and to expand our direct to consumer and direct to professional sales and marketing strategies to include individuals facing hair loss associated with inflammation. At such time in the future as we possess sufficient capital, of which there is no assurance, we intend to complete the formulation and testing of this planned product. However, we are unable to make any prediction as to when we would be able to complete such efforts.

Genomic-Related Patent Addition. In a May 9, 2023, press release, we announced that recently analyzed genomic mRNA data revealed differentially expressed genes when comparing tissue from patients with bladder, breast, and colon cancer, which data has been added to a provisional patent previously filed on September 20, 2022. Described in the patent application is our mRNA Inflammatory Index(TM) microarray technology, which measures 48 different cytokine and chemokine biomarkers of inflammation within noninvasively obtained patient cheek cells.

Additions to Executive Management. On September 5, 2023, our Sole Director and current President, Anne B. Blackstone, relinquished her position of Chief Executive Officer and, in her stead, appointed Marvin S. Hausman, M.D. to serve as Chief Executive Officer of our company. Prior to his becoming our Chief Executive Officer, Dr. Hausman served as a consultant to our company in the development of medical as well as scientific products. He will continue these efforts, as well as performing duties normally associated with his office. In addition, Thomas Terwilliger was appointed as our Chief Operating Officer, in which role he will direct and oversee our sales and marketing operations. These additions to our executive management team were made in anticipation of our expected increase in business activities during the end of 2023 and into 2024.

What is mRNA?

First, Ribonucleic acid ("RNA"), is a nucleic acid present in all living cells that has structural similarities to deoxyribonucleic acid ("DNA"). Unlike DNA, however, RNA is most often single stranded. An RNA molecule has a backbone made of alternating phosphate groups and the sugar ribose, rather than the deoxyribose found in DNA.

Next, mRNA, or messenger RNA, is, in simple terms, a type of RNA found in cells. mRNA molecules carry the genetic language and information from DNA that is needed to make proteins. They carry the information from the DNA in the nucleus of the cell to the cytoplasm where the proteins are made.

    Registration No. 333-271439

Precision Genomics Philosophy

We believe the future of healthcare will focus on personalized medicine that is preventative, rather than reactive, and we can be at the front of this revolution. We are of the opinion, and believe that many others share our sentiment, that the healthcare system, as it is currently structured, can be improved. The practice of healthcare is often reactive rather than preventative. This means that, in many instances, the detection and/or identification of diseases does not occur until they have already caused a certain amount of damage. This results in higher financial costs overall as well as a lower quality of life for people. We believe that healthcare does not have to remain this way. With precision medicine, of which we want our mRNA genetic indexing and supplementation program to be a part, diseases may be detected early and before they cause irreparable damage.

Recent research has revealed that inflammation plays a key role in many diseases and that reducing it can even prevent heart attacks and strokes, among other diseases. In a truly landmark study called the "CANTOS Trial", anti-inflammatory therapy, in people who had a prior heart attack, was shown to reduce their likelihood of subsequent heart attacks or strokes by 15 percent. It also decreased the need for major interventions such as angioplasty and bypass surgery by 30 percent, proving that addressing inflammation to prevent heart disease is essential.

The objective of the Precision Genomics program is to measure key mRNA genes that are involved in the production of inflammatory molecules, called cytokines and chemokines, that cause chronic tissue damage, such as those produced in heart attacks, strokes and inflammation related diseases. If caught early enough, appropriate anti-inflammatory treatment can be employed in an attempt to ward off the chronic process before it causes irreparable damage.

Chronic inflammation does not produce symptoms - and most people are not regularly screened for inflammation.

Products

Our products include our proprietary My RNA for Life Home Test Kits and My RNA for Life(TM) Genetic Centric Supplement.

My RNA for Life Home Test Kits

Our test kits use mRNA genetic indices to measure the expression of cytokines and chemokines, which are small proteins that create cellular signals. Increases and decreases in gene expression levels of pro-inflammatory cytokines and chemokines may be found in patients with active or inactive chronic disease conditions. The combination of mRNA genetic expression and machine learning AI could, we believe, with a certain degree of accuracy, identify individuals with the potential to develop chronic inflammatory diseases, such as cancer and heart disease. Through mRNA indices, we have the potential to obtain a personalized inflammatory score, which is like snapshot or signature, which may have the predictive power to diagnose chronic disease development, which further may provide us with the ability to evaluate treatment response. One example of treatment response is to evaluate patient outcomes to different anti-cancer therapies.

To better understand the relationship between genomic data and patient phenotype and clinical diagnosis the Company has developed, internally, a variety of statistical and data analysis approaches, all centering around a combined representation of machine learning and clustering methodology. We will examine the efficacy of three types of models:

1. A model using the biomarker embedding alone. 2. A model using the biomarker embedding in addition to patient demographic information. 3. A model using the biomarker embedding, patient demographic information, and relevant data extracted from the medical record.

Once individuals test over a certain period of time, we intend to illustrate via the snapshot index or picture how that individual's health may have changed, whether it is an improvement or worsening of their health by showing the changes in their levels of mRNA genes. We believe our approach will be unique as it is tailored to the individuality of each patient. For instance, we intend to personalize each patient's care based on their specific needs as determined by our mRNA indexing. We believe the benefits of our approach can potentially lead to earlier detection of inflammation that could lead to chronic disease development, which can improve patient outcomes, and hopefully lower individual healthcare costs.

Machine Learning (AI). In a general sense, machine learning (ML; often used interchangeably with the term "Artificial Intelligence", or AI) is a set of computational approaches wherein an algorithm is used to learn characteristics of some data set or group together entities in the data based on common characteristics. Machine learning has three main subfields: supervised, unsupervised, and reinforcement learning. In the present set of studies we mainly concern ourselves with supervised and unsupervised machine learning. In the former, labeled data are used to learn important predictive characteristics for some response variable. For example, one might have a set of measurements for a collection of three types of iris flowers. Using supervised methods, one could build a model to predict the species of previously unseen iris flowers based on their own measurements. Unsupervised machine learning is slightly different. Here, we don't have labels, but use observed characteristics (or features) of entities to cluster together into groups. Ideally, the groupings that result are associated with some latent shared labels (i.e., without using iris species labels we could cluster them based on their measurements and would likely find that flowers of the same species naturally land in the same group).

    Registration No. 333-271439

In the present work we will use a combination of the above methods, but our main proposal is to use the output of our inflammatory biomarker panel, along with patient metadata and clinical notes, in conjunction with a set of algorithms called autoencoders (AEs), to learn a lower dimensional embedding that lends itself to predicting disease state of patients. On their own, autoencoders are systems that learn something called the identity function-that is, their job is to, given some input, produce the same output. By imposing certain constraints on how this process is carried out, we're able to use these tools to do far more interesting tasks. For example, if we introduce some complexity penalty onto how it learns the identity function, we force the algorithm to make an accuracy/complexity tradeoff, effectively teaching it how to compress data while minimizing loss of information. Here, we impose an additional constraint on the system: given some labeled data (e.g., disease category and disease state), learn a lower dimensional embedding that compresses the data and minimizes information loss, but also does so in such a way that the lower-dimensional representation lends itself to clustering similar patients.

In order to take the above-described approach, we'll need a significant amount of data. While this is being collected, we will analyze all patient samples using standard approaches out of the frequentist statistical literature linear models corrected for multiple comparisons. This approach allows us to give feedback to patients on disease state, when relevant, but also confirm that there is relevant signal in the data we're collecting before attempting to derive our new AE-based approach.

My RNA for Life(TM) Genetic Centric Supplement

Once a personalized inflammatory mRNA signature is obtained, our My RNA for Life(TM) Genetic Centric Supplement is made with specific ingredients that have anti-inflammatory properties that may be able to modulate a person's previously measured inflammatory index or even potentially control further inflammatory reactions and continued disease development. Through multiple tests over a certain period of time, individuals can obtain a snapshot picture of possible changes in their health. Our supplement is specifically formulated to target mRNA-associated inflammatory biomarkers with the potential to modulate their expression.

Our supplement contains 20 Ingredients: Alpha Lipoic Acid; N-acetyl cysteine; Zinc picolinate; Coenzyme Q10; Glutathione; Vitamin A; Vitamin C; Vitamin D; Vitamin E; Quercetin dihydrate; Alpha-GPC Choline; Boron Citrate; Resveratrol; Magnesium diglycinate; Curcumin; Folic Acid; Niacin; Riboflavin; Thiamin; Selenium.

These 20 ingredients were selected on the basis of their anti-inflammatory capacity. The focus of the formula of ingredients is the potential modulation and/or reduction of the inflammatory genetic markers associated with chronic disease. Scientific articles in peer reviewed journals were reviewed on each of the compounds in the formula to establish data showing specific activity on mRNA biomarkers. For example: N-acetyl cysteine; Scientific Articles:

Science Related Genetic Application: reduced cytokines TNF-? and NF-?B, IFN-?, and IL-6 expression in LPS- induced cells in the pig small intestine (Lee, 2019)

    Registration No. 333-271439

The role that nutritional components, in particular vitamins and minerals, play in the modulation of mRNA profiles, and consequently health and disease, is increasingly being investigated, and as such it is a timely subject for review and study.

Dietary Supplement Formula License

In December 2022, we entered into a license agreement with Xikoz, Inc., with respect to a dietary supplement that we plan to further develop and market. The license obtained from Xikoz is perpetual and exclusive as to the manufacture and marketing of a dietary supplement formulation known as "FlamaBlue." In consideration of such license, we issued 1,000,000 shares of our common stock to Xikoz and are obligated to pay a per-bottle-sold royalty equal to $0.10. Under the license agreement, there is no minimum royalty due, nor any further payments due upon our achievement of defined milestones. There are no termination provisions in the license agreement.

After entering into the FlamaBlue license agreement, we decided to rename the product "NuGenea" and to improve the product by using a delayed release capsule formulation that resists dissolution in the acid environment of the stomach. Enteric coating is a polymer applied to oral medication. It serves as a barrier to prevent the gastric acids in the stomach from dissolving or degrading drugs after you swallow them. NuGenea features enteric coated delay release (vegetable-based) capsules, whereas FlamaBlue is manufactured with non-coated (animal-based) gelatin; NuGenea's label stated 5 mg of Magnesium Bis Glycinate, whereas FlamaBlue's label states 25 mg of Magnesium Bis Blycinate; and NuGenea's label states 25 mg of Turmeric 95% extract, whereas FlamaBlue's label does not show Turmeric.

Current Research Study

In December 2022, we received Institutional Review Board ("IRB") approval of our study titled "Using Measurements of mRNA and ELISA-based Cytokine/Protein Indices to Evaluate Pre- and Post- Diagnosis and Treatment Response of Patients with Urothelial Carcinoma of the Bladder." IRB approval is an important step in conducting a research study.

The IRB approved study is titled "Using Measurements of mRNA and Elisa-based Cytokine/Protein Indices to Evaluate Pre- and Post- Diagnosis and Treatment Response of Patients with Urothelial Carcinoma of the Bladder":

    Registration No. 333-271439

The objective of this study is to develop a computational risk model using mRNA and Elisa-based protein cellular biomarkers collected from bladder cancer patients who will undergo BCG immunotherapy as part of standard of care. Delivery of BCG intravesical immunotherapy is not an observational study procedure.

Elisa-based protein cellular biomarkers and Elisa technology: the enzyme linked immunosorbent assay ELISA is a powerful method for detecting and quantifying a specific protein in a complex mixture. Originally described by Engvall and Perlmann (1971), the method enables analysis of protein samples immobilized in microplate wells using specific antibodies. ELISA is the main approach for the sensitive quantification of protein biomarkers in body fluids and is currently employed in clinical laboratories for the measurement of clinical markers. As such, it also constitutes the main methodological approach for biomarker validation and further qualification.

ELISAs are typically performed in 96-well or 384-well polystyrene plates, which passively bind antibodies and proteins. It is this binding and immobilization of reagents that makes ELISAs easy to design and perform. Having the reactants of the ELISA immobilized to the microplate surface makes it easy to separate bound from non-bound material during the assay. This ability to use high-affinity antibodies and wash away non-specific bound materials makes ELISA a powerful tool for measuring specific analytes within a crude preparation.

Computational models in medicine are a new development and are used to create a personalized patient-specific model to provide a patient with optimal diagnosis and treatment. As the amount of diagnostic data increases, paralleled by the greater capacity to personalize treatment, the difficulty of using the full array of measurements of a patient to determine an optimal treatment seems also to be paradoxically increasing. Computational models are progressively addressing this issue by providing a common framework for integrating multiple data sets from individual patients. In the Ludwig clinical strategy, we will be using 48 mRNA based inflammatory genes called cytokines and chemokines plus other protein inflammatory biomarkers to obtain a computational diagnostic score relative a specify chronic inflammatory disease, such as bladder cancer, heart disease and preeclampsia, to name a few.

All diagnostic evaluation and treatment protocols are already under use at urological offices and clinics according to established industry standards of care for patients suspected of having urothelial carcinoma of the bladder and potential treatment with BCG Immunotherapy.

This study is purely observational and generated data and genetic risk scores will not be a determining factor in patient diagnosis and treatment.

Statistical analysis will be performed. The mRNA genetic analysis, measurement inflammatory proteins using Elisa technology plus a unique AI bioinformatics strategy may allow development of predictive models prior to onset of obvious manifestations of a disease. The resultant predictive risk profile, 'L-Statistic', could also potentially guide the therapeutic approach of the physician and decrease the severity of future associated comorbidities.

Under FDA regulations, IRB review and approval is required for projects that: (i) meet the definition of research, (ii) involve human subjects and (iii) include any interaction or intervention with human subjects or involve access to identifiable private information.

    Registration No. 333-271439

The objective of this clinical study, which will utilize our mRNA genomic-based technology, cytokines and related proteins is to establish a diagnostic paradigm for patients with urothelial carcinoma of the bladder and to use this data to evaluate the efficacy of Bacillus Calmette-Guerin ("BCG") immunotherapy as a personalized score for the patient. Integrating these disciplines into a computational model can develop a personalized patient diagnostic and treatment response, 'L- genomic bladder cancer risk' score, to aid in BCG immunotherapy disease management at a clinical practice level. BCG is approved by the FDA to treat bladder cancer patients. BCG is a non-specific potentiator (a reactant that enhances a physiologic response) of a person's immune system. The goal of the Company through this planned program is to illustrate the potential of our technology to detect early the development of the inflammation that leads to bladder cancer and to predict patient response to anti-cancer treatment. In anticipation of starting this observational cancer program, we filed a patent that identifies and describes the Company's proprietary 48 gene mRNA genomic technology plus a proprietary nutritional and supplements program called "My RNA for Life." These nutritional compounds within the supplement are specifically chosen to target mRNA-associated inflammatory biomarkers with the potential to modulate their expression.

The patient to be tested will swab the right and left buccal area (i.e., cheeks) with a soft flocked tip swab and place the swab in an envelope or tube. Targeted gene sequencing will be performed using a Thermo Fisher Scientific Gene Studio S5 System and Ion Chef CGX and PGX equipment. An Amplicon library for 48 target mRNA inflammatory cytokines was designed with a Thermo Fisher Scientific Ion-Ampliseq Designer; patent filed on the Company's proprietary 48 mRNA microarray panel.

The buccal cell samples will be analyzed, and expression profiles will be obtained of inflammatory cytokines involved in apoptosis, cellular proliferation, cellular repair, wound healing, etc. ELISA determined levels of proteins, cytokines, and chemokines will be measured in the urine, saliva and blood as dictated by the protocol and chronic disease diagnosis.

The test orders, results, and health information for all patients will be maintained on a centralized HIPAA compliant network containing personal health records."

All of the individual data points, 48 mRNA genes and approximately 10 Elisa based proteins such as TRAIL, 8oHdG, will be used to come up with an inflammatory index related to each specific chronic inflammatory disease being clinically studied. The number of data points as you can imagine is huge and machine learning AI will be needed to analyze the data points and come up with a computational score. For the bladder cancer study, we used""L-genomic bladder cancer risk score"" Appropriate names will be used for different clinical disease studies.

We believe that our mRNA inflammatory index has the potential to assess the presence of inflammation that can lead to early-stage bladder cancer and then monitor treatment cancer response to BCG immunotherapy. This genetic signature provides a potential framework to optimize early diagnosis and clinical management with appropriate therapy.

Additional Planned Research Studies

The following planned research studies will need to be submitted for Institutional Review Board (IRB) approval before initiation of the clinical study. Under the IRB system, a clinical protocol and application is completed, and the study is submitted to 1-2 IRB members for review. At a subsequent IRB member meeting this initial review is discussed and a vote for an action is taken. Additional adjustments to the study may be necessitated by IRB review until approved. There is no established timeline or guarantee for receiving IRB approval.

All proposals submitted for either expedited or full review must contain four primary sections:

- Purpose of investigation.

- Procedures.

- Anticipated risk and potential benefits to participants.

- Steps taken to protect the participants.

The criteria for IRB approval of a human research study includes:

- Risks to subjects are minimized.

- Procedures are consistent with sound research design and do not unnecessarily expose

subjects to risk.

- Study utilizes procedures already performed for diagnosis/treatment-- when appropriate.

Preeclampsia.

Preeclampsia is a pregnancy specific, hypertensive disorder that is associated with high maternal morbidity and mortality. Placental dysfunction is a major contributor to adverse pregnancy outcomes, including preeclampsia. "This imbalance between pro inflammatory and regulatory cytokines is associated with the placental ischemia that occurs during a preeclamptic pregnancy." (Harmon AC, et al. The Role of Inflammation in the Pathology of Preeclampsia. Clin. Sci. (Lond). 2016 Mar; 130(6):409-19).

The Precision Genomics mRNA Inflammatory Index(TM) has the potential to create a genetic signature in patients with preeclampsia.

Primary study endpoint: early diagnosis of preeclamptic condition.

Secondary study endpoint: Substantiate mRNA genetic signature for preeclampsia.

The Company's mRNA genetic signature may provide a therapeutic framework for the physician to obtain an earlier diagnosis of the preeclamptic condition which is not currently possible. Moreover, importantly, can allow earlier initiation of clinical management procedures which could be lifesaving.

Cardiovascular/Heart Diseases.

Cardiovascular diseases have a major societal impact due to morbidity, mortality, and the associated economic impacts. We intend to develop a paradigm of risk factors to manage cardiovascular disease(s) and conduct clinical studies to integrate data from cardiac genetic risk statistics and the Precision Genomics mRNA Inflammatory Index(TM).

Our ability to move forward with any additional planned research studies will be dependent on our ability to raise funds from this and other offerings.

Primary study endpoint: early diagnosis of cardiac condition.

Secondary study endpoint: Substantiate mRNA genetic signature for specific cardiovascular conditions, including but not limited to heart attacks, vascular clotting disorders, hypertension, and myocarditis.

This genetic signature may provide a therapeutic framework for the physician to obtain an earlier diagnosis of the preeclamptic condition which is not currently possible. Moreover, importantly, can allow earlier initiation of clinical management procedures which could be lifesaving.

    Registration No. 333-271439

Our Strategy

In terms of making assessments using RNA vs DNA, the flexibility of RNA is important. DNA holds the genetic blueprint for humans, but RNA actually carries out its instructions to create functional proteins. This means real time information is being translated into cellular language. Our objective is to capture a snapshot in real time of important inflammatory signaling biomarkers, called cytokines, present in specific cells and tissues.

The importance of RNA is that mRNA allows us to identify differentially expressed genes ("DEGs") involved in the inflammatory process associated with development of chronic diseases. Our Precision Genomics mRNA Inflammatory Index(TM) is intended to provide guidance as a predictive model, prior to onset of obvious manifestations of a disease. By utilizing machine learning AI and mRNA indices, we may discover hidden patterns and diagnostic markers within different biologic systems and organs. We have chosen 48 mRNA genes that our technology then uses to assess snapshots, creating a diagnostic disease index that is calculated from the gene panels. The mRNA genes chosen were based on specific chronic inflammatory diseases, such as heart disease, diabetes, cancer of the colon, breast and bladder, preeclampsia and osteoarthritis. The number 48 was based on the ability of Thermo Fisher Scientific to sequence the genes and place them on a microarray chip. Moreover, the uncovering of these hidden inflammatory patterns my allow anti-inflammatory nutritional interventions at an early stage before disease onset. We plan to combine measured levels of mRNA genes with machine learning AI to generate a statistical score. The objective is to develop a personalized inflammatory genetic signature for a patient and their respective disease(s).

With a portion of the proceeds of this offering, we expect to analyze approximately 3,000 mRNA samples obtained from patients with various chronic inflammatory diseases and choose the most significant mRNA diagnostic genes. Once we identify the key diagnostic genes related to specific diseases, we expect to develop a specific research plan that may include an internal lab or contracting with an outside lab, or a major pharmaceutical company to target the chosen genes. Our plan is to develop specific antibodies that bind to these genes and market them to biotech- and pharma-companies to treat chronic inflammatory diseases, such as cancer, diabetes and heart disease. Given the nascent stage of our development, we have yet to determine the precise strategies by which we would market our developed antibodies.

We believe that there are many medical technologies in current practices that are outdated; however, emerging technologies have recently started including nanomedicine and genome based personalized medicine to aid in care and treatment. Our technology is intended to enable physicians to employ new treatment modalities for their patients. Inflammation can be silent, present at one time, and undetected at others, similar to a light switch that can be turned on and off. The problem, however, is that it can stay on and cause both silent and visible diseases. We believe our technology provides an opportunity to integrate genetic technology into the diagnosis and treatment continuum of a patient.

We also aspire to provide more individualized care through nutritional supplementation, tailored to the genetic makeup of the individual. Our approach focuses on the body's cellular communication and responses.

Our Analysis Method

To understand inflammation, we will analyze both acute and chronic inflammation. Acute inflammation is how the body fights infections and helps speed up the healing process, which, in this context, is beneficial since it protects the body. However, if inflammation becomes chronic, it can lead to major diseases such as heart disease, diabetes, cancer, stroke and others. With both of the foregoing forms of inflammation, the goal is to recognize that something is awry and requires attention.

Chronic diseases are long-term medical conditions that are progressive. Examples of chronic diseases include cancer, diabetes, cardiovascular disease, chronic kidney disease, arthritis and stroke, and others. The root causes of these diseases are usually lifestyle, diet, stress, physical activity and the environment. The common denominators for all of chronic diseases are inflammation, cellular damage, and apoptosis (i.e., programmed cellular death).

Our solution is to integrate genetic disciplines into a computational model to increase diagnostic yield and provide a clearer genetic picture to determine actionable events to improve healthcare. These nutritional compounds within our supplement are specifically chosen to target mRNA-associated inflammatory biomarkers with the potential to modulate their expressions. After an initial test, the results of the assessment could lead to regular screenings and/or appointments in a doctor's office. The doctor and/or the patient may choose to use our nutritional supplement. After a period of no less than 3 months the individual may test again to assess their inflammatory index and the relationship to their current health status.

By using our Precision Genomics mRNA Inflammatory Index(TM) to match disease with its unique fingerprint mRNA, we believe treatment can be personally modified based on the patient's individual genetic makeup. With the help of machine learning AI, our proprietary Precision Genomics mRNA Inflammatory Index(TM) enables the modulation of key inflammatory related biomarkers with the potential to coordinate medical therapy through the use of our nutraceutical supplement. It is anticipated that our proprietary mRNA Inflammatory Index will be able to measure intercellular communication, subsequently allowing us to discover hidden gene patterns related to inflammatory causation of specific diseases.

The patient to be tested will swab the right and left buccal area (i.e., cheeks) with a soft flocked tip swab and place the swab in an envelope or tube. Targeted gene sequencing will be performed using a Thermo Fisher Scientific Gene Studio S5 System and Ion Chef CGX and PGX equipment. An Amplicon library for 48 target mRNA inflammatory cytokines was designed with a Thermo Fisher Scientific Ion-Ampliseq Designer; patent filed on the Company's proprietary 48 mRNA microarray panel.

The buccal cell samples will be analyzed, and expression profiles will be obtained of mRNA-based inflammatory cytokines, as well as proteins, involved in apoptosis, cellular proliferation, cellular repair, wound healing, etc. ELISA determined levels of proteins, cytokines, and chemokines will also be measured in the urine, saliva and blood as dictated by the protocol and chronic disease diagnosis.

The test orders, results, and health information for all patients will be maintained on a centralized HIPAA compliant network containing personal health records.

    Registration No. 333-271439

    Registration No. 333-271439

Intellectual Property

We have applied for the following Utility and/or Clinical Use patents:

    Registration No. 333-271439

These patents, via their inventor, our Chief Executive Officer, Marvin S. Hausman, M.D., identifies and describes the 48 genes mRNA genomic technology plus a proprietary nutritional and supplement program called My RNA For Life.

The non-provisional applications and/or PCT applications must be filed on or before the non-extendible due dates of September 20, 2023, and May 8, 2024, respectively. Non-provisional patents will be filed by such dates, with expiration dates of 20 years from the date of filing of the respective non-provisional patents.

The Precision Genomics Objectives.

? Establish diagnoses and show response to treatment;

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

The Long-Term Strategy. We intend to provide patients with cutting edge genetic tools using proprietary mRNA genetic methodology. These diagnostic tools will provide both physicians and patients with an optimized proactive approach in preventing disease. Execution of this strategy will require Precision Genomics to implement adequate infrastructure to offer screening and supplement programs in the United States and Canada. We believe the future of the Company is poised for continued adoption of its technology and success in the coming years. With a strong team in place and a clear vision for the future, we are well positioned to continue our growth trajectory.

Our core catalysts and value drivers are the following:

? mRNA Proprietary Inflammatory Panel, for which our patent has been filed.

? Additional clinical research studies.

? My RNA for Life(TM) Genetic Centric Supplement.

? Apoptotic Index(TM) technology, measuring DNA damage, cell damage and death, and

    Registration No. 333-271439

Our Planned Programs and Services

We intend to offer a "My RNA For Life" program, which we intend to be a comprehensive genetic test program that will provide an unparalleled snapshot of an individual's health by measuring the body's response to stressors. This program will allow anyone with a health concern to get an assessment of their health with a certain degree of accuracy. This snapshot uses the patent pending mRNA index coupled with machine learning AI to provide patient specific information, thus helping to diagnose chronic inflammation which can lead to other potential diseases. The test results can be reviewed with a physician or an My RNA for Life counselor to provide patients with an in-depth analysis and treatment plan.

    Registration No. 333-271439

Our nutritional supplement contains compounds with the potential to modulate expression of mRNA genes that produce inflammation. Our supplement has been formulated with the intent to help prevent disease, aid in healing and also improve overall health. By utilizing snapshots of the body's mRNA to track a patient's progress before and after supplementation, we believe we can demonstrate progress and overall efficacy in improving their health.

We intend for this snapshot to be able to be performed with our proprietary mRNA technology on specimens collected at a primary care physician's office or at home with a My RNA for Life Home Test Kit. Upon analyzing a patient's snapshots, we will utilize machine learning AI to predict, identify, and help to prevent the inflammation that leads to many common diseases. Our nutritional supplement will be integrated into the personalized genetic program. The objective is for an individual to build up an internal warehouse of these important anti-inflammatory nutritional compounds while one is healthy. When disease hits, your body can summon these needed compounds to naturally enhance the immune system and neutralize the out-of-control inflammatory processes. The objective of the unique formula of ingredients is the potential modulation and/or reduction of the inflammatory genetic markers associated with chronic disease.

Patient personal health and laboratory data will be stored on a trusted HIPAA-Compliant Cloud Storage platform.

In addition to the foregoing, we have entered into an agreement with Dr. Kim Farahay and Dr. Jeff Lee, with respect to our selling products to their Ketamine-centered treatment of patients with Treatment Resistant Depression. Under this agreement, Drs. Farahay and Lee have agreed to begin to purchase our NuGenea product for use in their treatment protocols, at such time as we have begun commercial sales of NuGenea. We expect commercial sales of NuGenea to begin late in the fourth quarter of 2023.

Our Planned Marketing and Distribution

As further described below, we have an initial marketing plan for each of B2B and B2C sales in order to market and distribute our products.

Our B2B approach will be to focus on engaging wellness center physicians as well as medical facilities to sell our My RNA for Life Home Test Kits. The physician or its staff would perform the cheek swab and send it back to us for testing. Once results have been finalized the result would be sent back to the ordering physician to be reviewed with the patient. There is no insurance coverage for our test kits at this time. As we approach the time that our test kits will be ready for sale to customers, we will attempt to obtain product liability insurance coverage. Should we fail to obtain product liability insurance for our test kits, it is possible that the Company would face significant losses for, or even be forced to cease operations by, successful product liability claims, including through litigation. We are not currently in any negotiations with any physicians or facilities that will sell our products.

We plan to market to physicians directly and will provide them with patient education tools such as pamphlets and handouts to educate them on our product and its benefits. We will also engage in special outreach programs which will include online seminars and educational tools in order to create new customers. We believe that physicians are key opinion leaders in the healthcare industry, and we hope to increase sales by encouraging them to engage with our product. We intend to negotiate with different pharmacies in order to have them sell our product. We believe that this multi-faceted approach will help us to successfully reach our target audiences and, in turn, generate sales.

In furtherance of these efforts, we had retained the business consulting services of Fannon Group, a Del Ray Beach, Florida-based consulting firm. Our agreement with Fannon Group commenced on April 1, 2023, and continues on a month-to-month basis until January 2024. The agreement with Fannon Group may be terminated by either party at any time, upon thirty-days' notice. The Fannon Group is to be compensated under its agreement, as follows: $5,000 in cash as a signed bonus; the issuance of 50,000 shares of our common stock as a further signing bonus; a monthly fee of $5,000 in cash; the issuance of 50,000 shares of our common stock as a further monthly fee, which share amount shall be reduced to 5,000 shares upon the effectiveness of the Registration Statement of which this prospectus forms a part. At such time as we obtain the first $10,000,000 in proceeds in this offering, of which there is no assurance, the monthly cash fee payable to Fannon Group would increase to $12,500. Effective September 5, 2023, our company and Fannon Group terminated the consulting agreement. Pursuant to the termination agreement, we issued 210,000 shares of our common stock to The Fannon Group in payment of the terminated remainder of the agreement.

We terminated the Fannon Group agreement in conjunction with our adding two executive officers, after determining The Fannon Group's involvement in our planned sales and marketing would no longer be necessary. Our new Chief Operating Officer, Thomas Terwilliger, will direct the implementation of our sales and marketing strategies.

Our B2C approach will utilize various marketing strategies to engage the individual at home. We intend to create marketing partnerships with certain health influencers to promote our products. Our initial approach will be to work with health influencers on a commission basis which we believe will incentivize them to promote our products. We plan to offer the My RNA for Life Home Test Kit to individuals directly via online websites. With our B2C approach, we intend to offer a service in which a "Certified Genetic Counselor" (which will be someone who has been trained as a geneticist and has a MD, PhD or Master's Degree) will provide a one-time call and an email to the patient after the patient has received their results.

We intend to engage social media marketing such as Facebook, Instagram and Twitter to reach potential customers. We will also utilize ad campaigns based on the successful models of similar companies.

Our ability to market and distribute our products will be dependent on our ability to raise capital through this Offering.

    Registration No. 333-271439

Laboratory Developed Test (LDT)

We intend to launch and market our testing kits as a Laboratory Developed Test (LDT). A LDT is defined by the FDA as "a type of in vitro diagnostic test that is designed, manufactured and used within a single laboratory." (Source: Laboratory Developed Tests, US Food and Drug Administration https://www.fda.gov/medical devices/in vitro diagnostics/laboratory developed tests Accessed 11/23/2022).

The classification of an LDT is partly dependent on its components. LDTs must use only in-house materials, general purpose reagents (GPRs), and analyte specific reagents (ASRs). GPRs are chemical reagents that might commonly be used in a laboratory, such as a pH buffer. ASRs are substances essential to the function of the diagnostic test and which act as the "active ingredient" in the test. ASRs might be "antibodies, both polyclonal and monoclonal, specific receptor proteins, ligands, nucleic acid sequences, and similar reagents which, through specific binding or chemical reactions with substances in a specimen, are intended for use in a diagnostic application for identification and quantification of an individual chemical substance or ligand in biological specimens" (21 CFR 864.4020). LDTs can use GPRs and ASRs manufactured by parties other than the laboratory developing the LDT - this does not affect the single laboratory requirement for the LDT.

The FDA requirements for a diagnostic test to be classed as LDT, and therefore subject to regulatory discretion, include single laboratory development and use, authorized physician instruction, and "CLIA" (Clinical Laboratory Improvement Amendments program) certification and accreditation. First, the development and performance of the test must be conducted by a single laboratory. The test can no longer be classified as an LDT if any aspect of the LDT extends beyond a single laboratory, such as the test having been developed in a separate laboratory, used in multiple laboratories, or relying on third party manufacturers for critical components not deemed ASRs, and will instead be classed as an IVD. Second, the LDT must be performed because of an instruction from an authorized physician or healthcare professional. An LDT cannot be offered direct-to-consumer, and a physician ordering the test must be independent from the laboratory offering the LDT. Third, the laboratory must be appropriately certified under the CLIA program as able to "perform high-complexity testing." The single laboratory requirement for test development and use refers to a single CLIA certification.

The FTC and the FDA share jurisdiction over the marketing of supplements as well as drugs, foods, devices and other health related products. FTC regulates the advertising of these products, including infomercials and other direct to consumer methods. The Company if not diligent in its accuracy of its representations to the market on its products could be at risk of a cease-and-desist order for marketing its products. This would result in a deleterious effect on the Company.

Our supplement manufacturer must follow Good Manufacturing Practices (GMP) established by the FDA, Department of Health and Human Services and the USDA. We are at risk if our principal manufacturer fails inspection for deploying GMP's. If our primary manufacturer were to cease operations, we would immediately halt sales and would be required to potentially recall our products and find new manufacturing capability. This could cause the Company to cease to exist.

Our inflammatory assessment tool is manufactured, distributed and analyzed by a third part CLIA and CAP certified laboratory. The Laboratory has made large investments in equipment, human resources and capital in order to facilitate the Company's business. If the Laboratory fails CLIA or CAP inspections the Company would cease to operate until a replacement Laboratory is established. The time and expense required by a Laboratory to come up to speed would be at least 12 months potentially causing the Company to cease to exist.

    Registration No. 333-271439

The CLIA require laboratories that perform clinical testing (including IVDs and LDTs) to be certified by the Centers for Medicare and Medicaid Services (CMS) before accepting materials derived from the human body for the purpose of providing information for the diagnosis, prevention, or treatment of any disease or the impairment of, or assessment of the health of human beings (42 CFR Part 493). CLIA requirements for certification depend on the complexity of tests conducted by the laboratory; LDTs are classed as high complexity and as such, the requirements include demonstration of the analytical validity of the test, quality assurance protocols, and presence of qualified personnel (42 CFR 493). The focus of the CLIA is to ensure accurate and reliable diagnostic test results. Laboratories must receive CLIA certification before releasing any test results and will be inspected by the CMS to ensure compliance with the requirements. All analytical validity assessments are conducted only within the laboratory because the test will be used only within the laboratory and therefore validation conducted outside the laboratory environment is not necessary or relevant. The validation is reviewed during its routine two-yearly survey.

There are no CLIA requirements for clinical validity, meaning there is no assessment of how well a test can diagnose or predict a clinical condition. Instead, the CMS evaluates whether the test successfully detects the substance it is designed to detect, for instance, assessing whether a test can accurately and reliably measure the presence of a biomarker associated with lung cancer rather than assessing whether the test can accurately diagnose lung cancer. Clinical validity requirements fall under FDA authority in the FD&C Act during the premarket review, something with which LDTs are not required to comply via enforcement discretion.5 LDTs are also not required to comply with the FDA's quality system regulations. However, enforcement discretion toward LDTs does not equal exemption, and the FDA can chose to enforce full regulatory compliance of an LDT "when appropriate, such as when it is appropriate to address significant public health concerns."6 In summary, the FDA focuses on ascertaining the safety and effectiveness of a diagnostic, and, if it is an IVD, the design and manufacture quality, whereas the CMS checks the scientific performance of the test.

Should any of our products be determined not to be LDT products, we would be forced to cease the sale of any such products, which could have a material adverse effect on our operating results. No prediction can be made in this regard, however. (See "Risk Factor--Risks Related to Our Business").

According to the FDA, "LDT's are important to the continued development of personalized medicine, so it is important that in vitro diagnostics are accurate so that patients and health care providers do not seek unnecessary treatments, delay needed treatments, or become exposed to inappropriate therapies.

Some common examples of LDT's include: flow cytometry, next generation sequencing of DNA and RNA, liquid and gas chromatography and liquid biopsy. All of these are considered to be key tests in personalized/precision medicine.

We intend to perform its LDT testing in a CLIA Certified, CAP Accredited, High Complexity Molecular Laboratory under the direction of a qualified Laboratory Director with fully licensed Medical Laboratory Scientists.

Currently, there is legislation that would clarify FDA authority to regulate LDTs. This is HR 4128: VALID Act of 2021 introduced on June 24, 2021. (Source: H.R. 4128 C 117th Congress: VALID Act of 2021.@ www.GovTrack.us. 2021. November 23, 2022 https://www.govtrack.us/congress/bills/117/hr4128 Accessed 11/23/2022). Should this bill pass and be signed into law, the earliest implementing regulations would take effect would be in 2027. Additionally, the VALID Act includes grandfathered status for tests that were first offered for clinical use by a laboratory prior to the date of enactment. (Source: Epstein, Becker and Green, Health Law Advisor, May 20, 2022 https://www.healthlawadvisor.com/2022/05/20/the valid act senate action brings fda regulation of ldts closer to fruition/ Accessed 11/23/2022).

We believe that our proprietary testing will fully qualify for grandfather status, should the VALID Act pass.

Manufacturing and Distribution

We are currently in negotiations with several manufacturers regarding our mRNA for Life, Inc.'s Genetic Centric Supplement. We believe that our chosen manufacturer will be able to manufacture the necessary products at the highest quality standard. We intend to store our finished products in our own facilities, once we secure the necessary warehouse facility, and distribute our products to consumers through physician offices, wellness centers and established chain pharmacies. We intend to have all of our products produced and manufactured in the U.S. at facilities with good manufacturing practices. We intend that our initial distribution facility will be located in Florida. We are not currently aware of any material issues concerning the sourcing and availability of the raw materials used in our formulation.

We use Grace Health Technology Inc. as our Clinical Research Organization ("CRO"); Grace Health Technology contracts with Designer Genomics International, Inc. for the performance of certain CRO-related functions (our company has no contractual relationship with Designer Genomics International). The agreement with Grace Health Technology is for an initial term ending in July 2023, with automatic renewal terms of one year, unless terminated by either party. Each month, in payment of its services, we are obligated to pay Grace Health Technology an amount equal to its hard expenses incurred in performing its services plus 11.5% of such total hard expenses. The agreement is terminable upon any breach of the agreement, in the discretion of the non-breaching party. Through our agreement with Grace Health Technology, Genetics Institute of America ("GIA") is to manufacture and distribute our testing kits.

Raw Materials

We do not anticipate difficulties in procuring the ingredients needed for the production of our nutritional supplement, as there exist numerous sources for such ingredients.

    Registration No. 333-271439

Competitive Environment

We believe there are few existing comparable competitors with an mRNA focus. We feel the closest competitors are companies that engage in direct-to-consumer DNA genetic testing, such as 23andME Inc., Alpha Laboratories Ltd., Centrillion Technology Holding Ltd., and others. According to Cision PR Newswire, the global direct to consumer Genetic Testing Market is positioned to grow by $1.38 billion USD through 2025, with a compound annual growth rate of 16.73%. We believe that advances in next generation genetic sequencing will be one of the key driving forces in the market through 2025. These trends are expected to have a major impact as companies expand into this new territory, which leads us to believe that this market will be fragmented.

We believe a main difference between us and any of the comparable companies described above is that we are focused on mRNA, while they focus on DNA. The mRNA changes day by day while DNA is permanent. That means they can suggest hereditary health concerns based on DNA indexes but cannot provide the detailed specificity that a mRNA index can provide. We believe this differentiates us from others, but also allows us to tap into a market that is not very saturated at this point. Since mRNA is everchanging, we will not have the single-service limitation that models that employ DNA-based testing have.

Our market industry is classified into two main distribution channels, direct sales and retail sales. We believe the direct sales segment will contribute the largest share of the market. Direct sales channels can give consumers access to their personal genetic and health information, regardless of the time and place. We understand consumers purchase genetic testing services directly based on quick turnaround time for test results and accessibility to the tests themselves. This has fueled the demand for online orders of genetic tests, thus boosting revenue growth in the direct sales segment.

We believe that we have little direct competition, due to its unique proposition of solely using mRNA patent-pending indexes for screening health. In addition, the patent-pending supplementation will also be a product unique in its markets. Due to these factors, we believe the primary barriers to entry are awareness and education.

Additionally, we believe our products and services could be used by many patients if supply and logistics were of no issue. Our initial target patient profile is an individual over the age of 35 that is health conscious, demonstrates buying habits of a healthy lifestyle (e.g., gym memberships, use of dietary supplements), and earns more than the mean U.S. yearly income.

Properties

We own no real property interest. The Company leases a small office that is sufficient for our current operations at a monthly rental of $400.

Employees

Currently, we have three executive officers who perform all required administrative functions, in addition to their respective executive officer activities. Further, we retain persons who perform required professional services on our behalf as consultants.

Corporate Information

The Company was originally organized as a Kentucky corporation on February 11, 1988. On February 8, 2006, we formed a wholly owned subsidiary, Ludwig Enterprises, Inc., a Nevada corporation. On March 28, 2006, Ludwig Enterprises, Inc., our Kentucky corporation, merged with and into Ludwig Enterprises, Inc., our Nevada corporation, with the Company, Ludwig Enterprises, Inc., the Nevada corporation, being the surviving entity.

Our principal executive offices, and our subsidiaries, are located at 1749 Victorian Avenue, #C-350, Sparks, Nevada 89431; our telephone number is (954) 908-3366; our corporate website is located at www.ludwigent.com. No information found on, or connected to, the Company's website is incorporated by reference into, any you must not consider the information to a part of, this prospectus.

    Registration No. 333-271439

Executive Officers and Directors

Below is a list of our executive officers and directors as of the date of this prospectus.

Name Age Position Anne B. Blackstone 70 President and Director Marvin S. Hausman, M.D. 82 Chief Executive Officer and Chief Science Officer Thomas Terwilliger 78 Chief Operating Officer, Treasurer and Secretary

    Registration No. 333-271439

Our directors serve until the earlier occurrence of the election of his or her successor at the next meeting of shareholders, death, resignation or removal by the Board of Directors. Officers serve at the discretion of our Board of Directors. There are no family relationships between or among our directors and executive officers.

Certain information regarding the backgrounds of our officers and director is set forth below.

Anne B. Blackstone has served as our President and sole director since June 1, 2022, and served as our Chief Executive Officer from June 1, 2022, to September 5, 2023. Ms. Blackstone is certified registered nurse and has been employed at Envision Physician Services in such capacity since 1997. For more than 20 years, Ms. Blackstone has been a Certified Registered Nurse Anesthetist in Level 1 Trauma Center facility management. She received her Bachelor's Degree in Fine Arts from the University of Florida and her Master's of Science from Barry University, Miami Shores, Florida. We believe Ms. Blackstone's vast experience in the medical industry qualifies her to serve as a member on our board of directors.

Marvin S. Hausman, M.D. has served as our Chief Executive Officer and Chief Science Officer since September 5, 2023, after serving as a key consultant to our company since July 2022. Dr. Hausman is an Immunologist and Board-Certified Urological Surgeon with more than 30 years of drug research and development experience with various pharmaceutical companies, including Bristol Myers International, Mead Johnson Pharmaceutical Co., E.R. Squibb, Medco Research, and Axonyx. An accomplished executive with domestic and international experience, Dr. Hausman successfully executed acquisitions of breakthrough medical technology, in conjunction with formation, funding and launch of several corporations. He is a co-founder of Medco Research Inc., a NYSE biopharmaceutical company acquired by King Pharmaceutical Inc. He is a founder of Axonyx Inc., acquired by Torrey Pines Therapeutics, Inc. He is a founder of Entia Biosciences, Inc., which designs and developments natural organic antioxidant food-based products to be used as nutritional supplements in humans and animals. He is Founder and President of Northwest Medical Research Partners, Inc., a company specializing in the identification and acquisition of breakthrough pharmaceutical and nutraceutical products. Dr. Hausman is a Member of Board of Governors of New York University School of Medicine Alumni Association.

Thomas Terwilliger has served as our Chief Operating Officer, Treasurer and Secretary since September 5, 2023. Prior to his joining our company as Chief Operating Officer, from July 2022 through September 5, 2022, Mr. Terwilliger, in his role as consultant to Homeopathic Partners, Inc., provided administrative services to our company, under our now-terminated consulting agreement with Homeopathic Partners, Inc. Mr. Terwilliger has over 40 years as a small investment banker helping public and private start-up companies with legal, accounting and regulatory issues. He has been president of a 12 state Association of Long-Distance Telephone Companies for 13 years, served on the President's Oversight Committee of the U.S. Small Business Administration for Telecommunications. He is well known on Capitol Hill for his involvement with telecommunications and other regulatory issues. For about 30 years he has owned or operated both public and private research and development companies specializing in emerging technologies. Mr. Terwilliger's technologies have been deployed in the U.S., Mexico and in many countries in Latin, South and Central America. He holds several patents relating to health technologies specific to food preservation and edible oils extraction/longevity. Since 2016, he has owned and operated Corporate World, a corporate services provider based in Nevada. From the early 1970's through 2009, Mr. Terwilliger served on the boards of communications companies, Kentucky Indiana Telephone Co. Inc., Kentucky Telephone A Service Corporation, Super Tel Com, Inc., SFM&T, Inc., Armed Forces Services, Inc., T-Tom-CATV, Inc., Trans American Cable, Inc., and financial services companies, Carco Leasing, Inc. and LL Holdings, Inc. From 2011 through 2016, Mr. Terwilliger was a Director of Home Health Care Associates, Inc., a Florida-based health care services company. During 2019 and 2020, Mr. Terwilliger was a Director of Employ Capital, Inc., a Florida-based financial services company. He currently is chairperson of a State of Florida chartered 3rd party voter registration organization. He was LSBC's fund raising chairperson for the Love Jen (Kids with Cancer) foundation at Joe DiMaggio Children's Hospital. He has been active with fund raising for Honor Flight being a 4-time Guardian to America's veterans. From 2020 to 2021, he served as CFO and CEO of Winners, Inc. (OTC:WNRS). During 2021, Mr. Terwilliger was a Director of ClickStream Corporation (OTC:CLIS).

Key Consultant

Kyle Ambert, PhD. Dr. Ambert is currently Director of Data Science at Nike, Inc. and has extensive experience in data analytics, machine learning, artificial intelligence and applied analytics. His previous experience includes postings with the National Library of Medicine and Intel Corp. Dr. Ambert holds a PhD in Biomedical Informatics from Oregon Health & Science University.

Additionally, Dr. Ambert has interests in the following: applied analytics, multivariate statistics, machine learning and deep learning, text mining and natural language processing, biomedical informatics, distributed computing, information visualization, and behavioral economics. These interests give him skills in technical communication, data analysis, data visualization, analytics, programing, deep learning frameworks, and health and life sciences, all of which we believe are of great value to the Company.

Under our consulting agreement dated July 1, 2022, with Dr. Ambert, we pay Dr. Ambert $2,500 per month. In addition, we issued Dr. Ambert 250,000 shares of our common stock upon his entering into the agreement. Dr. Ambert provides us with Biomedical Informatics Services, which includes developing data mining tools to quantitate, analyze and perform cluster analysis of DNA and RNA panels. The agreement is for a term of one year, which renews for additional one-year periods, unless either party elects not to renew the agreement.

Conflicts of Interest

Our executive officers, our sole director and our key consultant are engaged in other businesses, either individually or through partnerships and corporations in which they may have an interest, hold an office or serve on a board of directors. As a result, certain conflicts of interest may arise. We will attempt to resolve such conflicts of interest in favor of our company. In general, our officers and directors are accountable to us and our shareholders as fiduciaries, which requires that these officers and directors exercise good faith and integrity in handling our company's affairs. A shareholder may be able to institute legal action on behalf of our company or on behalf of itself and other similarly situated shareholders to recover damages or for other relief in cases of the resolution of conflicts is in any manner prejudicial to us.

Involvement in Certain Legal Proceedings

None of our executive officers and directors has, during the past ten years:

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

Code of Business Conduct and Ethics

As of the date of this prospectus, our Board of Directors has not adopted a code of ethics with respect to our directors, officers and employees. Our Board of Directors intends to adopt a Code of Business Conduct and Ethics in the near future.

Corporate Governance

We do not have a separate Compensation Committee, Audit Committee or Nominating Committee. These functions are conducted by our sole director. During the year ended December 31, 2021, our sole director did not hold a meeting, but instead took actions by written consent in lieu of a meeting.

There are no understandings between the sole director of the Company or any other person pursuant to which our sole officer or director was or is to be selected as an officer or director.

Independence of Board of Directors

Our sole director is not independent, within the meaning of definitions established by the SEC or any self-regulatory organization. We are not currently subject to any law, rule or regulation requiring that all or any portion of our Board of Directors include independent directors.

Shareholder Communications with Our Board of Directors

The Company welcomes comments and questions from our shareholders. Shareholders should direct all communications to our President, Anne B. Blackstone, at our executive offices. However, while we appreciate all comments from shareholders, we may not be able to respond individually to all communications. We will attempt to address shareholder questions and concerns in our press releases and documents filed with the SEC, so that all shareholders have access to information about us at the same time. Ms. Blackstone collects and evaluates all shareholder communications. All communications addressed to our directors and executive officers will be reviewed by those parties, unless the communication is clearly frivolous.

    Registration No. 333-271439

    Registration No. 333-271439

Named Executive Officers

Our Named Executive Officers are Anne B. Blackstone, Marvin S. Hausman, M.D., and Thomas Terwilliger.

Compensation of our Executive Officers for 2022 and 2021

    Registration No. 333-271439

The following table summarizes information concerning the compensation awarded, paid to or earned by, our named executive officers.

    Registration No. 333-271439

Note 1 Ms. Blackstone did not become our Chief Executive Officer until June 1, 2022.

Note 2 We issued 200,000 shares of common stock to Ms. Blackstone as a bonus, which shares were valued at $.026 per share, based on the closing price of our common stock on the date of issuance.

Note 3 Dr. Hausman did not become our Chief Executive Officer until September 5, 2023.

Note 4 Mr. Terwilliger did not become our Chief Operating Officer until September 5, 2023

Employment Agreements

Anne B. Blackstone. In June 2022, we entered into an employment agreement with our sole executive officer, Anne B. Blackstone. The employment agreement has a one-year term and is terminable by us or Ms. Blackstone at any time, upon 15-days' notice. Under the employment agreement, Ms. Blackstone was issued 200,000 shares of our common stock, which shares were valued at $0.026 per share, or $5,200, in the aggregate. In addition, Ms. Blackstone is paid $1,500 per month and is entitled to a commission equal to 10% of the net proceeds on any business generated by her during the term of the employment agreement, payable in perpetuity in cash. Effective September 5, 2023, Ms. Blackstone's employment agreement was amended to remove the duties of CEO from her responsibilities; she currently serves as our President, under her employment agreement, as amended.

Marvin S. Hausman, M.D. On September 5, 2023, we entered into an employment agreement with Marvin S. Hausman, M.D., pursuant to which Dr. Hausman serves as our Chief Executive Officer. Under his employment agreement, we will pay Dr. Hausman $5,000 per month. In addition, we will pay Dr. Hausman an amount equal to 10% of gross sales revenues attributable to Dr. Hausman's efforts, in perpetuity.

From July 1, 2022, to September 5, 2023, Dr. Hausman provided services on behalf of our company, pursuant to a consulting agreement. Under his consulting agreement, we paid Dr. Hausman $5,000 per month. In addition, we were responsible for paying Dr. Hausman an amount equal to 10% of gross sales revenues attributable to Dr. Hausman's efforts, in perpetuity. We made no payments to Dr. Hausman based on sales, during the term of his consulting agreement.

Thomas Terwilliger. On September 5, 2023, we entered into an employment agreement with Thomas Terwilliger, pursuant to which Mr. Terwilliger serves as our Chief Operating Officer, Treasurer and Secretary. Under his employment agreement, we will pay Mr. Terwilliger $5,000 per month. In addition, we will pay Mr. Terwilliger an amount equal to 10% of gross sales revenues attributable to Mr. Terwilliger's efforts, in perpetuity.

Outstanding Equity Awards

The following table sets forth information regarding equity awards held by our Named Executive Officers as of the date of this prospectus.

    Registration No. 333-271439

    Registration No. 333-271439

Outstanding Equity Awards

Our Board of Directors has made no equity awards and no such award is pending.

Long Term Incentive Plans

We currently have no employee incentive plans.

Director Compensation

We have made no payments to our directors in consideration of their services to date, and there is currently no agreement or arrangement to pay any of our directors for their service as directors in the future.

SECURITY OWNERSHIP OF CERTAIN BENEFICIAL OWNERS AND MANAGEMENT

The following table sets forth information regarding the beneficial ownership of our common stock by (i) each 5% shareholder, (ii) each director, (iii) each executive officer and (iv) all directors and executive officers as a group. Unless otherwise indicated, the address of each executive officer and director is c/o Ludwig Enterprises, Inc., 1749 Victorian Avenue, #C 350, Sparks, Nevada 89431. As of September ___, 2023, there were 152,408,220 shares of our common stock issued and outstanding.

The number of shares of common stock beneficially owned by each shareholder is determined under rules issued by the SEC regarding the beneficial ownership of securities. This information is not necessarily indicative of beneficial ownership for any other purpose. Under these rules, beneficial ownership of shares of our common stock includes (1) any shares as to which the person or entity has sole or shared voting power or investment power and (2) any shares as to which the person or entity has the right to acquire beneficial ownership within 60 days after the date hereof. Each holder's percentage ownership after this Offering is based on shares of common stock to be outstanding immediately after the consummation of this Offering. The percentages assume no exercise by the underwriters of their option to purchase additional shares.

    Registration No. 333-271439

    Registration No. 333-271439

* Less than 1% (1) Based on 1,023,570,966 shares outstanding, which includes (a) 323,570,966 issued shares, and (b) 700,000,000 unissued shares that underlie shares of Convertible Preferred Stock convertible within 60 days of the date of this prospectus, before this Offering. (2) Based on 1,070,570,966 shares outstanding, which includes (a) 370,570,966 issued shares, assuming the sale of all of the Offered Shares, and (b) 700,000,000 unissued shares that underlie shares of Convertible Preferred Stock convertible within 60 days of the date of this prospectus, after this Offering. (3) 200,000,000 of these shares are unissued, but underlie currently convertible shares of our Convertible Preferred Stock. (4) 25,830,338 of these shares are owned by SH Fund LLC, an entity owned by Mr. Terwilliger, our Chief Operating Officer; 1,175,992 of these shares are owned by Tadas Trust, James Williams, Trustee, the beneficiary of which is Mr. Terwilliger; and 102,710 of these shares are owned by Barr Irrevocable Trust, the trustee of which trust is Mr. Terwilliger. (5) The manager of Barranquilla Investments, LLC is Marvin S. Hausman, M.D., our Chief Executive Officer. Dr. Hausman has the sole voting and dispositive control over the shares held by Barranquilla Investments, LLC. The address of this shareholder is 1309 Coffeen Avenue, Suite 1200, Sheridan, Wyoming 82801. (6) These shares are unissued, but underlie currently convertible shares of our Convertible Preferred Stock owned by Barranquilla Investments, LLC. (7) Carl Rubin is the Chief Executive Officer of Homeopathic Partners, Inc. Mr. Rubin has the sole voting and dispositive control over the shares held by Homeopathic Partners, Inc. The address of this shareholder is 2363 Arbordale Avenue, The Villages, Florida 32162. (8) These shares are unissued, but underlie currently convertible shares of our Convertible Preferred Stock owned by Homeopathic Partners, Inc. (9) Corain McGinn is the Chief Executive Officer of Vasaio Capital, Inc. Mr. McGinn has the sole voting and dispositive control over the shares held by Vasaio Capital, Inc. The address of this shareholder is 288 Grove Streeet, Suite 361, Braintree, Massachusetts 02184. (10) These shares are unissued, but underlie currently convertible shares of our Convertible Preferred Stock owned by Vasaio Capital, Inc. (11) Each share of Convertible Preferred Stock (a) is convertible into 100 shares of our common stock at any time and (b) has the following voting rights: each share of Convertible Preferred Stock shall vote on all matters as a class with the holders of common stock and each share of Convertible Preferred Stock shall be entitled to the number of votes equal to the "conversion rate," or 100 votes per share.

    Registration No. 333-271439

Except as disclosed herein, no director, executive officer, shareholder holding at least 5% of shares of our common stock, or any family member thereof, had any material interest, direct or indirect, in any transaction, or proposed transaction since January 1, 2021, in which the amount involved in the transaction exceeds the lesser of $120,000 or one percent of the average of our total assets at the year-end for the last two completed fiscal years.

    Registration No. 333-271439

Employment Agreements

Anne B. Blackstone. In June 2022, we entered into an employment agreement with our Chief Executive Officer, Anne B. Blackstone. The employment agreement has an initial one-year term, which renews automatically for one-year terms, unless terminated by either party. Ms. Blackstone's employment agreement is terminable by us or Ms. Blackstone at any time, upon 15-days' notice. Under the employment agreement, Ms. Blackstone was issued 200,000 shares of our common stock, which shares were valued at $0.026 per share, or $5,200, in the aggregate. In addition, Ms. Blackstone is paid $1,500 per month and is entitled to a commission equal to 10% of the net proceeds on any business generated by her during the term of the employment agreement, payable in perpetuity in cash. Effective September 5, 2023, Ms. Blackstone's employment agreement was amended to remove the duties of CEO from her responsibilities; she currently serves as our President, under her employment agreement, as amended.

Marvin S. Hausman, M.D. On September 5, 2023, we entered into an employment agreement with Marvin S. Hausman, M.D., pursuant to which Dr. Hausman serves as our Chief Executive Officer. Under his employment agreement, we will pay Dr. Hausman $5,000 per month. In addition, we will pay Dr. Hausman an amount equal to 10% of gross sales revenues attributable to Dr. Hausman's efforts, in perpetuity.

From July 1, 2022, to September 5, 2023, Dr. Hausman provided services on behalf of our company, pursuant to a consulting agreement. Under his consulting agreement, we paid Dr. Hausman $5,000 per month. In addition, we were responsible for paying Dr. Hausman an amount equal to 10% of gross sales revenues attributable to Dr. Hausman's efforts, in perpetuity. We made no payments to Dr. Hausman based on sales, during the term of his consulting agreement.

Thomas Terwilliger. On September 5, 2023, we entered into an employment agreement with Thomas Terwilliger, pursuant to which Mr. Terwilliger serves as our Chief Operating Officer, Treasurer and Secretary. Under his employment agreement, we will pay Mr. Terwilliger $5,000 per month. In addition, we will pay Mr. Terwilliger an amount equal to 10% of gross sales revenues attributable to Mr. Terwilliger's efforts, in perpetuity.

Common Stock Repurchase Agreement

Effective August 10, 2023, we entered into a Common Stock Repurchase Agreement (the "Repurchase Agreement") with Worthington Financial Services, Inc. ("Worthington"), pursuant to which we repurchased 171,162,746 shares of our common stock (the "Worthington Shares"). In payment of such shares, we issued a promissory note (the "Worthington Note") in the principal amount of $122,873 that bears interest at 8% per annum. The Worthington Note is due on the earlier to occur of (1) our receipt of the first $500,000 in proceeds in this offering (of which there is no assurance) and (2) August 31, 2024. Under the Worthington Note, an event of default occurs if (1) we fail on the maturity date to pay timely the principal and accrued interest or (2) fail to timely file with OTC Markets or any regulatory agency, including the SEC, a required filing or (3) fail to timely pay, in full, any creditor or note holder of our company. Upon any such event of default, the then-unpaid principal amount shall bear interest at 18% per annum. In addition to customary rights of a creditor, upon an event of default under the Worthington Note, Worthington shall have the right, in its sole discretion, to rescind the Repurchase Agreement and to have the Worthington Shares reissued to it.

Consulting Agreement

Homeopathic Partners, Inc. Effective July 1, 2022, we entered into a consulting agreement with Homeopathic Partners, Inc. for the provision of general business consulting services. Upon the signing of this agreement, we issued Homeopathic Partners 2,000,000 shares of our Series B Preferred Stock. We pay Homeopathic Partners $10,000 per month. In addition, we are responsible to pay Homeopathic Partners an amount equal to 10% of gross sales revenues attributable to Homeopathic Partners' efforts, in perpetuity. The agreement is for a term of one year, which renews for additional one-year periods, unless either party elects not to renew the agreement; provided, however, that Homeopathic Partners' consulting agreement can be terminated at any time by either party, upon 15-days' notice.

Effective September 5, 2023, in conjunction with our adding two executive officers, we terminated the consulting agreement with Homeopathic Partners, pursuant to its terms of termination.

    Registration No. 333-271439

Policy for approval of related-person transactions

Prior to this Offering, we have not had a formal policy regarding approval of transactions with related persons. In connection with this Offering, our Board of Directors has adopted a related-person transaction policy that sets forth our procedures for the identification, review, consideration and approval or ratification for the review of any transaction, arrangement or relationship in which we are a participant, the amount involved exceeds $120,000 and one of our executive officers, directors, director nominees or each person whom we know to beneficially own more than 5% of our outstanding shares of common stock (a "5% shareholder") (or their immediate family members), each of whom we refer to as a "related person," has a direct or indirect material interest.

If a related person proposes to enter into such a transaction, arrangement or relationship, which we refer to as a "related-person transaction," the related person must report the proposed related-person transaction to our outside general counsel. The policy calls for the proposed related-person transaction to be reviewed by and if deemed appropriate approved by, the audit committee of our board of directors. Whenever practicable, the reporting, review and approval will occur prior to entry into the transaction. If advance review and approval is not practicable, the audit committee will review and, in its discretion, may ratify the related-person transaction. The policy also permits the chair of the audit committee to review, and if deemed appropriate approve, proposed related-person transactions that arise between audit committee meetings, subject to ratification by the audit committee at its next meeting. Any related-person transactions that are ongoing in nature will be reviewed annually.

A related-person transaction reviewed under the policy will be considered approved or ratified if it is authorized by the audit committee after full disclosure of the related person's interest in the transaction. As appropriate for the circumstances, the committee will review and consider:

? the related person's interest in the related-person transaction;

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

The audit committee may approve or ratify the transaction only if the audit committee determines that, under all of the circumstances, the transaction is not inconsistent with our best interests. The audit committee may impose any conditions on the related-person transaction that it deems appropriate.

The policy provides that transactions involving compensation of executive officers shall be reviewed and approved by the compensation committee of our board of directors in the manner specified in its charter.

    Registration No. 333-271439

    Registration No. 333-271439

General

Our authorized capital stock consists of (a) 1,250,000,000 shares of common stock, $.001 par value per share; and (b) 7,000,000 shares of preferred stock, $.001 par value per share, all of which have been designated Convertible Preferred Stock.

As of the date of this prospectus, there were (x) 152,408,220 shares of our common stock issued and outstanding held by approximately 28 holders of record; and (y) 7,000,000 shares of Convertible Preferred Stock were issued and outstanding held by three (3) holders of record.

Common Stock

General. The holders of our common stock currently have (a) equal ratable rights to dividends from funds legally available therefore, when, as and if declared by our Board of Directors; (b) are entitled to share ratably in all of our assets available for distribution to holders of common stock upon liquidation, dissolution or winding up of the affairs of the Company; (c) do not have preemptive, subscriptive or conversion rights and there are no redemption or sinking fund provisions or rights applicable thereto; and (d) are entitled to one non-cumulative vote per share on all matters on which shareholders may vote. Our bylaws provide that, at all meetings of the shareholders for the election of directors, a plurality of the votes cast shall be sufficient to elect. On all other matters, except as otherwise required by Nevada law or our Articles of Incorporation, as amended, a majority of the votes cast at a meeting of the shareholders shall be necessary to authorize any corporate action to be taken by vote of the shareholders.

Non-cumulative Voting. Holders of shares of our common stock do not have cumulative voting rights, which means that the holders of more than 50% of the outstanding shares, voting for the election of directors, can elect all of the directors to be elected, if they so choose, and, in such event, the holders of the remaining shares will not be able to elect any of our directors.

Pre-emptive Rights. As of the date of this prospectus, no holder of any shares of our capital stock has pre-emptive or preferential rights to acquire or subscribe for any unissued shares of any class of our capital stock not otherwise disclosed herein.

Convertible Preferred Stock

Voting Rights. The Convertible Preferred Stock has the following voting rights: each share of Convertible Preferred Stock shall vote on all matters as a class with the holders of common stock and each share of Convertible Preferred Stock shall be entitled to the number of votes equal to the "conversion rate," or 100 votes per share.

Dividends. The shares of Convertible Preferred Stock shall be treated pari passu with our common stock, except that the dividend on each share of Convertible Preferred Stock shall be equal to the amount of the dividend declared and paid on each share of common stock multiplied by the Conversion Rate, or 100 shares.

Conversion Rights. Each share of Convertible Preferred Stock is convertible into 100 shares of our common stock at any time.

    Registration No. 333-271439

Convertible Promissory Notes

The table below sets forth information with respect to the Convertible Notes as of the date of this prospectus. None of the Convertible Notes contains restrictive covenants with respect to the conduct of our business. In addition to the terms set forth in the table below, each of the Convertible Notes (a) may be prepaid by the Company at any time without penalty, (b) would be in default should the Company (i) fail to make any required payment when due, following a five-day cure period, or (ii) file for bankruptcy protection, (iii) become the subject of an involuntary bankruptcy proceeding and such proceeding shall not have been dismissed within 30 days or (iv) there shall have been appointed a receiver of the Company and such appointment shall remain beyond 120 days, (c) require the Company to register the shares of common stock underlying the Convertible Notes in the Registration Statement of which this prospectus forms a part, and (d) no conversion of a Convertible Note shall be permitted should any such conversion cause the converting holder's ownership of Company common stock to exceed 4.99%.

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

Prior to this Offering, there has been a limited public market for our common stock and a liquid trading market for our common stock may not develop or be sustained after this Offering. Future sales of our common stock in the public market after this Offering, or the perception that those sales may occur, could cause the prevailing market price for our common stock to fall or impair our ability to raise equity capital in the future. Future sales of our common stock in the public market either before (to the extent permitted) or after restrictions lapse, or the perception that those sales may occur, could adversely affect the prevailing market price of our common stock at such time and our ability to raise equity capital at a time and price we deem appropriate.

Sale of restricted shares

All of the shares of common stock to be sold in this Offering, and any shares sold upon exercise of the underwriters' option to purchase additional shares of common stock, will be freely tradable in the public market without restriction or further registration under the Securities Act, unless the shares are held by any of our "affiliates" as such term is defined in Rule 144 of the Securities Act. All remaining shares of common stock held by existing shareholders immediately prior to the consummation of this Offering will be "restricted securities" as such term is defined in Rule 144. These restricted securities were issued and sold by us in private transactions and are eligible for public sale only if registered under the Securities Act or if they qualified for an exemption from registration under the Securities Act, including the exemptions provided by Rule 144 or Rule 701.

Rule 144

In general, under Rule 144, as currently in effect, once we have been subject to the public company reporting requirements of the Exchange Act, for at least 90 days, a person (or persons whose shares are required to be aggregated) who is not deemed to have been one of our "affiliates" for purposes of Rule 144 at any time during the three months preceding a sale, and who has beneficially owned restricted securities within the meaning of Rule 144 for at least six months, including the holding period of any prior owner other than one of our "affiliates," is entitled to sell those shares in the public market (subject to the lock-up agreement referred to below, if applicable) without complying with the manner of sale, volume limitations or notice provisions of Rule 144, but subject to compliance with the public information requirements of Rule 144. Rule 144(a)(1) defines an "affiliate" of an issuing company as a person that directly, or indirectly through one or more intermediaries, controls, or is controlled by, or is under common control with, such issuer. Directors, officers and holders of ten percent or more of our voting securities (including securities which are issuable within the next 60 days) are deemed to be affiliates of the issuing company. If such a person has beneficially owned the shares proposed to be sold for at least one year, including the holding period of any prior owner other than "affiliates," then such person is entitled to sell such shares in the public market without complying with any of the requirements of Rule 144 (subject to the lock-up agreement referred to below, if applicable). In general, under Rule 144, as currently in effect, once we have been subject to the public company reporting requirements of the Exchange Act for at least 90 days, our "affiliates," as defined in Rule 144, who have beneficially owned the shares proposed to be sold for at least six months, including the holding period of any prior owner other than one of our "affiliates," are entitled to sell in the public market, upon expiration of any applicable lock-up agreements and within any three-month period, a number of those shares of our common stock that does not exceed the greater of:

    Registration No. 333-271439

    Registration No. 333-271439

Such sales under Rule 144 by our "affiliates" or persons selling shares on behalf of our "affiliates" are also subject to certain manner of sale provisions, notice requirements and to the availability of current public information about us.

    Registration No. 333-271439

    Registration No. 333-271439

The Offered Shares will be sold in a "direct public offering" through our Sole Officer and Director, Anne B. Blackstone, who may be considered an underwriter as that term is defined in Section 2(a)(11). Ms. Blackstone will not receive any commission in connection with the sale of shares, although we may reimburse her for expenses incurred in connection with the offer and sale of the Offered Shares. Ms. Blackstone intends to sell the Offered Shares being registered according to the following plan of distribution:

    Registration No. 333-271439

? she must not be subject to a statutory disqualification;

    Registration No. 333-271439

? she must not be an associated person of a broker dealer;

    Registration No. 333-271439

    Registration No. 333-271439

Ms. Blackstone will comply with the guidelines enumerated in Rule 3a4 1(a)(4)(ii). Neither Ms. Blackstone, nor any of her affiliates, will be purchasing shares in this Offering.

You may purchase Offered Shares by completing and manually executing a subscription agreement and delivering it with your payment in full for all subscribed Offered Shares to our offices. A form of the required subscription agreement is attached as an exhibit to our registration statement of which this Prospectus is a part. Your subscription shall not become effective until accepted by us and approved by our counsel. Acceptance will be based upon confirmation that you have purchased the Offered Shares in a state in which the Offered Shares have been registered or in a state for which there is an exemption from registration. Our subscription process is as follows:

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

In addition, and upon the effectiveness of this Offering, a total of $940,000 of principal amount of the Convertible Notes will, by their terms, be eligible for conversion into the Conversion Shares, at the election of their respective holders, at a price equal to 80% of the offering price for all of the Offered Shares, or $___[0.75-1.00] per Conversion Share. (See "Use of Proceeds and A Description of Securities Convertible Promissory Notes").

    Registration No. 333-271439

    Registration No. 333-271439

Transfer Agent

We have retained the services of Standard Registrar & Transfer Co., Inc., 440 East 400 South, Suite 200, Salt Lake City, Utah 84111, as the transfer agent for our common stock. Standard Registrar & Transfer Co.'s website is located at: www.standardtransferco.com. No information found on Standard Registrar & Transfer Co.'s website is part of this Prospectus.

    Registration No. 333-271439

On September 30, 2022, we engaged Assurance Dimensions, Inc. as our independent registered public accounting firm. During the two most recent fiscal years, and the subsequent interim period through the date of engagement, neither we, nor anyone engaged on our behalf, consulted with Assurance Dimensions, Inc. regarding either the application of accounting principles to a specified transaction, either completed or proposed, or the type of audit opinion that might be rendered on our financial statements.

The engagement of our independent public accountants was approved by our Sole Director.

    Registration No. 333-271439

The validity of the securities offered by this Prospectus will be passed upon for us by Newlan Law Firm, PLLC, Flower Mound, Texas.

    Registration No. 333-271439

Our balance sheets as of December 31, 2022 and 2021, and the related statements of operations, changes in stockholders' equity and cash flows for the years ended December 31, 2022 and 2021, included in this Prospectus have been audited by Assurance Dimensions, Inc., independent registered public accounting firm, as indicated in their report with respect thereto, and have been so included in reliance upon the report of such firm given on their authority as experts in accounting and auditing.

    Registration No. 333-271439

In the opinion of the Securities and Exchange Commission, indemnification for liabilities arising under the Securities Act is against public policy as expressed in the Securities Act and is, therefore, unenforceable. Insofar as indemnification for liabilities arising under the Securities Act may be permitted to directors, officers or persons controlling the registrant pursuant to the foregoing provisions, the registrant has been informed that in the opinion of the Securities and Exchange Commission such indemnification is against public policy as expressed in the Securities Act and is, therefore, unenforceable.

    Registration No. 333-271439

The provisions of Nevada law may have the effect of delaying, deferring or preventing another party from acquiring control of us. These provisions, summarized below, may discourage and prevent coercive takeover practices and inadequate takeover bids.

Nevada law contains a provision governing "acquisition of controlling interest." This law provides generally that any person or entity that acquires 20% or more of the outstanding voting shares of a publicly held Nevada corporation in the secondary public or private market may be denied voting rights with respect to the acquired shares, unless a majority of the disinterested shareholders of the corporation elects to restore such voting rights in whole or in part. The control share acquisition act provides that a person or entity acquires "control shares" whenever it acquires shares that, but for the operation of the control share acquisition act, would bring its voting power within any of the following three ranges: 20 to 33 1/3%; 33 1/3 to 50%; or more than 50%.

A "control share acquisition" is generally defined as the direct or indirect acquisition of either ownership or voting power associated with issued and outstanding control shares. The shareholders or board of directors of a corporation may elect to exempt the stock of the corporation from the provisions of the control share acquisition act through adoption of a provision to that effect in the articles of incorporation or bylaws of the corporation. Our articles of incorporation and bylaws do not exempt our common stock from the control share acquisition act.

The control share acquisition act is applicable only to shares of "Issuing Corporations" as defined by the Nevada law. An Issuing Corporation is a Nevada corporation which (i) has 200 or more shareholders, with at least 100 of such shareholders being both shareholders of record and residents of Nevada, and (ii) does business in Nevada directly or through an affiliated corporation.

    Registration No. 333-271439

At this time, we do not believe we have 100 shareholders of record resident of Nevada and we do not conduct business in Nevada directly. Therefore, we do not believe that the provisions of the control share acquisition act will apply to acquisitions of our shares and will not until such time as these requirements have been met. At such time as they may apply, the provisions of the control share acquisition act may discourage companies or persons interested in acquiring a significant interest in or control of us, regardless of whether such acquisition may be in the interest of our shareholders.

The Nevada "Combination with Interested Stockholders Statute" may also have an effect of delaying or making it more difficult to effect a change in control of us. This statute prevents an "interested stockholder" and a resident domestic Nevada corporation from entering into a "combination," unless certain conditions are met. The statute defines "combination" to include any merger or consolidation with an "interested stockholder," or any sale, lease, exchange, mortgage, pledge, transfer or other disposition, in one transaction or a series of transactions with an "interested stockholder" having (i) an aggregate market value equal to 5% or more of the aggregate market value of the assets of the corporation, (ii) an aggregate market value equal to 5% or more of the aggregate market value of all outstanding shares of the corporation, or (iii) representing 10% or more of the earning power or net income of the corporation.

An "interested stockholder" means the beneficial owner of 10% or more of the voting shares of a resident domestic corporation, or an affiliate or associate thereof. A corporation affected by the statute may not engage in a "combination" within three years after the interested stockholder acquires its shares unless the combination or purchase is approved by the board of directors before the interested stockholder acquired such shares. If approval is not obtained, then after the expiration of the three year period, the business combination may be consummated with the approval of the board of directors or a majority of the voting power held by disinterested stockholders, or if the consideration to be paid by the interested stockholder is at least equal to the highest of (i) the highest price per share paid by the interested stockholder within the three years immediately preceding the date of the announcement of the combination or in the transaction in which he became an interested stockholder, whichever is higher, (ii) the market value per common share on the date of announcement of the combination or the date the interested stockholder acquired the shares, whichever is higher, or (iii) if higher for the holders of preferred stock, the highest liquidation value of the preferred stock.

    Registration No. 333-271439

We have filed with the SEC the Registration Statement on Form S 1 under the Securities Act with respect to the Shares being offered by this Prospectus. This Prospectus, which constitutes a part of the Registration Statement, does not contain all of the information in the Registration Statement and its exhibits. For further information with respect to the Company and the Shares offered by this Prospectus, you should refer to the Registration Statement and the exhibits filed as a part thereof. Statements contained in this Prospectus as to the contents of any contract or any other document referred to are not necessarily complete and, in each instance, we refer you to the copy of the contract or other document filed as an exhibit to the Registration Statement. Each of these statements is qualified in all respects by this reference.

We are subject to the informational requirements of the Exchange Act and file annual, quarterly and current reports, proxy statements and other information with the SEC. You can read our SEC filings, including the Registration Statement, over the Internet at the SEC's website at http://www.sec.gov. You may also read and copy any document we file with the SEC at its public reference facilities at 100 F Street, N.E., Washington, D.C. 20549. You may also obtain copies of these documents at prescribed rates by writing to the Public Reference Section of the SEC at 100 F Street, N.E., Washington, D.C. 20549. Please call the SEC at 1 800 SEC 0330 for further information on the operation of the public reference facilities. You may also request a copy of these filings, at no cost, by writing or telephoning us at: Ludwig Enterprises, Inc., 1749 Victorian Avenue, #C-350, Sparks, Nevada 89431; our telephone number is (954) 908-3366.

YOU SHOULD RELY ONLY ON THE INFORMATION CONTAINED IN THIS PROSPECTUS. WE HAVE NOT AUTHORIZED ANYONE TO PROVIDE INFORMATION DIFFERENT FROM THAT CONTAINED IN THIS PROSPECTUS. WE ARE OFFERING TO SELL, AND SEEKING OFFERS TO BUY, SHARES OF COMMON STOCK ONLY IN JURISDICTIONS WHERE OFFERS AND SALES ARE PERMITTED. THE INFORMATION CONTAINED IN THIS PROSPECTUS IS ACCURATE ONLY AS OF THE DATE OF THIS PROSPECTUS REGARDLESS OF THE TIME OF DELIVERY OF THIS PROSPECTUS, OR OF ANY SALE OF OUR COMMON STOCK.

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

Balance Sheets as of June 30, 2023 (unaudited), and December 31, 2022 F-1

Statements of Operations for the Three and Six Months Ended June 30, 2023 F-2 and 2022 (unaudited)

Statements in Stockholders' Equity (Deficit) for the Six Months Ended June F-3 30, 2023 and 2022 (unaudited)

Statements of Cash Flows for the Six Months Ended June 30, 2023 and 2022 F-5 (unaudited)

Notes to Consolidated Financial Statements F-6

    Registration No. 333-271439

Report of Independent Registered Public Accounting Firm F-19

Balance Sheets as of December 31, 2022 and 2021 F-20

Statements of Operations for the Years Ended December 31, 2022 and 2021 F-21

Statements in Stockholders' Equity (Deficit) for the Years Ended F-22 December 31, 2022 and 2021

Statements of Cash Flows for the Years Ended December 31, 2022 and 2021 F-24

Notes to Unaudited Consolidated Financial Statements F-25

    Registration No. 333-271439

    Registration No. 333-271439

Assets

Current Assets Cash $ 85,770 $ 516,195 Prepaids 5,906 - Inventory 46,829 - Total Current Assets 138,505 516,195

Total Assets $ 138,505 $ 516,195

Liabilities and Stockholder'' Deficit

Current Liabilities Accounts payable and accrued expenses $ 50,447 $ 6,882 Notes payable -- net 507,136 507,136 Convertible notes payable-- net 578,267 828,344 Total Current Liabilities 1,135,850 1,342,362

Stockholder'' Deficit Preferred stock - $0.001 par value; convertible, 7,000,000 shares authorized; 7,000,000 and 7,000,000 shares issued and outstanding, respectively 7,000 7,000 Common stock - $0.001 par value, 1,250,000,000 shares authorized 323,360,966 and 315,188,929 shares issued and outstanding, respectively 323,360 315,188 Additional paid-in capital 2,017,503 637,577 Accumulated deficit (3,345,208) (1,785,932) Total Stockholder'' Deficit (997,345) (826,167)

Total Liabilities and Stockholder'' Deficit $ 138,505 $ 516,195

    Registration No. 333-271439

    Registration No. 333-271439

Operating expenses Research and development $ 394,210 $ 45,245 General and administrative expenses 684,256 83,527 Total operating expenses 1,078,466 128,772

Loss from operations (1,078,466) (128,772)

Other income (expense) Amortization of debt discount (372,781) (183,489) Gain on debt extinguishment - 44,475 Inducement expense (102,857) - Interest expense (5,172) (8,808) Total other income (expense)-- net (480,810) (147,822)

Net loss $ (1,559,276) $ (276,594)

Loss per share -- basic and diluted $ (0.00) $ (0.00)

Weighted average number of shares -- basic and diluted 318,241,235 311,838,929

    Registration No. 333-271439

    Registration No. 333-271439

December 31, 2022 7,000,000 $ 7,000 315,188,929 $ 315,188 $ 637,577 $ (1,785,932) $ (826,167)

Stock issued for license fee ($0.37.share) - - 1,000,000 1,000 369,000 - 370,000

Stock issued for services ($0.10 - $0.36/share) - - 873,334 873 221,510 - 222,383

Conversion of debt to common stock ($0.11/share) including inducement expense - - 6,298,703 6,299 789,416 - 795,715

Net loss - - - - - (1,559,276) (1,559,276)

June 30, 2023 7,000,000 $ 7,000 323,360,966 $ 323,360 $ 2,017,503 $ (3,345,208) $ (997,345)

    Registration No. 333-271439

December 31, 2021 - $ - 311,838,929 $ 311,838 $ 451,227 $ (820,782) $ (57,717)

Debt discount -- beneficial conversion feature - - - - 75,000 - 75,000

Stock issued for option to acquire common stock ($0.001/share) 1,000,000 1,000 - - - - 1,000

Stock issued for services ($0.26/share) - - 2,250,000 2,250 56,250 - 58,500

Stock issued for services--related party ($0.26/share) - - 200,000 200 5,000 - 5,200

Cancellation of common stock ($0.001/share) - - (100,000) (100) 100 - -

Net loss - - - - - (276,594) (276,594)

June 30, 2022 1,000,000 $ 1,000 314,188,929 $ 314,188 $ 587,577 $ (1,097,376) $ (194,611)

    Registration No. 333-271439

    Registration No. 333-271439

Operating activities Net loss $ (1,559,276) $ (276,594) Adjustments to reconcile net loss to net cash used in operations Stock issued for services 222,383 58,500 Stock issued for services--related party - 5,200 Stock issued for option to acquire common stock - 1,000 Stock issued for license fee 370,000 - Amortization of debt discount 372,781 183,489 Inducement expense 102,857 - Changes in operating assets and liabilities (Increase) decrease in Prepaids (5,906) - Inventory (46,829) - Increase (decrease) in Accounts payable and accrued expenses 43,565 (35,666) Net cash used in operating activities (500,425) (64,071)

Financing activities Proceeds from convertible notes payable -- net 70,000 75,000 Net cash provided by financing activities 70,000 75,000

Net increase (decrease) in cash (430,425) 10,929

Cash--beginning of period 516,195 125,000

Cash--end of period $ 85,770 $ 135,929

Supplemental disclosure of cash flow information Cash paid for interest $ - $ - Cash paid for income tax $ - $ -

Supplemental disclosure of non-cash investing and financing activities Original issuance debt discount $ 30,000 $ - Debt discount--beneficial conversion feature $ - $ 75,000 Conversion of notes payable into common stock $ 692,858 $ - Conversion of accrued interest into convertible notes payable $ - $ 9,473

    Registration No. 333-271439

    Registration No. 333-271439

Note 1-- Organization and Nature of Operations

Organization and Nature of Operations

Ludwig Enterprises, Inc. (collectively, "we," "us," "our" or the "Company"), a Nevada Corporation (incorporated February 2006).

The Company is currently seeking to develop products and services through the use of cutting-edge technologies in the health care industry.

Formation of Subsidiaries

On May 18, 2022, the Company formed mRNA for Life, Inc. ("mRNA"), a Wyoming corporation, which is a wholly-owned subsidiary of the Company. mRNA is expected to produce supplements to address clinical diagnoses from mRNA cheek swabs.

On November 18, 2022, the Company formed Precision Genomics, Inc. ("PGI"), a Wyoming corporation, which is a wholly-owned subsidiary of the Company. PGI will be developing proprietary medical artificial intelligence ("AI") technology that uses mRNA inflammatory language to potentially capture an inflammatory snapshot of disease and the body's response to treatment.

On June 6, 2023, the Company formed Exousia Ai, Inc. ("EXO"), a Wyoming corporation, which is a wholly-owned subsidiary of the Company. EXO was formed to focus on studying the expression of differentially expressed mRNA genes in various chronic inflammatory diseases.

Liquidity, Going Concern and Management's Plans

These financial statements have been prepared on a going concern basis, which contemplates the realization of assets and the settlement of liabilities and commitments in the normal course of business.

As reflected in the accompanying financial statements, for the six months ended June 30, 2023, the Company had:

? Net loss of $1,559,276; and ? Net cash used in operations was $500,425

Additionally, at June 30, 2023, the Company had:

? Accumulated deficit of $3,345,208 ? Stockholders' deficit of $997,345; and ? Working capital deficit of $997,345

The Company has cash on hand of $85,770 at June 30, 2023. The Company does not expect to generate sufficient revenues and positive cash flows from operations to meet its current obligations. However, the Company may seek to raise debt or equity-based capital at favorable terms, though such terms are not certain.

These factors create substantial doubt about the Company's ability to continue as a going concern within the twelve-month period subsequent to the date that these financial statements are issued.

The consolidated financial statements do not include any adjustments that might be necessary if the Company is unable to continue as a going concern. Accordingly, the financial statements have been prepared on a basis that assumes the Company will continue as a going concern and which contemplates the realization of assets and satisfaction of liabilities and commitments in the ordinary course of business.

    Registration No. 333-271439

Management's strategic plans include the following:

    Registration No. 333-271439

Note 2-- Summary of Significant Accounting Policies

Basis of Presentation

The accompanying unaudited consolidated financial statements have been prepared in accordance with accounting principles generally accepted in the United States of America for interim financial statements ("U.S. GAAP"). Accordingly, they do not contain all information and footnotes required by accounting principles generally accepted in the United States of America for annual financial statements.

In the opinion of the Company's management, the accompanying unaudited consolidated financial statements contain all of the adjustments necessary (consisting only of normal recurring accruals) to present the financial position of the Company as of June 30, 2023 and the results of operations and cash flows for the periods presented. The results of operations for the six months ended June 30, 2023 are not necessarily indicative of the operating results for the full fiscal year or any future period.

These unaudited consolidated financial statements should be read in conjunction with the financial statements and related notes thereto included in the Company's registration statement on Form S1 for the year ended December 31, 2022, initially filed with the SEC on April 26, 2023. The Company continues to file amendments to their registration statement pending declaration of effectiveness.

Management acknowledges its responsibility for the preparation of the accompanying unaudited consolidated financial statements which reflect all adjustments, consisting of normal recurring adjustments, considered necessary in its opinion for a fair statement of its consolidated financial position and the consolidated results of its operations for the periods presented.

Principles of Consolidation

These consolidated financial statements have been prepared in accordance with U.S. GAAP and include the accounts of the Company and its wholly owned subsidiaries mRNA and EXO. All intercompany transactions and balances have been eliminated.

    Registration No. 333-271439

Business Segments

The Company uses the "management approach" to identify its reportable segments. The management approach requires companies to report segment financial information consistent with information used by management for making operating decisions and assessing performance as the basis for identifying the Company's reportable segments. The Company has identified one single reportable operating segment. The Company manages its business on the basis of one operating and reportable segment.

Use of Estimates

Preparing financial statements in conformity with U.S. GAAP requires management to make estimates and assumptions that affect the reported amounts of assets and liabilities and the disclosure of contingent assets and liabilities at the date of the financial statements and revenues and expenses during the reported period. Actual results could differ from those estimates, and those estimates may be material.

Changes in estimates are recorded in the period in which they become known. The Company bases its estimates on historical experience and other assumptions, which include both quantitative and qualitative assessments that it believes to be reasonable under the circumstances.

Significant estimates during the six months ended June 30, 2023 and 2022 include valuation of stock-based compensation, uncertain tax positions, and the valuation allowance on deferred tax assets.

Fair Value of Financial Instruments

The Company accounts for financial instruments under Financial Accounting Standards Board ("FASB") ASC 820, Fair Value Measurements. ASC 820 provides a framework for measuring fair value and requires disclosures regarding fair value measurements. Fair value is defined as the price that would be received to sell an asset or paid to transfer a liability in an orderly transaction between market participants at the measurement date, based on the Company's principal or, in absence of a principal, most advantageous market for the specific asset or liability.

The Company uses a three-tier fair value hierarchy to classify and disclose all assets and liabilities measured at fair value on a recurring basis, as well as assets and liabilities measured at fair value on a non-recurring basis, in periods subsequent to their initial measurement. The hierarchy requires the Company to use observable inputs when available, and to minimize the use of unobservable inputs, when determining fair value.

The three tiers are defined as follows:

    Registration No. 333-271439

The determination of fair value and the assessment of a measurement's placement within the hierarchy requires judgment. Level 3 valuations often involve a higher degree of judgment and complexity. Level 3 valuations may require the use of various cost, market, or income valuation methodologies applied to unobservable management estimates and assumptions. Management's assumptions could vary depending on the asset or liability valued and the valuation method used. Such assumptions could include estimates of prices, earnings, costs, actions of market participants, market factors, or the weighting of various valuation methods. The Company may also engage external advisors to assist us in determining fair value, as appropriate.

Although the Company believes that the recorded fair value of our financial instruments is appropriate, these fair values may not be indicative of net realizable value or reflective of future fair values.

The Company's financial instruments are carried at historical cost. At June 30, 2023 and December 31, 2022, respectively, the carrying amounts of these instruments approximated their fair values because of the short-term nature of these instruments.

ASC 825-10 "Financial Instruments" allows entities to voluntarily choose to measure certain financial assets and liabilities at fair value ("fair value option"). The fair value option may be elected on an instrument-by-instrument basis and is irrevocable unless a new election date occurs. If the fair value option is elected for an instrument, unrealized gains and losses for that instrument should be reported in earnings at each subsequent reporting date. The Company did not elect to apply the fair value option to any outstanding financial instruments.

Cash and Cash Equivalents and Concentration of Credit Risk

For purposes of the statements of cash flows, the Company considers all highly liquid instruments with a maturity of three months or less at the purchase date and money market accounts to be cash equivalents.

At June 30, 2023 and December 31, 2022, respectively, the Company did not have any cash equivalents.

The Company is exposed to credit risk on its cash and cash equivalents in the event of default by the financial institutions to the extent account balances exceed the amount insured by the FDIC, which is $250,000.

At June 30, 2023 and December 31, 2022, the Company's cash balances exceeded FDIC insured limits by $0 and $256,583, respectively. The Company did not have any losses on cash in excess of the insured FDIC limit.

    Registration No. 333-271439

Inventory

Inventory consists solely of finished goods and is stated at the lower of cost or net realizable value. Specifically, the Company has bottles of vitamin supplements.

Cost is determined using the first-in, first-out (FIFO) method of inventory valuation.

Management assesses the recoverability and establishes reserves of the various inventory components on a quarterly basis and is based on the estimated net realizable values of respective finished inventory.

Slow moving and obsolete inventories are written down based on a comparison of on-hand quantities to historical and projected usages.

Inventory at June 30, 2023 and December 31, 2022 was $46,829 and $0, respectively.

Derivative Liabilities

The Company analyzes all financial instruments with features of both liabilities and equity under FASB ASC Topic No. 480, ("ASC 480"), "Distinguishing Liabilities from Equity" and FASB ASC Topic No. 815, ("ASC 815") "Derivatives and Hedging". Derivative liabilities are adjusted to reflect fair value at each reporting period, with any increase or decrease in the fair value recorded in the results of operations (other income/expense) as a gain or loss on the change in fair value of derivative liabilities. The Company uses a binomial pricing model to determine fair value of these instruments.

Upon conversion or repayment of a debt instrument in exchange for shares of common stock, where the embedded conversion option has been bifurcated and accounted for as a derivative liability (generally convertible debt and warrants), the Company records the shares of common stock at fair value, relieves all related debt, derivatives, and debt discounts, and recognizes a net gain or loss on debt extinguishment.

Equity instruments that are initially classified as equity that become subject to reclassification under ASC Topic 815 are reclassified to liabilities at the fair value of the instrument on the reclassification date.

At June 30, 2023 and December 31, 2022, the Company had no derivative liabilities.

Convertible Notes with Fixed Rate Conversion Options

The Company may enter into convertible notes, some of which may contain fixed rate conversion features, whereby the outstanding principal and accrued interest may be converted, by the holder, into common shares at a fixed discount to the price of the common stock at the time of conversion. The Company measures the fair value of the notes at the time of issuance, which is the result of the share price discount at the time of conversion and records the premium to interest expense on the note issuance date.

    Registration No. 333-271439

Beneficial Conversion Features

For instruments that are not considered liabilities under ASC 480 or ASC 815, the Company applies ASC 470-20 to convertible securities with beneficial conversion features that must be settled in stock. ASC 470-20 requires that the beneficial conversion feature be valued at the commitment date as the difference between the effective conversion price and the fair market value of the common stock (whereby the conversion price is lower than the fair market value) into which the security is convertible, multiplied by the number of shares into which the security is convertible limited to the amount of the loan. This amount is recorded as a debt discount and amortized to interest expense in the Consolidated Statements of Operations.

Debt Discount

For certain notes issued, the Company may provide the debt holder with an original issue discount. The original issue discount is recorded as a debt discount, reducing the face amount of the note, and is amortized to interest expense over the life of the debt, in the Consolidated Statements of Operations.

Debt Issue Cost

Debt issuance cost paid to lenders, or third parties are recorded as debt discounts and amortized to interest expense over the life of the underlying debt instrument, in the Consolidated Statements of Operations.

Research and Development

The Company accounts for research and development costs in accordance with ASC subtopic 730-10, Research and Development ("ASC 730-10").

Under ASC 730-10, all research and development costs must be charged to expense as incurred. Accordingly, internal research and development costs are expensed as incurred. Third-party research and development costs are expensed when the contracted work has been performed or as milestone results have been achieved as defined under the applicable agreement. Company-sponsored research and development costs related to both present and future products are expensed in the period incurred.

The Company incurred research and development expenses of $394,210 and $45,245 for the six months ended June 30, 2023 and 2022, respectively.

Income Taxes

The Company accounts for income tax using the asset and liability method prescribed by ASC 740, "Income Taxes". Under this method, deferred tax assets and liabilities are determined based on the difference between the financial reporting and tax bases of assets and liabilities using enacted tax rates that will be in effect in the year in which the differences are expected to reverse. The Company records a valuation allowance to offset deferred tax assets if based on the weight of available evidence, it is more-likely-than-not that some portion, or all, of the deferred tax assets will not be realized. The effect on deferred taxes of a change in tax rates is recognized as income or loss in the period that includes the enactment date.

    Registration No. 333-271439

The Company follows the accounting guidance for uncertainty in income taxes using the provisions of ASC 740 "Income Taxes". Using that guidance, tax positions initially need to be recognized in the financial statements when it is more likely than not the position will be sustained upon examination by the tax authorities.

As of June 30, 2023 and December 31, 2022, respectively, the Company had no uncertain tax positions that qualify for either recognition or disclosure in the financial statements.

The Company recognizes interest and penalties related to uncertain income tax positions in other expense. No interest and penalties related to uncertain income tax positions were recorded during the six months ended June 30, 2023 and 2022, respectively.

Advertising Costs

Advertising costs are expensed as incurred. Advertising costs are included as a component of general and administrative expense in the statements of operations.

The Company recognized $71,606 and $1,811 in marketing and advertising costs during the six months ended June 30, 2023 and 2022, respectively.

Stock-Based Compensation

The Company accounts for our stock-based compensation under ASC 718 "Compensation - Stock Compensation" using the fair value-based method. Under this method, compensation cost is measured at the grant date based on the value of the award and is recognized over the service period, which is usually the vesting period. This guidance establishes standards for the accounting for transactions in which an entity exchanges it equity instruments for goods or services. It also addresses transactions in which an entity incurs liabilities in exchange for goods or services that are based on the fair value of the entity's equity instruments or that may be settled by the issuance of those equity instruments.

The Company uses the fair value method for equity instruments granted to non-employees and use the Black-Scholes model for measuring the fair value of options.

The fair value of stock-based compensation is determined as of the date of the grant or the date at which the performance of the services is completed (measurement date) and is recognized over the vesting periods.

When determining fair value, the Company considers the following assumptions in the Black-Scholes model:

? Exercise price, ? Expected dividends, ? Expected volatility, ? Risk-free interest rate; and ? Expected life of option

    Registration No. 333-271439

Basic and Diluted Earnings (Loss) per Share

Pursuant to ASC 260-10-45, basic loss per common share is computed by dividing net loss by the weighted average number of shares of common stock outstanding for the periods presented. Diluted loss per share is computed by dividing net loss by the weighted average number of shares of common stock, common stock equivalents and potentially dilutive securities outstanding during the period. Potentially dilutive common shares may consist of common stock issuable upon the conversion of stock options and warrants (using the treasury stock method), convertible preferred stock, convertible notes and contingently issuable shares. These common stock equivalents may be dilutive in the future.

At June 30, 2023 and 2022, respectively, the Company had the following common stock equivalents, which are potentially dilutive equity securities:

    Registration No. 333-271439

Convertible Preferred Stock 700,000,000 100,000,000

Each share of preferred stock (7,000,000 and 1,000,000 shares, respectively) is convertible into 100 shares of common stock.

Related Parties

Parties are considered to be related to the Company if the parties, directly or indirectly, through one or more intermediaries, control, are controlled by, or are under common control with the Company. Related parties also include principal owners of the Company, its management, members of the immediate families of principal owners of the Company and its management and other parties with which the Company may deal with if one party controls or can significantly influence the management or operating policies of the other to an extent that one of the transacting parties might be prevented from fully pursuing its own separate interests.

Recent Accounting Standards

Changes to accounting principles are established by the FASB in the form of Accounting Standards Updates ("ASU's") to the FASB's Codification. We consider the applicability and impact of all ASU's on our financial position, results of operations, stockholders' deficit, cash flows, or presentation thereof. Management has evaluated all recent accounting pronouncements as issued by the FASB in the form of Accounting Standards Updates ("ASU") through the date these financial statements were available to be issued and found the following recent accounting pronouncements issued, but not yet effective accounting pronouncements, are not expected to have a material impact on the financial statements of the Company.

    Registration No. 333-271439

In August 2020, FASB issued ASU 2020-06, Accounting for Convertible Instruments and Contracts in an Entity; Own Equity ("ASU 2020-06"), as part of its overall simplification initiative to reduce costs and complexity of applying accounting standards while maintaining or improving the usefulness of the information provided to users of financial statements. Among other changes, the new guidance removes from GAAP separation models for convertible debt that require the convertible debt to be separated into a debt and equity component, unless the conversion feature is required to be bifurcated and accounted for as a derivative or the debt is issued at a substantial premium. As a result, after adopting the guidance, entities will no longer separately present such embedded conversion features in equity and will instead account for the convertible debt wholly as debt. The new guidance also requires use of the "if-converted" method when calculating the dilutive impact of convertible debt on earnings per share, which is consistent with the Company's current accounting treatment under the current guidance. The guidance is effective for financial statements issued for fiscal years beginning after December 15, 2023, and interim periods within those fiscal years, with early adoption permitted, but only at the beginning of the fiscal year.

This guidance was adopted on January 1, 2023. The adoption of ASU 2020-06 did not have a material impact on the Company's consolidated financial statements.

In March 2022, the Financial Accounting Standards Board (the "FASB") issued ASU 2022-02, Financial Instruments - Credit Losses (Topic 326): Troubled Debt Restructurings and Vintage Disclosures ("ASU 2022-02"), which eliminates the accounting guidance on troubled debt restructurings ("TDRs") for creditors in ASC 310, Receivables (Topic 310), and requires entities to provide disclosures about current period gross write-offs by year of origination. Also, ASU 2022-02 updates the requirements related to accounting for credit losses under ASC 326, Financial Instruments - Credit Losses (Topic 326), and adds enhanced disclosures for creditors with respect to loan refinancings and restructurings for borrowers experiencing financial difficulty. ASU 2022-02 was effective for the Company January 1, 2023. The adoption of ASU 2022-02 did not have a material impact on the Company's consolidated financial statements.

This guidance was adopted on January 1, 2023. The adoption of ASU 2022-02 did not have a material impact on the Company's consolidated financial statements.

Note 3 - Notes Payable and Convertible Notes Payable

Notes Payable-- Net

The Company had the following activity related to its notes payable:

    Registration No. 333-271439

Balance-- December 31, 2021 $ 432,136 Proceeds (face amount of note) 150,000 Original issue debt discount (75,000) Balance-- December 31, 2022 507,136 No activity in 2023 - Balance-- June 30, 2023 $ 507,136

Notes payable are summarized as follows:

Issue Date Maturity Date Interest Rate Collateral June 30, 2023 December 31, 2022

June 2012 January 2024 8 % Unsecured $ 6,240 $ 6,240 May 2014 January 2024 8 % Unsecured 3,456 3,456 June 2016 January 2024 8 % Unsecured 38,216 38,216 January 2017 January 2024 8 % Unsecured 7,344 7,344 November 2020 January 2024 12 % Unsecured 46,480 46,480 March 2021 January 2024 8 % Unsecured 5,400 5,400 November 2021 January 2024 0 % Unsecured 250,000 250,000 February 2022 January 2024 0 % Unsecured 150,000 150,000 $ 507,136 $ 507,136

Modification of Notes Payable

All of the notes listed above were originally due at various dates in 2023. In 2023, the Company extended the maturity dates of these notes listed above to January 2024.

The Company evaluated the modification of terms under ASC 470-50, "Debt-- Modification and Extinguishment", and concluded that the extension of the maturity dates did not result in significant and consequential changes to the economic substance of the debt and thus resulted in a modification of the debt and not extinguishment of the debt. Accordingly, no gain or loss on debt extinguishment was recorded.

Specifically, on the date of modification, the Company determined that the present value of the cash flows of the modified debt instruments were less than 10% different from the present value of the remaining cash flows under the original debt instruments.

Convertible Notes Payable-- Net

The Company had the following activity related to its convertible notes payable:

    Registration No. 333-271439

Balance-- December 31, 2021 $ - Proceeds (face amount of note) 1,307,857 Original issue debt discount (552,857) Debt discount-- beneficial conversion feature (75,000) Amortization of debt discount 138,871 Conversion of accrued interest into convertible notes payable 9,473 Balance-- December 31, 2022 828,344 Proceeds (face amount of note) 100,000 Original issue debt discount (30,000) Amortization of debt discount 372,781 Conversion of debt into common stock (692,858) Balance-- June 30, 2023 $ 578,267

Convertible Notes Payable are summarized as follows:

    Registration No. 333-271439

    Registration No. 333-271439

Note Issued in 2023

In 2023, the Company issued an unsecured, one (1) year, original issue discount convertible note with a face amount of $100,000. This note contained an original issue discount of $30,000, resulting in net proceeds of $70,000.

The total debt discount of $30,000 is being amortized over the life of the convertible note and has been recorded as a component of other income (expense) - net in the accompanying consolidated statements of operations.

This note is convertible at a 20% discount to market upon the effectiveness of the Company's Form S-1 registration statement. This convertible note contains an embedded contingent conversion feature that until the contingency is resolved (declared effectiveness of the S1 registration statement) is not required to be accounted for in accordance with the related accounting guidance. The embedded feature in this convertible note was not accounted for at June 30, 2023 and December 31, 2022, respectively, given the probability of the S1 not becoming effective as determined by the Company.

See below for discussion of inducement expense.

    Registration No. 333-271439

Notes Issued in 2022

During 2022, the Company issued a convertible note payable for $150,000. In connection with the issuance of this note, the Company recorded an original discount of $75,000. Additionally, due to the fixed rate embedded conversion feature, the Company also recorded a beneficial conversion feature of $75,000, resulting in an increase to additional paid in capital. The Company received $75,000 in net proceeds.

The total debt discount of $150,000 is being amortized over the life of the convertible note and has been recorded as a component of other income (expense) - net in the accompanying consolidated statements of operations.

The remaining convertible notes issued in 2022 totaling $1,232,857 contained original issue discounts totaling $477,857, resulting in net proceeds of $755,000. These original issue discounts are being amortized over the life of the notes and have been recorded as a component of other income (expense) - net in the accompanying consolidated statements of operations.

Each of these convertible notes aggregating $1,232,857 are convertible at a 20% discount to market upon the effectiveness of the Company's Form S-1 registration statement. These convertible notes each contain an embedded contingent conversion feature that until the contingency is resolved (declared effectiveness of the S1 registration statement) is not required to be accounted for in accordance with the related accounting guidance. The embedded feature in these convertible notes was not accounted for at December 31, 2022 given the probability of the S1 not becoming effective as determined by the Company.

See below regarding inducement expense.

Modification and Extinguishment of Convertible Notes Payable and Inducement Expense (Year Ended December 31, 2022 and Six Months Ended June 30, 2023)

Year Ended December 31, 2022

Elimination of Conversion Options and Balance Sheet Classification

In April and June 2022, the Company eliminated the conversion options ($0.001 - $0.01/share) associated with all of its then outstanding convertible notes payable, including certain original issue discount notes.

On the date of modification, the Company determined that the present value of the cash flows of the modified debt instruments (including accrued interest) were greater than 10% different from the present value of the remaining cash flows under the original debt instruments. Additionally, the Company determined that the elimination of the conversion options were substantive on the date of modification.

As a result, the Company recorded a gain on debt extinguishment of $44,475 as follows:

    Registration No. 333-271439

Debt--prior to modification $ 151,611 Debt--after modification 107,136 Gain on debt extinguishment $ 44,475

Conversion of Accrued Interest Payable into Notes Payable

$9,473 of accrued interest payable on the convertible notes payable outstanding at the time of modification were added to the existing balance of various notes and carried forward as new notes.

Interest Rate Change

Prior to the modification, the convertible notes payable bore interest ranging from 8% to 15%. In connection with the modification, interest rates ranged from 8% to 12%. There is no default interest rate for any notes or convertible notes issued.

Six Months Ended June 30, 2023

Maturity Date, Note Modification in 2022 and New Note Modification in 2023

Prior to the modification, the convertible notes payable matured on various dates ranging from 2020 and prior through 2022. In connection with the 2022 modification, maturity dates ranged from April 2023 to May 2023. In May 2023, certain of the notes listed above were again extended to January 2024.

The Company evaluated the modification of terms under ASC 470-50, "Debt--Modification and Extinguishment", and concluded that the extension of the maturity date did not result in significant and consequential changes to the economic substance of the debt and thus resulted in a modification of the debt and not extinguishment of the debt. Accordingly, no gain or loss on debt extinguishment was recorded.

Specifically, on the date of modification, the Company determined that the present value of the cash flows of the modified debt instrument was less than 10% different from the present value of the remaining cash flows under the original debt instrument.

In May 2023, as part of the outstanding $1,232,857 in convertible notes payable balance, $692,857 of these notes were converted to 6,298,703 shares of common stock ($0.11/share) (see Note 4 and below regarding inducement).

As a result, $540,000 in convertible notes remained from this initial debt modification (October 2022 - $440,000, and December 2022 - $100,000).

    Registration No. 333-271439

Inducement

In May 2023, the Company added a second conversion feature to certain notes aggregating $342,857. The Company, in addition to allowing conversion at a discount to market pending the effectiveness of their S1 registration statement, allowed these debt holders an option to convert their debt at a fixed rate of $0.11/share.

In adding this substantive conversion option ($0.11/share), the Company determined that an inducement had occurred. Of the $692,857 in debt converted, $342,857 was the amount of debt that received a fixed rate conversion option ($0.11/share), the remaining $350,000 in debt did not receive a fixed rate conversion option, however, was converted at an agreed upon amount of $0.11/share.

The entire $692,857 was converted into 6,298,703 shares of common stock. See Note 4.

The fair value of the Company's common stock on the date of inducement was in excess of the value of the debt converted by $102,857 as follows during the six months ended June 30, 2023:

Fair value of common stock on conversion date $ 445,714 Fair value of debt subject to inducement 342,857 Inducement expense $ 102,857

Note 4 - Stockholders' Deficit

The Company has two (2) classes of stock:

Common Stock

? 1,250,000,000 shares authorized ? $0.001 par value ? Voting at 1 vote per share

Preferred Stock

In May 2022 and December 2022, the Company's Articles of Incorporation, as amended, authorized the issuance of 7,000,000 shares of preferred stock which may be amended from time to time in one or more series. The Board of Directors is authorized to determine, prior to issuing any such series of preferred stock and without any vote or action by the shareholders, the rights, preferences, privileges and restrictions of the shares of such series, including dividend rights, voting rights, terms of redemption, the provisions of any purchase, retirement or sinking fund to be provided for the shares of any series, conversion and exchange rights, the preferences upon any distribution of the assets of the Company, including in the event of voluntary or involuntary liquidation, dissolution or winding up of the Company, and the preferences and relative rights among each series of preferred stock.

    Registration No. 333-271439

The Board of Directors has made the following designations of its preferred stock:

Series A, Convertible Preferred Stock

? 7,000,000 shares authorized. ? $0.001 par value. ? Conversion feature--each share of preferred stock is convertible into 100 shares of common stock. ? Voting--on an as converted basis with common stock, at the applicable conversion rate (100 votes for each share of convertible preferred held). ? Dividends--accrued only upon declaration of the board of directors, at the applicable conversion rate. ? Mandatorily redeemable (automatic conversion) on January 1, 2025. (See below amendment) ? Anti-dilution provision - rights exist for the period of two years after the convertible preferred shares were converted into common stock. Additionally, holders of the convertible preferred stock will have full ratchet anti-dilution protection rights at the rate of 65% calculated on a fully diluted basis. (See below amendment)

In connection with the issuance of these Series A, convertible preferred shares, the Company determined that there were no provisions within ASC 815 that were met, which would require derivative liability accounting treatment. Specifically, as noted below, upon amending the terms of the Series A, convertible preferred stock, at that time, there had been no new stock issuances of any type which may have triggered the anti-dilution provision.

In December 2022, the Company amended its articles of incorporation related to certain terms of its Series A, convertible preferred stock. At that time, the Company, along with approval from its convertible preferred stockholders agreed to remove provisions related to mandatory redemption as well as anti-dilution rights.

At June 30, 2023 and December 31, 2022, the Company had 7,000,000 and 7,000,000 shares issued and outstanding, respectively. See below for related issuances.

    Registration No. 333-271439

Equity Transactions for the Six Months Ended June 30, 2023

Stock Issued for Services

The Company issued 873,334 shares of common stock for services rendered, having a fair value of $222,383 ($0.10 - $0.36/share), based upon the quoted closing trading price.

Stock Issued for License

The Company issued 1,000,000 shares of common stock in exchange for the right to license, manufacture and market nutraceutical products. These shares had a fair value of $370,000 ($0.37/share), based upon the quoted closing trading price. Additionally, the Company was required to pay $0.10/bottle of product sold. In 2023, there were no sales of product.

The Company will expense the issuance of these shares as a component of research and development, since shortly after paying for the license, management concluded that it could not commercialize the technology.

Pursuant to Accounting Standard Codification 350 "Goodwill and Other Intangible Assets" ("ASC 350"), this guidance requires that assets with indefinite lives no longer be amortized, but instead be subject to annual impairment tests.

During the quarter ended March 31, 2023, management qualitatively assessed this intangible (license agreement) to determine whether testing was necessary.

Factors that management considered in this assessment included macroeconomic conditions, industry and market considerations, overall financial performance (both current and projected), changes in management and strategy, and changes in the composition and carrying amounts of net assets. This qualitative assessment indicated that it was more likely than not that the fair value of the reporting unit was less than it's carrying value, a quantitative assessment was then performed. Based on the qualitative analysis conducted during the quarter, management performed a quantitative analysis determining that the asset was not recoverable and would need to be expensed (and not capitalized) on the grant date.

In reaching our conclusion to expense the issuance on the grant date and in accordance with ASC 350-30-35-3, we evaluated pertinent factors in arriving at this estimate including the Company no longer pursuing commercialization of the license.

Ultimately, we concluded that since the intellectual property cannot be commercialized at this time, the expected use of the asset as well as the Company's historical experience (very limited) would not support capitalizing an asset that would have been deemed non recoverable on the acquisition date.

Extinguishment of Convertible Notes Payable and Debt Converted into Common Stock

In May 2023, the Company amended certain original issue discount notes aggregating $342,857 by adding a fixed rate conversion option of $0.11/share (inducement to convert). These notes already contained a conversion feature reflecting a 20% discount to market, pending declaration of effectiveness of their Form S1. The addition of the fixed rate conversion option at $0.11/share was deemed substantive.

    Registration No. 333-271439

On the date of modification, the Company determined that the present value of the cash flows of the modified debt instruments (including unamortized debt discount) were greater than 10% different from the present value of the remaining cash flows under the original debt instruments. The Company determined that the addition of the fixed rate conversion option was substantive on the date of modification.

On the date of the modification, holders of these notes simultaneously converted an aggregate $692,857 into 6,298,703 shares of common stock ($0.11/share). Of the total debt converted to common stock, $342,857 was converted into 3,116,882 shares of common stock (this conversion was related to the inducement of including a fixed rate conversion option of $0.11/share). An additional $350,000 was converted into 3,181,821 shares of common stock (these conversion were at an agreed upon $0.11/share, no fixed rate conversion option had been added to these debt instruments).

Accordingly, no gain or loss was recognized upon debt extinguishment. On the date of debt conversion, the remaining unamortized debt discount associated with these notes was fully amortized, resulting in each of these notes being accreted to their face value at the time of conversion.

See Note 3 for discussion of inducement expense.

Equity Transactions for the Year Ended December 31, 2022

Stock Issued for Cash

The Company issued 6,000,000 shares of Series A, convertible preferred stock for $6,000 ($0.001/share).

Stock Issued for Option to Acquire Common Stock

The Company issued 1,000,000 shares of Series A, convertible preferred stock to an existing stockholder for the right to repurchase 172,159,473 shares of common stock for $122,873. The Company has until December 31, 2023 to exercise this option. At this time, the Company does not expect to exercise the option.

The Company recorded an expense of $1,000 ($0.001/share), based upon recent cash offerings of preferred stock with third parties. The expense has been included as a component of general and administrative expenses on the accompanying statements of operations.

Stock Issued for Services

The Company issued 2,450,000 shares of common stock for services rendered, having a fair value of $91,500 ($0.026 - $0.23/share), based upon the quoted closing trading price.

Stock Issued for Services - Related Party

The Company issued 200,000 shares of common stock to its Chief Executive Officer for services rendered, having a fair value of $5,200 ($0.026/share), based upon the quoted closing trading price of its common stock.

    Registration No. 333-271439

Acquisition of Designer Genomics, Inc. (Asset Purchase)

On July 1, 2022, the Company acquired the assets of Designer Genomics International, Inc. ("DGI") a start-up entity) in exchange for 1,000,000 shares of common stock, having a fair value of $18,000 ($0.018/share), based upon the quoted closing trading price.

The assets of DGI consisted solely of the technological know-how of its owners. The Company was a dormant inactive entity at the time of asset purchase. The Company has recorded $18,000 as research and development expense in the accompanying consolidated statements of operations.

Pursuant to ASU 2017-01, Business Combinations (Topic 805): "Clarifying the Definition of a Business", this acquisition was determined to be that of an asset and not a business, therefore, there was not a business combination requiring acquisition accounting or related financial reporting. Since this was deemed to be an asset purchase, this did not result in the recognition of goodwill or other identifiable intangible assets.

Cancellation of Common Stock

The Company cancelled 100,000 shares of common stock at par value. The net effect on stockholders' deficit was $0. These shares were originally issued in 2019 for a research and development project that was never completed.

Beneficial Conversion Feature

The Company recorded a beneficial conversion feature of $75,000 in connection with the issuance of a convertible note payable resulting in an increase to additional paid in capital.

See Note 3.

Note 5 - Subsequent Events

Common Stock Repurchase Agreement and Note Payable

Subsequent to June 30, 2023, the Company repurchased 171,162,746 shares of common stock in exchange for a note totaling $122,873. The note bears interest at 8% and is unsecured. The note is due on the earlier of (a) $500,000 in proceeds from the Company's S-1 offering and (b) August 31, 2024.

    Registration No. 333-271439

    Registration No. 333-271439

To the Board of Directors and Of Ludwig Enterprises Inc.

Opinion on the Financial Statements

We have audited the accompanying consolidated balance sheets of Ludwig Enterprises, Inc. and Subsidiaries (the Company) as of December 31, 2022 and 2021, and the related statements of operations, changes in stockholders' deficit and cash flows for each of the two years in the period ended December 31, 2022, and the related notes (collectively referred to as the financial statements). In our opinion, the consolidated financial statements present fairly, in all material respects, the financial position of the Company as of December 31, 2022 and 2021 and the results of its operations and its cash flows for each of the years in the two year period ended December 31, 2022, in conformity with accounting principles generally accepted in the United States of America.

Basis for Opinion

These financial statements are the responsibility of the Company's management. Our responsibility is to express an opinion on the Company's consolidated financial statements based on our audit. We are a public accounting firm registered with the Public Company Accounting Oversight Board (United States) (PCAOB) and are required to be independent with respect to the Company in accordance with the U.S. federal securities laws and the applicable rules and regulations of the Securities and Exchange Commission and the PCAOB.

We conducted our audits in accordance with the standards of the PCAOB. Those standards require that we plan and perform the audit to obtain reasonable assurance about whether the financial statements are free of material misstatement, whether due to error or fraud. The Company is not required to have, nor were we engaged to perform, an audit of its internal control over financial reporting. As part of our audits, we are required to obtain an understanding of internal control over financial reporting, but not for the purpose of expressing an opinion on the effectiveness of the Company's internal control over financial reporting. Accordingly, we express no such opinion.

Our audits included performing procedures to assess the risks of material misstatement of the financial statements, whether due to error or fraud, and performing procedures that respond to those risks. Such procedures included examining, on a test basis, evidence regarding the amounts and disclosures in the financial statements. Our audits also included evaluating the accounting principles used and significant estimates made by management, as well as evaluating the overall presentation of the financial statements. We believe that our audits provide a reasonable basis for our opinion.

Critical Audit Matters

The critical audit matters are matters arising from the current period audit of the financial statements that are required to be communicated to the audit committee and that: (1) relate to accounts or disclosures that are material to the financial statements and (2) involved our especially challenging, subjective, or complex judgments. The communication of critical audit matters does not alter in any way our opinion on the financial statements, taken as a whole, and we are not, by communicating the critical audit matters below, providing separate opinions on the critical audit matters or on the accounts or disclosures to which they relate.

We did not identify any critical audit matters that need to be communicated.

[[Image Removed]] We have served as the Company's auditor since 2022.

Margate, Florida April 14, 2023

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

Current Assets Cash $ 516,195 $ 125,000 Total Current Assets 516,195 125,000

Total Assets $ 516,195 $ 125,000

Liabilities and Stockholder'' Deficit

Current Liabilities Accounts payable and accrued expenses $ 6,882 $ 46,762 Notes payable--net 507,136 - Convertible notes payable--net 828,344 135,955 Total Current Liabilities 1,342,362 182,717

Stockholder'' Deficit Preferred stock - $0.001 par value; convertible, 7,000,000 shares authorized; 7,000,000 and 0 shares issued and outstanding, repsectively 7,000 - Common stock - $0.001 par value, 1,250,000,000 shares authorized 315,188,929 and 311,838,929 shares issued and outstanding, respectively 315,188 311,838 Common stock issuable (200,000 and 0 shares, respectively, at $0.001 par value) 33,000 - Additional paid-in capital 604,577 451,227 Accumulated deficit (1,785,932) (820,782) Total Stockholder'' Deficit (826,167) (57,717)

Total Liabilities and Stockholder'' Deficit $ 516,195 $ 125,000

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

Operating expenses Research and development $ 447,260 $ 45,723 General and administrative expenses 113,245 - Total operating expenses 560,505 45,723

Loss from operations (560,505) (45,723)

Other income (expense) Amortization of debt discount (435,052) (79,792) Interest expense (14,068) (11,952) Gain on debt extinguishment 44,475 Total other income (expense) - net (404,645) (91,744)

Net loss $ (965,150) $ (137,467)

Loss per share--basic and diluted $ (0.00) $ (0.00)

Weighted average number of shares--basic and diluted 313,736,463 331,209,483

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

December 31, 2021 - $ - 311,838,929 $ 311,838 - $ - $ 451,227 $ (820,782) $ (57,717)

Stock issued for cash 6,000,000 6,000 - - - - - - 6,000

Stock issued for option to acquire common stock 1,000,000 1,000 - - - - - - 1,000

Stock issued for services - - 2,250,000 2,250 200,000 33,000 56,250 - 91,500

Stock issued for services-- related party - - 200,000 200 - - 5,000 - 5,200

Stock issued for asset purchase - - 1,000,000 1,000 - - 17,000 - 18,000

Cancellation of common stock - - (100,000) (100) - - 100 - -

Debt discount-- beneficial conversion feature - - - - - - 75,000 - 75,000

Net loss - - - - - - - (965,150) (965,150)

December 31, 2022 7,000,000 $ 7,000 315,188,929 $ 315,188 200,000 $ 33,000 $ 604,577 $ (1,785,932) $ (826,167)

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

December 31, 2020 - $ - 335,891,762 $ 335,891 $ 180,500 $ (683,315) $ (166,924)

Conversion of notes payable into common stock - - 8,047,167 8,047 72,127 - 80,174

Cancellation of common stock - - (32,100,000) (32,100) 32,100 - -

Debt discount-- beneficial conversion feature - - - - 166,500 - 166,500

Net loss - - - - - (137,467) (137,467)

December 31, 2021 - $ - 311,838,929 $ 311,838 $ 451,227 $ (820,782) $ (57,717)

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

Operating activities Net loss $ (965,150) $ (137,467) Adjustments to reconcile net loss to net cash used in operations Stock issued for services 91,500 - Stock issued for services--related party 5,200 - Stock issued for option to acquire common stock 1,000 - Stock issued for asset purchase 18,000 - Amortization of debt discount 435,052 79,792 Gain on debt extinguishment (44,475) - Changes in operating assets and liabilities Increase (decrease) in Accounts payable and accrued expenses 14,068 11,952 Net cash used in operating activities (444,805) (45,723)

Financing activities Proceeds from preferred stock issued for cash 6,000 - Proceeds from convertible notes payable--net 830,000 166,500 Net cash provided by financing activities 836,000 166,500

Net increase in cash 391,195 120,777

Cash--beginning of year 125,000 4,223

Cash--end of year $ 516,195 $ 125,000

Supplemental disclosure of cash flow information Cash paid for interest $ - $ 9,364 Cash paid for income tax $ - $ -

Supplemental disclosure of non-cash investing and financing activities Cancellation of common stock $ 100 $ 3,210 Conversion of accrued interest into convertible notes payable $ 9,473 $ 80,174 Original issuance debt discount $ 552,857 $ 125,000 Debt discount--beneficial conversion feature $ 75,000 $ 166,500 Reclassification from convertible notes to notes payable $ 507,136 $ - Conversion of notes payable and accrued interest payable into common stock $ - $ 80,174

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

Note 1-- Organization and Nature of Operations

Organization and Nature of Operations

Ludwig Enterprises, Inc. (collectively, "we," "us," "our" or the "Company"), a Nevada Corporation (incorporated February 2006).

The Company is currently seeking to develop products and services through the use of cutting-edge technologies in the health care industry.

Formation of Subsidiaries

On May 18, 2022, the Company formed mRNA for Life, Inc. ("mRNA"), a Wyoming corporation, which is a wholly-owned subsidiary of the Company. mRNA is expected to produce supplements to address clinical diagnoses from mRNA cheek swabs.

On November 18, 2022, the Company formed Precision Genomics, Inc. ("PGI"), a Wyoming corporation, which is a wholly-owned subsidiary of the Company. PGI will be developing proprietary medical artificial intelligence ("AI") technology that uses mRNA inflammatory language to potentially capture an inflammatory snapshot of disease and the body's response to treatment.

Liquidity, Going Concern and Management's Plans

These financial statements have been prepared on a going concern basis, which contemplates the realization of assets and the settlement of liabilities and commitments in the normal course of business.

As reflected in the accompanying financial statements, for the year ended December 31, 2022, the Company had:

? Net loss of $965,150; and

? Net cash used in operations was $444,805

Additionally, at December 31. 2022, the Company had:

? Accumulated deficit of $1,785,932

? Stockholders' deficit of $826,167; and

? Working capital deficit of $826,167

The Company has cash on hand of $516,195 at December 31, 2022. The Company does not expect to generate sufficient revenues and positive cash flows from operations to meet its current obligations. However, the Company may seek to raise debt or equity-based capital at favorable terms, though such terms are not certain.

These factors create substantial doubt about the Company's ability to continue as a going concern within the twelve-month period subsequent to the date that these financial statements are issued.

The consolidated financial statements do not include any adjustments that might be necessary if the Company is unable to continue as a going concern. Accordingly, the financial statements have been prepared on a basis that assumes the Company will continue as a going concern and which contemplates the realization of assets and satisfaction of liabilities and commitments in the ordinary course of business.

Management's strategic plans include the following:

? Execute business operations more fully during the year ended December 31, 2023,

- Seek out strategic acquisitions of health care technology; and

- Explore prospective partnership opportunities

    Registration No. 333-271439

Note 2-- Summary of Significant Accounting Policies

Basis of Presentation

The accompanying consolidated financial statements have been prepared in accordance with accounting principles generally accepted in the United States of America ("U.S. GAAP").

Principles of Consolidation

These consolidated financial statements have been prepared in accordance with U.S. GAAP and include the accounts of the Company and its wholly owned subsidiary mRNA. All intercompany transactions and balances have been eliminated.

Business Segments

The Company uses the "management approach" to identify its reportable segments. The management approach requires companies to report segment financial information consistent with information used by management for making operating decisions and assessing performance as the basis for identifying the Company's reportable segments. The Company has identified one single reportable operating segment. The Company manages its business on the basis of one operating and reportable segment.

Use of Estimates

Preparing financial statements in conformity with U.S. GAAP requires management to make estimates and assumptions that affect the reported amounts of assets and liabilities and the disclosure of contingent assets and liabilities at the date of the financial statements and revenues and expenses during the reported period. Actual results could differ from those estimates, and those estimates may be material.

Changes in estimates are recorded in the period in which they become known. The Company bases its estimates on historical experience and other assumptions, which include both quantitative and qualitative assessments that it believes to be reasonable under the circumstances.

Significant estimates during the years ended December 31, 2022 and 2021 include valuation of stock-based compensation, uncertain tax positions, and the valuation allowance on deferred tax assets.

Fair Value of Financial Instruments

The Company accounts for financial instruments under Financial Accounting Standards Board ("FASB") ASC 820, Fair Value Measurements. ASC 820 provides a framework for measuring fair value and requires disclosures regarding fair value measurements. Fair value is defined as the price that would be received to sell an asset or paid to transfer a liability in an orderly transaction between market participants at the measurement date, based on the Company's principal or, in absence of a principal, most advantageous market for the specific asset or liability.

The Company uses a three-tier fair value hierarchy to classify and disclose all assets and liabilities measured at fair value on a recurring basis, as well as assets and liabilities measured at fair value on a non-recurring basis, in periods subsequent to their initial measurement. The hierarchy requires the Company to use observable inputs when available, and to minimize the use of unobservable inputs, when determining fair value.

The three tiers are defined as follows:

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

The determination of fair value and the assessment of a measurement's placement within the hierarchy requires judgment. Level 3 valuations often involve a higher degree of judgment and complexity. Level 3 valuations may require the use of various cost, market, or income valuation methodologies applied to unobservable management estimates and assumptions. Management's assumptions could vary depending on the asset or liability valued and the valuation method used. Such assumptions could include estimates of prices, earnings, costs, actions of market participants, market factors, or the weighting of various valuation methods. The Company may also engage external advisors to assist us in determining fair value, as appropriate.

Although the Company believes that the recorded fair value of our financial instruments is appropriate, these fair values may not be indicative of net realizable value or reflective of future fair values.

The Company's financial instruments are carried at historical cost. At December 31, 2022 and 2021, respectively, the carrying amounts of these instruments approximated their fair values because of the short-term nature of these instruments.

ASC 825-10 "Financial Instruments" allows entities to voluntarily choose to measure certain financial assets and liabilities at fair value ("fair value option"). The fair value option may be elected on an instrument-by-instrument basis and is irrevocable unless a new election date occurs. If the fair value option is elected for an instrument, unrealized gains and losses for that instrument should be reported in earnings at each subsequent reporting date. The Company did not elect to apply the fair value option to any outstanding financial instruments.

Cash and Cash Equivalents and Concentration of Credit Risk

For purposes of the statements of cash flows, the Company considers all highly liquid instruments with a maturity of three months or less at the purchase date and money market accounts to be cash equivalents.

At December 31, 2022 and 2021, respectively, the Company did not have any cash equivalents.

The Company is exposed to credit risk on its cash and cash equivalents in the event of default by the financial institutions to the extent account balances exceed the amount insured by the FDIC, which is $250,000.

At December 31, 2022 and 2021, the Company's cash balances exceeded FDIC insured limits by $256,583 and $0, respectively. The Company did not have any losses on cash in excess of the insured FDIC limit.

Derivative Liabilities

The Company analyzes all financial instruments with features of both liabilities and equity under FASB ASC Topic No. 480, ("ASC 480"), "Distinguishing Liabilities from Equity" and FASB ASC Topic No. 815, ("ASC 815") "Derivatives and Hedging". Derivative liabilities are adjusted to reflect fair value at each reporting period, with any increase or decrease in the fair value recorded in the results of operations (other income/expense) as change in fair value of derivative liabilities. The Company uses a binomial pricing model to determine fair value of these instruments.

Upon conversion or repayment of a debt instrument in exchange for shares of common stock, where the embedded conversion option has been bifurcated and accounted for as a derivative liability (generally convertible debt and warrants), the Company records the shares of common stock at fair value, relieves all related debt, derivatives, and debt discounts, and recognizes a net gain or loss on debt extinguishment.

Equity instruments that are initially classified as equity that become subject to reclassification under ASC Topic 815 are reclassified to liabilities at the fair value of the instrument on the reclassification date.

At December 31, 2022 and 2021, the Company had no derivative liabilities.

Convertible Notes with Fixed Rate Conversion Options

The Company may enter into convertible notes, some of which may contain fixed rate conversion features, whereby the outstanding principal and accrued interest may be converted, by the holder, into common shares at a fixed discount to the price of the common stock at the time of conversion. The Company measures the fair value of the notes at the time of issuance, which is the result of the share price discount at the time of conversion and records the premium to interest expense on the note issuance date.

Beneficial Conversion Features

For instruments that are not considered liabilities under ASC 480 or ASC 815, the Company applies ASC 470-20 to convertible securities with beneficial conversion features that must be settled in stock. ASC 470-20 requires that the beneficial conversion feature be valued at the commitment date as the difference between the effective conversion price and the fair market value of the common stock (whereby the conversion price is lower than the fair market value) into which the security is convertible, multiplied by the number of shares into which the security is convertible limited to the amount of the loan. This amount is recorded as a debt discount and amortized to interest expense in the Consolidated Statements of Operations.

    Registration No. 333-271439

Debt Discount

For certain notes issued, the Company may provide the debt holder with an original issue discount. The original issue discount is recorded as a debt discount, reducing the face amount of the note, and is amortized to interest expense over the life of the debt, in the Consolidated Statements of Operations.

Debt Issue Cost

Debt issuance cost paid to lenders, or third parties are recorded as debt discounts and amortized to interest expense over the life of the underlying debt instrument, in the Consolidated Statements of Operations.

Research and Development

The Company accounts for research and development costs in accordance with ASC subtopic 730-10, Research and Development ("ASC 730-10").

Under ASC 730-10, all research and development costs must be charged to expense as incurred. Accordingly, internal research and development costs are expensed as incurred. Third-party research and development costs are expensed when the contracted work has been performed or as milestone results have been achieved as defined under the applicable agreement. Company-sponsored research and development costs related to both present and future products are expensed in the period incurred.

The Company incurred research and development expenses of $113,245 and $0 for the years ended December 31, 2022 and 2021, respectively.

Income Taxes

The Company accounts for income tax using the asset and liability method prescribed by ASC 740, "Income Taxes". Under this method, deferred tax assets and liabilities are determined based on the difference between the financial reporting and tax bases of assets and liabilities using enacted tax rates that will be in effect in the year in which the differences are expected to reverse. The Company records a valuation allowance to offset deferred tax assets if based on the weight of available evidence, it is more-likely-than-not that some portion, or all, of the deferred tax assets will not be realized. The effect on deferred taxes of a change in tax rates is recognized as income or loss in the period that includes the enactment date.

The Company follows the accountin" gui'ance for uncertainty in income taxes using the provisions of ASC 740 "Income Taxes". Using that guidance, tax positions initially need to be recognized in the financial statements when it is more likely than not the position will be sustained upon examination by the tax authorities.

As of December 31, 2022 and 2021, respectively, the Company had no uncertain tax positions that qualify for either recognition or disclosure in the financial statements.

The Company recognizes interest and penalties related to uncertain income tax positions in other expense. No interest and penalties related to uncertain income tax positions were recorded during the years ended December 31, 2022 and 2021, respectively.

Advertising Costs

Advertising costs are expensed as incurred. Advertising costs are included as a component of general and administrative expense in the statements of operations.

The Company recognized $79,931 and $0 in marketing and advertising costs during the years ended December 31, 2022 and 2021, respectively.

Stock-Based Compensation

The Company accounts for our stock-based compensation under ASC 718 "Compensation - Stock Compensation" using the fair value-based method. Under this method, compensation cost is measured at the grant date based on the value of the award and is recognized over the service period, which is usually the vesting period. This guidance establishes standards for the accounting for transactions in which an entity exchanges it equity instruments for goods or services. It also addresses transactions in which an entity incurs liabilities in exchange for goods or services that are based on the fair value of the entity's equity instruments or that may be settled by the issuance of those equity instruments.

The Company uses the fair value method for equity instruments granted to non-employees and use the Black-Scholes model for measuring the fair value of options.

The fair value of stock-based compensation is determined as of the date of the grant or the date at which the performance of the services is completed (measurement date) and is recognized over the vesting periods.

When determining fair value, the Company considers the following assumptions in the Black-Scholes model:

? Exercise price,

? Expected dividends,

? Expected volatility,

? Risk-free interest rate; and

? Expected life of option

    Registration No. 333-271439

Basic and Diluted Earnings (Loss) per Share

Pursuant to ASC 260-10-45, basic loss per common share is computed by dividing net loss by the weighted average number of shares of common stock outstanding for the periods presented. Diluted loss per share is computed by dividing net loss by the weighted average number of shares of common stock, common stock equivalents and potentially dilutive securities outstanding during the period. Potentially dilutive common shares may consist of common stock issuable for stock options and warrants (using the treasury stock method), convertible preferred stock, convertible notes and common stock issuable. These common stock equivalents may be dilutive in the future.

At December 31, 2022 and 2021, respectively, the Company had the following common stock equivalents, which are potentially dilutive equity securities:

    Registration No. 333-271439

Convertible Preferred Stock 700,000,000 -

Each share of preferred stock (7,000,000 and 0 shares, respectively) is convertible into 100 shares of common stock.

Related Parties

Parties are considered to be related to the Company if the parties, directly or indirectly, through one or more intermediaries, control, are controlled by, or are under common control with the Company. Related parties also include principal owners of the Company, its management, members of the immediate families of principal owners of the Company and its management and other parties with which the Company may deal with if one party controls or can significantly influence the management or operating policies of the other to an extent that one of the transacting parties might be prevented from fully pursuing its own separate interests.

Recent Accounting Standards

Changes to accounting principles are established by the FASB in the form of Accounting Standards Updates ("ASU's") to the FASB's Codification. We consider the applicability and impact of all ASU's on our financial position, results of operations, stockholders' deficit, cash flows, or presentation thereof. Management has evaluated all recent accounting pronouncements as issued by the FASB in the form of Accounting Standards Updates ("ASU") through the date these financial statements were available to be issued and found the following recent accounting pronouncements issued, but not yet effective accounting pronouncements, are not expected to have a material impact on the financial statements of the Company.

In August 2020, FASB issued ASU 2020-06, Accounting for Convertible Instruments and Contracts in an Entity; Own Equity ("ASU 2020-06"), as part of its overall simplification initiative to reduce costs and complexity of applying accounting standards while maintaining or improving the usefulness of the information provided to users of financial statements. Among other changes, the new guidance removes from GAAP separation models for convertible debt that require the convertible debt to be separated into a debt and equity component, unless the conversion feature is required to be bifurcated and accounted for as a derivative or the debt is issued at a substantial premium. As a result, after adopting the guidance, entities will no longer separately present such embedded conversion features in equity and will instead account for the convertible debt wholly as debt. The new guidance also requires use of the "if-converted" method when calculating the dilutive impact of convertible debt on earnings per share, which is consistent with the Company's current accounting treatment under the current guidance. The guidance is effective for financial statements issued for fiscal years beginning after December 15, 2023, and interim periods within those fiscal years, with early adoption permitted, but only at the beginning of the fiscal year.

We do not expect the adoption of this pronouncement will have a material effect on the Company's financial statements.

Note 3 - Notes Payable and Convertible Notes Payable

Notes payable and Convertible Notes Payable are summarized as follows:

Maturity Date Interest Rate December 31,2022 December 31, 2021 April 2023 8% - 12% $ 53,824 $ 45,300 May 2033 8% 53,312 49,363 August 2023 0% 150,000 - September 2023 0% 790,000 250,000 November 2023 0% 692,858 - 1,739,994 347,663 Less: unamortized debt discount (404,514) (211,709) $ 1,335,480 $ 135,954

    Registration No. 333-271439

Notes payable are detailed as follows:

    Registration No. 333-271439

    Registration No. 333-271439

Balance--December 31, 2020 $ 121,163 $ - $ 121,163 Proceeds (face amount of note) - 291,500 291,500 Original issue debt discount - (125,000) (125,000) Debt discount--beneficial conversion feature - (166,500) (166,500) Amortization of debt discount - 79,792 79,792 Conversion of notes payable to common stock - (65,000) (65,000) Balance--December 31, 2021 $ 121,163 $ 14,792 $ 135,955 Proceeds (face amount of note) - 150,000 150,000 Original issue debt discount - (75,000) (75,000) Amortization of debt discount - 296,181 296,181 Balance--December 31, 2022 $ 121,163 $ 385,973 $ 507,136

* See Note 4 regarding conversion of debt to equity.

Convertible Notes Payable are detailed as follows:

    Registration No. 333-271439

Issuance dates of notes February-- December 2022 Maturity date November 2022--November 2023 Interest rate Unsecured Collateral See below Conversion rate

Balance--December 31, 2021 $ - Proceeds (face amount of note) 1,307,857 Original issue debt discount (552,857) Debt discount--beneficial conversion feature (75,000) Amortization of debt discount 138,871 Conversion of notes payable to common stock 9,473 Balance--December 31, 2022 $ 828,344

    Registration No. 333-271439

Notes Issued in 2022

During 2022, the Company issued a convertible note payable for $150,000. In connection with the issuance of this note, the Company recorded an original discount of $75,000. Additionally, due to the fixed rate embedded conversion feature, the Company also recorded a beneficial conversion feature of $75,000, resulting in an increase to additional paid in capital. The Company received $75,000 in net proceeds.

The total debt discount of $150,000 is being amortized over the life of the convertible note and has been recorded as a component of other income (expense) - net in the accompanying consolidated statements of operations.

The remaining convertible notes issued in 2022 totaling $1,232,857 contained original issue discounts totaling $477,857, resulting in net proceeds of $755,000. These original issue discounts are being amortized over the life of the notes and have been recorded as a component of other income (expense) - net in the accompanying consolidated statements of operations.

Each of these convertible notes aggregating $1,232,857 are convertible at a 20% discount to market upon the effectiveness of the Company's Form S-1 registration statement. These convertible notes each contain an embedded contingent conversion feature that until the contingency is resolved (declared effectiveness of the S1 registration statement) is not required to be accounted for in accordance with the related accounting guidance. The embedded feature in these convertible notes was not accounted for at December 31, 2022.

Notes Issued in 2021

During 2021, the Company issued convertible notes payable totaling $291,500. In connection with the issuance of these notes, the Company recorded an original discount of $125,000. Additionally, due to the fixed rate embedded conversion feature, the Company also recorded a beneficial conversion feature of $166,500, resulting in an increase to additional paid in capital.

The total debt discount of $291,500 is being amortized over the life of the convertible notes and has been recorded as a component of other expenses in the accompanying statements of operations.

For the years ended December 31, 2022 and 2021, the Company recorded amortization of debt discount of $435,052 and $79,792, respectively.

Modification and Extinguishment of Convertible Notes Payable (Year Ended December 31, 2022)

Elimination of Conversion Options and Balance Sheet Classification

In April and June 2022, the Company eliminated the conversion options ($0.001 - $0.01/share) associated with all of its then outstanding convertible notes payable, including certain original issue discount notes.

On the date of modification, the Company determined that the present value of the cash flows of the modified debt instruments (including accrued interest) were greater than 10% different from the present value of the remaining cash flows under the original debt instruments. Additionally, the Company determined that the elimination of the conversion options were substantive on the date of modification.

As a result, the Company recorded a gain on debt extinguishment of $44,475 as follows:

Debt--prior to modjfication $ 151,611 Debt--after modification 107,136 Gain on debt extinguishment $ 44,475

All classification terminology on the accompanying balance sheets for these notes was changed from convertible notes payable-- net to notes payable - net for 2022, whereas the classification of convertible notes payable - net was reflected for the year ended December 31, 2021 since at that time, these notes had an effective conversion option.

All notes issued subsequent to the modifications are classified as convertible notes in the accompanying consolidated balance sheets.

Conversion of Accrued Interest Payable into Notes Payable

$9,473 of accrued interest payable on the convertible notes payable outstanding at the time of modification were added to the existing balance of various notes and carried forward as new notes.

    Registration No. 333-271439

Interest Rate

Prior to the modification, the convertible notes payable bore interest ranging from 8% to 15%. In connection with the modification, interest rates ranged from 8% to 12%.

There is no default interest rate for any notes or convertible notes issued.

Maturity Date

Prior to the modification, the convertible notes payable matured on various dates ranging from 2020 and prior through 2022. In connection with the modification, maturity dates ranged from April 2023 to May 2023.

Note 4 - Stockholders' Deficit

The Company has two (2) classes of stock:

Common Stock

- 1,250,000,000 shares authorized

- $0.001 par value

- Voting at 1 vote per share

Preferred Stock

In May 2022 and December 2022, the Company's Articles of Incorporation, as amended, authorized the issuance of 7,000,000 shares of preferred stock which may be amended from time to time in one or more series. The Board of Directors is authorized to determine, prior to issuing any such series of preferred stock and without any vote or action by the shareholders, the rights, preferences, privileges and restrictions of the shares of such series, including dividend rights, voting rights, terms of redemption, the provisions of any purchase, retirement or sinking fund to be provided for the shares of any series, conversion and exchange rights, the preferences upon any distribution of the assets of the Company, including in the event of voluntary or involuntary liquidation, dissolution or winding up of the Company, and the preferences and relative rights among each series of preferred stock.

The Board of Directors has made the following designations of its preferred stock.

Series A, Convertible Preferred Stock

- 7,000,000 shares authorized.

- $0.001 par value.

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

In connection with the issuance of these Series A, convertible preferred shares, the Company determined that there were no provisions within ASC 815 that were met, which would require derivative liability accounting treatment. Specifically, as noted below, upon amending the terms of the Series A, convertible preferred stock, at that time, there had been no new stock issuances of any type which may have triggered the anti-dilution provision.

In December 2022, the Company amended its articles of incorporation related to certain terms of its Series A, convertible preferred stock. At that time, the Company, along with approval from its convertible preferred stockholders agreed to remove provisions related to mandatory redemption as well as anti-dilution rights.

At December 31, 2022 and 2021, the Company had 7,000,000 and 0 shares issued and outstanding, respectively. See below for related issuances.

    Registration No. 333-271439

Equity Transactions for the Year Ended December 31, 2022

Stock Issued for Cash

The Company issued 6,000,000 shares of Series A, convertible preferred stock for $6,000 ($0.001/share).

Stock Issued for Option to Acquire Common Stock

The Company issued 1,000,000 shares of Series A, convertible preferred stock to an existing stockholder for the right to repurchase 172,159,473 shares of common stock for $122,873. The Company has until December 31, 2023 to exercise this option. At this time, the Company does not expect to exercise the option.

The Company recorded an expense of $1,000 ($0.001/share), based upon recent cash offerings of preferred stock with third parties. The expense has been included as a component of general and administrative expenses on the accompanying statements of operations.

Stock Issued for Services

The Company issued 2,450,000 shares of common stock for services rendered, having a fair value of $91,500 ($0.026 - $0.23/share), based upon the quoted closing trading price.

Stock Issued for Services - Related Party

The Company issued 200,000 shares of common stock to its Chief Executive Officer for services rendered, having a fair value of $5,200 ($0.026/share), based upon the quoted closing trading price of its common stock.

Acquisition of Designer Genomics International Corporation (Asset Purchase)

On July 1, 2022, the Company acquired the assets of Designer Genomics International Corporation ("DGI") (a start-up entity) in exchange for 1,000,000 shares of common stock, having a fair value of $18,000 ($0.018/share), based upon the quoted closing trading price.

The assets of DGI consisted solely of the technological know-how of its owners. The Company was a dormant inactive entity at the time of asset purchase. The Company has recorded $18,000 as research and development expense in the accompanying consolidated statements of operations.

Pursuant to ASU 2017-01, Business Combinations (Topic 805): "Clarifying the Definition of a Business", this acquisition was determined to be that of an asset and not a business, therefore, there was not a business combination requiring acquisition accounting or related financial reporting. Since this was deemed to be an asset purchase, this did not result in the recognition of goodwill or other identifiable intangible assets.

Cancellation of Common Stock

The Company cancelled 100,000 shares of common stock at par value. The net effect on stockholders' deficit was $0. These shares were originally issued in 2019 for a research and development project that was never completed.

Beneficial Conversion Feature

The Company recorded a beneficial conversion feature of $75,000 in connection with the issuance of a convertible note payable resulting in an increase to additional paid in capital. See Note 3.

Equity Transactions for the Year Ended December 31, 2021

Conversion of Notes Payable into Common Stock

The Company issued 8,047,167 shares of common stock in exchange for notes and related accrued interest of $80,174 ($0.01/share). Of the total, $65,000 was note principal and $15,174 was related accrued interest payable. Accordingly, there was no gain or loss on debt extinguishment.

    Registration No. 333-271439

Cancellation of Common Stock

The Company cancelled 31,850,000 shares of common stock at par value. The net effect on stockholders' deficit was $0. These shares were originally issued in 2019 for a research and development project that was never completed. The Company also returned shares it had received in the initial transaction.

Beneficial Conversion Feature

The Company recorded a beneficial conversion feature of $75,000 in connection with the issuance of a convertible note payable resulting in an increase to additional paid in capital.

Note 5 - Income Taxes

The Compan''s tax expense differs from the""expecte"" tax expense for the period (computed by applying the blended corporate and state tax rates of 24.52% to loss before taxes), are approximately as follows:

    Registration No. 333-271439

The tax effects of temporary differences that give rise to significant portions of deferred tax

assets and liabilities at December 31, 2022 and 2021 are approximately as follows:

    Registration No. 333-271439

Deferred tax assets and liabilities are computed by applying the federal and state income tax rates in effect to the gross amounts of temporary differences and other tax attributes, such as net operating loss carryforwards. In assessing if the deferred tax assets will be realized, the Company considers whether it is more likely than not that some or all of these deferred tax assets will be realized. The ultimate realization of deferred tax assets is dependent upon the generation of future taxable income during the period in which these deductible temporary differences reverse.

During the year ended December 31, 2022, the valuation allowance increased by approximately $207,000. The total valuation allowance results from the Company's estimate of its uncertainty in being unable to recover its net deferred tax assets.

At December 31, 2022, the Company has federal net operating loss carryforwards, which are available to offset future taxable income, of approximately $1,200,000. The Company is in the process of analyzing their NOL and has not determined if the Company has had any change of control issues that could limit the future use of these NOL's.

NOL carryforwards that were generated after 2017 of approximately $1,200,000 may only be used to offset 80% of taxable income and are carried forward indefinitely.

    Registration No. 333-271439

These carryforwards may be subject to an annual limitation under Section 382 and 383 of the Internal Revenue Code of 1986, and similar state provisions if the Company experienced one or more ownership changes which would limit the amount of NOL and tax credit carryforwards that can be utilized to offset future taxable income and tax, respectively. In general, an ownership change, as defined by Section 382 and 383, results from transactions increasing ownership of certain stockholders or public groups in the stock of the corporation by more than 50 percentage points over a three- year period. The Company has not completed an IRC Section 382/383 analysis. If a change in ownership were to have occurred, NOL and tax credit carryforwards could be eliminated or restricted.

If eliminated, the related asset would be removed from the deferred tax asset schedule with a corresponding reduction in the valuation allowance. Due to the existence of the valuation allowance, limitations created by future ownership changes, if any, will not impact the Company's effective tax rate.

The Company files corporate income tax returns in the United States and Florida jurisdictions. Due to the Company's net operating loss posture, all tax years are open and subject to income tax examination by tax authorities. The Company's policy is to recognize interest expense and penalties related to income tax matters as tax expense. At December 31, 2022 and 2021, respectively, there were no unrecognized tax benefits, and there are

no significant accruals for interest related to unrecognized tax benefits or tax penalties.

Note 6 - Subsequent Events

Stock Issued for Services

In February 2023, the Company issued 490,000 shares of common stock for services rendered, having a fair value of $176,400 ($0.36/share), based upon the quoted closing trading price.

Stock Issued for License

In February 2023, the Company issued 1,000,000 shares of common stock in exchange for the right to license, manufacture and market nutraceutical products. These shares had a fair value of $370,000 ($0.37/share), based upon the quoted closing trading price. The Company will expense the issuance of these shares as a component of research and development. Additionally, the Company will pay $0.10/bottle of product sold.

Convertible Note Payable

In January 2023, the Company issued an unsecured, one-year (one), original issue discount convertible note with a face amount of $100,000. This note contained an original issue discount of $30,000, resulting in net proceeds of $70,000.

This note is convertible at a 20% discount to market upon the effectiveness of the Company's Form S-1 registration statement. This convertible note contains an embedded contingent conversion feature that until the contingency is resolved (declared effectiveness of the S1 registration statement) is not required to be accounted for in accordance with the related accounting guidance.

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

Through and including ________, 2023 (the 40th day after the date of this prospectus), all dealers effecting transactions in these securities, whether or not participating in this offering, may be required to deliver a prospectus. This requirement is in addition to a dealer's obligation to deliver a prospectus when acting as an underwriter and with respect to an unsold allotment or subscription.

    Registration No. 333-271439

    Registration No. 333-271439

Item 13. Other Expenses of Issuance and Distribution

The following table sets forth the costs and expenses payable by us in connection with the issuance and distribution of the securities being registered hereunder. No expenses will be borne by the Selling Stockholder. All of the amounts shown are estimates, except for the SEC registration fee.

    Registration No. 333-271439

Item 14. Indemnification of Directors and Officers

Our Bylaws provide that the Company shall indemnify our directors and officers from and against any liability arising out of their service as a director or officer of the Company or any subsidiary or affiliate of which they serve as an officer or director at our request to the fullest extent not prohibited by NRS Chapter 78. The effect of this provision of our bylaws is to eliminate our right and our stockholders (through stockholders' derivative suits on behalf of the Company) to recover damages against a director or officer for breach of the fiduciary duty of care as a director or officer (including breaches resulting from negligent or grossly negligent behavior), except under certain situations defined by statute. We believe that the indemnification provisions in our bylaws are necessary to attract and retain qualified persons as directors and officers.

Insofar as indemnification for liabilities arising under the Securities Act may be permitted to directors, officers and controlling persons of the registrant pursuant to the foregoing provisions, or otherwise, the registrant has been advised that in the opinion of the SEC such indemnification is against public policy as expressed in the Securities Act and is, therefore, unenforceable. In the event that a claim for indemnification against such liabilities (other than the payment by the registrant of expenses incurred or paid by a director, officer or controlling person of the registrant in the successful defense of any action, suit or proceeding) is asserted by such director, officer or controlling person in connection with the securities being registered, the registrant will, unless in the opinion of its counsel the matter has been settled by controlling precedent, submit to a court of appropriate jurisdiction the question whether such indemnification by it is against public policy as expressed in the Securities Act and will be governed by the final adjudication of such issue.

Item 15. Recent Sales of Unregistered Securities

The following is a summary of transactions by us within the past three years involving sales or our securities that were not registered under the Securities Act.

    Registration No. 333-271439

Item 16. Exhibits and Financial Statement Schedules

(10) Exhibits

    Registration No. 333-271439

    Registration No. 333-271439

Item 17. Undertakings

(a) The undersigned registrant hereby undertakes:

(1) To file, during any period in which offers or sales are being made, a post-effective amendment to this registration statement:

(i) To include any prospectus required by section 10(a)(3) of the Securities Act of 1933;

(ii) To reflect in the prospectus any facts or events arising after the effective date of the registration statement (or the most recent post-effective amendment thereof) which, individually or in the aggregate, represent a fundamental change in the information set forth in the registration statement. Notwithstanding the foregoing, any increase or decrease in volume of securities offered (if the total dollar value of securities offered would not exceed that which was registered) and any deviation from the low or high end of the estimated maximum offering range may be reflected in the form of prospectus filed with the Commission pursuant to Rule 424(b) if, in the aggregate, the changes in volume and price represent no more than 20% change in the maximum aggregate offering price set forth in the "Calculation of Registration Fee" table in the effective registration statement.

(iii) To include any material information with respect to the plan of distribution not previously disclosed in the registration statement or any material change to such information in the registration statement; provided, however, that paragraphs (a)(1)(i), (a)(1)(ii), and (a)(1)(iii) of this section do not apply if the information required to be included in a post-effective amendment by those paragraphs is contained in reports filed with or furnished to the SEC by the registrant pursuant to section 13 or section 15(d) of the Securities Exchange Act of 1934 that are incorporated by reference in the registration statement.

(2) That, for the purpose of determining any liability under the Securities Act of 1933, each such post-effective amendment shall be deemed to be a new registration statement relating to the securities offered therein, and the offering of such securities at that time shall be deemed to be the initial bona fide offering thereof.

(3) To remove from registration by means of a post-effective amendment any of the securities being registered which remain unsold at the termination of the Offering.

(4) That, for the purpose of determining liability under the Securities Act of 1933 to any purchaser, each prospectus filed pursuant to Rule 424(b) as part of a registration statement relating to an offering, other than registration statements relying on Rule 430B or other than prospectuses filed in reliance on Rule 430A, shall be deemed to be part of and included in the registration statement as of the date it is first used after effectiveness. Provided, however, that no statement made in a registration statement or prospectus that is part of the registration statement or made in a document incorporated or deemed incorporated by reference into the registration statement or prospectus that is part of the registration statement will, as to a purchaser with a time of contract of sale prior to such first use, supersede or modify any statement that was made in the registration statement or prospectus that was part of the registration statement or made in any such document immediately prior to such date of first use.

(5) That, for the purpose of determining liability of the registrant under the Securities Act of 1933 to any purchaser in the initial distribution of the securities, the undersigned registrant undertakes that in a primary offering of securities of the undersigned registrant pursuant to this registration statement, regardless of the underwriting method used to sell the securities to the purchaser, if the securities are offered or sold to such purchaser by means of any of the following communications, the undersigned registrant will be a seller to the purchaser and will be considered to offer or sell such securities to such purchaser:

(i) Any preliminary prospectus or prospectus of the undersigned registrant relating to the Offering required to be filed pursuant to Rule 424;

(ii) Any free writing prospectus relating to the Offering prepared by or on behalf of the undersigned registrant or used or referred to by the undersigned registrant;

    Registration No. 333-271439

(iii) The portion of any other free writing prospectus relating to the Offering containing material information about the undersigned registrant or its securities provided by or on behalf of the undersigned registrant; and

(iv) Any other communication that is an offer in the Offering made by the undersigned registrant to the purchaser.

(b) That, insofar as indemnification for liabilities arising under the Securities Act may be permitted to directors, officers and controlling persons of the registrant pursuant to the foregoing provisions, or otherwise, the registrant has been advised that in the opinion of the SEC such indemnification is against public policy as expressed in the Securities Act and is, therefore, unenforceable. In the event that a claim for indemnification against such liabilities (other than the payment by the registrant of expenses incurred or paid by a director, officer or controlling person of the registrant in the successful defense of any action, suit or proceeding) is asserted by such director, officer or controlling person in connection with the securities being registered, the registrant will, unless in the opinion of its counsel the matter has been settled by controlling precedent, submit to a court of appropriate jurisdiction the question whether such indemnification by it is against public policy as expressed in the Securities Act and will be governed by the final adjudication of such issue.

(c) The undersigned registrant hereby undertakes:

(1) That, for the purpose of determining any liability under the Securities Act, each post-effective amendment that contains a form of prospectus shall be deemed to be a new registration statement relating to the securities offered therein, and the Offering of such securities at that time shall be deemed to be the initial bona fide offering thereof.

(2) That, for purposes of determining any liability under the Securities Act, the information omitted from the form of prospectus filed as part of this registration statement in reliance upon Rule 430A and contained in a form of prospectus filed by the registrant pursuant to Rule 424(b)(1) or (4) or 497(h) under the Securities Act shall be deemed to be part of this registration statement as of the time it was declared effective.

    Registration No. 333-271439

    Registration No. 333-271439

Pursuant to the requirements of the Securities Act of 1933, the registrant certifies that it has reasonable grounds to believe that it meets all of the requirements for filing Form S-1 and has duly caused this registration statement on Form S-1 to be signed on its behalf by the undersigned, thereunto duly authorized, in Sparks, Nevada, on October 5 , 2023.

LUDWIG ENTERPRISES, INC.

    Registration No. 333-271439

Pursuant to the requirements of the Securities Act of 1933, as amended, this registration statement on Form S-1 has been signed below by the following persons on behalf of the registrant and in the capacities and on the dates indicated.

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

    Registration No. 333-271439

This constitutes Amendment No. 1 to that certain Employment Agreement (the "Agreement") dated as of June 1, 2022, by and between Ludwig Enterprises, Inc. (the "Company"), and Anne B. Blackstone ("Executive"). Capitalized terms herein shall have the same meanings as set forth in the Agreement.

WHEREAS, the Board of Directors of the Company has retained the services of two additional executive officers and, in conjunction therewith, has determined it to be advisable to reassign executive officer duties.

NOW, THEREFORE, for good and valuable consideration, the receipt and adequacy of which is hereby acknowledged, the Company and Executive agree, as follows:

Section 1.1 of the Agreement is hereby deleted in its entirety and replaced with the following:

1.1 Employment. The Company agrees to employ Executive, and Executive hereby accepts employment with the Company, to serve as the Company's President and director, upon the terms and subject to the conditions set forth in this Agreement. The period during which Executive is employed by the Company is referred to herein as the "Employment Period." The effective date on which the Executive's Employment Period ends for any reason or no reason is referred to herein as the "Termination Date."

In all other aspects, the Agreement is ratified and affirmed as the 5th day of September, 2023.

    Registration No. 333-271439

By: /s/ Marvin Hausman, M.D. Marvin Hausman, M.D. Chief Executive Officer

    Registration No. 333-271439

COMTEX_441503556/2255/2023-10-06T01:39:08

(c) 1995-2023 Cybernet Data Systems, Inc. All Rights Reserved

The Canadian Press
Press Release, Saturday, December 31, 2022 - 11:00:18 UTC -0500 2134 mots

British Columbia Discovery Fund Inc. (formerly British Columbia Discovery Fund (VCC) Inc.) Provides Update on Liquidation

Globenewswire

VANCOUVER, British Columbia, Dec. 31, 2022 (GLOBE NEWSWIRE) -- British Columbia Discovery Fund Inc., (formerly British Columbia Discovery Fund (VCC) Inc.) (the "Fund"), by The Bowra Group Inc. in its capacity as liquidator of the Fund (the "Liquidator"), provides the following update as to the liquidation proceedings of the Fund.

Pricing Net Asset Value per Class A Common Share is $1.68 as at November 30, 2022 compared to $2.60 as at August 31, 2022, a decrease of 35%. The principal reason for this change is the decrease in value of the Fund's publicly traded investments in D-Wave Systems Inc. and Tantalus Systems Holdings Inc.

The following is an update of the Fund's portfolio companies and the Liquidator's activities:

D-Wave Systems Inc. ("D-Wave") - D-Wave is a quantum computing company based in Burnaby, B.C. D-Wave continues to advance the science used in its products, build its technology, and build its core business of quantum computing services.On August 5, 2022 DPCM Capital, Inc. ("DPCM") and D-Wave, completed a business combination transaction and D-Wave Quantum Inc. ("D-Wave Quantum") became the parent company of both D-Wave and DPCM.On August 8, 2022 D-Wave Quantum began trading on the New York Stock Exchange under stock symbol QBTS.The shares in D-Wave Quantum issued to the Fund are subject to a trading restriction for a period of 180 days from the date of the public listing of D-Wave Quantum.D-Wave Quantum's 20 day average for Pricing Net Asset Value was $9.70 USD as at August 31, 2022 and $2.55 USD as at November 30, 2022.The decrease in value of the Funds investment in D-Wave is the primary reason for the 35% decrease in Net Asset Value per Common Share from the last press release.Details of the transaction and information about D-Wave can be found at: www.dwavesys.com.The Liquidator is continuing to monitor D-Wave Quantum and assess its strategy for the realization of the Fund's position subsequent to expiry of the trading restriction period. Tantalus Systems Holdings Inc. - ("Tantalus") - Tantalus is a technology company which develops and operates smart grid solutions for utilities based in Burnaby, B.C. Tantalus is currently publicly listed and trades on the Toronto Stock Exchange under symbol GRID.The Liquidator notes that the share price of Tantalus decreased in the period used to calculate the November 30, 2022 Net Asset Value per Class A Common Share.The decrease in the Tantalus share price contributed to the change in Net Asset Value per Class A Common Share from the last press release however the decrease was primarily influenced by the decrease in value of the Funds holdings in D-Wave Quantum.Further updates and information about Tantalus can be found at: www.tantalus.com and SEDAR. In particular, see Tantalus' MD&A for the period ending September 30, 2022 for discussion of Tantalus' financial performance.The Liquidator is continuing to monitor Tantalus and review and assess opportunities for the sale of the Fund's Tantalus shares. Phemi Systems Corporation ("Phemi") - Phemi is a technology company which provides data management, analysis, privacy, and security for healthcare based in Vancouver, B.C.Since the last press release, the Liquidator has not identified any new material events that would impact the Fund's investment in Phemi.Further updates and information about Phemi can be found at: www.phemi.com.The Liquidator is continuing to monitor Phemi and review any potential opportunities for liquidity events pursuant to its mandate. 3760073 Canada Corp. (formerly Navarik Corp.) ("Navarik") - Navarik is a technology company providing software and data solutions for cargo and shipping of petroleum products based in Vancouver, B.C. Navarik sold all of its assets to Vela Software Group ("Vela") in September 2020. The Fund's current interest in Navarik is limited to future distributions Navarik may make to its shareholders pursuant to the transaction with Vela.Since the last press release, the Liquidator has not identified any new material events that would impact the Fund's investment in Navarik.The Liquidator is continuing to monitor Navarik and the potential for any future distributions to the Fund pursuant to the terms of its sale to Vela. MTI Limited Partnership (acquired as a result of the sale of Mobidia Technology Inc.) ("MTI LP") - Mobidia was a Fund portfolio company that was sold to App Annie in 2015. The Fund's current interest in MTI LP is limited to its respective interest in App Annie shares held by MTI LP exchanged in the sale of Mobidia transaction.Since the last press release, the Liquidator has not identified any new material events that would impact the Fund's investment in MTI LP.The Liquidator is continuing to monitor MTI LP and App Annie and review any opportunities for liquidity events pursuant to its mandate.

The Fund will continue to realize on its investments in portfolio companies through participation in liquidity events when possible pursuant to its liquidation mandate and to address remaining outstanding matters relating to its liquidation, including tax matters.At this time, the Fund is not aware of the anticipated date of any distribution, and the Fund has not yet determined a date for the dissolution of the Fund.The Liquidator released the Liquidator's First Report on November 30, 2021 and a copy of the Report is available on the Liquidator's website under Liquidator - Reports at: www.bowragroup.com.Updates and materials related to the Fund's liquidation proceedings can be found on the Liquidator's website at: www.bowragroup.com. The Liquidator will continue to make available on its website additional information and updates on the status of the Fund's liquidation proceedings and disseminate a news release on at least a quarterly basis.

Risk Factors and Forward-Looking Information

This news release may include statements about expected future events and/or financial results that are forward-looking in nature and subject to risks and uncertainties. The issuer cautions that actual performance will be affected by a number of factors, many of which are beyond the control of the Liquidator.

Certain risks include but are not limited to: the Fund cannot assure its shareholders of the timing or amount of any liquidation distributions. The timing of liquidation of the Fund's portfolio assets depends on the timing of occurrence of liquidity events in the underlying portfolio companies and on the timing of trading opportunities for the publically-traded securities in the portfolio, and the amount of such distributions depends on the proceeds realized from such dispositions which in turn will depend on the many factors that impact the value of the portfolio companies. The Fund will continue to incur expenses that will reduce the value of any liquidation distributions; if the Fund fails to retain sufficient funds to pay the expenses and liabilities actually owed to the Fund's creditors, each shareholder receiving liquidation distributions could be held liable for payment to the Fund's creditors, of his, her or its pro rata share of any shortfall, up to the amount actually distributed to each shareholder; if, at the time of a distribution to shareholders, the Fund cannot pass statutory solvency tests, the distribution may be prohibited; there are no assurances that the Liquidator will achieve the same financial results that management might achieve if it had continued as the manager of the Fund; the tax treatment of liquidation distributions may vary from shareholder to shareholder, and shareholders should consult their own tax advisors; and the Class A Shares may, in certain circumstances, cease to be ''qualified investments'' for "registered plans" for the purposes of the Income Tax Act (Canada).

See "Risk Factors" in the information circular of the Fund dated May 22, 2020 and available on www.sedar.com.

Additional Information

Additional information relating to the Fund's liquidation and associated matters is contained in the information circular of the Fund dated May 22, 2020, which is available on SEDAR at www.sedar.com.

The Bowra Group is a boutique financial advisory firm with offices in Vancouver, British Columbia and Edmonton, Alberta. The Bowra Group specializes in insolvency and restructuring, and services offered include business restructurings, business viability and performance improvement assessments and turnaround management. The Bowra Group is a Licensed Insolvency Trustee and acts formally as Trustee, Monitor, Receiver and Liquidator in engagements across a variety of industries.

Further information about The Bowra Group and updates to shareholders and information on the liquidation of the Fund can be found at www.bowragroup.com.

Gordon Brown The Bowra Group Inc. Suite 430 - 505 Burrard Street, Vancouver, B.C. V7M 2C1 Phone: 604-689-8939 Email: [email protected]

NEWS RELEASE TRANSMITTED BY Globe Newswire

Note(s):

D-Wave Systems Inc. ("D-Wave") - D-Wave is a quantum computing company based in Burnaby, B.C. D-Wave continues to advance the science used in its products, build its technology, and build its core business of quantum computing services.On August 5, 2022 DPCM Capital, Inc. ("DPCM") and D-Wave, completed a business combination transaction and D-Wave Quantum Inc. ("D-Wave Quantum") became the parent company of both D-Wave and DPCM.On August 8, 2022 D-Wave Quantum began trading on the New York Stock Exchange under stock symbol QBTS.The shares in D-Wave Quantum issued to the Fund are subject to a trading restriction for a period of 180 days from the date of the public listing of D-Wave Quantum.D-Wave Quantum's 20 day average for Pricing Net Asset Value was $9.70 USD as at August 31, 2022 and $2.55 USD as at November 30, 2022.The decrease in value of the Funds investment in D-Wave is the primary reason for the 35% decrease in Net Asset Value per Common Share from the last press release.Details of the transaction and information about D-Wave can be found at: www.dwavesys.com.The Liquidator is continuing to monitor D-Wave Quantum and assess its strategy for the realization of the Fund's position subsequent to expiry of the trading restriction period. Tantalus Systems Holdings Inc. - ("Tantalus") - Tantalus is a technology company which develops and operates smart grid solutions for utilities based in Burnaby, B.C. Tantalus is currently publicly listed and trades on the Toronto Stock Exchange under symbol GRID.The Liquidator notes that the share price of Tantalus decreased in the period used to calculate the November 30, 2022 Net Asset Value per Class A Common Share.The decrease in the Tantalus share price contributed to the change in Net Asset Value per Class A Common Share from the last press release however the decrease was primarily influenced by the decrease in value of the Funds holdings in D-Wave Quantum.Further updates and information about Tantalus can be found at: www.tantalus.com and SEDAR. In particular, see Tantalus' MD&A for the period ending September 30, 2022 for discussion of Tantalus' financial performance.The Liquidator is continuing to monitor Tantalus and review and assess opportunities for the sale of the Fund's Tantalus shares. Phemi Systems Corporation ("Phemi") - Phemi is a technology company which provides data management, analysis, privacy, and security for healthcare based in Vancouver, B.C.Since the last press release, the Liquidator has not identified any new material events that would impact the Fund's investment in Phemi.Further updates and information about Phemi can be found at: www.phemi.com.The Liquidator is continuing to monitor Phemi and review any potential opportunities for liquidity events pursuant to its mandate. 3760073 Canada Corp. (formerly Navarik Corp.) ("Navarik") - Navarik is a technology company providing software and data solutions for cargo and shipping of petroleum products based in Vancouver, B.C. Navarik sold all of its assets to Vela Software Group ("Vela") in September 2020. The Fund's current interest in Navarik is limited to future distributions Navarik may make to its shareholders pursuant to the transaction with Vela.Since the last press release, the Liquidator has not identified any new material events that would impact the Fund's investment in Navarik.The Liquidator is continuing to monitor Navarik and the potential for any future distributions to the Fund pursuant to the terms of its sale to Vela. MTI Limited Partnership (acquired as a result of the sale of Mobidia Technology Inc.) ("MTI LP") - Mobidia was a Fund portfolio company that was sold to App Annie in 2015. The Fund's current interest in MTI LP is limited to its respective interest in App Annie shares held by MTI LP exchanged in the sale of Mobidia transaction.Since the last press release, the Liquidator has not identified any new material events that would impact the Fund's investment in MTI LP.The Liquidator is continuing to monitor MTI LP and App Annie and review any opportunities for liquidity events pursuant to its mandate.

IFEX (web site ref.) - IFEX
December 6, 2023 15881 mots
Repression and resistance in Belarus: A monthly chronology

Cathal Sheerin 28 November 2023 84 minute read Hundreds of Belarusian people living in Krakow gathered during a Solidarity Rally against the Belarusian leader, Alexander Lukashenko. (Photo by Cezary Kowalski/SOPA... Voir l'article

Ce document référence un lien URL de site non hébergé par Cision.

FOX News (web site ref.) - Fox News
October 12, 2023 51693 mots
Netanyahu says 'Hamas is ISIS' as Israel prepares for ground invasion of Gaza

incoming update… A former Trump deputy national security adviser called on the United States to stop "feeding" the "monster" Iran after Hamas terrorists provoked war with Israel. Victoria Coates, who serves... Voir l'article

Ce document référence un lien URL de site non hébergé par Cision.

Reports - Telecommunication - FCC

Publication date: October 21, 2023 15432 mots

- pdf - FCC-23-85A1.pdf

23 pages

Please note : This extract may not display a well formed paragraph

... Federal Communications Commission FCC 23-85 Before the Federal Communications Commission Washington, D.C. 20554 In the Matter of Broadband Connectivity and Maternal Health— Implementation of the Data Mapping to Save...

Full report:
https://docs.fcc.gov/public/attachments/FCC-23-85A1.pdf
Web sites - Business Management - Business Line
October 31, 2023 22095 mots
Share Market Highlights 31 October 2023: Sensex sheds 237 pts, Nifty closes below 19,100; SBI Life, Titan gain

Sensex, Nifty updates on 31 October 2023: Find here all the live updates related to Sensex, Nifty, BSE, NSE, share prices and Indian stock markets for 31 October 2023. Indian blue... Voir l'article

Ce document référence un lien URL de site non hébergé par Cision.

EDGAR Online-8-K Glimpse
Friday, October 13, 2023 8876 mots, p. NA

8-K: Relay Therapeutics, Inc.

(EDGAR Online via COMTEX) -- 0001812364false00018123642023-10-122023-10-12

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

Pursuant to Section 13 or 15(d) of the Securities Exchange Act of 1934

Date of Report (Date of earliest event reported): October 12, 2023

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

Registrant's Telephone Number, Including Area Code: (617) 370-8837

(Former Name or Former Address, if Changed Since Last Report)

Check the appropriate box below if the Form 8-K filing is intended to simultaneously satisfy the filing obligation of the registrant under any of the following provisions:

?Written communications pursuant to Rule 425 under the Securities Act (17 CFR 230.425)

?Soliciting material pursuant to Rule 14a-12 under the Exchange Act (17 CFR 240.14a-12)

?Pre-commencement communications pursuant to Rule 14d-2(b) under the Exchange Act (17 CFR 240.14d-2(b))

?Pre-commencement communications pursuant to Rule 13e-4(c) under the Exchange Act (17 CFR 240.13e-4(c))

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

Indicate by check mark whether the registrant is an emerging growth company as defined in Rule 405 of the Securities Act of 1933 (230.405 of this chapter) or Rule 12b-2 of the Securities Exchange Act of 1934 (240.12b-2 of this chapter).

Emerging growth company ?

If an emerging growth company, indicate by check mark if the registrant has elected not to use the extended transition period for complying with any new or revised financial accounting standards provided pursuant to Section 13(a) of the Exchange Act. ?

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

On October 12, 2023, Relay Therapeutics, Inc. (the "Company") issued a press release announcing initial clinical data for RLY-4008 (lirafugratinib), a potent, selective and oral small molecule inhibitor of fibroblast growth factor receptor 2 ("FGFR2") in patients with FGFR2-altered solid tumors, a copy of which is being furnished as Exhibit 99.1 to this Current Report on Form 8-K. The Company intends to host a conference call and live webcast on October 12, 2023 at 5:30 p.m. E.T. to discuss this data for RLY-4008 (lirafugratinib). The Company has made available a slide presentation to accompany the call, a copy of which is being furnished as Exhibit 99.2 to this Current Report on Form 8-K.

The information in this Item 7.01, including Exhibit 99.1 and Exhibit 99.2 attached hereto, is intended to be furnished and shall not be deemed "filed" for purposes of Section 18 of the Securities Exchange Act of 1934, as amended (the "Exchange Act"), or otherwise subject to the liabilities of that section, nor shall it be deemed incorporated by reference in any filing under the Securities Act of 1933, as amended, or the Exchange Act, except as expressly set forth by specific reference in such filing.

Item 8.01 Other Events.

RLY-4008 (lirafugratinib)

On October 12, 2023, the Company announced initial clinical data for RLY-4008 (lirafugratinib) in patients with FGFR2-altered solid tumors that was presented at the 2023 AACR-NCI-EORTC International Conference on Molecular Targets and Cancer Therapeutics.

RLY-4008 (lirafugratinib) is currently being evaluated in the two-part global Phase 1/2 ReFocus trial in patients with FGFR2-altered tumors. The first part of the trial, or the dose escalation, is complete, and the second part of the trial, or the dose expansion, is ongoing at the 70mg once daily recommended Phase 2 dose. The dose expansion part of the trial includes four cholangiocarcinoma ("CCA") arms and three tumor agnostic (non-CCA) arms (such tumor agnostic arms being: (1) FGFR2 fusions, (2) FGFR2 amplifications and (3) FGFR2 mutations). As of the August 23, 2023 data cut-off date, the three tumor agnostic arms of the trial had enrolled 84 FGFR inhibitor-naive patients who were efficacy evaluable across 18 tumor types, including 26 patients with FGFR2 fusions, 34 patients with FGFR2 amplifications and 24 patients with FGFR2 mutations. Across these arms of the trial, enrolled patients had received a median of approximately three prior lines of therapy, with the vast majority (94%) having received prior chemotherapy/ADC and nearly half (45%) having received prior targeted therapies.

In patients with FGFR2 fusions, there was consistent activity across a range of tumor types.

- Nine of 26 patients experienced a partial response ("PR") (35% overall response rate ("ORR")). - Sixty-three percent of confirmed responders experienced a duration of response of at least six months as of the August 23, 2023 data cut-off date. - There were 11 tumor types represented amongst enrolled patients with FGFR2 fusions, including pancreatic (n=6), ovarian (n=3), gastric (n=3), non-small-cell lung ("NSCLC") (n=2), and breast (n=2).

The trial enrolled 14 patients with breast cancer across all FGFR2 alterations, 10 of whom had HR+/HER2- breast cancer.

- Four of the 10 HR+/HER2- patients achieved PRs (40% ORR). o Three of the four responders remain on treatment, with the longest duration of response 72 weeks and ongoing, as of the August 23, 2023 data cut-off date. - All responders had a duration of response of at least 6 months. - All 14 patients were very heavily pre-treated, with a median of six prior lines of therapy. o All patients had received prior targeted therapies. o Nearly all patients had received prior chemotherapy/ADC (93%). o The vast majority of patients had received prior endocrine therapy (79%) and prior cyclin dependent kinase 4/6 ("CDK 4/6") (71%).

There were signals of activity in patients with a range of FGFR2-amplified tumor types.

- Eight of 34 patients experienced a PR (24% ORR). o PRs were seen across tumor types, including gastric, breast, colorectal, and esophageal. - Six patients remain on treatment as of the August 23, 2023 data cut-off date, including four responders, one patient with stable disease and one patient who continued treatment beyond disease progression. - Forty-three percent of confirmed responders experienced a duration of response of at least six months.

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

The safety analysis from the tumor agnostic cohorts, as of the August 23, 2023 data cut-off date, was generally consistent with the analysis reported by the Company at the European Society for Medical Oncology Congress 2022.

- Most treatment-related adverse events were expected FGFR2 on-target, low-grade, monitorable, generally manageable and largely reversible. - There were no observed Grade 4 or 5 adverse events. - Off-target toxicities of hyperphosphatemia and diarrhea continued to be clinically insignificant.

Enrollment is complete in the pivotal expansion cohort in patients with FGFR2-fusion CCA who have not previously received an FGFR inhibitor.

Other Updates

On October 12, 2023, the Company announced additional pipeline updates, including the Company's plans to initiate a triplet combination with RLY-2608, fulvestrant and CDK4/6, and the Company's decision to pause further development efforts on RLY-2139, its CDK2 inhibitor. Taking into account the updates across the Company's portfolio, the Company expects its cash, cash equivalents and investments will be sufficient to fund its current operating plan into the second half of 2026.

Cautionary Note Regarding Forward Looking Statements

This Current Report on Form 8-K and certain of the materials furnished or filed herewith contain forward-looking statements within the meaning of the Private Securities Litigation Reform Act of 1995, as amended, including, without limitation, implied and express statements regarding the Company's strategy, business plans and focus; the progress and timing of updates on the clinical development of the programs across the Company's portfolio, including RLY-4008; expected therapeutic benefits of its programs; and the Company's expected cash runway into the second half of 2026. The words "may," "might," "will," "could," "would," "should," "plan," "anticipate," "intend," "believe," "expect," "estimate," "seek," "predict," "future," "project," "potential," "continue," "target" and similar words or expressions are intended to identify forward-looking statements, although not all forward-looking statements contain these identifying words.

Any forward-looking statements are based on management's current expectations and beliefs and are subject to a number of risks, uncertainties and important factors that may cause actual events or results to differ materially from those expressed or implied by any forward-looking statements contained in this Current Report on Form 8-K or the materials furnished or filed herewith, including, without limitation, risks associated with: the impact of global economic uncertainty, geopolitical instability, or public health epidemics or outbreaks of an infectious disease, such as COVID-19, on countries or regions in which the Company has operations or does business, as well as on the timing and anticipated results of its clinical trials, strategy, future operations and profitability; the delay of any current or planned clinical trials or the development of the Company's drug candidates; the risk that the preliminary results of its preclinical or clinical trials may not be predictive of future or final results in connection with future clinical trials of its product candidates; the Company's ability to successfully demonstrate the safety and efficacy of its drug candidates; the timing and outcome of its planned interactions with regulatory authorities; and obtaining, maintaining and protecting its intellectual property. These and other risks and uncertainties are described in greater detail in the section entitled "Risk Factors" in the Company's most recent Annual Report on Form 10-K and Quarterly Report on Form 10-Q, as well as any subsequent filings with the Securities and Exchange Commission. In addition, any forward-looking statements represent the Company's views only as of today and should not be relied upon as representing its views as of any subsequent date. The Company explicitly disclaims any obligation to update any forward-looking statements. No representations or warranties (expressed or implied) are made about the accuracy of any such forward-looking statements.

Item 9.01 Financial Statements and Exhibits.

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

Pursuant to the requirements of the Securities Exchange Act of 1934, the registrant has duly caused this report to be signed on its behalf by the undersigned hereunto duly authorized.

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

Relay Therapeutics to host a conference call today, October 12, at 5:30 p.m. ET

Boston - October 12, 2023 - Relay Therapeutics, Inc. (Nasdaq: RLAY), a clinical-stage precision medicine company transforming the drug discovery process by combining leading-edge computational and experimental technologies, today announced initial clinical data for RLY-4008 (lirafugratinib) in patients with FGFR2-altered solid tumors. The data demonstrate activity across several sub-groups, including patients with FGFR2-fusion tumors and patients with FGFR2-altered HR+/HER2- breast cancer. These data are being presented today at the 2023 AACR-NCI-EORTC International Conference on Molecular Targets and Cancer Therapeutics.

"These data provide important early evidence that RLY-4008, or lirafugratinib, has the potential to help both patients with FGFR2-fusion cholangiocarcinoma as previously reported, as well as those with multiple other types of FGFR2-altered tumors," said Don Bergstrom, M.D., Ph.D., President of R&D at Relay Therapeutics. "We are excited by the potential for lirafugratinib to help many more patients and are focused on advancing this opportunity as well as our PI3K? programs, with the initiation of a RLY-2608 triplet combination trial this year."

ReFocus Trial

Lirafugratinib is currently being evaluated in the two-part global Phase 1/2 ReFocus trial in patients with FGFR2-altered tumors. The first part of the study (dose escalation) is complete, and the second part of the study (dose expansion) is ongoing at the 70mg QD recommended Phase 2 dose. The dose expansion portion of the study includes four cholangiocarcinoma (CCA) arms and three (non-CCA) tumor agnostic arms (1: FGFR2 fusions, 2: FGFR2 amplifications and 3: FGFR2 mutations).

As of the August 23, 2023 cut-off date, the three tumor agnostic arms of the study had enrolled 84 FGFR inhibitor-naive patients who were efficacy evaluable across 18 tumor types, including 26 patients with FGFR2 fusions, 34 patients with FGFR2 amplifications and 24 patients with FGFR2 mutations. Across these arms of the study, enrolled patients had received a median of approximately three prior lines of therapy, with the vast majority (94%) having received prior chemotherapy/ADC and nearly half (45%) having received prior targeted therapies.

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

Encouraging Initial FGFR2-Fusion Tumor-Agnostic Signal with Promising Durability

In patients with FGFR2 fusions, there was consistent activity across a range of tumor types.

- Nine of 26 patients experienced a partial response (PR) (35% overall response rate (ORR))

- Sixty-three percent of confirmed responders experienced a duration of response of at least 6 months as of the data cut-off date

- There were 11 tumor types represented amongst enrolled patients with FGFR2 fusions, including pancreatic (n=6), ovarian (n=3), gastric (n=3), non-small-cell lung (NSCLC, n=2), and breast (n=2)

Compelling Response Rate with Multiple Long-Term Responses in Heavily Pre-Treated Patients with HR+/HER2- Breast Cancer

The study enrolled 14 patients with breast cancer across all FGFR2 alterations, 10 of whom had HR+/HER2- breast cancer.

- Four of the 10 HR+/HER2- patients achieved PRs (40% ORR)

o Three of the four responders remain on treatment, with the longest duration of response 72 weeks and ongoing as of the data cut-off date

o All responders had a duration of response of at least 6 months

- All 14 patients were very heavily pre-treated, with a median of six prior lines of therapy

o All patients had received prior targeted therapies

o Nearly all patients had received prior chemotherapy/ADC (93%)

o The vast majority of patients had received prior endocrine therapy (79%) and prior CDK4/6 (71%)

Early Tumor-Agnostic Signal in FGFR2-Amplifications

There were signals of activity in patients with a range of FGFR2-amplified tumor types.

- Eight of 34 patients experienced a PR (24% ORR)

o PRs seen across tumor types, including gastric, breast, colorectal, and esophageal

- Six patients remain on treatment as of data cut-off, including four responders, one patient with stable disease and one patient who continued treatment beyond disease progression

- Forty-three percent of confirmed responders experienced a duration of response of at least 6 months

Additional Signals

Early, promising efficacy signals were seen in patients with FGFR2-fusions and amplifications across eight tumor types, including gastric, breast, pancreatic, NSCLC, ovarian, colorectal, esophageal, and

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

carcinoma of unknown primary origin. In addition, three of the 24 patients with FGFR2 mutations achieved a PR (breast, gastric and ameloblastic tumors).

Safety Data Remain Generally Consistent with Previously Reported Profile

The safety analysis from the tumor agnostic cohorts, as of the data cut-off date, was generally consistent with the analysis from the 2022 ESMO data disclosure.

- Most treatment-related adverse events were expected FGFR2 on-target, low-grade, monitorable, generally manageable and largely reversible

- There were no observed Grade 4 or 5 adverse events

- Off-target toxicities of hyperphosphatemia and diarrhea continued to be clinically insignificant

Lirafugratinib Next Steps

- Continue enrollment in the three tumor agnostic cohorts

o The company expects to report additional clinical data and a regulatory update in 2024

- Enrollment is complete in the pivotal expansion cohort in patients with FGFR2-fusion CCA who have not previously received an FGFR inhibitor

- Near-term commercial readiness activities for CCA will be paused and aligned with the broader tumor agnostic opportunity

The AACR-NCI-EORTC presentation and poster are available on the Relay Therapeutics website under Publications: https://relaytx.com/publications/.

Pipeline Updates

The company will continue to prioritize and expand further PI3K? mutant selective development, including:

- RLY-2608: continue ongoing ReDiscover trial with focus on RLY-2608 + fulvestrant cohorts

o Initiate triplet combination with RLY-2608 + fulvestrant + CDK4/6 by the end of 2023

- Next PI3K? clinical data update expected in 2024

- Additionally, Relay Therapeutics has decided to pause further development efforts on RLY-2139 (CDK2 inhibitor)

Cash Runway Extended

With the decision to pause CCA commercial readiness and RLY-2139 development, Relay Therapeutics expects its cash, cash equivalents and investments will be sufficient to fund its current operating plan into the second half of 2026.

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

Relay Therapeutics will host a conference call and live webcast today, Thursday, October 12, 2023, at 5:30 p.m. ET. Registration and dial-in for the conference call may be accessed on Relay Therapeutics' website under Events in the News & Events section through the following link: https://ir.relaytx.com/news-events/events-presentations. An archived replay of the webcast will be available following the event.

About RLY-4008 (lirafugratinib)

RLY-4008 (lirafugratinib) is a potent, selective and oral small molecule inhibitor of FGFR2, a receptor tyrosine kinase that is frequently altered in certain cancers. FGFR2 is one of four members of the FGFR family, a set of closely related proteins with highly similar protein sequences and properties. Preclinically, lirafugratinib demonstrated FGFR2-dependent killing in cancer cell lines and induced regression in in vivo models, while minimal inhibition of other targets was observed, including other members of the FGFR family. In addition, lirafugratinib demonstrated strong activity against known clinical on-target resistance mutations in cellular and in vivo preclinical models. Lirafugratinib is currently being evaluated in a clinical trial in patients with advanced or metastatic FGFR2-altered solid tumors with a single arm, potentially registration-enabling cohort for FGFRi-naive FGFR2-fusion CCA. To learn more about the clinical trial of lirafugratinib, please visit here.

ReFocus Trial Background

RLY-4008 (lirafugratinib) is currently being evaluated in a global Phase 1/2 clinical trial (ReFocus) in patients with FGFR2-altered CCA and multiple other solid tumors including a single-arm, potentially registration-enabling cohort for FGFRi-naive FGFR2-fusion CCA. The Phase 1 dose escalation has been completed, and 70 mg QD has been selected as the registrational dose. The expansion cohorts were initiated in December 2021 and now consist of seven different cohorts based on FGFR2 alteration and tumor type. Of the seven cohorts, the potential pivotal cohort consists of approximately 100 previously treated, FGFRi-naive FGFR2-fusion CCA patients.

About Relay Therapeutics

Relay Therapeutics is a clinical-stage precision medicine company transforming the drug discovery process by combining leading-edge computational and experimental technologies with the goal of bringing life-changing therapies to patients. As the first of a new breed of biotech created at the intersection of complementary techniques and technologies, Relay Therapeutics aims to push the boundaries of what's possible in drug discovery. Its Dynamo(TM) platform integrates an array of leading-edge computational and experimental approaches designed to drug protein targets that have previously been intractable or inadequately addressed. Relay Therapeutics' initial focus is on enhancing small molecule therapeutic discovery in targeted oncology and genetic disease indications. For more information, please visit www.relaytx.com or follow us on Twitter.

Cautionary Note Regarding Forward-Looking Statements

This press release contains forward-looking statements within the meaning of the Private Securities Litigation Reform Act of 1995, as amended, including, without limitation, implied and express statements regarding Relay Therapeutics' strategy, business plans and focus; the progress and timing of updates on the clinical development of the programs across Relay Therapeutics' portfolio, including 4

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

RLY-4008; the expected therapeutic benefits of its programs; and the expected cash runway. The words "may," "might," "will," "could," "would," "should," "plan," "anticipate," "intend," "believe," "expect," "estimate," "seek," "predict," "future," "project," "potential," "continue," "target" and similar words or expressions are intended to identify forward-looking statements, although not all forward-looking statements contain these identifying words.

Any forward-looking statements in this press release are based on management's current expectations and beliefs and are subject to a number of risks, uncertainties and important factors that may cause actual events or results to differ materially from those expressed or implied by any forward-looking statements contained in this press release, including, without limitation, risks associated with: the impact of global economic uncertainty, geopolitical instability, or public health epidemics or outbreaks of an infectious disease, such as COVID-19, on countries or regions in which Relay Therapeutics has operations or does business, as well as on the timing and anticipated results of its clinical trials, strategy, future operations and profitability; the delay of any current or planned clinical trials or the development of Relay Therapeutics' drug candidates; the risk that the preliminary results of its preclinical or clinical trials may not be predictive of future or final results in connection with future clinical trials of its product candidates; Relay Therapeutics' ability to successfully demonstrate the safety and efficacy of its drug candidates; the timing and outcome of its planned interactions with regulatory authorities; and obtaining, maintaining and protecting its intellectual property. These and other risks and uncertainties are described in greater detail in the section entitled "Risk Factors" in Relay Therapeutics' most recent Annual Report on Form 10-K and Quarterly Report on Form 10-Q, as well as any subsequent filings with the Securities and Exchange Commission. In addition, any forward-looking statements represent Relay Therapeutics' views only as of today and should not be relied upon as representing its views as of any subsequent date. Relay Therapeutics explicitly disclaims any obligation to update any forward-looking statements. No representations or warranties (expressed or implied) are made about the accuracy of any such forward-looking statements.

Contact: Megan Goulart 617-545-5526 [email protected]

Media: Dan Budwick 1AB 973-271-6085 [email protected]

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

RLY-4008 (lirafugratinib) in FGFR2-Altered Solid Tumors October 2023 Exhibit 99.2

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

Disclaimer This presentation contains forward-looking statements within the meaning of the Private Securities Litigation Reform Act of 1995, as amended, including, without limitation, implied and express statements regarding the progress and timing of the clinical development of the programs across our portfolio, including the expected therapeutic benefits of our programs, timing of enrollment completion, and potential efficacy and tolerability; the timing of clinical data updates across our pipeline; the possibility that unconfirmed results from these trials will not be confirmed by additional data as our clinical trials progress; the potential of RLY-2608 or RLY-5836 to address a major unmet medical need; expectations regarding our pipeline, operating plan, use of capital, expenses and other financial results; our cash runway projection; the competitive landscape and potential market opportunities for our product candidates; the expected strategic benefits under our collaborations; our ability to successfully establish or maintain collaborations or strategic relationships for our product candidates; expectations regarding current and future interactions with the U.S. Food and Drug Administration (FDA); our ability to manufacture our product candidates in conformity with the FDA's requirements; the capabilities and development of our DynamoTM platform; our plans to develop, manufacture and commercialize our current product candidates and any future product candidates; and the implementation of our business model and strategic plans for our business, current product candidates and any future product candidates. The words "may," "might," "will," "could," "would," "should," "plan," "anticipate," "intend," "believe," "expect," "estimate," "seek," "predict," "future," "project," "potential," "continue," "target" and similar words or expressions, or the negative thereof, are intended to identify forward-looking statements, although not all forward-looking statements contain these identifying words. Any forward-looking statements in this presentation are based on management's current expectations and beliefs and are subject to a number of risks, uncertainties and important factors that may cause actual events or results to differ materially from those expressed or implied by any forward-looking statements contained in this presentation, including, without limitation, risks associated with: the impact of global economic uncertainty, geopolitical instability, or public health epidemics or outbreaks of an infectious disease on countries or regions in which we have operations or do business, as well as on the timing and anticipated results of our clinical trials, strategy, future operations and profitability; the delay of any current or planned clinical trials or the development of our drug candidates; the risk that the preliminary results of our preclinical or clinical trials may not be predictive of future or final results in connection with future clinical trials of our product candidates; our ability to successfully demonstrate the safety and efficacy of our drug candidates; the timing and outcome of our planned interactions with regulatory authorities; and obtaining, maintaining and protecting our intellectual property. These and other risks, uncertainties and important factors are described in the section entitled "Risk Factors" in our most recent Annual Report on Form 10-K and Quarterly Report on Form 10-Q, as well as any subsequent filings with the Securities and Exchange Commission. Any forward-looking statements represent our views only as of the date of this presentation and we undertake no obligation to update or revise any forward-looking statements, whether as a result of new information, the occurrence of certain events or otherwise. We may not actually achieve the plans, intentions or expectations disclosed in our forward-looking statements, and you should not place undue reliance on our forward-looking statements. No representations or warranties (expressed or implied) are made about the accuracy of any such forward-looking statements. Certain information contained in this presentation relates to or is based on studies, publications, surveys and other data obtained from third-party sources and our own internal estimates and research. While we believe these third-party studies, publications, surveys and other data to be reliable as of the date of this presentation, we have not independently verified, and make no representation as to the adequacy, fairness, accuracy or completeness of, any information obtained from third-party sources. In addition, no independent source has evaluated the reasonableness or accuracy of our internal estimates or research and no reliance should be made on any information or statements made in this presentation relating to or based on such internal estimates and research. This presentation contains trademarks, trade names and service marks of other companies, which are the property of their respective owners.

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

RLY-4008 - Embodies The Power of Our R&D Engine Motion Based Drug Design......Created First Known Selective FGFR2 FGFR2 First Patient Dosed Sep 2020 Oct 2023 Pivotal Cohort Fully Enrolled RP2D selected, demonstrated PoC, escalation cohorts initiated Down Down Up Up Down Down Down Relay Approach Standard FGFR1 FGFR2 Patients Treated Within 3 Years1 ~450 1. RLY-4008-101 treated patient total as of 29 Sept 2023 Strong Clinical Execution Drives Rapid Pathway to Potential Registration

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

RLY-4008 (lirafugratinib) - Initial Clinical Efficacy Observed Across Tumor Types cORR = Confirmed Objective Response Rate; ORR = Objective Response Rate Sources: ACS; SEER; Globocan; World Bank; 3rd party sources; 1. ORR includes 2 unconfirmed partial responses that confirmed post data cut off; 2. Range reflects all doses to 70mg QD RP2D, ESMO 2022 interim readout; 3. As of 23 Aug 2023; 4. Global patient totals reflect annual incidence; 5. 85K is inclusive of HR+ breast cancer (all FGFR2 alterations) and advanced solid tumors with FGFR2 amplifications or fusions (excluding breast cancer) Cholangiocarcinoma Cohort Continues to Mature 58-82% cORR in fusion+, FGFRi-naive CCA2 Differentiated profile Pivotal cohort fully enrolled ~6k Global Patients4 ~85k5 Global Patients4 Broad Activity Across Alteration and Tumor Types 24-40% cORR1 in FGFR2-altered, non-CCA advanced solid tumors at Triple Meeting 2023 interim readout All Fusions 35% All Amplifications 24% Add'l signals (ORR) observed in: Gastric: 19% (5 of 26 pt) NSCLC: 50% (2 of 4 pt) Ovarian: 50% (2 of 4 pt) Majority of responders with durability ? 6 months3 HR+ Breast Cancer (all alts) 40% Objective Response Rate Preliminary data as of 23 Aug 2023

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

Relay Tx - Patient-Driven Cash, cash equivalents and investments as of the end of 2Q 2023 Current cash, cash equivalents and investments are expected to be sufficient to fund current operating plan into 2H 2026 ~$872M...Focusing Investment......To Create Long Term Value Productive In-House R&D Engine... EXPERIMENTATION COMPUTATION Chemical biology insights Deep structural understanding Physics-based simulations AI / ML PEOPLE 4 clinical assets Sources: Global Data product sales; Global Data HER2-/HR+ Breast Cancer Global Forecast; 3rd party data 1. Includes prevalent PI3K? mutated HR+/HER2- patients receiving therapy in Neoadjuvant/Adjuvant setting (includes incident patients in 2023 receiving endocrine or non-endocrine therapy in Neo/Adjuvant settings [~50k], and patients diagnosed in previous years with local/regional disease receiving sequential endocrine therapy in 2023 [~69k]), and prevalent PI3K? mutated HR+/HER2- metastatic patients receiving therapy in 1L or 2L setting Extend Cash Runway & Enable Execution Focus Pause CDK2 at IND Pause CCA commercial build & align with TA RLY-4008 Pre-clinical HR+ /HER2- Breast Cancer1 (US Patients) 2L ~14k 1L ~18k (Neo) adjuvant ~120k PI3K? Mutant Selective Franchise RLY-2608 RLY-5836 H1047R specific Addresses large patient population Initiate CDK4/6 Triplet by YE 2023 Tumor agnostic (TA) focus RLY-4008 Continue Enrollment FGFR2

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

FGFR2 - Tumor Agnostic Opportunity Current data suggests potentially large global opportunity All Solid Tumors: FGFR2 Amplifications All Solid Tumors: FGFR2 Fusions Global patients per year1 US patients per year ~7k Up to ~34k ~13k Up to ~43k ~2k ~1k Up to ~6k Up to ~67k ~9k Up to ~28k Gastric Cancer: All Alterations2 HR+ Breast Cancer: All Alterations2 CCA: Fusions Tumor Agnostic Tumor Specific Indication + Incidence; Global includes US, EU4+UK, Japan, China; 2. Alterations include fusions, amplifications and mutations Sources: ACS; SEER; Globocan; World Bank; 3rd party sources; Cholangiocarcinoma EU website; Jpn J Clin Oncol 2021, June, Tsujie; CCA News, 2021 Yr in review, "FGFR2 Fusion and/or Rearrangement Profiling in Chinese Patients with Intrahepatic CCA"; Nature, Jan 2012, K Matsumoto; Clin Cancer Res, May 2013, L Xie; Br J Cancer, Feb 2014, X Su; Ann Translational Med, Oct 2020, Yi Sun; Life (Basel), Jan 2022, C Lengyel; Am J Cancer Res, 2021, W Gu

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

PI3K? mutants PI3K? Represents a Major Market Opportunity Kinase Helical Other Total 14% EGFR ERBB2 BRAF ALK 6% 6% 6% 1% % of all solid tumors with alteration E542X E545X H1047X ~$7B Total 2022 Global Revenue ~$9B ~$2B ~$3B PI3K? is the most frequently mutated kinase in solid tumors HR+/HER2- Breast Cancer represents a significant market with high unmet need 2L 1L (Neo) Adjuvant Patient Segment (PI3K? mutated) US Patients ~14k ~18k ~120k ~150k US PI3K? Mutation HR+/HER2- Breast Cancer Patients1 Breast Cancer Non-Breast Cancer RLY-2608 Triplet Trials with CDK4/6 inhibitors to be initiated before YE 2023 Piqray Inavolisib Capivasertib Current Tx Relay Tx RLY-2608 RLY-5836 Initial observed tolerability profile enables potential earlier lines of use Broad earlier use potentially unlikely due to tolerability challenges Approved Ph 32 Filed2 1. Includes prevalent PI3K? mutated HR+/HER2- patients receiving therapy in Neoadjuvant/Adjuvant setting (includes incident patients in 2023 receiving endocrine or non-endocrine therapy in Neo/Adjuvant settings [~50k], and patients diagnosed in previous years with local/regional disease receiving sequential endocrine therapy in 2023 [~69k]), and prevalent PI3K? mutated HR+/HER2- metastatic patients receiving therapy in 1L or 2L setting; 2. Phase 3 trials are focused in patients with early progression on endocrine therapy (during or within 12 months of completing adjuvant treatment); Sources: Global Data product sales; Global Data HER2-/HR+ Breast Cancer Global Forecast; 3rd party data

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

PI3K? Franchise Moving Rapidly to Triplet Combinations Monotherapy Doublet (combo with fulvestrant) Triplet (combo with fulvestrant and CDK4/6i) Part 1: Dose Escalation PIK3CAmut adv solid tumors PIK3CAmut, HR+/HER2- advanced / metastatic Breast Cancer PIK3CAmut, HR+/HER2- advanced / metastatic Breast Cancer Includes mixed histologies Part 2: Dose Expansion PIK3CAmut, HR+, HER2- advanced BC, prior PI3K? inhibitor allowed PIK3CAmut, HR+, HER2- advanced BC RLY-2608 first expansion cohort initiated at 600mg BID dose RLY-2608 triplet cohort to initiate by YE 2023 PIK3CAmut advanced solid tumor MTD/RP2D MTD/RP2D MTD/RP2D

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

Relay Tx's Execution & Capital Focus on Highest Value Opportunities Target Program Annual US Patient # PI3K? franchise RLY-2608 PI3K?PAN Monotherapy ~10-68K breast cancer ~76-238K all solid tumors Endocrine Tx (ET) doublet CDK4/6i + ET triplet RLY-5836 PI3K?PAN Monotherapy Endocrine Tx (ET) doublet CDK4/6i + ET triplet PI3K?H1047R ~4-25K breast cancer ~15-48K all solid tumors FGFR2 RLY-4008 ~11-35K4 Solid Tumor 2 programs To be announced Genetic Disease 2 programs To be announced CDK2 RLY-2139 ~46K2 ER? ER? Degrader ~29-196K3 SHP2 GDC-1971 ~37-69K5 Preclinical Early Clinical Late Clinical Breast Cancer Tumor Agnostic (incl. CCA) 3 ongoing combo studies 1. Unless otherwise indicated, all breast cancer patient numbers refer to HR+/HER2- breast cancer tumors; 2. ~46K HR+/HER2- breast cancer patients expected to receive CDK 4/6 inhibitors in adjuvant setting, first-line setting, and second-line setting in 2023, per Decision Resources Breast Cancer Market Forecast report dated June 2022; 3. HR+/HER2- US late-line breast cancer patients compared to HR+/HER2- US incident breast cancer patients; 4. FGFR2 altered late-line solid tumors compared to comprehensive annual FGFR2 altered incident solid tumors including additional FGFR gene fusions and rearrangements resulting from truncation of the protein at exon 18 and all breast cancer patients with FGFR2 alterations; 5. SHP2 combo only includes KRAS G12C in lung and colorectal, EGFR mutations in lung, and ALK fusions in lung Note: Unless otherwise indicated, patient #'s refer to total annual number of US patients with late-line cancers compared to comprehensive annual incidence that may be amenable to treatment with our programs Pausing programs YE 2023

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

Initial RLY-2608 data in 1H 2023 RLY-5836 clinical start in 2Q 2023 RLY-2608 expansion cohorts initiated 2H 2023 RLY-2608 Triplet Dose Escalation initiated by YE 2023 Additional data update in 2024 Relay Tx - Capital, Team & Execution Focus to Deliver on Key Milestones Undisclosed RLY-4008 (lirafugratinib) Full dose escalation data in 1H 2023 (2023 ASCO) Tumor Agnostic expansion cohorts data in 2H 2023 (2023 Triple) Pivotal cohort full enrollment in 2H 2023 Clinical data & regulatory update in 2024 GDC-1971 (SHP2) Ongoing combo trials; Genentech controls data disclosures To be announced New program(s) to be disclosed in 2024 5+ undisclosed programs in preclinical development and additional early-stage efforts across platform Tumor Agnostic Breast Cancer Franchise Cash, cash equivalents and investments as of the end of 2Q 2023 ~$872M ER? development candidate nomination in 2023 CDK2i RLY-2139 clinical start in early 2024 RLY-2608 RLY-5836 (PI3K?PAN) PI3K? Companions + Current cash, cash equivalents and investments are expected to be sufficient to fund current operating plan into 2H 2026 Pausing both programs YE 2023 + +

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

FGFR2 - Limitations of Current CCA and Non-CCA Treatment Options 1. Sources: Pemigatinib - prescribing information; futibatinib - prescribing Information; erdafitinib - prescribing information; (note: AEs are reflective of respective label indications); 2. From pemigatinib NDA review documents: "Pemigatinib 13.5 mg daily provided 76% inhibition of ex vivo phosphorylated FGFR2? at trough"; 3. Reflects reported ORRs in key randomized studies evaluating NCCN recommended regimens for recurrent/metastatic patients (second/third line or later) for the following tumor types: HR+ breast cancer, gastric cancer, pancreatic cancer, NSCLC, ovarian cancer, and head and neck (studies on slide 23). FDA Approved Compound1 % of Patients with Hyperphosphatemia % of Patients with Diarrhea Pemigatinib 93% 39% Futibatinib 88% 33% Erdafitinib 71% 59% Limited Tolerability Limited Target Coverage Limited Efficacy 36-42% ORR in currently approved tx1 (in fusion+ CCA, FGFRi-naive pt) Limited Selectivity Approved Pan-FGFRis are non-specific across FGFR family E.g., pemigatinib 13.5mg QD achieves 76% inhibition of FGFR2 at trough2 High rates of off-target toxicity (esp. FGFR1,4) Limited Limited Limited Limited CCA ORR in approved late-line tx3 (based on NCCN guidelines) Non-CCA Solid Tumors mPFS 1-5mo in non-CCA solid tumors Chemo and other late line therapies have high rates of AEs and dose modifications 0-15%

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

RLY-4008 (lirafugratinib) - ReFocus Trial Design Part 1: Dose Escalation Unresectable or metastatic solid tumors FGFR2 alterations per local assessment Both FGFRi-naive & FGFRi-treated allowed RLY-4008 RP2D: 70 mg QD Part 2: Dose Expansion Today's Disclosure

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

Baseline Characteristics - Heavily Pre-Treated Patients Across 18 Tumor Types Parameter Efficacy Population (N=84) Sex, n (%) Female 51 (61) Age (years), median (range) 62 (33, 84) Race, n (%) White 46 (55%) Asian 12 (14%) Other/Unknown 26 (31%) ECOG PS, n (%) 0 31 (37%) 1 52 (62%) 2 1 (1%) Prior lines of systemic therapy, n (%) 0 2 (2%) 1 14 (17%) 2 26 (31%) ?3 42 (50%) Prior systemic therapy, n (%) Chemotherapy 79 (94%) FGFR inhibitor 0 Parameter Efficacy Population (N=84) Tumor types, n (%) Gastric cancer 26 (31%) Breast Cancer 14 (17%) Pancreatic 7 (8%) Ovarian 5 (6%) Colorectal 4 (5%) NSCLC 4 (5%) Endometrial 4 (5%) CUP 3 (4%) Salivary 2 (2%) Others1 15 (18%) FGFR2 oncogenic alteration, n (%) by local testing FGFR2 fusion or rearrangement 26 (31%) FGFR2 amplification2 34 (40%) FGFR2 mutation 24 (29%) *Includes ameloblastic, ampullary, cervical, duodenal, esophageal, fallopian, melanoma, orbita, thyroid Amplification define as FGFR2 locus with copy number ?8 in tumor tissue or validated by next generation sequencing (NGS). No amplification cutoff is defined for circulating tumor DNA (ctDNA) Note: Efficacy population includes 84 patients with FGFR2 fusions, amplifications, or mutations by local testing who had measurable disease and ?1 post-baseline tumor assessment

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

Tumor Responses Observed Across Multiple FGFR2-Fusion Solid Tumors ORR: 35% (9/26) DCR: 69% (18/26) 6 patients ongoing: 3 responders 3 stable disease Note: Waterfall includes patients with post-baseline scans. ORR calculation includes 26 efficacy evaluable patients; ORR = Objective Response Rate; DCR = Disease Control Rate * Response confirmed post data cutoff Consistent activity signal seen across a range of tumor types Indication PR SD N ORR DCR All Fusions 9 9 26 35% 69% NSCLC 2 0 2 100% 100% Ovarian 2 1 3 67% 100% Pancreatic 2 2 6 33% 67% Gastric 1 2 3 33% 100% Breast 0 0 2 0% 0% Other 2 4 10 20% 60% Preliminary data as of 23 Aug 2023 SD uPR PR Stable Disease Unconfirmed Partial Response Confirmed Partial Response Progressive Disease PD BOR = Best Overall Response: *

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

Durable Responses Observed Across FGFR2-Fusion Solid Tumors Range DoR (mon): 2+, 12 % pt with DoR ?6mo: 63% Preliminary data as of 23 Aug 2023 SD uPR PR Stable Disease Unconfirmed Partial Response Confirmed Partial Response Progressive Disease PD BOR = Best Overall Response: * * Response confirmed post data cutoff

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

Early Signal in FGFR2-Amplifications Driven by Key Tumor Types ORR: 24% (8/34) DCR: 62% (21/34) 6 patients ongoing: 4 responders 1 stable disease 1 treated beyond PD Encouraging gastric cancer signal where current approved last line of treatment yields 4% ORR, <4mo mPFS1 Indication PR SD N ORR DCR All Amps 8 13 34 24% 62% Breast 3 2 5 60% 100% Colorectal 1 1 2 50% 100% Gastric 3 8 19 16% 58% NSCLC 0 1 2 0% 50% Other 1 1 6 17% 33% Preliminary data as of 23 Aug 2023 SD uPR PR Stable Disease Unconfirmed Partial Response Confirmed Partial Response Progressive Disease PD BOR = Best Overall Response: Note: Waterfall includes patients with post-baseline scans. ORR calculation includes 34 efficacy evaluable patients; ORR = Objective Response Rate; DCR = Disease Control Rate 1. Bang 2018 Ann Oncol 29:2052 (n=186); These data are derived from different clinical trials at different points in time, with differences in trial design and patient populations. As a result, cross-trial comparisons cannot be made, and no head-to-head clinical trials have been conducted.; * Response confirmed post data cutoff; ** TBP: Treated Beyond Progression * **

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

Durable Responses Observed Across FGFR2-Amplification Solid Tumors Range DoR (mon): 3+, 13+ % pt with DoR ?6mo: 43% Preliminary data as of 23 Aug 2023 3/3 breast pts with DOR >6mo and ongoing SD uPR PR Stable Disease Unconfirmed Partial Response Confirmed Partial Response Progressive Disease PD BOR = Best Overall Response: * ** * Response confirmed post data cutoff; ** TBP: Treated Beyond Progression

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

Strong Signal in HR+/HER2- Breast Cancer ORR: 40% (4/10) DCR: 70% (7/10) 3 responders ongoing Subtype HR+/HER2- HR+/HER2- HR+/HER2- HR+/HER2- HR+/HER2- HR+/HER2- HR+/HER2-* HR+/HER2- - HR+/HER2- - - HR+/HER2- Prior LoT Prior ET? Prior CDK4/6? ESR1 status 10 9 6 5 3 7 6 8 11 - Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y - + - + + + + - + 7 Y Y + Current late line standard of care1 (ET, chemo) yields 2-16% ORR, <6mo mPFS ESR1 alteration status per central testing; ORR = Objective Response Rate; DCR = Disease Control Rate * Local HER2 result equivocal and patient was treated with a single dose of concomitant fulvestrant; - Patient treated with concomitant letrozole and leuprorelin; - - Patient treated with concomitant anastrozole; 1. Reflects reported ORRs in key randomized studies evaluating NCCN recommended regimens for recurrent/metastatic patients (second/third line or later) for HR+ breast cancer (studies on slide 23). These data are derived from different clinical trials at different points in time, with differences in trial design and patient populations. As a result, cross-trial comparisons cannot be made, and no head-to-head clinical trials have been conducted. Preliminary data as of 23 Aug 2023 Median 7 prior lines of systemic therapy SD uPR PR Stable Disease Unconfirmed Partial Response Confirmed Partial Response Progressive Disease PD BOR = Best Overall Response:

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

Multiple Long-Term Responses Observed in Heavily Pre-Treated HR+/HER2- Breast Cancer Range DoR (mon): 6+, 13+ % pt with DoR ?6mo: 100% 5 10 9 3 6 Y - Y Y Y Y Y Y Y Y Prior LoT Prior ET? Prior CDK4/6? ESR1 status + - + + - HR+/ HER2- HR+/ HER2- HR+/ HER2- HR+/ HER2- HR+/ HER2- Subtype HR+/ HER2- HR+/ HER2- HR+/ HER2- - HR+/ HER2- - - HR+/ HER2-* 7 7 8 11 6 Y Y Y Y Y Y Y Y Y Y + + - + + Preliminary data as of 23 Aug 2023 * Local HER2 result equivocal and patient was treated with a single dose of concomitant fulvestrant; - Patient treated with concomitant letrozole and leuprorelin; - - Patient treated with concomitant anastrozole SD uPR PR Stable Disease Unconfirmed Partial Response Confirmed Partial Response Progressive Disease PD BOR = Best Overall Response:

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

Durable cPR in Heavily Pre-Treated FGFR2-Amplified HR+ Breast Cancer Baseline Cycle 9 Courtesy Dr Tai, NCC Singapore ctDNA cleared at C2 Initial PR at Cycle 5, Max 46% tumor regression Patient ongoing treatment at Cycle 19 Generally tolerable safety profile with dose mods Maintained cPR on 20mg QD Treated with a single dose of concomitant fulvestrant, otherwise single agent RLY-4008 66yr female with HR+/HER2- mBC* FGFR2 amplification (copy number: 10) 6 prior lines of therapy, including endocrine therapy, CDK4/6 inhibitor, and chemotherapy Patient Profile Impact of RLY-4008 Preliminary data as of 23 Aug 2023 * Local HER2 result equivocal

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

ORR & DCR by FGFR2 Alteration Types Efficacy Parameter Fusion N=26 Amplification N=34 Mutation N=24 Best Overall Response, n (%) Partial response, n (%)* 9 (35%) 8 (24%) 3 (13%) Stable disease, n (%) 9 (35%) 13 (38%) 7 (29%) Progressive disease, n (%) 6 (23%) 9 (26%) 12 (50%) Not evaluable, n (%)** 2 (8%) 4 (12%) 2 (8%) ORR n (%) 95% CI 9 (35%) 17, 56 8 (24%) 11, 41 3 (13%) 3, 32 Disease control rate, n (%) 95% CI 18 (69%) 48, 86 21 (62%) 44, 78 10 (42%) 22, 63 ORR = Objective Response Rate; DCR = Disease Control Rate *Including ongoing 1 uPR in ovarian cancer patient with FGFR2 fusion, confirmed after data extraction, 1 ongoing uPR in esophageal cancer patient with FGFR2 amplification, and 1 ongoing uPR in gastric cancer patient with FGFR2 mutation ** Including N=2 fusion: 1 patient who discontinued due to death before first post-baseline scan and 1 patient with 1 post-baseline scan that did not meet the minimum duration of > 8 weeks from baseline for SD; N=4 amplification: 3 patients who discontinued due to progressive disease before first post-baseline scan and 1 patient with 1 post-baseline scan that did not meet the minimum duration of > 8 weeks from baseline for SD; N=2 mutation: 2 patients who discontinued due to progressive disease before first post-baseline scan Preliminary data as of 23 Aug 2023

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

Encouraging ORR Across FGFR2 Fusions and Amplifications in Key Tumor Types Efficacy Evaluable Fusions and Amplifications (N=60) ORR = Objective Response Rate; DCR = Disease Control Rate Note: ORR includes PR + 1 ongoing uPR in ovarian cancer patient with FGFR2 fusion confirmed after data extraction, 1 ongoing uPR in esophageal cancer patient with FGFR2 amplification Other includes: ampula vater, cervical, endometrial, esophageal, fallopian, melanoma, salivary, thyroid; ORR = Objective Response Rate; DCR = Disease Control Rate All Tumor Types (N=60) Gastric (N=22) Breast (N=7) Pancreatic (N=6) NSCLC (N=4) Ovarian (N=4) CRC (N=3) CUP (N=3) Other (N=11) 65% 64% 71% 67% 75% 75% 67% 100% 45% ORR DCR Responses observed in 8 tumor types: gastric, breast, pancreatic, NSCLC, ovarian, CRC, CUP, and esophageal Preliminary data as of 23 Aug 2023

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

Current Limitations of Late Line Standard of Care for FGFR2 Non-CCA Tumors Tumor Regimen(s) Med Prior LoT ORR HR+ Breast Cancer1,2 Endocrine Tx1, chemo2 1-3+ 2-16% Gastric Cancer3 Chemotherapy 2 4% Pancreatic Cancer4-6 Chemotherapy 1-2 0-6%* NSCLC7,8 Chemotherapy 2 6-7% Ovarian9,10 Chemotherapy 1-2 - 6-15% HNSCC11 Cetuximab 1-2 7% Sources: 1. Bidard 2022 J Clin Oncol 1:3246 (EMERALD, n=238), 2. ASCO 2022 #LBA3 (DB04, n=163), 3. Bang 2018 Ann Oncol 29:2052 (n=186), 4. Kobayashi 2023 BMC Cancer 21:177 (n=43), 5. Wang-Gillam 2016 Lancet 387:545 (NAPOLI-1, n=419), 6. Yoo 2009 Br J Cancer 101:10 (n=31), 7. Gidard 2009 J Thorac Oncol 4:1544 (n=173), 8. Shepherd 2000 J Clin Oncol 18:2095 (n=103), 9. ASCO 2023 #LBA5507 (MIRASOL, n=226), 10. Mutch 2007 J Clin Oncol 25:2811 (n=195), 11. Seiwert 2004 Ann Oncol 25:1813 (n=60); *ORR excludes 117 pts in NAPOLI-1 (70% ?1 prior lines of therapy) treated with nanoliposomal irinotecan + fluorouracil + folinic acid, which is recommended for good performance status 2L pts (and less likely to be a 3L regimen) - Platinum resistant ovarian cancer. Ovarian CTx: Paclitaxel, liposomal doxorubicin, topetecan, or gemcitabine; Breast CTx: capecitabine, eribulin, gemcitabine, paclitaxel, nab-paclitaxel; Pancreatic Cancer CTx: FOLFOX, 5-FU + fluorouracil, modified FOLFIRI3, NSCLC CTx: Docetaxel, gemcitabine, pemetrexed; Gastric Cancer: Paclitaxel or irinotecan Table reflects NCCN recommended regimens. Median prior LoT and ORR are as reported in studies corresponding to each therapy

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

RLY-4008 (lirafugratinib) - Safety Profile Consistent with Previous Data Treatment ongoing: N=38 (31%) Discontinued from study treatment N=86 (69%): Due to progressive disease N=73 (59%) Due to adverse event N=3 (2.4%; 2 unrelated) No treatment-related Grade 4/5 AEs Interruption, n (%) 59 (48%) Reduction, n (%) 44 (36%) Discontinuation, n (%) 1 (<1%) Consistent, manageable safety profile that minimizes off-isoform toxicity Safety population: FGFRi-naive and FGFRi-pretreated non-CCA PPE: Palmarplantar erythrodysesthesia, RPED: retinal pigment epithelium detachment Treatment-related AEs ?15% Solid Tumor; 70mg QD (N=124)* Treatment-Related Dose Modifications Solid Tumor; 70mg QD (N=124)* Most AEs are low-grade, reversible and manageable on-target events All Grades Grade 3 Preliminary data as of 23 Aug 2023

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

RLY-4008 (lirafugratinib) - Regulatory Strategy to Address More Patients Up to ~6k patients CCA Fusions Up to ~43k patients Tumor Agnostic Fusions Up to ~34k patients Tumor Agnostic Amplifications Up to ~28k patients Breast Cancer (all alts) Revised regulatory strategy: Initial NDA focused on broader tumor agnostic opportunity Larger overall opportunity Strategy driven by IRA Preserves near-term capital Note: Patient totals shown are global incidence rates

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

Relay Tx's Execution & Capital Focus on Highest Value Opportunities Target Program Annual US Patient # PI3K? franchise RLY-2608 PI3K?PAN Monotherapy ~10-68K breast cancer ~76-238K all solid tumors Endocrine Tx (ET) doublet CDK4/6i + ET triplet RLY-5836 PI3K?PAN Monotherapy Endocrine Tx (ET) doublet CDK4/6i + ET triplet PI3K?H1047R ~4-25K breast cancer ~15-48K all solid tumors FGFR2 RLY-4008 ~11-35K4 Solid Tumor 2 programs To be announced Genetic Disease 2 programs To be announced CDK2 RLY-2139 ~46K2 ER? ER? Degrader ~29-196K3 SHP2 GDC-1971 ~37-69K5 Preclinical Early Clinical Late Clinical Breast Cancer Tumor Agnostic (incl. CCA) 3 ongoing combo studies 1. Unless otherwise indicated, all breast cancer patient numbers refer to HR+/HER2- breast cancer tumors; 2. ~46K HR+/HER2- breast cancer patients expected to receive CDK 4/6 inhibitors in adjuvant setting, first-line setting, and second-line setting in 2023, per Decision Resources Breast Cancer Market Forecast report dated June 2022; 3. HR+/HER2- US late-line breast cancer patients compared to HR+/HER2- US incident breast cancer patients; 4. FGFR2 altered late-line solid tumors compared to comprehensive annual FGFR2 altered incident solid tumors including additional FGFR gene fusions and rearrangements resulting from truncation of the protein at exon 18 and all breast cancer patients with FGFR2 alterations; 5. SHP2 combo only includes KRAS G12C in lung and colorectal, EGFR mutations in lung, and ALK fusions in lung Note: Unless otherwise indicated, patient #'s refer to total annual number of US patients with late-line cancers compared to comprehensive annual incidence that may be amenable to treatment with our programs Pausing programs YE23

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

Initial RLY-2608 data in 1H 2023 RLY-5836 clinical start in 2Q 2023 RLY-2608 expansion cohorts initiated 2H 2023 RLY-2608 Triplet Dose Escalation initiated by YE 2023 Additional data update in 2024 Relay Tx - Capital, Team & Execution Focus to Deliver on Key Milestones Undisclosed RLY-4008 (lirafugratinib) Full dose escalation data in 1H 2023 (2023 ASCO) Tumor Agnostic expansion cohorts data in 2H 2023 (2023 Triple) Pivotal cohort full enrollment in 2H 2023 Clinical data and regulatory update in 2024 GDC-1971 (SHP2) Ongoing combo trials; Genentech controls data disclosures To be announced New program(s) to be disclosed in 2024 5+ undisclosed programs in preclinical development and additional early-stage efforts across platform Tumor Agnostic Breast Cancer Franchise Cash, cash equivalents and investments as of the end of 2Q 2023 ~$872M ER? development candidate nomination in 2023 CDK2i RLY-2139 clinical start in early 2024 RLY-2608 RLY-5836 (PI3K?PAN) PI3K? Companions + Current cash, cash equivalents and investments are expected to be sufficient to fund current operating plan into 2H 2026 Pausing both programs YE 2023 + +

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

RLY-4008 - Non-CCA Mutations Note: ORR calculation includes 24 efficacy evaluable patients; mutations per local assessment ORR: 13% (3/24) DCR: 42% (10/24) 4 pt total ongoing: 2 responders 2 stable disease Add'l deep response (67% tumor reduction) in salivary gland cancer in pt previously treated with carboplatin/paclitaxel, lenvatinib Indication PR SD N ORR DCR All Muts 3 7 24 13% 42% Ameloblastic 1 1 2 50% 100% Gastric 1 1 4 25% 50% Breast 1 2 7 14% 43% Salivary 0 1 1 0% 100% Other 0 2 10 0% 20% L550R S252W N549K N549K P253R N549K N549K L618F C382R S252W N549K P253R P253R P253R C382R P253R V564L K659M R678G L763Hfs N549K C382R Mutation Preliminary data as of 23 Aug 2023

    UNITED STATES
     SECURITIES AND EXCHANGE COMMISSION
     WASHINGTON, D.C. 20549

RLY-4008 - Non-CCA Mutations Range DoR (mon): 9, 15 % pt with DoR ?6mo: 100% Preliminary data as of 23 Aug 2023 C382R L763Hfs K659M C382R P253R N549K P253R R678G P253R L618F P253R P253R N549K C382R N549K S252W V564L N549K L550R S252W N549K C382R S252W N549K Mutation

Oct 12, 2023

COMTEX_441824846/2254/2023-10-13T00:59:03

(c) 1995-2023 Cybernet Data Systems, Inc. All Rights Reserved

EDGAR Online-8-K Glimpse
Friday, October 6, 2023 26219 mots, p. NA

S-1: Naploy Corp.

(EDGAR Online via COMTEX) -- Table of Contents

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

Approximate date of commencement of proposed sale to the public: as soon as practicable after the effective date of this Registration Statement.

If any of the securities being registered on this Form are to be offered on a delayed or continuous basis pursuant to Rule 415 under the Securities Act of 1933, check the following box.?

If this Form is filed to register additional securities for an offering pursuant to Rule 462(b) under the Securities Act, check the following box and list the Securities Act Registration Statement number of the earlier effective Registration Statement for the same offering. ?

If this Form is a post-effective amendment filed pursuant to Rule 462(c) under the Securities Act, check the following box and list the Securities Act Registration Statement number of the earlier effective Registration Statement for the same offering. ?

If this Form is a post-effective amendment filed pursuant to Rule 462(d) under the Securities Act, check the following box and list the Securities Act Registration Statement number of the earlier effective Registration Statement for the same offering. ?

Indicate by check mark whether the registrant is a large accelerated filer, an accelerated filer, a non-accelerated filer, or a smaller reporting company. See definitions of "Large accelerated filer," "Accelerated filer," "Smaller reporting company" and "Emerging growth company" in Rule 12b-2 of the Exchange Act (check one):

Large accelerated filer ? Accelerated Filer ? Non-accelerated filer ? Smaller reporting company ? (Do not check if a smaller reporting company) Emerging growth company ?

If an emerging growth company, indicate by check mark if the registrant has elected not to use the extended transition period for complying with any new or revised financial accounting standards provided pursuant to Section 13(a) of the Exchange Act. ?

Indicate by check mark whether the registrant is a shell company (as defined in Rule 12b-2 of the Exchange Act). Yes ? No ?

    UNITED STATES

    UNITED STATES

    UNITED STATES

The Registrant hereby amends this registration statement on such date or dates as may be necessary to delay its effective date until the registrant shall file a further amendment which specifically states that this registration statement shall thereafter become effective in accordance with section 8(a) of the Securities Act of 1933 or until the registration statement shall become effective on such date as the Securities and Exchange Commission, acting pursuant to such section 8(a), may determine.

THE INFORMATION IN THIS PROSPECTUS IS NOT COMPLETE AND MAY BE CHANGED. THESE SECURITIES MAY NOT BE SOLD UNTIL THE REGISTRATION STATEMENT FILED WITH THE SECURITIES AND EXCHANGE COMMISSION ("SEC") IS EFFECTIVE. THIS PROSPECTUS IS NOT AN OFFER TO SELL THESE SECURITIES AND IT IS NOT SOLICITING AN OFFER TO BUY THESE SECURITIES IN ANY STATE WHERE THE OFFER OR SALE IS NOT PERMITTED.

    UNITED STATES

ii

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

This is the initial offering of Common stock of Naploy Corp., a Wyoming corporation, and no public market exists for the securities being offered. Naploy Corp. is offering for sale a total of up to 6,000,000 shares of common stock at a fixed price of $0.02 per share for aggregate net proceeds of up to $120,000, assuming that the entire offering is completed.

There is no minimum number of shares required to be purchased. This offering is on a best effort, meaning, no minimum number of shares must be sold. See " Use of Proceeds " and " Plan of Distribution ".

The offering is being conducted on a self-underwritten, best efforts basis, which means our directors, Frederick Sidney Reinhard Arnold and Rafael Angel Ulloa Bonilla, will attempt to sell the shares without the participation of an underwriter. This prospectus will permit our directors to sell the shares directly to the public, with no commission or other remuneration payable to them for any shares they may sell. We will pay all expenses incurred in this offering.

In offering the securities on our behalf, Mr. Arnold and Mr. Ulloa Bonilla will rely on the safe harbor from broker-dealer registration set out in Rule 3a4-1 under the Securities and Exchange Act of 1934. The shares will be offered at a fixed price of $0.02 per share for a period of three hundred and sixty-five (365) days from the effective date of this prospectus, unless extended by our Board of Directors for an additional 90 days.

Naploy Corp. is a development stage, Start-up Company. Any investment in the shares offered herein involves a high degree of risk. You should only purchase shares if you can afford a complete loss of your investment.

Naploy Corp. qualifies as an "emerging growth company" as defined in the Jumpstart our Business Startups Act (the "JOBS Act").

BEFORE INVESTING, YOU SHOULD CAREFULLY READ THIS PROSPECTUS AND CONSIDER THE SECTION OF THIS PROSPECTUS ENTITLED " RISK FACTORS ".

NEITHER THE SECURITIES AND EXCHANGE COMMISSION NOR ANY STATE SECURITIES DIVISION HAS APPROVED OR DISAPPROVED THESE SECURITIES, OR DETERMINED IF THIS PROSPECTUS IS TRUTHFUL OR COMPLETE. ANY REPRESENTATION TO THE CONTRARY IS A CRIMINAL OFFENSE.

THE INFORMATION IN THIS PROSPECTUS IS NOT COMPLETE AND MAY BE CHANGED. WE WILL NOT SELL THESE SECURITIES UNTIL THE REGISTRATION STATEMENT IS FILED WITH THE U.S. SECURITIES AND EXCHANGE COMMISSION AND HAS BEEN CLEARED OF COMMENTS AND IS DECLARED EFFECTIVE. THIS PROSPECTUS IS NOT AN OFFER TO SELL THESE SECURITIES AND IT IS NOT SOLICITING AN OFFER TO BUY THESE SECURITIES IN ANY STATE WHERE THE OFFER OF SALE IS NOT PERMITTED.

iii

    UNITED STATES

    UNITED STATES

PROSPECTUS SUMMARY 2 General Information about Our Company 2 The Offering 5 RISK FACTORS 6 Risks Associated With Our Company 6 Risks Associated With This Offering 10 USE OF PROCEEDS 13 DETERMINATION OF OFFERING PRICE 14 DILUTION OF THE PRICE YOU PAY FOR YOUR SHARES 14 PLAN OF DISTRIBUTION 15 Terms of the Offering 16 Penny Stock Rules 16 Market Information 17 Deposit of Offering Proceeds 17 Procedures for and Requirements for Subscription 17 DESCRIPTION OF SECURITIES TO BE REGISTERED 17 INTEREST OF NAMED EXPERTS AND COUNSEL 18 DESCRIPTION OF OUR BUSINESS 19 DESCRIPTION OF PROPERTY 27 LEGAL PROCEEDINGS 27 MARKET FOR COMMON EQUITY AND RELATED STOCKHOLDER MATTERS 30 MANAGEMENT'S DISCUSSION AND ANALYSIS OR PLAN OF OPERATION 32 CHANGES IN AND DISAGREEMENTS WITH ACCOUNTANTS ON ACCOUNTING AND 34 FINANCIAL DISCLOSURE DIRECTORS, EXECUTIVE OFFICERS, PROMOTERS AND CONTROL PERSONS 35 EXECUTIVE COMPENSATION 36 SECURITY OWNERSHIP OF CERTAIN BENEFICIAL OWNERS AND MANAGEMENT 38 CERTAIN RELATIONSHIPS AND RELATED TRANSACTIONS 39 INDEMNIFICATION 39 AVAILABLE INFORMATION 39 FINANCIAL STATEMENTS 39

1

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

You should read the following summary together with the more detailed business information, financial statements and related notes that appear elsewhere in this prospectus. In this prospectus, unless the context otherwise denotes, references to "we," "us," "our" and "Naploy Corp." are to Naploy Corp.

You should rely only on the information contained in this prospectus. We have not authorized any other person to provide you with different information. This prospectus is neither an offer to sell, nor is it seeking an offer to buy, these securities in any state where the offer or sale is not permitted. The information in this prospectus is complete and accurate as of the date on the front cover, but the information may have changed since that date.

    UNITED STATES

Naploy Corp. was incorporated on April 6, 2023 under the laws of the state of Wyoming. Our primary focus is on launching a news blog that provides the latest updates on health-related topics, including but not limited to medical breakthroughs, healthy lifestyle tips, and updates on healthcare policies. Our executive and business office is located at 95 Lias Estate Kafe district Abuja, FCT 900108 Nigeria, and our telephone number is +13072133163.

We have developed a full business plan. We are offering our services to the clients in Nigeria and then we are going to spread our services in other African countries. Our mobile application is available in three languages: African, English, and French, making it accessible to a broader audience. The Company has no revenue and has incurred losses since its inception. Our possesses assets in a form of an operative mobile application and a website. The Mobile Application and Website Purchase Agreement is filed as Exhibit 10.2 to this Registration Statement.

Our Naploy app is your go-to source for the latest health news and updates. Naploy App offers an article library- News Blog that deals with the most common health topics. Our health blog covers diverse health related concerns such as nutrition and diet, fitness, weight control, diseases, disease management, societal trends affecting health, analysis about health, business of health and health research. The app is available for both Android and iOS mobile operating systems and provides you with quick access to a vast healthcare and medical database. With the " Naploy App," you can stay informed about the latest health news anytime, anywhere. We are dedicated to bringing you high-quality health information and keeping you up-to-date on the latest developments in the world of healthcare.

One of our main App features is Symptom Diagnostic. Symptom Diagnostic is an advanced tool that uses high-grade AI technology to provide diagnoses. Currently, our AI technology already working, but during the lifetime of the App it should be refined and improved. To begin, you will have to enter your age and gender, after which you can select or type in your symptoms, intensity and duration. This step is then followed up by some more questions to determine which symptom is bothering you the most and if you are on meds and/or have had any conditions in the past. Thereafter, it will give you a list of possible conditions (about 5, starting with the most likely) which you can then click on and find more details about the disease.

Symptom Diagnostics are an innovative addition to digital health. This tool does not provide medical advice It is intended for informational purposes only. Nevertheless, these services should not be considered as definite diagnostic tools but rather as a guide to point the user towards possible conditions relating to their symptoms. Consulting an actual physician will help you have a more accurate diagnosis and subsequent treatment.

2

Our "Naploy app" includes a convenient Clinic Search feature that allows clients to contact us and send a request for searching the clinics and proper medical services that suit their needs for a fee. Through this feature, clients can request information about the type of treatment they need, as well as leave their phone number and email. Our team will then contact the client to clarify all the necessary details about their diagnosis and treatment needs. Our expert managers will then provide information about the best medical institutions for the client, including details about the location, clinic licenses, doctors, we will monitor all the reviews and feedbacks and check all the doctors for their professional qualifications. Our clients can expect top-notch customer service, as our managers will communicate with them through phone, email, and messengers according to their preferences. We are dedicated to providing the professional services in searching the best medical institutions, making for the right medical care for our clients. We will make this process much easier and comfortable for clients from our professional website.

In addition, we also offer paid contextual advertising services for medical institutions on our Naploy app's news blog:

-Banner ads

Our banner advertising will consist of static or animated images or media and would be placed in high-visibility areas. Banner advertising is attractive because it can help create medical institutions awareness and generate leads.

-Pop up

Another effective form of our advertising services. Unlike banner ads, the pop-up will appear in the center of the screen, drawing the attention of customers.

By utilizing our advertising services, medical institutions can increase their online presence and reach a wider audience. Our goal is to provide a comprehensive platform for both health news and healthcare advertising, and we believe that this additional feature will be a valuable asset for both our users and medical institutions.

The Company's revenues are expected to be derived primarily from the clients who will get the online information help services for finding medical institutions for their needs, as well as from paid contextual advertising services offered to medical institutions through our website and mobile application.

We plan constantly expand the functionality in our services to make our application and website more attractive for our consumers. We have purchased the mobile application and website for iOS and Android platforms for total consideration of US $45,000.

The payment is made in several stages:

    UNITED STATES

The links for the "Naploy" application:

In Google Play - https://play.google.com/store/apps/details?id=naploy.app&hl=uk&gl=USIn

App Store - https://apps.apple.com/us/app/naploy/id6451121811

Our website address is https://naploy.com/#/app

Here are some of the technologies that we intend successfully to implement in our mobile application:

- Improvement of the AI technology

- Map View

- Reviews

- Booking Services

- Notifications

- Marketing Opportunities

- Body map symptom checker

- Personal health tracker

- Medicine reminder

- Language translation

3

At the present there is no assurance that we will be successful in providing our services.

From inception on April 6, 2023 until the date of this filing, we have had limited operating activities. Our financial statements from inception on April 6, 2023 through July 31, 2023 reports $25,700 in Accounts Payable (Purchase of the Website and Mobile Application and professional fees) and a net loss of $6,380 consisting of depreciation expense $375, general and administrative expenses $105, professional fees $5,900; the Company issued common stock 2,000,000 shares at par value $0.0001 in consideration of $200 to pay partial Incorporation fees expenses. Our independent auditor has issued an audit opinion with respect to our financial statements for the period ended July 31, 2023, which includes a statement expressing substantial doubt as to our ability to continue as a going concern.

Our principal offices are located at 95 Lias Estate Kafe district Abuja, FCT 900108 Nigeria. Our telephone number is +13072133163 and our email address is [email protected].

Currently, we have no employees, only our officers and Directors - Mr. Frederick Sidney Reinhard Arnold and Mr. Rafael Angel Ulloa Bonilla. They will offer the shares to friends, relatives, acquaintances and business associates.

This is a direct participation offering since we are offering the stock directly to the public without the participation of an underwriter. Our directors will be solely responsible for selling shares under this offering and no commission will be paid to them on any sales. There has been no market for our securities and a public market may never develop, or, if any market does develop, it may not be sustained. Our common stock is not traded on any exchange or on the over-the-counter market. After the effective date of the registration statement relating to this prospectus, we will seek to have a market maker file an application with FINRA for our common stock to be eligible for trading on the OTC Markets quotation system. We do not have an arrangement in place for a market maker to file such and application and there is no guarantee that we will be able to find one to do so.

4

    UNITED STATES

Following is a brief summary of this offering. Please see the " Plan of Distribution " section for a more detailed description of the terms of the offering.

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

Shares outstanding prior 2,000,000 to the offering:

Shares outstanding after 8,000,000, assuming the entire offering is sold. the offering:

    UNITED STATES

Our officers, directors, control persons and/or affiliates do not intend to purchase any shares in this offering.

Summary Financial Information

The following Financial information summarizes the more complete historical financial information at the end of this prospectus. The total Expenses are composed of incorporation and banking Costs.

    UNITED STATES

    UNITED STATES

5

    UNITED STATES

An investment in our common stock involves a high degree of risk. Before investing in our common stock of Naploy Corp., you should carefully consider the risks described below and the other information in this prospectus. If any of the following risks or the risks which may or may not be foreseen and might not be included below occurs, our business, operating results and financial condition could be seriously harmed. The trading price of our common stock, when and if we trade at a later date, could decline due to any of these risks, and you may lose all or part of your investment.

    UNITED STATES

BECAUSE WE HAVE NOT YET COMMENCED BUSINESS OPERATIONS, WE FACE A HIGH RISK OF BUSINESS FAILURE

We have not yet attracted any potential customers and our online health platform services just started recently. Accordingly, we have no way to evaluate the likelihood that our business will be successful. We were incorporated on April 6, 2023 and to date have been involved primarily in organizational activities. We have not earned any revenues as of the date of this prospectus and do not anticipate earning revenue until after the completion of our intended offering, of which there is no guarantee. Potential investors should be aware of the difficulties normally encountered by development stage companies and the high rate of failure of such enterprises. The likelihood of success must be considered in light of the problems, expenses, difficulties, complications in marketing campaign and in recognition of our product.

SINCE WE ARE A DEVELOPMENT STAGE COMPANY, HAVE GENERATED NO REVENUES AND LACK AN OPERATING HISTORY, AN INVESTMENT IN THE SHARES OFFERED HEREIN IS HIGHLY RISKY AND COULD RESULT IN A COMPLETE LOSS OF YOUR INVESTMENT IF WE ARE UNSUCCESSFUL IN OUR BUSINESS PLANS.

Our company was incorporated on April 6, 2023; we have not yet realized any revenues. We have no operating history upon which an evaluation of our future prospects can be made. Based upon current plans, we expect to incur operating losses in future periods as we incur significant expenses associated with the initial start-up of our business. Further, we cannot guarantee that we will be successful in realizing revenues or in achieving or sustaining positive cash flow at any time in the future. Any such failure could result in the possible closure of our business or force us to seek additional capital through loans or additional sales of our equity securities to continue business operations, which would dilute the value of any shares you purchase in this offering.

WE HAVE YET TO EARN REVENUE AND OUR ABILITY TO SUSTAIN OUR OPERATIONS DEPENDS ON OUR ABILITY TO RAISE FUNDING. FURTHERMORE, THERE IS A RISK ASSOCIATED WITH THE BUSINESS DEPENDENCE ON THE MARKET IN NIGERIA.

Our future is dependent upon our ability to obtain financing and upon future profitable operations. Furthermore, the finances required to fully develop our plan cannot be predicted with any certainty and may exceed any estimates we set forth. These factors raise doubt that we will be able to continue as a going concern. Any financial changes on the market in Nigeria could curb our ability to raise additional funds by issuing new debt or equity securities or otherwise. If we fail to raise sufficient capital when required, we will not be able to complete our business plan. As a result, we may have to liquidate our business and you may lose the money you invest. You should consider our independent registered public accountant's comments when assessing whether an investment in Naploy Corp. is safe.

6

IF OUR BUSINESS PLAN FAILS, WE WILL DISSOLVE AND INVESTORS MAY NOT RECEIVE ANY PORTION OF THEIR INVESTMENT BACK

If we are unable to realize profitable operations, our business will eventually fail. In such circumstances, it is likely that we will dissolve and, depending on our remaining assets at the time of dissolution, we may not be able to return any funds back to investors.

BECAUSE WE ARE A SMALL COMPANY AND HAVE LIMITED CAPITAL, OUR MARKETING CAMPAIGN MAY NOT BE GOOD ENOUGH TO ATTRACT SUFFICIENT CLIENTS FOR US TO OPERATE PROFITABLY. IF WE DO NOT MAKE A PROFIT, WE WILL SUSPEND OR CEASE OPERATIONS.

Due to the fact we are a small company and have limited capital, we must limit our marketing activities and may not be able to make our product known to potential customers. Because we will be limiting our marketing activities, we may not be able to attract enough customers to operate profitably. If we cannot operate profitably, we may have to suspend or cease operations.

BECAUSE OUR ONLINE HEALTH PLATFORM WILL NOT BE PATENT PROTECTED, OTHER COMPETITORS COULD COPY OUR TECHNOLOGY, WHICH COULD CAUSE OUR BUSINESS TO FAIL.

Our potential competitive advantage will be our online health platform, which will help to find medical institutions for customer's treatment and paid advertising and marketing for other medical institutions that are interested in advertising their institutions. Due to the costs involved and the potential inability to qualify, we will not apply for patent protection of our platform. Accordingly, our business is subject to the risk that competitors could either copy or reverse engineer our technology. If this occurs, our ability to sell our services could be jeopardized, which could cause our business to fail.

WE MAY NOT BE ABLE TO COMPETE EFFECTIVELY AGAINST OUR COMPETITORS.

The healthcare business sector is rather competitive. The sector includes large, established international companies and services which have better brand recognition, price and marketing capabilities. So, the competitors of our business will have greater financial resources and may be able to withstand price competition and attract customers better than we will. We also expect to face competition from new market entrants. We may be unable to compete effectively with the existing or new competitors, which could have a material adverse effect on our financial condition and results of operations.

THE OFFICERS AND DIRECTORS OF THE COMPANY, MR. ARNOLD AND MR. ULLOA BONILLA, CURRENTLY DEVOTE APPROXIMATELY 30 HOURS PER WEEK EACH TO OUR COMPANY MATTERS. THEY DO NOT HAVE ANY PUBLIC COMPANY EXPERIENCE AND ARE INVOLVED IN OTHER BUSINESS ACTIVITIES. THE COMPANY'S NEEDS COULD EXCEED THE AMOUNT OF TIME OR LEVEL OF EXPERIENCE THEY MAY HAVE. THIS COULD RESULT IN THEIR INABILITY TO PROPERLY MANAGE THE COMPANY'S AFFAIRS WHICH COULD FURTHER RESULT IN NO REVENUES OR PROFITS.

Our business plan does not provide for the hiring of any additional employees until sales will support the expense. Until that time the responsibility of developing the company's business, the offering and selling of the shares through this prospectus and fulfilling the reporting requirements of a public company all fall upon Mr. Arnold and Mr. Ulloa Bonilla. We have not formulated a plan to resolve any possible conflicts of interests if any appear with their other business activities. Currently there are no any conflicts of interests with our officers and their business activities. In the event they are unable to fulfill any aspect of their duties to the company we may experience a shortfall or complete lack of sales resulting in little or no profits and eventual closure of the business.

BECAUSE WE RELY ON FREDERICK SIDNEY REINHARD ARNOLD AND RAFAEL ANGEL ULLOA BONILLA, OUR OFFICERS AND DIRECTORS, TO CONDUCT OUR OPERATIONS, OUR BUSINESS WILL LIKELY FAIL IF WE LOSE THEIR SERVICES.

We depend on the services of our officers and directors, Frederick Sidney Reinhard Arnold and Rafael Angel Ulloa Bonilla, for the future success of our business. The loss of the services of our directors could result in the failure of our business and could have an adverse effect on our business, financial condition and results of operations. Frederick Sidney Reinhard Arnold and Rafael Angel Ulloa Bonilla are our officers and directors, and if they should die there will be no one to appoint a new officer and, in that event, we will have no alternative but to cease operations.

7

INVESTORS CANNOT WITHDRAW FUNDS ONCE THEIR SUBSCRIPTION AGREEMENTS ARE ACCEPTED BY THE COMPANY. THEREFORE, BECAUSE THE INVESTMENT IS IRREVOCABLE, INVESTORS MUST BE PREPARED THAT THEY MAY LOSE THEIR ENTIRE INVESTMENT IF THE BUSINESS FAILS.

Investors do not have the right to withdraw invested funds once the subscription agreement is accepted by the Company. Subscription payments will be paid to Naploy Corp. and held in our corporate bank account. Once the Company reviews the Subscription Agreements, and determines that they are in good order, and the Company accepts the subscription, investors will not have the right of return of such funds, the investment will become irrevocable. Therefore, if the business of the Company fails, the investor must be prepared to lose their entire investment in the Company.

BECAUSE OUR COMPANY'S HEADQUARTER, ASSETS AND DIRECTORS ARE IN OTHER COUNTRY, INVESTORS MAY EXPERIENCE DIFFICULTIES IN ATTEMPTING TO EFFECT SERVICE OF PROCESS AND TO ENFORCE JUDGMENTS BASED UPON U.S. FEDERAL SECURITIES LAWS AGAINST THE COMPANY AND ITS NON-U.S. RESIDENT OFFICER AND DIRECTOR.

While we are organized under the laws of State of Wyoming, our officers and Directors are non-residents of the USA and our headquarters and assets are located outside the United States. Our headquarters and major assets are located in Nigeria. Consequently, it may be difficult for investors to affect service of process on them in the United States and to enforce in the United States judgments obtained in United States courts against them based on the civil liability provisions of the United States securities laws, enforce judgments based on the civil liability provisions of the United States securities laws or bring an original action against them in Nigeria court to enforce liabilities based upon the United States federal securities laws. Since our major assets, other than our bank account, are currently located outside U.S. it may be difficult or impossible for U.S. investors to collect a judgment against us.

IF WE CONTINUE TO INCUR NET LOSSES, OUR BUSINESS WILL FAIL

From our incorporation on April 6, 2023 until July 31, 2023, we incurred cumulative net losses of $6,380. We expect to incur losses in the foreseeable future as our business develops. Unless we are able to generate profit from our business operations within a reasonable time, our business will fail.

WE ARE AFFECTED BY EXTENSIVE LAWS, GOVERNMENTAL REGULATIONS, ADMINISTRATIVE DETERMINATIONS, COURT DECISIONS AND SIMILAR CONSTRAINTS THAT COULD INCREASE IN SEVERITY AND HURT RESULTS OF OPERATIONS.

Our industry is subject to federal, state and other governmental regulation. Certain federal and state agencies, such as the Federal Trade Commission, or the "FTC", regulate and enforce such laws relating to advertising, disclosures to consumers, privacy, consumer pricing and billing arrangements and other consumer protection matters. A determination by a federal or state agency, or a court, that any of our practices do not meet existing or new laws or regulations could result in liability, adverse publicity and restrictions of our business operations. Some advertising practices in the wellness and nutritional supplement industry, in particular, have led to investigations from time to time by the FTC and other governmental agencies and many companies in the wellness and nutritional supplement industry, have entered into consent decrees with the FTC relating to wellness and nutritional supplement claims and other advertising practices. In addition, the FTC's Guides concerning the Use of Endorsements and Testimonials in Advertising require us and other wellness and nutritional supplement companies to use a statement as to what the typical benefits a customer can expect to achieve on our programs when using a customer's wellness benefit testimonial in advertising. Federal and state regulation of advertising practices generally, and in the wellness and nutritional supplement industry in particular, may increase in scope or severity in the future, which could have a material adverse impact on our business.

8

IF THE SECURITY OF OUR CUSTOMERS' CONFIDENTIAL INFORMATION STORED IN OUR SYSTEMS IS BREACHED OR OTHERWISE SUBJECTED TO UNAUTHORIZED ACCESS, SECURE INFORMATION MAY BE STOLEN, OUR REPUTATION MAY BE HARMED, AND WE MAY BE EXPOSED TO LIABILITY.

Our internet content and e-commerce platform stores information, which may be personally-identifiable sensitive information, of our past, current and prospective customers. Any accidental or willful security breaches or other unauthorized access could cause secure information to be stolen and used for criminal purposes. Security breaches or unauthorized access to secure information could also expose us to liability related to the loss of the information, time-consuming and expensive litigation, and negative publicity. If security measures are breached because of third-party action, employee error, malfeasance or otherwise, or if design flaws in our internet content and e-commerce platform are exposed and exploited, and, as a result, a third party or disaffected employee obtains unauthorized access to any of our customers' data, our relationships with our customers will be severely damaged, and we could incur significant liability. Because techniques used to obtain unauthorized access or to sabotage systems change frequently and generally are not recognized until they are launched against a target, we and our third-party hosting services, content providers and e-commerce providers may be unable to anticipate these techniques or to implement adequate preventative measures. In addition, many states have enacted laws requiring companies to notify individuals of data security breaches involving their personal data. These mandatory disclosures regarding a security breach are costly to implement and often lead to widespread negative publicity, which may cause our customers to lose confidence in the effectiveness of our data security measures. Any security breach, whether actual or perceived, would harm our reputation, and we could lose customers.

THE SARBANES-OXLEY ACT IMPOSES CONSIDERABLE ENCUMBRANCE UPON THE COMPANY WITHOUT PROVIDING EQUITABLE BENEFITS TO THE COMPANY.

The Sarbanes-Oxley Act of 2002 (the "Sarbanes-Oxley Act") was enacted in response to public concern regarding corporate responsibility in the wake numerous accounting scandals. The stated goals of the Sarbanes-Oxley Act are to increase corporate accountability, provide enhanced penalties for accounting and auditing improprieties at publicly traded companies and protect investors by improving the transparency, accuracy and reliability of corporate disclosures pursuant to applicable securities laws. The Sarbanes-Oxley Act applies to all companies that file or are required to file regular reports with the SEC under the Securities Exchange Act of 1934 (the "Exchange Act").

Upon becoming a public company, we will be required to comply with the Sarbanes-Oxley Act. Since the enactment of the Sarbanes-Oxley Act has resulted in the imposition of a series of guidelines by the SEC that increase the responsibilities and liabilities of directors and executive officers, the perceived heightened personal risk associated with these changes may deter qualified individuals from accepting such roles. Consequently, it may be more difficult for us to attract and retain suitable persons to serve as our directors or executive officers, and we may need to incur additional operating costs. This could curtail the company from becoming a profitable business.

THE CORONAVIRUS (COVID-19) PANDEMIC COULD ADVERSELY IMPACT THE DEMAND FOR OUR HEALTHCARE SERVICES AND OUR OPERATING RESULTS; IT COULD INCREASE THE LIKELIHOOD THAT OUR BUSINESS FAILS.

The COVID-19 pandemic has negatively impacted the global economy, disrupted consumer spending and global supply chains, and created significant volatility and disruption of financial markets. The extent of the impact of the COVID-19 pandemic, including our ability to execute our business strategies as planned, will depend on future developments, including the duration and severity of the pandemic, which are highly uncertain and cannot be predicted. If the overall economy is impacted for an extended period, the Company's future operating results may be materially adversely affected.

The COVID-19 pandemic could also adversely affect our liquidity and ability to access the capital markets. Uncertainty regarding the duration of the COVID-19 pandemic may adversely impact our ability to raise additional capital. The extent of the impact of COVID-19 on our business and financial results will also depend on future developments, including the duration and spread of the pandemic and different COVID variants, its impact on the financial markets in which we operate.

9

    UNITED STATES

THERE IS NO MINIMUM NUMBER OF SHARES THAT MUST BE SOLD IN OUR OFFERING AND NO ASSURANCE THAT THE PROCEEDS FROM THE SALE OF SHARE WILL ALLOW US TO MEET OUR GOALS.

We are selling our shares on a "best efforts" basis, and there is no minimum number of shares that must be sold by us in this Offering. Similarly, there are no minimum purchase requirements. We do not have an underwriter, and no party has made a firm commitment to buy any or all of our securities. We intend to sell the shares through our directors who will not be separately compensated for their efforts. Even if we only raise a nominal amount of money, we will not refund any funds collected from you. Any money we do receive will be immediately used by us for our business purposes. Upon completion of this offering, we intend to utilize the net proceeds to finance our business operations. While we believe that the net proceeds from the sale of all shares in this offering will enable us to meet our business plans and enable us to operate as other than a going concern, there can be no assurance that all these goals can be achieved. Moreover, if less than all of the shares are sold, management will be required to adjust its plans and allocate proceeds in a manner which it believes, in our sole discretion, will be in our best interests. It is highly likely that if not all of the shares are sold there will be a need for additional financing in the future, without which our ability to operate as other than a going concern may be jeopardized. No assurance whatsoever can be given or is made that such additional financing, if and when needed, will be available or that it can be obtained on terms favorable to us. Accordingly, you may be investing in a company that does not have adequate funds to conduct its operations. If that happens, you will suffer a loss of your investment. The funds raised in this offering will not be placed into an escrow account or trust account and will be immediately accessible to the Company.

WE ARE SELLING THIS OFFERING WITHOUT AN UNDERWRITER AND MAY BE UNABLE TO SELL ANY SHARES.

This offering is self-underwritten, that is, we are not going to engage the services of an underwriter to sell the shares; we intend to sell our shares through our officers and directors, who will receive no commissions. They will offer the shares to friends and relatives, acquaintances and business associates. Unless they are successful in selling at least 25% of the shares and receiving $30,000 in the proceeds from this offering, we may have to seek alternative financing to operate our business.

ANY FUTURE SALE OF STOCK HELD BY EXISTING STOCKHOLDER OF THE COMPANY, WHO WILL HOLD APPROXIMATELY 25% OF OUR TOTAL ISSUED AND OUTSTANDING SHARES AFTER COMPLETION OF THIS OFFERING, COULD SEVERELY IMPACT THE MARKET PRICE OF OUR STOCK.

Since inception, a total of 2,000,000 shares of common stock have been issued to Frederick Sidney Reinhard Arnold, our officer and director and our only existing principal stockholder. These shares are "restricted securities", as that term is defined in Rule 144 of the Rules and Regulations of the SEC promulgated under the Act. Under Rule 144, such shares can be publicly sold, subject to volume restrictions and certain restrictions on the manner of sale, commencing one year after their acquisition. Any sale of these shares held by Frederick Sidney Reinhard Arnold after the applicable restrictions expire could have a depressive effect on the price of our common stock in any market that may develop, of which there is no guarantee. Mr. Arnold does not currently have any plans to sell his shares at any time after this offering is completed.

THE TRADING IN OUR SHARES WILL BE REGULATED BY THE SECURITIES AND EXCHANGE COMMISSION RULE 15G-9, WHICH ESTABLISHED THE DEFINITION OF A "PENNY STOCK."

The shares being offered are defined as a penny stock under the Securities and Exchange Act of 1934, as amended (the "Exchange Act"), and rules of the Commission. The Exchange Act and such penny stock rules generally impose additional sales practice and disclosure requirements on broker-dealers who sell our securities to persons other than certain accredited investors who are, generally, institutions with assets in excess of $5,000,000 or individuals with net worth in excess of $1,000,000 or annual income exceeding $200,000 ($300,000 jointly with spouse), or in transactions not recommended by the broker-dealer. For transactions covered by the penny stock rules, a broker dealer must make certain mandated disclosures in penny stock transactions, including the actual sale or purchase price and actual bid and offer quotations, the compensation to be received by the broker-dealer and certain associated persons, and deliver certain disclosures required by the Commission. Consequently, the penny stock rules may make it difficult for you to resell any shares you may purchase, if at all.

10

THERE IS NO LIQUIDITY AND NO ESTABLISHED PUBLIC MARKET FOR OUR COMMON STOCK AND WE MAY NOT BE SUCCESSFUL AT OBTAINING A QUOTATION ON A RECOGNIZED QUOTATION SERVICE. IN SUCH EVENT IT MAY BE DIFFICULT TO SELL YOUR SHARES.

There is currently no market for our common stock and we can provide no assurance that a market will develop. We currently plan to apply for listing of our common stock on the OTC Markets upon the effectiveness of the registration statement, of which this prospectus forms a part. However, we can provide investors with no assurance that our shares will be traded on the bulletin board or, if traded, that a public market will materialize. If no market is ever developed for our shares, it will be difficult for shareholders to sell their stock. In such a case, shareholders may find that they are unable to achieve benefits from their investment.

BECAUSE WE DO NOT INTEND TO PAY ANY CASH DIVIDENDS ON OUR COMMON STOCK, OUR STOCKHOLDERS WILL NOT BE ABLE TO RECEIVE A RETURN ON THEIR SHARES UNLESS THEY SELL THEM.

We intend to retain any future earnings to finance the development and expansion of our business. We do not anticipate paying any cash dividends on our common stock in the foreseeable future. Unless we pay dividends, our stockholders will not be able to receive a return on their shares unless they sell them. There is no assurance that stockholders will be able to sell shares when desired.

FINANCIAL INDUSTRY REGULATORY AUTHORITY ("FINRA") SALES PRACTICE REQUIREMENTS MAY ALSO LIMIT YOUR ABILITY TO BUY AND SELL OUR COMMON STOCK, WHICH COULD DEPRESS THE PRICE OF OUR SHARES.

FINRA rules require broker-dealers to have reasonable grounds for believing that an investment is suitable for a customer before recommending that investment to the customer. Prior to recommending speculative low-priced securities to their non-institutional customers, broker-dealers must make reasonable efforts to obtain information about the customer's financial status, tax status and investment objectives, among other things. Under interpretations of these rules, FINRA believes that there is a high probability such speculative low-priced securities will not be suitable for at least some customers. Thus, FINRA requirements make it more difficult for broker-dealers to recommend that their customers buy our common stock, which may limit your ability to buy and sell our shares, have an adverse effect on the market for our shares, and thereby depress our share price.

OUR OFFICERS AND DIRECTORS HAVE NO EXPERIENCE MANAGING A PUBLIC COMPANY WHICH IS REQUIRED TO ESTABLISH AND MAINTAIN DISCLOSURE CONTROLS AND PROCEDURES AND INTERNAL CONTROL OVER FINANCIAL REPORTING.

We have never operated as a public company. Frederick Sidney Reinhard Arnold and Rafael Angel Ulloa Bonilla, our officers and directors have no experience managing a public company, which is required to establish and maintain disclosure controls and procedures and internal control over financial reporting. As a result, we may not be able to operate successfully as a public company, even if our operations are successful. We plan to comply with all of the various rules and regulations, which are required for a public company. However, if we cannot operate successfully as a public company, your investment may be materially adversely affected. Our inability to operate as a public company could be the basis of losing your entire investment in us.

OUR DIRECTORS WILL CONTINUE TO EXERCISE SIGNIFICANT CONTROL OVER OUR OPERATIONS, WHICH MEANS AS A MINORITY SHAREHOLDER, YOU WOULD HAVE NO CONTROL OVER CERTAIN MATTERS REQUIRING STOCKHOLDER APPROVAL THAT COULD AFFECT YOUR ABILITY TO EVER RESELL ANY SHARES YOU PURCHASE IN THIS OFFERING.

Currently 25% of all shares of common stock of our Company are beneficially owned by all officers and directors as a group. After the completion of this offering, our management will own major of our common stock. In the event that fewer than the maximum shares of the offering are sold, management's percentage ownership will raise. It will have a significant influence in determining the outcome of all corporate transactions, including the election of directors, approval of significant corporate transactions, changes in control of the company or other matters that could affect your ability to ever resell your shares. Its interests may differ from the interests of the other stockholders and thus result in corporate decisions that are disadvantageous to other shareholders.

11

OUR STATUS AS AN "EMERGING GROWTH COMPANY" UNDER THE JOBS ACT OF 2012 MAY MAKE IT MORE DIFFICULT TO RAISE CAPITAL WHEN WE NEED TO DO IT.

Because of the exemptions from various reporting requirements provided to us as an "emerging growth company" and because we will not have an extended transition period for complying with new or revised financial accounting standards, we may be less attractive to investors and it may be difficult for us to raise additional capital as and when we need it. Investors may be unable to compare our business with other companies in our industry if they believe that our financial accounting is not as transparent as other companies in our industry. If we are unable to raise additional capital as and when we need it, our financial condition and results of operations may be materially and adversely affected.

MARKET FOR PENNY STOCK HAS SUFFERED IN RECENT YEARS FROM PATTERNS OF FRAUD AND ABUSE

According to SEC Release No. 34-29093, the market for penny stocks has suffered in recent years from patterns of fraud and abuse. Such patterns include:

    UNITED STATES

Our management is aware of the abuses that have occurred historically in the penny stock market. Although we do not expect to be in a position to dictate the behavior of the market or of broker-dealers who participate in the market, management will strive within the confines of practical limitations to prevent the described patterns from being established with respect to our securities. The occurrence of these patterns or practices could increase the volatility of our share price.

WE WILL NOT BE REQUIRED TO COMPLY WITH CERTAIN PROVISIONS OF THE SARBANES-OXLEY ACT FOR AS LONG AS WE REMAIN AN "EMERGING GROWTH COMPANY."

We are not currently required to comply with the SEC rules that implement Sections 302 and 404 of the Sarbanes-Oxley Act, and are therefore not required to make a formal assessment of the effectiveness of our internal controls over financial reporting for that purpose. Upon becoming a public company, we will be required to comply with certain of these rules, which will require management to certify financial and other information in our quarterly and annual reports and provide an annual management report on the effectiveness of our internal control over financial reporting. Though we will be required to disclose changes made in our internal control procedures on a quarterly basis, we will not be required to make our first annual assessment of our internal control over financial reporting pursuant to Section 404 until the later of the year following our first annual report required to be filed with the SEC, or the date we are no longer an "emerging growth company" as defined in the JOBS Act.

Our independent registered public accounting firm is not required to formally attest to the effectiveness of our internal control over financial reporting until the later of the year following our first annual report required to be filed with the SEC, or the date we are no longer an "emerging growth company." At such time, our independent registered public accounting firm may issue a report that is adverse in the event it is not satisfied with the level at which our controls are documented, designed or operating.

12

    UNITED STATES

Our public offering of 6,000,000 shares is being made on a self-underwritten basis. No minimum number of shares must be sold in order for the offering to proceed. The offering price per share is $0.02. The following Use of Proceeds table sets forth the uses of proceeds assuming the sale of 25% (i.e., $30,000), 50% (i.e., $60,000), 75% (i.e., $90,000), and 100% (i.e., $120,000) of the securities we are offering for sale. There is no assurance that we will raise the full $120,000 as anticipated.

Use of Proceeds relates to anticipated expenditures for the 12-month period following the completion of this offering. The expenditures are categorized by significant area of activity.

Our detailed description of the Use of Proceeds in the "Plan of Distribution" section of this prospectus.

    UNITED STATES

To prioritize our objectives, we will refer to the order in which they are listed in the Use of Proceed table. For instance, costs of being a reporting public company and application AI technology maintaining will have higher priority compared to computer equipment.

None of the proposed allocations set forth in the foregoing table is a firm commitment by us. Projected expenditures are estimations or approximations only. Actual expenditures will differ from projected expenditures if: (1) less than the maximum offering is sold; (2) more funds than estimated are required to accomplish the objectives set by management in a particular area; (3) a particular objective can be obtained with less funding than anticipated; or (4) the objectives set by management are determined to be unobtainable. To the extent that the proposed objectives cannot be achieved for the scheduled amounts, management may draw supplemental amounts from other categories of estimated expenses (if available), from operating revenues (if any) or from additional financing, the availability of which cannot be assured. Any amounts not expended for scheduled purposes will be reallocated for general corporate purposes. In the event we are not successful in selling all of the Common Stock offered herein, the amount allocated in the above table will be reduced proportionately to the amount of proceeds actually received.

13

    UNITED STATES

The offering price of the 6,000,000 shares being offered has been determined arbitrarily by us. The price does not bear any relationship to our assets, book value, earnings, or other established criteria for valuing a privately held company. In determining the number of shares to be offered and the offering price, we took into consideration the amount of money we would need to implement our business plan. Accordingly, the offering price should not be considered an indication of the actual value of the securities.

    UNITED STATES

The price of our offering of 6,000,000 shares is fixed at $0.02 per share for the duration of the offering.

Dilution represents the difference between the offering price and the net tangible book value per share immediately after completion of this offering. Net tangible book value is the amount that results from subtracting total liabilities and intangible assets from total assets. Dilution arises mainly as a result of our arbitrary determination of the offering price of the shares being offered. Dilution of the value of the shares you purchase is also a result of the lower book value of the shares held by our existing stockholders. The following tables compare the differences of your investment in our shares with the investment of our existing stockholders.

As of July 31, 2023, the net tangible book value of our shares was $(6,180) or approximately $(0.0015) per share, based upon 2,000,000 shares outstanding.

The table below represents the dilution per share to the new investors. However, it does not give any effect to the results of any operations after July 31, 2023. The following table shows the per share dilution assuming that 25%, 50%, 75% and 100% of the shares respectively of the primary Offering by the Company is sold.

Percent of Offering Completed 25% 50% 75% 100% Amount of new funding $ 30,000 $ 60,000 $ 90,000 $ 120,000 Offering price $ 0.02 $ 0.02 $ 0.02 $ 0.02 Shares after offering 3,500,000 5,000,000 6,500,000 8,000,000 Book value before distribution per share $ (0.0015) $ (0.0015) $ (0.0015) (0.0015) Increase in book value per share 0.0041 0.0093 0.0121 0.0139 Book value after distribution per share $ 0.0025 $ 0.0078 $ 0.0106 $ 0.0124 Dilution to purchasers $ 0.0175 $ 0.0122 $ 0.0094 $ 0.0076 Dilution as percentage 87.41% 61.19% 47.07% 38.24% % ownership of old shareholders 57.14% 40.00% 30.77% 25.00% % ownership of new shareholders 42.86% 60.00% 69.23% 75.00%

The following table summarizes the number and percentage of shares purchased the amount and percentage of consideration paid and the average price per Share paid by our existing stockholder and by new investors in this offering:

    UNITED STATES

Existing Stockholder 1. $ 0.0001 2,000,000 25% $ 200 Investors in this Offering $ 0.02 6,000,000 75% $ 120,000

14

    UNITED STATES

Offering will be sold by our officers and directors

This is a self-underwritten offering. This prospectus is part of a prospectus that permits our Mr. Arnold and Mr. Ulloa Bonilla to sell the Shares on behalf of the Company directly to the public, with no commission or other remuneration payable to them for any Shares they sell.

There are no plans or arrangements to enter into any contracts or agreements to sell the Shares with a broker or dealer. Frederick Sidney Reinhard Arnold and Rafael Angel Ulloa Bonilla, our officers and directors, will sell the shares on behalf of the Company and intends to offer them to friends, family members and business associates. In offering the securities on our behalf, Mr. Arnold and Mr. Ulloa Bonilla will rely on the safe harbor from broker dealer registration set out in Rule 3a4-1 under the Securities Exchange Act of 1934.

Mr. Arnold and Mr. Ulloa Bonilla will not register as broker-dealers pursuant to Section 15 of the Securities Exchange Act of 1934, in reliance upon Rule 3a4-1, which sets forth those conditions under which a person associated with an Issuer, may participate in the offering of the Issuer's securities and not be deemed to be a broker-dealer.

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

(A) primarily perform, or are intended primarily to perform at the end of the offering, substantial duties for or on behalf of our company, other than in connection with transactions in securities; and

(B) are not brokers or dealers, or been associated persons of a broker or dealer, within the preceding twelve months; and

(C) have not participated in selling and offering securities for any Issuer more than once every twelve months other than in reliance on Paragraphs (a)(4)(i) (a)(4)(iii).

Our officers, directors, control persons and affiliates of same do not intend to purchase any shares in this offering.

15

    UNITED STATES

The shares will be sold at the fixed price of $0.02 per share until the completion of this offering. There is no minimum amount of subscription required per investor, and subscriptions, once received, are irrevocable.

This offering will commence on the date of this prospectus and continue for a period not to exceed 365 days (the "Expiration Date"), unless extended by our Board of Directors for an additional 90 days.

    UNITED STATES

The Securities Exchange Commission has also adopted rules that regulate broker-dealer practices in connection with transactions in "penny stocks" as such term is defined by Rule 15g-9. Penny stocks are generally equity securities with a price of less than $5.00 (other than securities registered on certain national securities exchanges or provided that current price and volume information with respect to transactions in such securities is provided by the exchange).

The shares offered by this prospectus constitute penny stock under the Securities and Exchange Act. The shares will remain penny stock for the foreseeable future. The classification of penny stock makes it more difficult for a broker-dealer to sell the stock into a secondary market, which makes it more difficult for a purchaser to liquidate his or her investment. Any broker-dealer engaged by the purchaser for the purpose of selling his or her shares in our company will be subject to the penny stock rules.

The penny stock rules require a broker-dealer, prior to a transaction in a penny stock not otherwise exempt from those rules, deliver a standardized risk disclosure document prepared by the Commission, which: (i) contains a description of the nature and level of risk in the market for penny stocks in both public offerings and secondary trading; (ii) contains a description of the broker's or dealer's duties to the customer and of the rights and remedies available to the customer with respect to a violation to such duties or other requirements of Securities' laws; (iii) contains a brief, clear, narrative description of a dealer market, including bid and ask prices for penny stocks and significance of the spread between the bid and ask price; (iv) contains a toll-free telephone number for inquiries on disciplinary actions; (v) defines significant terms in the disclosure document or in the conduct of trading in penny stocks; and (vi) contains such other information and is in such form as the Commission shall require by rule or regulation. The broker-dealer also must provide to the customer, prior to effecting any transaction in a penny stock, (i) bid and offer quotations for the penny stock; (ii) the compensation of the broker-dealer and its salesperson in the transaction; (iii) the number of shares to which such bid and ask prices apply, or other comparable information relating to the depth and liquidity of the market for such stock; and (iv) monthly account statements showing the market value of each penny stock held in the customer's account.

In addition, the penny stock rules require that prior to a transaction in a penny stock not otherwise exempt from those rules; the broker-dealer must make a special written determination that the penny stock is a suitable investment for the purchaser and receive the purchaser's written acknowledgment of the receipt of a risk disclosure statement, a written agreement to transactions involving penny stocks, and a signed and dated copy of a written suitability statement. These disclosure requirements will have the effect of reducing the trading activity in the secondary market for our stock because it will be subject to these penny stock rules. Therefore, stockholders may have difficulty selling those securities.

16

    UNITED STATES

There is no established public trading market for our securities and a regular trading market may not develop, or if developed, may not be sustained. A shareholder in all likelihood, therefore, will not be able to resell his or her securities should he or she desire to do so when eligible for public resales.

    UNITED STATES

This is a "best effort" offering and, as such, there is no assurance that we will sell any or all of the shares.

    UNITED STATES

If you decide to subscribe for any shares in this offering, you will be required to execute a Subscription Agreement and tender it, together with a check or certified funds to us. All checks or wires for subscriptions should be made payable to Naploy Corp.

    UNITED STATES

COMMON STOCK

On the date hereof, there were 2,000,000 shares of common stock issued and outstanding. Our authorized capital stock consists of 75,000,000 shares of common stock, par value $.0001. The holders of our common stock:

(i) have equal ratable rights to dividends from funds legally available therefore, when, as and if declared by our Board of Directors;

(ii) are entitled to share in all of our assets available for distribution to holders of common stock upon liquidation, dissolution or winding up of our affairs;

(iii) do not have pre-emptive, subscription or conversion rights and there are no redemption or sinking fund provisions or rights; and (iv) are entitled to one non-cumulative vote per share on all matters on which stockholders may vote.

CASH DIVIDENDS

As of the date of this prospectus, we have not paid any cash dividends to stockholders. The declaration of any future cash dividend will be at the discretion of our Board of Directors and will depend upon our earnings, if any, our capital requirements and financial position, our general economic conditions, and other pertinent conditions. It is our present intention not to pay any cash dividends in the foreseeable future, but rather to reinvest earnings, if any, in our business operation.

17

PREEMPTIVE RIGHTS

No holder of any of our shares has preemptive or preferential rights to acquire or subscribe for any unissued shares of any class of stock or any unauthorized securities convertible into or carrying any right, option or warrant to subscribe for or acquire shares of any class of stock not disclosed herein.

NON-CUMULATIVE VOTING

Holders of shares of our common stock do not have cumulative voting rights, which means that the holders of more than 50% of the outstanding shares, voting for the election of directors, can elect all of the directors to be elected, if they so choose, and, in such event, the holders of the remaining shares will not be able to elect any of our directors.

PREFERRED STOCK

We do not have an authorized class of preferred stock.

SHARE PURCHASE WARRANTS

We have not issued and do not have outstanding any warrants to purchase shares of our common stock.

STOCK OPTIONS GRANTS

We have not issued and do not have outstanding any options to purchase shares of our common stock.

CONVERTIBLE SECURITIES

We have not issued and do not have outstanding any securities convertible into shares of our common stock or any rights convertible or exchangeable into shares of our common stock.

    UNITED STATES

No expert or counsel named in this prospectus as having prepared or certified any part of this prospectus or having given an opinion upon the validity of the securities being registered or upon other legal matters in connection with the registration or offering of the common stock was employed on a contingency basis, or had, or is to receive, in connection with the offering, an interest, direct or indirect, in the registrant or any of its parents or subsidiaries. Nor was any such person connected with the registrant or any of its parents or subsidiaries as a promoter, managing or principal underwriter, voting trustee, director, officer, or employee.

Haddan & Zepfel LLP has provided an opinion on the validity of our common stock.

The financial statements included in this prospectus and the registration statement have been audited by Mainor Audit ja Partnerid OU to the extent and for the periods set forth in their report appearing elsewhere in this document and in the registration statement filed with the SEC, and are included in reliance upon such report given upon the authority of said firm as experts in auditing and accounting.

18

    UNITED STATES

Naploy Corp. was incorporated in the State of Wyoming and established on April 6, 2023. The Company has no revenue and has incurred losses since inception. Our primary focus is on launching a news blog that provides the latest updates on health-related topics, including but not limited to medical breakthroughs, healthy lifestyle tips, and updates on healthcare policies. We have developed a full business plan.

Currently, we have no employees, only our officers and Directors - Mr. Frederick Sidney Reinhard Arnold and Mr. Rafael Angel Ulloa Bonilla. Our executive and business office is located at 95 Lias Estate Kafe district Abuja, FCT 900108 Nigeria, and our telephone number is +13072133163.

The COVID-19 pandemic has had a significant impact on the healthcare industry and has led to changes in the way healthcare services are delivered, including through mobile applications that offer online information help services for finding medical institutions. Here are some ways the pandemic has affected these types of apps:

Increased demand: The pandemic has increased the demand for healthcare services, and many people have turned to mobile apps to find information about medical institutions and services.

Safety concerns: Many people are hesitant to visit medical institutions in person due to safety concerns, and mobile apps that offer information about medical institutions and their safety protocols can help alleviate these concerns.

We are a development stage company and currently have no revenues or significant assets and we have incurred losses since its inception. As of July 31, 2023, our total assets were $45,520 and our total current liabilities were $51,700.

Our Naploy App is your go-to source for the latest health news and updates. Naploy App offers an article library- News Blog that deals with the most common health topics. Our health blog covers diverse health related concerns such as nutrition and diet, fitness, weight control, diseases, disease management, societal trends affecting health, analysis about health, business of health and health research. The app is available for both Android and iOS mobile operating systems and provides you with quick access to a vast healthcare and medical database. With the " Naploy App," you can stay informed about the latest health news anytime, anywhere. We are dedicated to bringing you high-quality health information and keeping you up-to-date on the latest developments in the world of healthcare.

One of our main App features is Symptom Diagnostic. Symptom Diagnostic is an advanced tool that uses high-grade AI technology to provide diagnoses. Currently, our AI technology is already working, but during the lifetime of the APP it should be refined and improved. To begin, you will have to enter your age and gender, after which you can select or type in your symptoms, intensity and duration. This step is then followed up by some more questions to determine which symptom is bothering you the most and if you are on meds and/or have had any conditions in the past. Thereafter, it will give you a list of possible conditions (about 5, starting with the most likely) which you can then click on and find more details about the disease.

Symptom Diagnostics are an innovative addition to digital health. This tool does not provide medical advice It is intended for informational purposes only. Nevertheless, these services should not be considered as definite diagnostic tools but rather as a guide to point the user towards possible conditions relating to their symptoms. Consulting an actual physician will help you have a more accurate diagnosis and subsequent treatment.

19

Our "Naploy App" includes a convenient Clinic Search feature that allows clients to contact us and send a request for searching the clinics and proper medical services that suit their needs for a fee. Through this feature, clients can request information about the type of treatment they need, as well as leave their phone number and email. Our team will then contact the client to clarify all the necessary details about their diagnosis and treatment needs. Our expert managers will then provide information about the best medical institutions for the client, including details about the location, clinic licenses, doctors, we will monitor all the reviews and feedbacks and check all the doctors for their professional qualifications. Our clients can expect top-notch customer service, as our managers will communicate with them through phone, email, and messengers according to their preferences. We are dedicated to providing the professional services in searching the best medical institutions, making for the right medical care for our clients. We will make this process much easier and comfortable for clients from our professional website.

In addition, we also offer paid contextual advertising services for medical institutions on our Naploy app's news blog:

-Banner ads

Our banner advertising will consist of static or animated images or media and would be placed in high-visibility areas. Banner advertising is attractive because it can help create medical institutions awareness and generate leads.

-Pop up

Another effective form of our advertising services. Unlike banner ads, the pop-up will appear in the center of the screen, drawing the attention of customers.

By utilizing our advertising services, medical institutions can increase their online presence and reach a wider audience. Our goal is to provide a comprehensive platform for both health news and healthcare advertising, and we believe that this additional feature will be a valuable asset for both our users and medical institutions.

We are offering our services to the clients in Nigeria and then we are going to spread our services in other African countries.

We have purchased the mobile application and website for iOS and Android platforms for total consideration of US $45,000.

The payment is made in several stages:

    UNITED STATES

We have signed the Mobile Application and Website Purchase Agreement with Mario Jimenez Martinez - the Developer, who is a specialist in mobile and web development with extensive experience. The Mobile Application and Website Purchase Agreement is filed as Exhibit 10.2 to this Registration Statement.

The links for the "Naploy" application:

In Google Play - https://play.google.com/store/apps/details?id=naploy.app&hl=uk&gl=US

In App Store - https://apps.apple.com/us/app/naploy/id6451121811

Our website address is https://naploy.com/#/app

20

Here are some of the technologies that we intend successfully to implement in our mobile application:

- Improvement of the AI technology

- Map View

- Reviews

- Booking Services

- Notifications

- Marketing Opportunities

- Body map symptom checker

- Personal health tracker

- Medicine reminder

- Language translation

Our "Naploy App" is regularly updated with articles written by healthcare professionals and industry experts, ensuring that our clients have access to high-quality and reliable health information. We believe that our app will not only keep our clients informed but also empower them to take control of their health and make informed decisions about their wellbeing. All our features make our mobile application a comprehensive resource for clients seeking reliable and relevant health information. We intend continuously make improvements, maintenances and expand of our application as well as develop complementary products and services for our consumers.

OUR MOBILE APPLICATION AND THE PROCESS

Currently, we have a mobile application for Android and iOS platforms known as "Naploy App". Links for the application: - https://play.google.com/store/apps/details?id=naploy.app&hl=uk&gl=US and https://apps.apple.com/us/app/naploy/id6451121811. Our application is completely operational and ready for use, enabling customers to access and acquire our company's services. However, we plan to further develop and expand the application's functionality by integrating new and beneficial features and systems that will enhance the experience for our potential customers.

The main functionality features and opportunities of currently application are:

News Blog:

    UNITED STATES

Symptom Diagnostic:

    UNITED STATES

21

Clinic Search:

    UNITED STATES

Here are some of the technologies that we intend successfully to implement in our mobile application:

    UNITED STATES

While visual symptom checkers can be useful, it's important to note that they should not replace the advice of a medical professional. If someone is experiencing severe symptoms, they should seek immediate medical attention from a doctor or emergency services.

    UNITED STATES

22

REVENUE

Advertising: The app can feature advertisements from medical institutions, pharmaceutical companies, or other related businesses. The fee for in-app ads can vary based on the size and placement of the ad.

We offer such paid contextual advertising services:

- Banner ads

Our banner advertising will consist of static or animated images or media and would be placed in high-visibility areas. Banner advertising is attractive because it can help create medical institutions awareness and generate leads.

- Pop up

Another effective form of our advertising services. Unlike banner ads, the pop-up will appear in the center of the screen, drawing the attention of customers.

Clinic Search: Clients will be charged a fee for using our Clinic Search feature to find the best medical institutions that suit their needs. The fee will vary depending on the complexity of the search and the level of support required from our team.

In future the additional source of revenue could be through other services:

Subscription Model: We will offer a subscription model for clients who need ongoing support from our team in finding medical institutions for their specific needs. The subscription fee will provide access to our team's expertise and support.

Referral fees: The app can earn referral fees from medical institutions for each new patient that the app directs to them. This could include fees for booking appointments or fees for any services provided by the medical institution. The prices for referral fees can vary depending on the type of service provided and the level of commission offered.

Data analytics: The app can collect and analyze user data to provide insights to healthcare providers and researchers. This could include anonymized data on user demographics, medical conditions, and treatment outcomes. The app can charge fees to healthcare providers and researchers for access to this data. The prices for data analytics can vary depending on the level of access and the type of data provided.

u Prices for Services:

Advertising: $0.50-$1.00 per click or monthly advertising $150-$1,000

Clinic Search: Starting at $50-$500 per search, prices will vary based on the complexity of the search and level of support required.

u Prices for Services in future:

Subscription Model: Starting from $70 per month, prices will vary based on the level of support required.

Referral fees: 5%-15% of the total cost of service

Data analytics: $200-$2,000 per report, depending on the level of detail and analysis provided.

23

MARKET OVERVIEW

The demand for online health platforms is increasing day by day. According to recent research, more than 70% of patients search for medical information online before consulting a doctor. With the growth of the healthcare industry, the market for healthcare apps is expanding rapidly. The global healthcare mobile app market is expected to reach $111.1 billion by 2025, with a CAGR of 38.7% from 2020 to 2025.

Moreover, the COVID-19 pandemic has further accelerated the demand for online healthcare services. The growing adoption of smartphones, rising healthcare costs, and increasing awareness about health are also driving the market growth.

Our App will provide users with the latest medical news and information to help them make informed decisions about their health. Our team of healthcare experts will work to ensure that the platform is up-to-date and provides users with accurate and reliable information. By offering a comprehensive online health platform, we aim to improve the overall health and well-being of our users while providing a valuable service to the healthcare industry.

COMPETITION

The health app market is highly competitive, with many established players and new entrants vying for a share of the market. Some of the major competitors in the field of health apps include Zocdoc, Healthgrades, and WebMD.

In addition to these major players, there are many other health apps on the market that offer a variety of features. As the demand for health-related apps continues to grow, the competition in this space is likely to remain fierce.

Through our marketing strategy and continuous development of new features, we believe that our mobile app can succeed in the health market.

MARKETING

Marketing and sales strategy are crucial components for the success of any business, including mobile applications. In order to ensure the success of our online health platform, we plan to implement a multi-faceted marketing and sales strategy.

- Digital Marketing:

We will use various digital marketing techniques to reach our target audience, including search engine optimization (SEO), pay-per-click (PPC) advertising, social media marketing, and email marketing. We will use relevant keywords and phrases to optimize our app's visibility on search engines and social media platforms. We will also use targeted email marketing campaigns to promote our app to potential users.

- Content Marketing:

We will develop a content marketing strategy that focuses on creating valuable and informative content related to healthcare, medical institutions, and related topics. This content will be published on our website and social media platforms, and shared with relevant online communities and groups.

- Influencer Marketing:

We will work with healthcare influencers and bloggers to promote our app and reach a wider audience. We will collaborate with influencers to develop content related to our app and its features and encourage them to share their experiences with our app with their followers.

24

- Partnering with Medical Institutions:

We will partner in future with medical institutions such as hospitals, clinics, and healthcare centers to promote our app to their patients.

- To invite new clients via word-of-mouth referrals.

- To place outdoor display advertisements in public transportation terminals and residential complexes in selected cities.

We are going to spend some part of proceeds on the development of our website and mobile application and extension of functionality in order to attract more potential customers and to make our services more desirable.

EMPLOYEES

We are a development stage company and currently have no employees, other than our officers, Mr. Arnold and Mr. Ulloa Bonilla.

OFFICES

Our corporate headquarters is located at 95 Lias Estate Kafe district Abuja, FCT 900108 Nigeria and our phone number is +13072133163. Further, this space has been provided by our executives Mr. Frederick Sidney Reinhard Arnold and Mr. Rafael Angel Ulloa Bonilla free of cost. We consider our current principal office space arrangement adequate and will reassess our needs based upon the future growth of the company.

PATENTS AND TRADEMARK

Currently, we do not own, either legally or beneficially, any patents or trademarks.

GOVERNMENT AND INDUSTRY REGULATION

We will be subject to applicable laws and regulations that relate directly or indirectly to our operations including United States securities laws. We will be required to comply with all regulations, rules and directives of governmental authorities and agencies applicable to our services in Nigeria and to operation of any facility in any jurisdiction which we would conduct activities. We believe that government regulation will have no material impact on the way we conduct our business.

EMERGING GROWTH COMPANY STATUS UNDER THE JOBS ACT

Naploy Corp. qualifies as an "emerging growth company" as defined in the Jumpstart our Business Startups Act (the "JOBS Act").

The JOBS Act creates a new category of issuers known as "emerging growth companies." Emerging growth companies are those with annual gross revenues of less than $1, 07 billion (as indexed for inflation) during their most recently completed fiscal year. The JOBS Act is intended to facilitate public offerings by emerging growth companies by exempting them from several provisions of the Securities Act of 1933 and its regulations. An emerging growth company will retain that status until the earliest of:

- The first fiscal year after its annual revenues exceed $1,07 billion;

- The first fiscal year after the fifth anniversary of its IPO;

    UNITED STATES

    UNITED STATES

25

Financial and Audit Requirements

Under the JOBS Act, emerging growth companies are subject to scaled financial disclosure requirements. Pursuant to these scaled requirements, emerging growth companies may:

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

Offering Requirements

In addition, during the IPO offering process, emerging growth companies are exempt from:

    UNITED STATES

    UNITED STATES

The requirement initially to publicly file IPO Registration Statements. Emerging growth companies can confidentially file draft Registration Statements and any amendments with the SEC. Public filings of the draft documents must be made at least 21 days prior to commencement of the IPO "road show."

Other Public Company Requirements

Emerging growth companies are also exempt from other ongoing obligations of most public companies, such as:

    UNITED STATES

    UNITED STATES

    UNITED STATES

Election under Section 107(b) of the JOBS Act

As an emerging growth company, we have made the irrevocable election to not adopt the extended transition period for complying with new or revised accounting standards under Section 107(b), as added by Section 102(b), of the JOBS Act. This election allows companies to delay the adoption of new or revised accounting standards that have different effective dates for public and private companies until those standards apply to private companies.

26

    UNITED STATES

Our business office is located at 95 Lias Estate Kafe district Abuja, FCT 900108 Nigeria. We consider our current principal office space arrangement adequate and will reassess our needs based upon the future growth of the company. Further, this space has been provided by our executives Mr. Frederick Sidney Reinhard Arnold and Mr. Rafael Angel Ulloa Bonilla for free.

    UNITED STATES

We are not involved in any pending legal proceeding nor are we aware of any pending or threatened litigation against us.

    UNITED STATES

No public market currently exists for shares of our common stock. We intend to apply to the OTC Markets to have our common stock quoted through a market maker that is a licensed broker dealer. There can be no guarantee that our common stock will be accepted for quotation on the OTC Markets.

PENNY STOCK RULES

The Securities and Exchange Commission has also adopted rules that regulate broker-dealer practices in connection with transactions in penny stocks. Penny stocks are generally equity securities with a price of less than $5.00 (other than securities registered on certain national securities exchanges or quoted on the Nasdaq system, provided that current price and volume information with respect to transactions in such securities is provided by the exchange or system).

A purchaser is purchasing penny stock which limits the ability to sell the stock. The shares offered by this prospectus constitute penny stock under the Securities and Exchange Act. The shares will remain penny stocks for the foreseeable future. The classification of penny stock makes it more difficult for a broker-dealer to sell the stock into a secondary market, which makes it more difficult for a purchaser to liquidate his/her investment. Any broker-dealer engaged by the purchaser for the purpose of selling his or her shares in us will be subject to Rules 15g-1 through 15g-10 of the Securities and Exchange Act. Rather than creating a need to comply with those rules, some broker-dealers will refuse to attempt to sell penny stock.

The penny stock rules require a broker-dealer, prior to a transaction in a penny stock not otherwise exempt from those rules, to deliver a standardized risk disclosure document, which:

    UNITED STATES

    UNITED STATES

    UNITED STATES

- toll-free telephone number for inquiries on disciplinary actions;

    UNITED STATES

    UNITED STATES

27

The broker-dealer also must provide, prior to effecting any transaction in a penny stock, to the customer:

- the bid and offer quotations for the penny stock;

- the compensation of the broker-dealer and its salesperson in the transaction;

    UNITED STATES

    UNITED STATES

In addition, the penny stock rules require that prior to a transaction in a penny stock not otherwise exempt from those rules; the broker-dealer must make a special written determination that the penny stock is a suitable investment for the purchaser and receive the purchaser's written acknowledgment of the receipt of a risk disclosure statement, a written agreement to transactions involving penny stocks, and a signed and dated copy of a written suitability statement. These disclosure requirements will have the effect of reducing the trading activity in the secondary market for our stock because it will be subject to these penny stock rules. Therefore, stockholders may have difficulty selling their securities.

FINANCIAL AND AUDIT REQUIREMENTS

Under the JOBS Act, emerging growth companies are subject to scaled financial disclosure requirements. Pursuant to these scaled requirements, emerging growth companies may:

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

ELECTION UNDER SECTION 107(b) OF THE JOBS

As an emerging growth company, we have made the irrevocable election to not adopt the extended transition period for complying with new or revised accounting standards under Section 107(b), as added by Section 102(b), of the JOBS Act. This election allows companies to delay the adoption of new or revised accounting standards that have different effective dates for public and private companies until those standards apply to private companies.

28

STOCK TRANSFER AGENT

We do not have a stock transfer agent at this time. We intend to appoint a stock transfer agent following the completion of this offering.

REPORTS

We are subject to certain reporting requirements and will furnish annual financial reports to our stockholders, certified by our independent accountants, and will furnish un-audited quarterly financial reports in our quarterly reports filed electronically with the SEC. All reports and information filed by us can be found at the SEC website, www.sec.gov.

REGULATION M

Our officers and directors, who will offer and sell the Shares, are aware that they are required to comply with the provisions of Regulation M promulgated under the Securities Exchange Act of 1934, as amended. With certain exceptions, Regulation M precludes the officers and directors, sales agents, any broker-dealer or other person who participate in the distribution of shares in this offering from bidding for or purchasing, or attempting to induce any person to bid for or purchase any security which is the subject of the distribution until the entire distribution is complete.

29

    UNITED STATES

We are a development stage corporation with limited operations and no revenues from our business operations. Our auditors have issued a going concern opinion. This means that our auditors believe there is substantial doubt that we can continue as an on-going business for the next twelve months. We do not anticipate that we will generate significant revenues until we have raised the funds necessary to conduct a marketing program. There is no assurance we will ever generate revenue even if we raised all necessary funds.

To meet our need for cash we are attempting to raise money from this offering. We believe that we will be able to raise enough money through this offering to expand operations but we cannot guarantee that once we expand operations we will stay in business after doing so. If we are unable to successfully find customers we may quickly use up the proceeds from this offering and will need to find alternative sources. In case we need additional financing, our Mr. Ulloa Bonilla verbally agreed to loan us funds to implement our business plan.

RESULTS OF OPERATIONS

We have generated no revenue to date of this prospectus.

We have incurred operating expenses of $6,380 for company setup and professional fees since inception to July 31, 2023.

Our full business plan entails activities described in the Plan of Operation section below. Long term financing beyond the maximum aggregate amount of this offering may be required to expand our business. The exact amount of funding will depend on the scale of our development and expansion. We do not currently have planned our expansion, and we have not decided yet on the scale of our development and expansion and on exact amount of funding needed for our long term financing. If we do not generate any revenue we may need additional funding at the end of the twelve-month period described in our "Plan of Operation" below to maintain a reporting status.

Our independent registered public accountant has issued a going concern opinion. This means that there is a doubt that we can continue as an on-going business for the next twelve months unless we obtain additional capital to pay our bills. This is because we have not generated revenues and no revenues are anticipated until we complete our initial business development. There is no assurance we will ever reach that stage.

To meet our need for cash we are attempting to raise money from this offering. We believe that we will be able to raise enough money through this offering to continue our proposed operations but we cannot guarantee that once we continue operations we will stay in business after doing so.

We have not attained profitable operations and are dependent upon obtaining financing to pursue our business plan and our business operations. So, for these reasons, there is substantial doubt that we will be able to continue as a going concern.

30

PLAN OF OPERATION

We anticipate achieving the following business milestones in the 12 months after the completion is as follows:

    UNITED STATES

Mobile application and AI technology maintaining. Estimated Cost $4,000 - 25,000.

The following are the steps we can take to maintain the mobile application and AI technology:

Monitoring and Updating: We must monitor the mobile app and AI technology continuously to detect any issues and bugs that could negatively impact performance. Regular updates should be implemented to improve the functionality and user experience.

User Feedback: We should encourage users to provide feedback about the mobile application and AI technology. We can collect feedback through surveys, app store reviews, and social media platforms. The feedback received will help us identify areas that need improvement.

Bug Fixes: Any bugs that are detected must be addressed promptly. We must prioritize fixing any issues that affect the user experience, such as crashes or slow loading times.

Security Maintenance: Security maintenance must be a top priority when it comes to maintaining our mobile app and AI technology. We must implement regular security updates to protect user data and ensure that the mobile application and AI technology are not vulnerable to hacking attempts.

Performance Optimization: We must optimize the performance of the mobile app and AI technology to ensure that it runs smoothly and efficiently. This can include optimizing loading times, reducing the size of the app, and reducing battery usage.

Continuous Improvement: Finally, we must continuously improve the mobile app and AI technology. This includes adding new features, updating the user interface, and improving the accuracy of the AI technology. We expect this process to take approximately 6 months.

By following these steps, we can maintain our mobile application and AI technology to ensure optimal performance, user satisfaction, and continued success in the market.

31

Marketing and advertising. Estimated Cost $9,000-68,000.

Our plan of operation includes the following strategies:

- Digital Marketing:

We will use various digital marketing techniques to reach our target audience, including search engine optimization (SEO), pay-per-click (PPC) advertising, social media marketing, and email marketing. We will use relevant keywords and phrases to optimize our app's visibility on search engines and social media platforms. We will also use targeted email marketing campaigns to promote our app to potential users.

- Content Marketing:

We will develop a content marketing strategy that focuses on creating valuable and informative content related to healthcare, medical institutions, and related topics. This content will be published on our website and social media platforms, and shared with relevant online communities and groups.

- Influencer Marketing:

We will work with healthcare influencers and bloggers to promote our app and reach a wider audience. We will collaborate with influencers to develop content related to our app and its features and encourage them to share their experiences with our app with their followers.

- Partnering with Medical Institutions:

We will partner in future with medical institutions such as hospitals, clinics, and healthcare centers to promote our app to their patients.

- To invite new clients via word-of-mouth referrals.

    UNITED STATES

By implementing a multi-faceted marketing and sales strategy, we are confident that we can establish our presence in the market and attract a loyal user base. We expect this process to take approximately 6-9 months.

Computer equipment. Estimated Cost $1,000-6,000.

Our plan of operation for computer equipment includes obtaining the basic equipment necessary to run our business, such as a computer or laptop, an MFU for printing and scanning, a mobile smartphone, a landline phone, and a Wi-Fi router with internet connectivity. As our business grows and we acquire more clients, we may need to rent or purchase a server to store our service data and host our services.

We will also continuously assess our equipment needs and upgrade our technology as necessary to ensure efficient and effective operation of our business. We expect this process to take approximately 6-9 months.

32

LIQUIDITY AND CAPITAL RESOURCES

As of July 31, 2023, our total assets were $45,520 consisting of cash of $895 and intangible assets of $44,625. As of July 31, 2023, our current liabilities were $51,700 consisting of accounts payable of $25,700 and related party advances of $26,000.

Cash Flows from Operating Activities

For the period from April 6, 2023 (inception) to July 31, 2023, net cash flows used in operating activities was $19,695.

Cash Flows from Investing Activities

For the period from April 6, 2023 (inception) to July 31, net cash flows provided by investing activities was $(45,000)

Cash Flows from Financing Activities

For the period from April 6, 2023 (inception) to July 31, net cash flows provided by financing activities was $26,200.

Since inception, we have sold 2,000,000 shares of our common stock to our officer and director Frederick Sidney Reinhard Arnold at a price of $0.0001 per share, for aggregate proceeds of $200.

Our auditors have issued a "going concern" opinion, meaning that there is substantial doubt if we can continue as an on-going business for the next twelve months unless we obtain additional capital. No substantial revenues are anticipated until we have completed the financing from this offering and implemented our plan of operations. Our only source for cash at this time is investments by others in this offering. We must raise cash to implement our strategy and stay in business. The amount of the offering will likely allow us to operate for at least one year and have the capital resources required to cover the material costs with becoming a publicly reporting. The company anticipates over the next 12 months the cost of being a reporting public company will be approximately $15,000.

We cannot guarantee that we will be able to sell all the shares offered herein. If we are successful, any money raised will be applied to the items set forth in the Use of Proceeds section of this Prospectus. We will attempt to raise the necessary funds to proceed with all phases of our plan of operation. The sources of funding we may consider to fund this work include a public offering, a private placement of our securities or loans from our directors or others.

As of the date of this registration statement, the current funds available to us are not sufficient to implement our business plan until we raise funds from this offering. In case we need additional financing, our Mr. Ulloa Bonilla verbally agreed to loan us funds to implement our business plan. Management believes if we do not raise sufficient funds in this Offering to cover the costs of implementing our business plan, as well as the costs associated with being a reporting company, we will have to cease all such efforts. As such, your investment may be lost in its entirety. See " Risk Factors. "

If we need additional cash and cannot raise it, we will either have to suspend operations until we do raise the cash, or cease operations entirely.

To meet our need for cash we are attempting to raise money from this offering. We believe that we will be able to raise enough money through this offering to expand operations but we cannot guarantee that once we expand operations we will stay in business after doing so. If we are unable to successfully find customers, we may quickly use up the proceeds from this offering and will need to find alternative sources. At the present time, we have not made any arrangements to raise additional cash, other than through this offering and also the funds from our directors.

33

Management believes that the net proceeds, assuming a minimum of $30,000 are raised (provided that we are not required to raise any minimum amount of funding in the offering), will be sufficient to implement our initial plan of operations in the 12 months period. However, after one year we may need to raise additional financing.

We will be highly dependent upon the success of future private offerings of equity or debt securities, as described herein. Therefore, the failure thereof would result in the need to seek capital from other resources such as taking loans, which would likely not even be possible for the Company. However, if such financing were available, because we are a development stage company with limited operations to date, we would likely have to pay additional costs associated with high risk loans and be subject to an above market interest rate. At such time these funds are required, management would evaluate the terms of such debt financing. If the Company cannot raise additional proceeds via a private placement of its equity or debt securities, or secure a loan, the Company would be required to cease business operations as a result, investors would lose all of their investment.

CHANGES AND DISAGREEMENT WITH ACCOUNTANTS

There have been no changes in or disagreements with accountants regarding our accounting, financial disclosures or any other matter.

OFF-BALANCE SHEET ARRANGEMENTS

We have no off-balance sheet arrangements that have or are reasonably likely to have a current or future effect on our financial condition, changes in financial condition, revenues or expenses, results of operations, liquidity, capital expenditures or capital resources.

    UNITED STATES

The report of our auditor on the audited financial statements of the Company for the fiscal year ended July 31, 2023 did not contain any adverse opinion or disclaimer of opinion, nor was it qualified or modified as to uncertainty, audit scope, or accounting principles, except for a going concern qualification on the Company's financial statements for the fiscal year ended July 31, 2023.

During the fiscal years ended July 31, 2023 the Company nor anyone acting on its behalf consulted the Auditor Entity with respect to (i) the application of accounting principles to a specified transaction, either completed or proposed, or the type of audit opinion that might be rendered on the Company's financial statements, and neither a written report nor oral advice was provided to the Company that the Auditor Entity concluded was an important factor considered by the Company in reaching a decision as to the accounting, auditing or financial reporting issues; or (ii) any matter that was the subject of a disagreement or a reportable event set forth in Item 304(a)(1)(iv) and (v), respectively, of Regulation S-K.

34

    UNITED STATES

Directors of the corporation are elected by the stockholders to a term of one year and serve until a successor is elected and qualified. Officers of the corporation are appointed by the Board of Directors to a term of one year and serves until a successor is duly appointed and qualified, or until he or she is removed from office. The Board of Directors has no nominating, auditing or compensation committees.

Our executive officers and directors, their names, age, and positions as of the date of this prospectus are as follows:

Name and Address Age Position(s) Frederick Sidney Reinhard Arnold 37 President, 95 Lias Estate Kafe district Abuja, Chief Financial Officer, FCT 900108 Chief Executive Officer, Nigeria Director

Name and Address Age Position(s) Rafael Angel Ulloa Bonilla 73 Director 95 Lias Estate Kafe district Abuja, FCT 900108 Nigeria

Frederick Sidney Reinhard Arnold and Rafael Angel Ulloa Bonilla have been holding the above stated positions since the inception of the Company and the appointment on May 22, 2023, respectively. They are expected to hold them until the next annual meeting of our stockholders. Thereby, Mr. Frederick Sidney Reinhard Arnold and Mr. Rafael Angel Ulloa Bonilla are currently the Officers/Directors and control persons of Naploy Corp.

BACKGROUND INFORMATION ABOUT OUR OFFICERS AND DIRECTORS

Frederick Sidney Reinhard Arnold, Age 37

Mr. Frederick Sidney Reinhard Arnold has served as the Company's President, Chief Executive Officer, Secretary, Treasurer and a Director since its incorporation on April 6, 2023.

Frederick Sidney Reinhard Arnold, age 37, is entrepreneur and investor. He has been self-employed for the past 10 years, managing several successful businesses in various industries, including technology sector. He is known for his innovative thinking, strategic planning, and exceptional leadership skills. With his drive and determination, he has propelled the businesses to great success, and he is now ready to bring his expertise to the Company as its President, Chief Executive Officer, Secretary, Treasurer, and Director.

Rafael Angel Ulloa Bonilla, Age 73

Mr. Rafael Angel Ulloa Bonilla has served as the Company's Director since his appointment on May 22, 2023.

Rafael Angel Ulloa Bonilla, age 73, has a degree in accounting and finance, attended pre-medical school. He has been working in administrative department of a hospital for a long time, for the past 15 years has worked independently, overseeing multiple thriving ventures across diverse industries. His reputation is built on his wide experience, ability to think creatively, devise strategic plans, and exhibit outstanding leadership qualities. Through his unwavering dedication and perseverance, he has steered these enterprises towards remarkable achievements. Now, he aims to utilize his extensive expertise as the Director of the Company.

35

SECTION 16(a) BENEFICIAL OWNERSHIP REPORTING COMPLIANCE

In the event that we register under the Securities Exchange Act of 1934 (the "Exchange Act" or "1934 Act"), Section 16(a) of that act will require our directors and executive officers, and persons who own more than ten percent of our common stock, to file with the Securities and Exchange Commission initial reports of ownership and reports of changes of ownership of our common stock. Officers, directors and greater than ten percent stockholders will be required by SEC regulation to furnish us with copies of all Section 16(a) forms they file.

We intend to ensure to the best of our ability that all Section 16(a) filing requirements applicable to our officers, directors and greater than ten percent beneficial owners are complied with in a timely fashion.

    UNITED STATES

Since inception, we have not paid any compensation to our officers or directors. The tables below summarize all compensation awarded to, earned by, or paid to our executive officers by any person for all services rendered in all capacities to us for the fiscal period from our incorporation on April 6, 2023 to July 31, 2023 (our fiscal year end) and subsequent thereto to the date of this prospectus.

SUMMARY COMPENSATION TABLE

    UNITED STATES

Rafael Angel Ulloa Bonilla, 2023 0 0 0 0 0 0 0 0 Director

36

OUTSTANDING EQUITY AWARDS AT JULY 31, 2023

    UNITED STATES

Rafael Angel Ulloa 0 0 0 0 0 0 0 0 0 Bonilla

OFFICERS COMPENSATION

    UNITED STATES

Rafael Angel Ulloa 0 0 0 0 0 0 0 Bonilla

OPTION GRANTS. There have been no individual grants of stock options to purchase our common stock made to the executive officers named in the Summary Compensation Table.

AGGREGATED OPTION EXERCISES AND FISCAL YEAR-END OPTION VALUE.There have been no stock options exercised by the executive officers named in the Summary Compensation Table.

LONG-TERM INCENTIVE PLAN ("LTIP") AWARDS. There have been no awards made to a named executive officer in the last completed fiscal year under any LTIP.

37

SECURITY OWNERSHIP OF CERTAIN BENEFICIAL OWNERS AND MANAGEMENT

The following tables set forth the ownership, as of the date of this prospectus, of our common stock by each person known by us to be the beneficial owner of more than 5% of our outstanding common stock, our directors, and our executive officers and directors as a group. To the best of our knowledge, the persons named have sole voting and investment power with respect to such shares, except as otherwise noted. There are no any pending or anticipated arrangements that may cause a change in control. The information presented below regarding beneficial ownership of our voting securities has been presented in accordance with the rules of the Securities and Exchange Commission and is not necessarily indicative of ownership for any other purpose. Under these rules, a person is deemed to be a "beneficial owner" of a security if that person has or shares the power to vote or direct the voting of the security or the power to dispose or direct the disposition of the security.

    UNITED STATES

    UNITED STATES

A beneficial owner of a security includes any person who, directly or indirectly, through any contract, arrangement, understanding, relationship, or otherwise has or shares: (i) voting power, which includes the power to vote, or to direct the voting of shares; and (ii) investment power, which includes the power to dispose or direct the disposition of shares. Certain shares may be deemed to be beneficially owned by more than one person (if, for example, persons share the power to vote or the power to dispose of the shares). In addition, shares are deemed to be beneficially owned by a person if the person has the right to acquire the shares (for example, upon exercise of an option) within 60 days of the date as of which the information is provided. In computing the percentage ownership of any person, the amount of shares outstanding is deemed to include the amount of shares beneficially owned by such person (and only such person) by reason of these acquisition rights. As a result, the percentage of outstanding shares of any person as shown in this table does not necessarily reflect the person's actual ownership or voting power with respect to the number of shares of common stock actually outstanding on July 31, 2023. As of July 31, 2023, there were 2,000,000 shares of our common stock issued and outstanding.

38

    UNITED STATES

As of April 7, 2023, we have issued 2,000,000 shares of company common stock valued at 0.0001 per share to Frederick Sidney Reinhard Arnold in the capacity of Director of the Company in consideration of $200 to pay company expenses and keep on top of the business development.

As of July 31, 2023, the Company had a loan outstanding with a related party: Mr. Rafael Angel Ulloa Bonilla, our Director, who has given us a loan in the amount of $26,000. The loan is non-interest bearing, due upon demand and unsecured. No principal of this loan has been repaid yet.

    UNITED STATES

Pursuant to the Articles of Incorporation and By-Laws of the corporation, we may indemnify a director who is made a party to any proceeding, including a law suit, because of his position, if he acted in good faith and in a manner he reasonably believed to be in our best interest. In certain cases, we may advance expenses incurred in defending any such proceeding. To the extent that the director is successful on the merits in any such proceeding as to which such person is to be indemnified, we must indemnify him against all expenses incurred, including attorney's fees. With respect to a derivative action, indemnity may be made only for expenses actually and reasonably incurred in defending the proceeding, and if the director is judged liable, only by a court order. The indemnification is intended to be to the fullest extent permitted by the laws of the State of Wyoming.

Insofar as indemnification for liabilities arising under the Securities Act may be permitted to our directors, officers and controlling persons pursuant to the provisions above, or otherwise, we have been advised that in the opinion of the Securities and Exchange Commission, such indemnification is against public policy as expressed in the Securities Act, and is, therefore, unenforceable.

In the event that a claim for indemnification against such liabilities, other than the payment by us of expenses incurred or paid by one of our directors, officers, or controlling persons in the successful defense of any action, suit or proceeding, is asserted by one of our directors, officers, or controlling persons in connection with the securities being registered, we will, unless in the opinion of our counsel the matter has been settled by controlling precedent, submit to a court of appropriate jurisdiction the question whether such indemnification is against public policy as expressed in the Securities Act, and we will be governed by the final adjudication of such issue.

    UNITED STATES

We have filed a registration statement on Form S-1, of which this prospectus is a part, with the U.S. Securities and Exchange Commission. Upon completion of the registration, we will be required to file all requisite reports, such as Forms 10-K, 10-Q and 8-K, and other information with the Commission. Upon our registration under the 1934 Act, we would also be required to file additional documents with the Commission such as proxy statements under Section 14 of the 1934 Act. Such reports, proxy statements, this registration statement and other information, may be inspected and copied at the public reference facilities maintained by the Commission at 100 Fifth Street NE, Washington, D.C. 20549. Copies of all materials may be obtained from the Public Reference Section of the Commission's Washington, D.C. office at prescribe rates. You may obtain information regarding the operation of the Public Reference Room by calling the SEC at 1-800-SEC-0330. The Commission also maintains a website that contains reports, proxy and information statements and other information regarding registrants that file electronically with the Commission at http://www.sec.gov

    UNITED STATES

Our fiscal year end is July 31. We intend to provide financial statements audited by an Independent Registered Public Accounting Firm to our shareholders in our annual reports. The audited financial statements for the period from inception to July 31, 2023 can be found on page F-1.

39

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

Report of Independent Public Accounting Firm F-2

Balance Sheet of July 31, 2023 F-3

Statements of Operations for the period from April 6, 2023 (Inception) to July 31, 2023 F-4

Statements of Stockholder's Equity for the period from April 6, 2023 (Inception) to July 31, 2023 F-5

Statements of Cash Flows for the period from April 6, 2023 (Inception) to July 31, 2023 F-6

Notes to the Audited Financial Statements F-7

F-1

    UNITED STATES

To: The Board of Directors and Stockholders of Naploy Corp.

Opinion on the Financial Statements

We have audited the accompanying balance sheets of Naploy Corp. (the Company) as of July 31, 2023, and the related statements of operations, stockholders' equity, and cash flows for each of the two years in the period ended July 31, 2023, and the related notes (collectively referred to as the financial statements). In our opinion, the financial statements present fairly, in all material respects, the financial position of the Company as of July 31, 2023, and the results of its operations and its cash flows in the period ended July 31, 2023, in conformity with accounting principles generally accepted in the United States of America.

Explanatory Paragraph Regarding Going Concern

The accompanying financial statements have been prepared assuming that the Company will continue as a going concern. As discussed in Note 2 to the financial statements, the Company has suffered a loss from operations of US$6,380 and has a net capital deficiency of US$6,180 that raises substantial doubt about its ability to continue as a going concern. Management's plans in regard to these matters are also described in Note 2. The financial statements do not include any adjustments that might result from the outcome of this uncertainty.

Basis for Opinion

These financial statements are the responsibility of the Company's management. Our responsibility is to express an opinion on the Company's financial statements based on our audits. We are a public accounting firm registered with the Public Company Accounting Oversight Board (United States) (PCAOB) and are required to be independent with respect to the Company in accordance with the U.S. federal securities laws and the applicable rules and regulations of the Securities and Exchange Commission and the PCAOB.

We conducted our audits in accordance with the standards of the PCAOB. Those standards require that we plan and perform the audit to obtain reasonable assurance about whether the financial statements are free of material misstatement, whether due to error or fraud. The Company is not required to have, nor were we engaged to perform, an audit of its internal control over financial reporting. As part of our audits, we are required to obtain an understanding of internal control over financial reporting, but not for the purpose of expressing an opinion on the effectiveness of the Company's internal control over financial reporting. Accordingly, we express no such opinion.

Our audits included performing procedures to assess the risks of material misstatement of the financial statements, whether due to error or fraud, and performing procedures that respond to those risks. Such procedures included examining, on a test basis, evidence regarding the amounts and disclosures in the financial statements. Our audits also included evaluating the accounting principles used and significant estimates made by management, as well as evaluating the overall presentation of the financial statements. We believe that our audits provide a reasonable basis for our opinion.

Critical Audit Matter

The Critical Audit Matter communicated below is a matter arising from the current period audit of the financial statements that was communicated or required to be communicated to the audit committee and that: (1) relates to accounts or disclosures that are material to the financial statements and (2) involved our especially challenging, subjective, or complex judgments. The communication of critical audit matters does not alter in any way our opinion on the financial statements, taken as a whole, and we are not, by communicating the critical audit matter below, providing a separate opinion on the critical audit matter or on the accounts or disclosures to which it relates. We determined that there are no critical audit matters.

/s/ MAINOR AUDIT JA PARTNERID OU

We have served as the Company's auditor since 2023.

MAINOR AUDIT JA PARTNERID OU.

Kadaka pst 85a, Tallinn, Harju maakond 10922 PCAOB ID Number 2333

/s/ MAINOR AUDIT JA PARTNERID OU.

September 28, 2023

F-2

    UNITED STATES

    UNITED STATES

    UNITED STATES

Cash $ 895 Total Current Assets 895

Intangible Assets, Net 44,625 Total Assets $ 45,520

    UNITED STATES

Accounts Payable - Related Party $ 26,000 Accounts Payable 25,700 Total Current Liabilities 51,700

Common stock, $0.0001 par value, 75,000,000 shares authorized; 2,000,000 shares issued and outstanding 200 Accumulated deficit (6,380) Total Stockholders' Equity (6,180)

Total Liabilities and Stockholders' Equity $ 45,520

The accompanying notes are an integral part of these financial statements.

F-3

    UNITED STATES

    UNITED STATES

    UNITED STATES

REVENUES $ -

OPERATING EXPENSES Depreciation Expense 375 General and Administrative Expenses 105 Professional Fees 5,900 TOTAL OPERATING EXPENSES (6,380)

NET INCOME (LOSS) FROM OPERATIONS (6,380)

PROVISION FOR INCOME TAXES -

NET INCOME (LOSS) $ (6,380)

NET LOSS PER SHARE: BASIC AND DILUTED $ (0.00)

WEIGHTED AVERAGE NUMBER OF SHARES OUTSTANDING: BASIC AND DILUTED 2,000,000

The accompanying notes are an integral part of these financial statements.

F-4

    UNITED STATES

    UNITED STATES

    UNITED STATES

Inception, April 6, 2023 - $ - $ - $ - $ -

Shares issued for cash at $0.0001 per share on April 6, 2023 2,000,000 200 - - 200

Net loss for the year ended July 31, 2023 - - - (6,380) (6,380)

Balance, July 31, 2023 2,000,000 $ 200 $ - $ (6,380) $ (6,180)

The accompanying notes are an integral part of these financial statements.

F-5

    UNITED STATES

    UNITED STATES

    UNITED STATES

CASH FLOWS FROM OPERATING ACTIVITIES Net income (loss) $ (6,380) 375 Accounts Payable 25,700 CASH FLOWS USED IN OPERATING ACTIVITIES 19,695

CASH FLOWS FROM INVESTING ACTIVITIES Mobile Application and Website Acquisition (45,000) CASH FLOWS PROVIDED BY INVESTING ACTIVITIES $ (45,000)

CASH FLOWS FROM FINANCING ACTIVITIES Proceeds from Sale of Common Stock 200 Accounts Payable -Related Party Loans 26,000 CASH FLOWS PROVIDED BY FINANCING ACTIVITIES $ 26,200

Net increase in cash and equivalents 895 Cash and equivalents at beginning of the period - Cash and equivalents at end of the period 895

Supplemental cash flow information: Cash paid for: Interest $ - Taxes $ -

The accompanying notes are an integral part of these financial statements.

F-6

    UNITED STATES

    UNITED STATES

    UNITED STATES

NOTE 1 - ORGANIZATION AND BASIS OF PRESENTATION

Naploy Corp. (referred as the "Company", "we", "our") was incorporated in the State of Wyoming and established on April 6, 2023. Our primary focus is on launching a news blog that provides the latest updates on health-related topics, including but not limited to medical breakthroughs, healthy lifestyle tips, and updates on healthcare policies.

NOTE 2 - GOING CONCERN

The Company's financial statements have been prepared assuming that it will continue as a going concern, which contemplates continuity of operations, realization of assets, and liquidation of liabilities in the normal course of business.

As reflected in the financial statements, the Company had an accumulated deficit of $6,380 at July 31, 2023, a net loss of $6,380 since inception to July 31, 2023. The Company has accounts payable on a balance sheet of $25,700 at July 31, 2023. These factors raise substantial doubt about the Company's ability to continue as a going concern.

The Company is attempting to commence operations and generate sufficient revenue; however, the Company's cash position may not be sufficient to support the Company's daily operations. Management intends to raise additional funds by way of a private or public offering. While the Company believes in the viability of its strategy to commence operations and generate sufficient revenue and in its ability to raise additional funds, there can be no assurances to that effect. The ability of the Company to continue as a going concern is dependent upon the Company's ability to further implement its business plan and generate sufficient revenue and its ability to raise additional funds by way of a public or private offering.

The financial statements do not include any adjustments related to the recoverability and classification of recorded asset amounts or the amounts and classification of liabilities that might be necessary should the Company be unable to continue as a going concern.

NOTE 3 - SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES

Basis of Presentation

The accompanying financial statements have been prepared in accordance with generally accepted accounting principles in the United States of America.

The Company's year-end is July 31.

Development Stage Company

The Company is a development stage company as defined in ASC 915 "Development Stage Entities". The Company is devoting substantially all of its efforts on establishing the business and its planned principal operations have not commenced. All losses accumulated since Inception has been considered as part of the Company's development stage activities.

The Company has elected to adopt application of Accounting Standards Update No. 2014-10, Development Stage Entities (Topic 915): Elimination of Certain Financial Reporting Requirements. Upon adoption, the Company no longer presents or discloses inception-to-date information and other remaining disclosure requirements of Topic 915.

F-7

Use of Estimates

The preparation of financial statements in conformity with generally accepted accounting principles requires management to make estimates and assumptions that affect the reported amounts of assets and liabilities and disclosure of contingent assets and liabilities at the date the financial statements and the reported amount of revenues and expenses during the reporting period. Actual results could differ from those estimates.

Cash and Cash Equivalents

The Company considers all highly liquid investments with the original maturities of three months or less to be cash equivalents.

Fair Value of Financial Instruments

AS topic 820 "Fair Value Measurements and Disclosures" establishes a three-tier fair value hierarchy, which prioritizes the inputs in measuring fair value. The hierarchy prioritizes the inputs into three levels based on the extent to which inputs used in measuring fair value are observable in the market.

These tiers include:

Level 1: defined as observable inputs such as quoted prices in active markets; Level 2: defined as inputs other than quoted prices in active markets that are either directly or indirectly observable; and Level 3: defined as unobservable inputs in which little or no market data exists, therefore requiring an entity to develop its own assumptions.

The carrying value of cash and the Company's loan from shareholder approximates its fair value due to their short-term maturity.

Income Taxes

Income taxes are computed using the asset and liability method. Under the asset and liability method, deferred income tax assets and liabilities are determined based on the differences between the financial reporting and tax bases of assets and liabilities and are measured using the currently enacted tax rates and laws. A valuation allowance is provided for the amount of deferred tax assets that, based on available evidence, are not expected to be realized.

Basic Income (Loss) Per Share

The Company computes income (loss) per share in accordance with FASB ASC 260 "Earnings per Share". Basic loss per share is computed by dividing net income (loss) available to common shareholders by the weighted average number of outstanding common shares during the period. Diluted income (loss) per share gives effect to all dilutive potential common shares outstanding during the period. Dilutive loss per share excludes all potential common shares if their effect is anti-dilutive.

As of July 31, 2023, there were no potentially dilutive debt or equity instruments issued or outstanding.

Stock-Based Compensation

Stock-based compensation is accounted for at fair value in accordance with ASC Topic 718. To date, the Company has not adopted a stock option plan and has not granted any stock options.

Recent Accounting Pronouncements

Management does not believe that any recently issued, but not yet effective accounting pronouncements, when adopted, will have a material effect on the accompanying financial statements.

F-8

Note 4 - INTANGIBLE ASSETS

The Company follows the provisions of ASC 985, Software, which requires that all costs relating to the purchase or internal development and production of software products to be sold, leased or otherwise marketed, be expensed in the period incurred unless the requirements for technological feasibility have been established. The Company amortizes these costs using the straight-line method over the remaining estimated economic life of the product.

As of July 31, 2023, the Company acquired mobile application and website for $45,000, which is being amortized over a five-year life. The accumulated amortization was $375 as of July 31, 2023.

Note 5 - LOAN FROM RELATED PARTY

As of July 31, 2023, the Company owed $26,000 to the Company's director, Rafael Angel Ulloa Bonilla, for the Company's working capital purposes. The amount is outstanding and payable upon request.

Note 6 - COMMON STOCK

On April 6, 2023, the Company issued 2,000,000 shares of common stock to the director, Frederick Sidney Reinhard Arnold, at in consideration of $200 at $0.0001 per share to pay partial Incorporation fees expenses.

As of July 31, 2023, the Company had 2,000,000 shares issued and outstanding.

Note 7 - INCOME TAXES

On December 22, 2017, the President of the United States signed into law the Tax Cuts and Jobs Act ("Tax Reform Act"). The legislation significantly changes U.S. tax law by, among other things, lowering corporate income tax rates, implementing a territorial tax system and imposing a transition tax on deemed repatriated earnings of foreign subsidiaries. The Tax Reform Act permanently reduces the U.S. corporate income tax rate from a maximum of 35% to a flat 21% rate, effective January 1, 2018. As a result of the reduction in the U.S. corporate income tax rate from 34% to 21% under the Tax Reform Act, the Company revalued its ending net deferred tax assets.

The reconciliation of income tax benefit (expenses) at the U.S. statutory rate at 21% for the period ended as follows:

    UNITED STATES

Tax benefit (expenses) at U.S. statutory rate $ (1,340) Change in valuation allowance 1,340 Tax benefit (expenses), net $ -

The tax effects of temporary differences that give rise to significant portions of the net deferred tax assets are as follows:

    UNITED STATES

Net operating loss $ 1,340 Valuation allowance (1,340) Deferred tax assets, net $ -

F-9

The Company has accumulated approximately $6,380 of net operating losses ("NOL") carried forward to offset future taxable income up to 20 years, if any, in future years which begin to expire in year 2040. In assessing the realization of deferred tax assets, management considers whether it is more likely than not that some portion or all of the deferred tax assets will be realized. The ultimate realization of deferred tax assets is dependent upon the generation of future taxable income during the periods in which those temporary differences become deductible. Management considers the scheduled reversal of deferred tax liabilities, projected future taxable income and tax planning strategies in making this assessment. Based on the assessment, management has established a full valuation allowance against all of the deferred tax asset relating to NOLs for every period because it is more likely than not that all of the deferred tax asset will not be realized.

Note 8 - SUBSEQUENT EVENTS

In accordance with ASC 855-10 the Company has analyzed its operations subsequent to July 31, 2023 to the date these financial statements were issued, and has determined that it does not have any material subsequent events to disclose in these financial statements.

F-10

    UNITED STATES

"UNTIL ______________, ALL DEALERS THAT EFFECT TRANSACTIONS IN THESE SECURITIES, WHETHER OR NOT PARTICIPATING IN THIS OFFERING, MAY BE REQUIRED TO DELIVER A PROSPECTUS. THIS IS IN ADDITION TO THE DEALERS' OBLIGATION TO DELIVER A PROSPECTUS WHEN ACTING AS UNDERWRITERS AND WITH RESPECT TO THEIR UNSOLD ALLOTMENTS OR SUBSCRIPTIONS."

    UNITED STATES

ITEM 13. OTHER EXPENSES OF ISSUANCE AND DISTRIBUTION.

Expenses incurred or (expected) relating to this prospectus and distribution are as follows:

SEC Fee $ 17.71 Legal and Professional Fees 1,200 Accounting and auditing 4,500 Transfer Agent fees 2,000 EDGARization 3,000 TOTAL $ 10,717

ITEM 14. INDEMNIFICATION OF DIRECTORS AND OFFICERS.

Pursuant to the Articles of Incorporation and By-Laws of the corporation, we may indemnify an officer or director who is made a party to any proceeding, including a law suit, because of his position, if he acted in good faith and in a manner, he reasonably believed to be in our best interest. In certain cases, we may advance expenses incurred in defending any such proceeding. To the extent that the director is successful on the merits in any such proceeding as to which such person is to be indemnified, we must indemnify him against all expenses incurred, including attorney's fees. With respect to a derivative action, indemnity may be made only for expenses actually and reasonably incurred in defending the proceeding, and if the director is judged liable, only by a court order. The indemnification is intended to be to the fullest extent permitted by the laws of the State of Wyoming.

As to indemnification for liabilities arising under the Securities Act of 1933, as amended, for directors, officers or controlling persons, we have been informed that in the opinion of the Securities and Exchange Commission such indemnification is against public policy and is, therefore, unenforceable.

ITEM 15. RECENT SALES OF UNREGISTERED SECURITIES.

Set forth below is information regarding the issuance and sales of securities without registration since inception. No such sales involved the use of an underwriter; no advertising or public solicitation was involved; the securities bear a restrictive legend; and no commissions were paid in connection with the sale of any securities.

On April 7, 2023 the Company issued a total of 2,000,000 shares of common stock at a price of $0.0001 per share for a consideration of $200 to Mr. Frederick Sidney Reinhard Arnold, CEO of Naploy. Corp

These securities were issued in reliance upon the exemption contained in Section 4(2) of the Securities Act of 1933. These securities were issued to a promoter of the company, bear a restrictive legend and were issued to a non-US resident.

II-1

ITEM 16. EXHIBITS.

The following exhibits are included with this registration statement:

Exhibit Number Description 3.1 Articles of Incorporation 3.2 Bylaws 4.1 Subscription Agreement 5.1 Opinion re: Legality 10.2 Mobile Application and Website Purchase Agreement 23.2 Consent of Independent Auditor 107 Calculation of Filing Fee

ITEM 17. UNDERTAKINGS.

a. The undersigned registrant hereby undertakes:

1. To file, during any period in which offers or sales are being made, a post-effective amendment to this registration statement:

i. To include any prospectus required by section 10(a)(3) of the Securities Act of 1933;

ii. To reflect in the prospectus any facts or events arising after the effective date of the registration statement (or the most recent post-effective amendment thereof) which, individually or in the aggregate, represent a fundamental change in the information set forth in the registration statement. Notwithstanding the foregoing, any increase or decrease in Volume of securities offered (if the total dollar value of securities offered would not exceed that which was registered) and any deviation from the low or high end of the estimated maximum offering range may be reflected in the form of prospectus filed with the Commission pursuant to Rule 424(b) if, in the aggregate, the changes in volume and price represent no more than 20% change in the maximum aggregate offering price set forth in the "Calculation of Registration Fee" table in the effective registration statement.

iii. To include any material information with respect to the plan of distribution not previously disclosed in the registration statement or any material change to such information in the registration statement;

2. That, for the purpose of determining any liability under the Securities Act of 1933, each such post-effective amendment shall be deemed to be a new registration statement relating to the securities offered therein, and the offering of such securities at that time shall be deemed to be the initial bona fide offering thereof.

To remove from registration by means of a post-effective amendment any of the securities being registered which remain unsold at the termination of the offering.

II-2

4. That, for the purpose of determining liability under the Securities Act of 1933 to any purchaser:

i. If the registrant is relying on Rule 430B (230.430B of this chapter):

A. Each prospectus filed by the registrant pursuant to Rule 424(b)(3) shall be deemed to be part of the registration statement as of the date the filed prospectus was deemed part of and included in the registration statement; and

B. Each prospectus required to be filed pursuant to Rule 424(b)(2), (b)(5), or (b)(7) as part of a registration statement in reliance on Rule 430B relating to an offering made pursuant to Rule 415(a)(1)(i), (vii), or (x) for the purpose of providing the information required by section 10(a) of the Securities Act of 1933 shall be deemed to be part of and included in the registration statement as of the earlier of the date such form of prospectus is first used after effectiveness or the date of the first contract of sale of securities in the offering described in the prospectus. As provided in Rule 430B, for liability purposes of the issuer and any person that is at that date an underwriter, such date shall be deemed to be a new effective date of the registration statement relating to the securities in the registration statement to which that prospectus relates, and the offering of such securities at that time shall be deemed to be the initial bona fide offering thereof. Provided, however, that no statement made in a registration statement or prospectus that is part of the registration statement or made in a document incorporated or deemed incorporated by reference into the registration statement or prospectus that is part of the registration statement will, as to a purchaser with a time of contract of sale prior to such effective date, supersede or modify any statement that was made in the registration statement or prospectus that was part of the registration statement or made in any such document immediately prior to such effective date; or

ii. If the registrant is subject to Rule 430C, each prospectus filed pursuant to Rule 424(b) as part of a registration statement relating to an offering, other than registration statements relying on Rule 430B or other than prospectuses filed in reliance on Rule 430A, shall be deemed to be part of and included in the registration statement as of the date it is first used after effectiveness. Provided, however, that no statement made in a registration statement or prospectus that is part of the registration statement or made in a document incorporated or deemed incorporated by reference into the registration statement or prospectus that is part of the registration statement will, as to a purchaser with a time of contract of sale prior to such first use, supersede or modify any statement that was made in the registration statement or prospectus that was part of the registration statement or made in any such document immediately prior to such date of first use.

That, for the purpose of determining liability of the registrant under the Securities Act of 1933 to any purchaser in the initial distribution of the securities: The undersigned registrant undertakes that in a primary offering of securities of the undersigned registrant pursuant to this registration statement, regardless of the underwriting method used to sell the securities to the purchaser, if the securities are offered or sold to such purchaser by means of any of the following communications, the undersigned registrant will be a seller to the purchaser and will be considered to offer or sell such securities to such purchaser:

i. Any preliminary prospectus or prospectus of the undersigned registrant relating to the offering required to be filed pursuant to Rule 424;

ii. Any free writing prospectus relating to the offering prepared by or on behalf of the undersigned registrant or used or referred to by the undersigned registrant;

iii.The portion of any other free writing prospectus relating to the offering containing material information about the undersigned registrant or its securities provided by or on behalf of the undersigned registrant; and

iv. Any other communication that is an offer in the offering made by the undersigned registrant to the purchaser.

Insofar as indemnification for liabilities arising under the 1933 Act may be permitted to our director, officer and controlling persons of the small business issuer pursuant to the foregoing provisions, or otherwise, the small business issuer has been advised that in the opinion of the Commission such indemnification is against public policy as expressed in the 1933 Act, and is, therefore, unenforceable.

II-3

In the event that a claim for indemnification against such liabilities (other than the payment by the small business issuer of expenses incurred or paid by a director, officer or controlling person of the small business issuer in the successful defense of any action, suit or proceeding) is asserted by such director, officer or controlling person in connection with the securities being registered, the small business issuer will, unless in the opinion of its counsel the matter has been settled by controlling precedent, submit to a court of appropriate jurisdiction the question whether such indemnification by it is against public policy as expressed in the 1933 Act, and will be governed by the final adjudication of such issue.

3. To remove from registration by means of a post-effective amendment any of the securities being registered hereby which remain unsold at the termination of the offering.

4. Insofar as indemnification for liabilities arising under the Securities Act of 1933 (the "Act") may be permitted to directors, officers and controlling persons of the small business issuer pursuant to the By-Laws of the company, or otherwise, we have been advised that in the opinion of the Securities and Exchange Commission such indemnification is against public policy as expressed in the Act, and is, therefore unenforceable.

In the event that a claim for indemnification against such liabilities(other than the payment of expenses incurred or paid by a director, officer or controlling person in the successful defense of any action, suit or proceeding) is asserted by such director, officer, or other control person in connection with the securities being registered, we will, unless in the opinion of our legal counsel the matter has been settled by controlling precedent, submit to a court of appropriate jurisdiction the question whether such indemnification by it is against public policy as expressed in the Securities Act and will be governed by the final adjudication of such issue.

II-4

    UNITED STATES

In accordance with the requirements of the Securities Act of 1933, the registrant has duly caused this registration statement to be signed on its behalf by the undersigned, thereunto duly authorized, on October 6, 2023.

Naploy Corp., Registrant

    UNITED STATES

Pursuant to the requirements of the Securities Act of 1933, this registration statement has been signed by the following persons in the capacities and on the dates indicated.

    UNITED STATES

II-5

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

Section 1 - Annual Meetings

The annual meeting of the shareholders of the Corporation shall be held at the time fixed, from time to time, by the Board of Directors.

Section 2 - Special Meetings

Special meetings of the shareholders may be called by the Board of Directors or such person or persons authorized by the Board of Directors.

Section 3 - Place of Meetings

Meetings of the shareholders shall be held at the principal business office of the corporation or at such other place as may be determined by the Board of Directors.

Section 4 - Notice of Meetings

An announcement summoning an annual or extraordinary assembly, explicitly stating the venue, date, and time of the gathering, alongside the general scope of the meeting's agenda, must be transmitted via facsimile, personally delivered, or dispatched by mail with prepaid postage to every shareholder of the Corporation who possesses the right to vote at said meeting. The notification shall be dispatched to the shareholder's address as recorded in the Corporation's stock transfer ledger, at least ten (10) days prior to the scheduled gathering. It should be duly noted that an inadvertent omission or non-receipt of the meeting notice by a shareholder shall not render the proceedings of the meeting invalid.

Section 5 - Action Without a Meeting

Unless otherwise stipulated by applicable laws, any action that necessitates a shareholders' meeting or any other action that can be carried out at such a meeting may be undertaken without convening a physical gathering, prior notice, or formal voting. Instead, written consents signed by shareholders representing a majority of the shares eligible to vote at said meeting shall suffice. However, if a different proportion of voting power is mandated by law, the Articles of Incorporation, or the Bylaws, then the corresponding proportion of written consents must be obtained. These written consents must be documented and kept on record with the minutes of the Corporation's shareholders' proceedings.

Section 6 - Voting

Subject to a special voting rights or restrictions attached to a class of shares, each shareholder shall be entitled to one vote for each share of stock in his or her own name on the books of the corporation, whether represented in person or by proxy.

Section 7 - Dispute as to Entitlement to Vote

In a dispute as to the admission or rejection of a vote at an annual or special meeting, the decision of the chairman made in good faith is conclusive.

1

Section 8 - Equality of Votes

In the case of an equality of votes, the chairman of the meeting at which the vote takes place is not entitled to have a casting vote in addition to the vote or votes to which he may be entitled as a shareholder of proxyholder.

Section 9 - Motions

No motion proposed at an annual or special meeting need be seconded.

Section 10 - Quorum

    UNITED STATES

Section 11 - Proxy

    UNITED STATES

    UNITED STATES

Section 1 - Duties, Powers and Remuneration

    UNITED STATES

2

Section 2 - Number, Term, Election and Qualifications

    UNITED STATES

Section 3 - Removal

All or any number of the directors may be removed, with or without cause, at a meeting called expressly for that purpose, by a vote of the holders of a majority of the shares then entitled to vote at an election of directors.

Section 4 - Committees

    UNITED STATES

times as the Board may from time to time require. The Board has the power at any time to revoke or override the authority given to or acts done by any Committee.

    UNITED STATES

3

Section 5 - Meetings of Directors

    UNITED STATES

4

    UNITED STATES

Section 1 - Number, Qualification, Election and Term of Office

    UNITED STATES

Section 2 - Remuneration

The remuneration of the Officers of the Corporation may from time to time be determined by the Directors or, if the Directors decide, by the shareholders.

Section 3 - Resignation

Any officer may resign at any time by giving written notice of such resignation to the Corporation.

Section 4 - Conflict of Interest

Each officer of the Corporation who holds another office or possesses property whereby, whether directly or indirectly, duties or interests might be created in conflict with his or her duties or interests as an officer of the Corporation shall, in writing, disclose to the President the fact and the nature, character and extent of the conflict and abstain from voting with respect to any resolution in which the officer has a personal interest.

Section 5 - Removal

Any officer appointed by the Board of Directors may be removed by a majority vote of the Board, either with or without cause, and a successor appointed by the Board at any time, and any officer or assistant officer, if appointed by another officer, may likewise be removed by such officer.

    UNITED STATES

Section 1 - Fractional Shares

Without being restricted by any other provision in these Bylaws, the Corporation retains the discretion, upon resolution by the Directors, to refrain from issuing fractional shares in relation to an amalgamation, consolidation, exchange, or conversion. At the discretion of the Directors, fractional interests in shares may be rounded to the nearest whole number, with fractions of 1/2 being rounded to the next highest whole number, or may be purchased for cancellation by the Corporation for such consideration as the Directors determine. The Directors may determine the manner in which fractional interests in shares are to be transferred and delivered to the Corporation in exchange for consideration and a determination so made is binding upon all shareholders of the Corporation. In case shareholders having fractional interests in shares fail to deliver them to the Corporation in accordance with a determination made by the Directors, the Corporation may deposit with the Corporation's Registrar and Transfer Agent a sum sufficient to pay the consideration payable by the Corporation for the fractional interests in shares, such deposit to be set aside in trust for such shareholders. Such setting aside is deemed to be payment to such shareholders for the fractional interests in shares not so delivered which will thereupon not be considered as outstanding and such shareholders will not be considered to be shareholders of the Corporation with respect thereto and will have no right except to receive payment of the money so set aside and deposited upon delivery of the certificates for the shares held prior to the amalgamation, consolidation, exchange or conversion which result in fractional interests in shares.

5

Section 2 - Certificate of Stock

    UNITED STATES

    UNITED STATES

    UNITED STATES

Section 3 - Record Date

    UNITED STATES

6

Section 4 - Transfers of Shares

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

7

    UNITED STATES

The fiscal year end of the Corporation shall be fixed, and shall be subject to change, by the Board of Directors from time to time, subject to applicable law.

    UNITED STATES

If the Corporation possesses a corporate seal, it shall be designed in a manner as determined and modified by the Board of Directors as needed. However, the utilization of a seal or stamp by the Corporation on official corporate documents is not obligatory, and the absence of such seal shall not impact the legal validity of any corporate document.

    UNITED STATES

The Board is expressly empowered to adopt, amend, or repeal these Bylaws (or any provision hereof). The stockholders shall also have power to adopt, amend, or repeal these Bylaws (or any provision hereof).

    UNITED STATES

    UNITED STATES

    UNITED STATES

8

ARTICLE XI: ANNUAL LIST OF OFFICERS, DIRECTORS AND REGISTERED AGENT

Within sixty days following the submission of its Articles of Incorporation to the Secretary of State, the Corporation is required to file, and subsequently annually by the last day of the month in which the anniversary date of incorporation falls, a list with the Secretary of State. This list should include the names of its president, secretary, and treasurer, as well as all Directors. Furthermore, the list should provide the post office box or street address, whether it is the residential or business address, and the designation of the Corporation's resident agent in the state of Wyoming. It is mandatory that the list is certified by an authorized officer of the Corporation.

ARTICLE XII: INDEMNITY OF DIRECTORS, OFFICERS, EMPLOYEES AND AGENTS

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

9

    UNITED STATES

    UNITED STATES

Intending to become a possessor of common stocks (the "Shares") of NAPLOY CORP., a corporation established in accordance with the statutes of Wyoming (known as the "Company"), the undersigned (the "Subscriber") has affixed their signature below.

Accordingly, the Subscriber hereby agrees as follows:

I. Subscription

The Subscriber, intending to be bound, hereby irrevocably agrees to purchase from the Company, the number of shares, set forth on the Signature Page at the end of this subscription Agreement (the "Agreement") at a purchase price of $0.02 per share, upon the terms and conditions hereinafter set forth. This subscription is submitted to the Company in accordance with and subject to the terms and conditions described in this Agreement. The Subscriber acknowledges that the Company reserves the right, in its sole and absolute discretion, to accept or reject this subscription and the subscription will not be binding until accepted by the Company in writing.

The closing of the Subscription of Shares hereunder (the "Closing") shall occur immediately upon:

    UNITED STATES

II. Representations of Subscriber

By entering into this Agreement, the Subscriber hereby affirms, declares, and provides warranties to the Company, with the intention and understanding that the Company will rely on them:

    UNITED STATES

III. Purchase Procedure

The Subscriber acknowledges that, in order to subscribe for Shares, he must, and he does hereby, deliver to the Company:

    UNITED STATES

1

IV. Execution in Counterparts

This Subscription Agreement may be executed in one or more counterparts.

V. Applicable Law

This Subscription Agreement shall be governed by and construed in accordance with the laws of the State of Wyoming as applied to the contracts made and wholly to be performed in that State.

VI. Persons Bound

This Subscription Agreement, unless otherwise stipulated herein, shall be advantageous to and enforceable by the Company, its successors, and assigns, as well as each Subscriber, their respective heirs, executors, administrators, successors, and assigns.

VII. Notices

Any notice, demand or other communication which any party hereto may be required, or may elect, to give to any other party hereunder shall be sufficiently given in writing and shall be delivered personally, telegraphed, telexed, sent by facsimile transmission or sent by certified, registered or express mail, postage prepaid, to the address of each party set forth herein.

VIII. Certification

The Subscriber confirms that they have thoroughly read the entirety of this subscription agreement and that every statement made by the Subscriber herein is accurate and comprehensive.

2

    UNITED STATES

The undersigned, desiring to subscribe for the number of Shares of NAPLOY CORP. (the "Company") as is set forth below, acknowledges that he/she has received and understands the terms and conditions of the Subscription Agreement attached hereto and that he/she does hereby agree to all the terms and conditions contained therein.

IN WITNESS WHEREOF, the undersigned has hereby executed this Subscription Agreement as of the date set forth below.

(PLEASE PRINT OR TYPE THE INFORMATION IN THE TABLE BELOW)

Number of Shares (x $0.02 per share)

Total Amount of Subscription

Exact name of Subscriber

Address of Subscriber

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

3

    UNITED STATES

    UNITED STATES

    UNITED STATES

NAPLOY CORP. 95 Lias Estate Kafe district Abuja, FCT 900108 Nigeria

Dear Sirs:

We have acted as counsel to you (the "Company"), in connection with the proposed filing of a Registration Statement on Form S-1, (as it may be amended, the "Registration Statement"), under the Securities Act of 1933, as amended (the "Act"), relating to the Company's offering of 6,000,000 shares (the "Shares") of the Company's common stock (the "Common Stock.")

We have examined the originals, or certified, conformed or reproduction copies, of all such records, agreements, instruments and documents as we have deemed relevant or necessary as the basis for the opinion hereinafter expressed. In all such examinations, we have assumed the genuineness of all signatures on originals or certified copies and the conformity to original or certified copies of all copies submitted to us as conformed or reproduction copies. As to various questions of fact relevant to such opinion, we have relied upon, and assumed the accuracy of, certificates and oral or written statements and other information of or from public officials, officers or representatives of the Company, and others.

Based on the foregoing, and the laws of the State of Wyoming, we are of the opinion that the Shares have been duly authorized and, upon issuance and delivery against payment therefor in accordance with the terms of the Registration Statement, the Shares will be validly issued, fully paid and non-assessable.

We hereby consent to the filing of this opinion as an exhibit to the Registration Statement. In giving this consent, we do not hereby admit that we are in the category of persons whose consent is required under Section 7 of the Act.

Very truly yours,

/s/Haddan & Zepfel

Haddan & Zepfel LLP

    UNITED STATES

    UNITED STATES

This Mobile Application and Website Purchase Agreement (the "Agreement") is made and effective from June 22, 2023.

BETWEEN:

Naploy Corp. (hereinafter called as the "Client"), located at 95 Lias Estate Kafe district Abuja, FCT 900108 Nigeria.

AND:

Mario Jimenez Martinez (hereinafter called as the "Developer"), located at Las Marias, Nuevo Casa 27, Gaspar Hernandez 56000, Dominican Republic.

And hereinafter, the parties hereto shall be referred to as "Party" or "Parties".

    UNITED STATES

Whereas, Naploy Corp. wishes to purchase the mobile application "NAPLOY" and the website, developed by the Developer as an independent contractor for the specific purpose of developing and purchasing the NAPLOY Mobile App as well as the website, that includes the transfer of a variety of rights and assets, proprietary software that forms the core of the product, and infrastructure, as well as the transfer of accounts, data, all components and relevant functionality, both essential and ancillary to the operation of the application and backend software contained for Android and iOS devices and to be published in the Apple and Google marketplaces (hereinafter called as the "Project", the "Mobile Application", the "App") and also software items, and infrastructure, as well as the transfer of accounts, data, all components and relevant functionality, both essential and ancillary to the operation of the website (hereinafter called as the "Project", the "Website", the "Site") respectively, developed as per the requirements specifications by Client within this Mobile Application and Website Purchase Agreement.

Whereas, the "Developer" is engaged in the making of such applications and websites, holding all the necessary tools to obtain the needed results of this Project for Naploy Corp.

NOW, THEREFORE, in consideration of the mutual covenants and agreements herein contained, the parties hereto, intending, to be legally bound, agree as follows:

I. Representations and Warranties of the Parties

1. Representations and Warranties of the Client

The Client hereby makes the following representations and warranties to the Developer and acknowledges that the Developer is relying on such representations and warranties in entering into this Agreement and completing the purchase and sale of the Application and the Website as well as all other transactions contemplated by this Agreement.

    UNITED STATES

    UNITED STATES

2. Representations and Warranties of the Developer.

    UNITED STATES

    UNITED STATES

1

II. Project Scope

The Client and the Developer have established that the Mobile Application and the Website will contain the main following functions:

    UNITED STATES

The Client and the Developer have established that the Mobile Application and the Website will also contain the following accompanying graphics:

- All background images; original and/or modified for the application. - Icon design; original function and the application icon itself.

The Developer will also provide the client with graphics for use in promoting the mobile app and agrees complete the scope of work as outlined in section VII of this Agreement.

III. Mobile Application and Website Rights, Operational Data and Databases

Rights of the mobile application and website as well as images produced by Developer will be owned solely by the Client. The Client only assigns the right directly to the Developer to display graphics and other application and website elements as examples of their work and for marketing purposes provided advanced notice and specifics are provided to Client.

All operational data and databases relating to the Mobile Application and the Website shall be owned by the Client. The Developer shall not be entitled to use the data for any purpose that competes directly or indirectly with the Client's use and operation of the Mobile Application and the Website for online health platform services.

2

IV. Cost of the Mobile Application and the Website

The cost of NAPLOY Application and Website (with the inclusion of the mobile application and the website itself, accompanying designs, the transfer of a variety of rights and assets, proprietary software that forms the core of the product, and infrastructure, as well as the transfer of accounts, data, all components and relevant functionality, both essential and ancillary to the operation of and the application and the website, including backend software contained for Android and iOS in particular for the application) is $45,000.

THEREFORE, on the terms and subject to the fulfillment of the conditions of this Agreement, the Developer agrees to sell, assign and transfer to the Client, and the Client agrees to purchase from the Developer the Mobile Application and the Website, in consideration for Forty-Five Thousand US Dollars ($45,000.00).

The payment is made in several stages:

    UNITED STATES

    UNITED STATES

Development

Compatibility. The mobile app with be compatible with smart phones utilizing the following operating systems

- Apple iOS, for use on iPhone and iPad devices - Google Android OS, for use on Android powered devices;

as well as the website, adoptable and compatible for PCs and smart phones.

V. Maintenance, Technical Support, and Updates

This agreement allows for minor maintenance and updates to the application and the website after launch of the Mobile Application and the Website, including updating links and making minor changes to content.

VI. Project Timeline

The Developer will work expeditiously to complete this Project, and the estimated date of submission to the app markets and the ending of website development is approximately 50 days from the execution of the Agreement. The Client acknowledges that the Apple and Android markets' review and publishing process is not subject to this agreement, and on average takes between 7 and 28 business days once submitted. The project timeline is simply an estimate, and does not constitute a guarantee as delays may arise (such as from the client in approval and review, as well as review by Apple or Google in particular for the application).\

3

VII. Intellectual Property Rights

To the best knowledge of the Developer, the Application and the Website do not in any respect infringe the right of any person under or in respect of any patent, design, trade mark, and trade name, copyright or other industrial or intellectual property.

VIII. The Agreement

This Agreement constitutes the sole agreement between the Developer and the Client regarding this mobile application and website project. Client acknowledges that any additional feature, element, or work not specified in this Agreement, must be authorized by verbal request or written request signed by Client and Developer, and may incur additional cost.

IX. Waiver, Amendment

Except as expressly provided in this Agreement, no amendment or waiver of this Agreement shall be binding unless executed in writing by the Party are bound. No waiver of any provision of this Agreement shall constitute a waiver of any other provision, nor shall any waiver of any provision of this Agreement constitute a continuing waiver unless otherwise expressly provided.

X. Terms

Activities and operations of the Developer with respect to the Mobile App and the Website, including the development, design, bug fixes and release of the Mobile App and the Website with all the necessary functionality should be finished to the execution of this Agreement.

This term may be extended, provided that both parties have reached an agreement on this and have been notified of this at least 60 days in advance in a writing form, transmitted by similar means of recorded electronic communication or sent by registered mail.

XI. Dispute Resolution Clauses

Any dispute arising under the Agreement shall be resolved by the process set forth herein. All issues shall as an initial attempt, be resolved by negotiation between representatives of the contracting parties. The failure to negotiate a resolution shall result in the dispute being referred to the mediator qualified in contract disputes and having knowledge of the mediation process. The parties shall initiate good faith efforts in the selection of the mediator and the process which shall be governed. All costs of mediation shall be shared equally between the parties. If the mediation process is unsuccessful, the parties shall resort to final and binding arbitration by ether selecting the mediator as arbitrator or selecting another individual as arbitrator.

XII. Assignment

The rights of the Client hereunder are not assignable without the written consent of the Developer. The rights of the Developer hereunder are not assignable without the written consent of the Client.

XIII. Negotiation of Agreement

As the contracting parties have over a period of time negotiated the terms of this Contract, neither one shall be considered as the drafter of the terms of this Agreement. Both parties have had the opportunity to seek legal counsel to review the terms of this Agreement and are satisfied they have a complete and full understanding of the terms and provisions contained herein. In addition, each party has been fully authorized to sign the Agreement for and on behalf of the entity they represent as designated herein.

4

The undersigned hereby agree to the terms, conditions and stipulations of this agreement on behalf of his or her organization or business.

AGREED BY:

    UNITED STATES

/s/ Frederick Sidney Reinhard Arnold /s/ Mario Jimenez Martinez

Frederick Sidney Reinhard Arnold, Secretary Mario Jimenez Martinez

5

    UNITED STATES

    UNITED STATES

    UNITED STATES

To the Board of Directors and Stockholders

Naploy Corp.

We consent to the inclusions of our report dated September 28, 2023, with respect to our audit of the financial statements of Naploy Corp. as of May 31. 2023 into the Registration Statement of Naploy Corp. Form S-1 (pages F1 to F7). Except for our audit report and the accompanying financial statements and notes, we are not in the position to agree or disagree with any other information contained in the Registration Statement of Naploy Corp. Form S-1.

/s/ MAINOR AUDIT JA PARTNERID OU

We have served as the Company's auditor since 2023.

MAINOR AUDIT JA PARTNERID OU.

Kadaka pst 85a, Tallinn, Harju maakond 10922

PCAOB ID Number 2333

[[Image Removed]]

Date: September 28, 2023

    UNITED STATES

    UNITED STATES

    UNITED STATES

    UNITED STATES

COMTEX_441524187/2254/2023-10-06T12:56:00

(c) 1995-2023 Cybernet Data Systems, Inc. All Rights Reserved

Blogs - Finance (blog ref.) - Canadian Insider
November 10, 2023 14275 mots
ALLIED GOLD ANNOUNCES THIRD QUARTER 2023 RESULTS: MARKING A NEW ERA AS A PUBLIC COMPANY AND THE START OF ASSET OPTIMIZATIONS AND ROBUST, FULLY FUNDED GROWTH INITATIVES ACROSS ITS PORTFOLIO

ALLIED GOLD ANNOUNCES THIRD QUARTER 2023 RESULTS: MARKING A NEW ERA AS A PUBLIC COMPANY AND THE START OF ASSET OPTIMIZATIONS AND ROBUST, FULLY FUNDED GROWTH INITATIVES ACROSS ITS PORTFOLIO Canada... Voir l'article

Ce document référence un lien URL de site non hébergé par Cision.

PR Newswire UK Disclose
Thursday, December 8, 2022 - 02:00:00 UTC -0500 25099 mots

BlackRock Frontiers Investment Trust Plc - Final Results

BlackRock Investment Management (UK) Limited

BlackRock Frontiers Investment Trust plc

(LEI: 5493003K5E043LHLO706)

Annual results announcement for the year ended 30 September 2022

PERFORMANCE RECORD

The Company’s financial statements are presented in US Dollars. The Company’s shares are listed on the London Stock Exchange and quoted in British Pound Sterling. The British Pound Sterling amounts for performance returns shown below are presented for convenience. The difference in performance returns measured in US Dollars and in British Pound Sterling reflects the change in the value of British Pound Sterling versus the US Dollar over the period.

1 The change in net assets reflects dividends paid and portfolio movements during the year.

2 Based on an exchange rate of US$1.1163 to £1 at 30 September 2022 and US$1.3484 to £1 at 30 September 2021.

3 Alternative Performance Measures, see Glossary in the Company’s Annual Report for the year ended 30 September 2022.

4 The Company was incorporated on 15 October 2010 and its shares were admitted to trading on the London Stock Exchange on 17 December 2010.

5 With effect from 1 April 2018, the Benchmark Index changed to the MSCI Emerging Markets Index ex Selected Countries + MSCI Frontier Markets Index + MSCI Saudi Arabia Index. Prior to 1 April 2018, the Benchmark Index was the MSCI Frontier Markets Index. The performance returns of the Benchmark Index since inception have been blended to reflect this change.

6 Net return (NR) indices calculate the reinvestment of dividends net of withholding taxes.

Sources: BlackRock and Datastream.

CHAIRMAN’S STATEMENT

OVERVIEW

Over the year to 30 September 2022, your Company’s Net Asset Value per share decreased by -10.9%, compared to a decrease in the Benchmark Index of -7.3%, resulting in an underperformance of 3.6% (in US Dollar terms with dividends reinvested). As a result of the strong appreciation of the US Dollar, for Sterling based shareholders, the equivalent return for the year was +7.7%, with the benchmark returning +12.0% (in Sterling terms with dividends reinvested).

Since the financial year end, and up to close of business on 5 December 2022, the Company’s NAV has increased by 9.4% compared with an increase in the Benchmark Index of 5.2% over the same period (in US Dollar terms with dividends reinvested).

Our portfolio managers provide a detailed description of the key contributors and detractors to performance during the period, insight into the positioning of the portfolio and their views on the outlook for the forthcoming year in their report which follows.

REVENUE RETURN AND DIVIDENDS

The Company’s revenue return per share for the year amounted to 6.35 cents (2021: 7.09 cents). The Directors are recommending the payment of a final dividend of 4.25 cents per ordinary share (2021: 4.25 cents) in respect of the year ended 30 September 2022. Together with the interim dividend of 2.75 cents per share (2021: 2.75 cents), this represents a total of 7.00 cents per share (2021: 7.00 cents). This year’s dividend has been funded through current year revenue and has been supported by a small proportion of brought forward revenue reserves representing 9.4% of the total dividend. The Board continues to monitor closely the level of revenue generated by the Company's investment portfolio and will aim to maintain the dividend at 7.00 cents per share for the next financial year, through a combination of, primarily, dividend income supported by revenue reserves where deemed necessary.

Subject to shareholder approval, this dividend will be paid on 14 February 2023 to shareholders on the register at close of business on 6 January 2023. The ex-dividend date will be 5 January 2023. The Company does not have a policy of actively targeting income; nevertheless, this return represents an attractive yield of 4.5% (please see the Glossary in the Company’s Annual Report for the year ended 30 September 2022 for the inputs to the yield calculation).

SHARE CAPITAL

For the year under review, the Company’s ordinary shares have traded at an average discount to NAV of 9.2% and were trading at a discount of 10.4% on a cum-income basis at 5 December 2022, the latest practicable date prior to the issue of this report.

The Directors recognise the importance to investors of ensuring that the Company’s share price is as close to its underlying NAV as possible. Accordingly, the Directors monitor the share price closely and will consider the issue of shares at a premium or the repurchase at a discount to help balance demand and supply in the market. However, the Board has not seen fit to buy back any of its shares in recent years, and believes that the best way to encourage a narrowing of the discount at which the Company's shares trade is to deliver strong investment performance and to continue to communicate the unique attractiveness of our investment proposition to both existing and new shareholders.

As at 30 September 2022, the Company had 189,325,748 ordinary shares in issue, including 52,497,053 shares held in treasury. No shares were issued or bought back during the year under review or post year end from 1 October 2022 up to the date of this report.

The Directors have been granted the authority by shareholders to buy back up to 14.99% of the Company’s issued share capital (excluding any shares held in treasury) and also to issue or sell from treasury on a non-pre-emptive basis up to 10% of the Company’s issued share capital. Both authorities expire on the conclusion of the forthcoming Annual General Meeting (AGM) to be held on Tuesday, 7 February 2023, at which time resolutions will be put to shareholders seeking a renewal of these powers. Further information can be found in the Directors’ Report in the Company's Annual Report for the year ended 30 September 2022.

GEARING

One of the advantages of the investment trust structure is that the Company can use gearing with the objective of increasing portfolio returns over the long term. The Company utilised its ability to gear the portfolio through its CFD exposure during the year. As at the year-end, net gearing stood at 1.0%.

BOARD COMPOSITION

As at 30 September 2022 the Board consisted of six independent non-executive Directors. As part of its succession plan the Board regularly considers its composition to ensure that a suitable balance of skills, knowledge, experience, independence and diversity is achieved to enable the Board to effectively discharge its duties. As I mentioned in the Half-yearly Report, as part of the Board’s ongoing succession plan, we appointed two new Directors during the year, Lucy Taylor-Smith and Elisabeth Airey. They each bring a wealth of relevant experience and expertise and I am pleased to be able to say that both have contributed greatly during our meetings this year.

The Directors submit themselves for re-election annually and therefore all Directors will each stand for re-election at the forthcoming AGM.

SENIOR INDEPENDENT DIRECTOR

In accordance with the UK Corporate Governance Code, the Board has resolved to appoint Katrina Hart as Senior Independent Director, with effect from publication of the annual report. Further information on the role and responsibilities of the Senior Independent Director can be found in the Company's Annual Report for the year ended 30 September 2022.

DIRECTORS’ REMUNERATION

Having reviewed the Directors’ fees during the year the Board is seeking shareholder approval to increase the maximum limit on aggregate Directors’ fees payable in any one year from £200,000 to £250,000. This will ensure that there is sufficient headroom to accommodate the additional Directors appointed last year and any potential increase in the future as may be necessary. Please be assured that there is no intention to increase the fees paid up to the new maximum cap in the short term. The change in Directors’ fees over the last five years is set out in the Directors’ Remuneration Report. Further information on the rationale for the proposed increase in the maximum cap on Directors' remuneration can be found in the Directors’ Report in the Company's Annual Report for the year ended 30 September 2022 and a resolution approving this increase is included in the Notice of the AGM.

CORPORATE GOVERNANCE

The Board takes its governance responsibilities very seriously and follows best practice requirements as closely as possible. The UK Code of Corporate Governance (the UK Code) requires enhanced disclosure setting out how we, as Directors, have fulfilled our duties in taking into account the wider interests of stakeholders in promoting the success of the Company. As part of this reporting, and given the environmental, social and governance (ESG) issues that are faced by many companies within the Company’s Benchmark Index and the Company’s investment portfolio, we have provided a detailed report on these matters in the Strategic Report below. We have also provided more information on our Manager’s approach to shareholder engagement and voting activities.

ENVIRONMENTAL, SOCIAL AND GOVERNANCE (ESG) CONSIDERATIONS

ESG issues can present both opportunities and risks to long-term investment performance. While the Company does not have an ESG investment objective or exclude investments based only on ESG criteria, these ethical and sustainability issues are a consideration of the Company, and your Board is committed to a diligent oversight of the activities of our Investment Manager in these areas. The frontier markets in which the Company can invest are home to over 3 billion of the world’s population and through our investments we bring much needed capital to markets largely overlooked by developed world investors.

We believe that the companies in which the portfolio is invested should operate within a healthy ecosystem of all their stakeholders whether these are shareholders, employees, customers, regulators or suppliers and that this can aid the sustainability of long-term returns.

ANNUAL GENERAL MEETING

I am pleased to report that it is the Board’s intention that this year’s AGM will be held in person at 12:30 p.m. on Tuesday, 7 February 2023 at the offices of BlackRock at 12 Throgmorton Avenue, London EC2N 2DL.

At present, UK Government restrictions on public gatherings are no longer in force in connection with COVID-19 and therefore we intend to hold the AGM in the normal way with physical attendance by shareholders. However, although unlikely, shareholders should be aware that it is possible that such restrictions could be reimposed if required prior to the date of the AGM and therefore we recommend that as well as physical attendance, shareholders also cast their votes by proxy to ensure that their votes are counted.

Shareholders who intend to attend the AGM should ensure that they have read the venue requirements for entry to the AGM. These requirements, along with further information on the business of this year’s AGM, can be found in the Directors’ Report.

The Board very much looks forward to meeting shareholders and answering any questions you may have on the day. We hope you can attend this year’s AGM.

SHAREHOLDER COMMUNICATION

We appreciate how important access to regular information is to our shareholders. To supplement our Company website, we now offer shareholders the ability to sign up to the Trust Matters newsletter which includes information on the Company as well as news, views and insights. Further information on how to sign up is included on the inside cover of in the Company's Annual Report for the year ended 30 September 2022.

OUTLOOK

Many of the developed markets are experiencing soaring inflation and the spectre of recession. As governments and central banks grapple with the challenges brought about by the COVID-19 pandemic and the effects of the Russia-Ukraine conflict, our diverse and uncorrelated investment universe looks ever more attractive.

Our Company provides shareholders with the opportunity to invest in countries that we consider to have superior growth prospects, favourable population demographics, relatively low levels of debt and more normal levels of inflation. In many cases, these markets continue to trade at a significant valuation discount relative to both the developed markets and their own history. The Company’s dividend yield also remains attractive and may become ever more valuable to shareholders seeking income against a backdrop of high inflation and increasing interest rates as central banks act to bring stability to the developed markets.

Success in these complex frontier markets requires in-depth research and analysis and, in particular, boots on the ground. I am therefore pleased to be able to report that our portfolio managers were able to resume travel this year following the removal of the COVID-19 restrictions and visited many countries, including Egypt, Kazakhstan, Saudi Arabia, Turkey, the United Arab Emirates (UAE) and Uzbekistan to name just a few. They met with the management of the companies in which we invest, as well as government officials, economists and other parties with local knowledge, a vital component of the research process.

We have long extolled the diversification benefits of the frontier markets. This relative economic stability and, in many cases, countries which are in the growth phase of their economic cycles, in our view further strengthens the investment case for exposing an investment portfolio to the frontier markets. We believe that, collectively, these factors and attributes provide the long-term shareholder with a compelling investment opportunity.

AUDLEY TWISTON-DAVIES

Chairman

7 December 2022

INVESTMENT MANAGER’S REPORT

MARKET REVIEW

The world today is a drastically different place from when we last wrote this report. If we gave you two year-on-year inflation figures of 8% and 3% at the start of 2022 and asked you to tag them as Vietnam vs Germany, you would likely laugh at a rather obvious question. Alas, the macro environment today has turned a lot of conventional wisdom and common knowledge on its head. We are seeing most of the developed world edge towards double digit inflation while many emerging and frontier markets generally have trundled along with much more mundane price increases. Whilst the inflation seen across the developed world is the highest in seven decades, the majority of frontier markets are just experiencing a normal economic cycle, a situation that is pretty remarkable.

To understand the impacts of the current high inflation environment, we should split frontier markets into three groups. Firstly, there are a number of countries across frontier markets where inflation remains muted. The meteoric rise in energy prices that we have seen across Europe has not been reflected globally. As you can see in the chart in the Company’s Annual Report for the year ended 30 September 2022, for many of the countries where we invest, energy prices have seen little change over the past year.

For energy exporting countries, the current boom in energy prices offers them the fiscal resources to support their domestic populations and protect them from the global increases in food and other commodity prices. Inflation in Saudi Arabia is currently at 2.9%, Indonesia at 5.9% and Vietnam at 3.9%. These countries are not currently seeing and are unlikely to see inflation outside their normal expected levels.

Secondly, there are a number of countries which are currently experiencing high inflation. However, in stark contrast to the western world, we have seen governments and central banks take dramatic action to try to bring price levels back under control across these countries. To put this in historical context, in Chile, the policy rate of 10.75% is the highest since 1996 (with the exception of a three month period in 1998). Interest rates in Hungary are at a 19-year high and in Colombia, at a 14-year high. Inflation levels are unprecedented, but so has been the stock market reaction to the extent where we now believe these levels present attractive yield opportunities and could start to drive flows into the region.

There is a third group of countries where inflation is currently very high, policy approaches are either unorthodox or significantly behind the curve and we remain concerned about their future economic trajectory. Luckily these are few and far between within the frontier market universe and we have no exposure to these countries.

The Company’s Benchmark Index is down 7.3% for the year ended 30 September 2022, faring significantly better than the MSCI Emerging Markets Index which is down 28.1% and the MSCI World Index which is down 20.0% over the same period (all in US Dollar terms). Under the hood, the drivers of various parts of the frontier market universe are unsurprisingly quite divergent.

Regionally, the Middle East has been the strongest performer, with Qatar, Saudi Arabia, the United Arab Emirates (UAE) and Kuwait all delivering positive returns. The region has been buoyed by elevated oil prices following Russia's incursion into Ukraine. The Gulf Cooperation Council region is currently on track to report the highest current account and fiscal account surpluses for nearly a decade.

In contrast, Eastern Europe has had a challenging year. While the year started with optimism about a post COVID-19 recovery and disbursement of EU Recovery funds, Russia’s invasion of Ukraine marked a drastic turn of events for the region. In addition to the tragic loss of life, it has also led to a significant disruption to exports, higher energy prices and import bills, and cast a large cloud of uncertainty over geopolitical stability for the entire continent.

In Southeast Asia, the story is more nuanced. On the one hand, Indonesia and Malaysia have benefited hugely from commodity price strength as well as the accelerating tourism recovery. On the other hand, in Thailand and the Philippines we are concerned that the current high inflation will cause their respective central banks to raise interest rates substantially whilst economic recovery remains relatively weak.

In Latin America, performance has been strong, albeit volatile, given the commodity-heavy nature of the region. Chile has been in the news for constitutional reform for most of this year. It culminated in early September 2022 with voters overwhelmingly rejecting the new changes. We believe this is a positive outcome for the market but expect political noise to continue.

NOTES FROM THE ROAD

One of our highlights of the past year was our ability to get back out on the road and meet the management of the companies in which we invest, as well as government officials, economists and other parties with local knowledge. This element of on-the-ground research has always been a core component of our investment process and we are glad to have resumed it.

Earlier in the year, we visited Egypt, Kazakhstan, Saudi Arabia, Turkey, the UAE and Uzbekistan. As some of the earliest international investors to be returning to these countries, we were able to arrange fantastic schedules, meeting contacts across the political and economic spectrum, as well as several of new investment opportunities, including companies that had recently listed.

We travelled to Southeast Asia over the summer. In Indonesia, we see clear activity recovery and a pass-through of higher commodity prices into domestic recovery as well as external accounts. In addition, long-term structural improvements in tax and labour market legislation bolster our positive outlook towards the country. We are also seeing an improvement in foreign direct investment after a long period of underinvestment. In Malaysia, one of the key themes is supply chain recalibration away from China. There is a nascent, but interesting, start-up ecosystem emerging in the country.

On the tourism front, Malaysia has significant room for recovery, particularly if and when China’s borders re-open given China made up 12% of all tourist arrivals in 2019. For Thailand, the outlook has been marred to some degree by inflation, currency weakness, and unorthodox monetary policy. 28% of Thailand’s tourists came from mainland China in 2019 and the lack of recovery has weighed on the country’s economy.

We also travelled to the Middle East, namely Qatar and Kuwait. They continue to be relatively attractive in the current environment of oil price tightness. In August, we travelled far south to Colombia, Peru and Argentina. While we have not had exposure to Argentina for the last few years, we are excited by the work that Argentina is currently undertaking to increase its pipeline capacity for oil exports, seeing a significant increase in export earnings as a game changer for the country.

Most recently, we visited Poland and Hungary. We prefer Hungary on a relative basis. The extent of corrective actions taken by the central bank over the past nine months is unprecedented, with policy rates now a very punchy 18%. We will be watching closely how inflation fares (currently hovering close to 20%) and how they close the fiscal gap. In Poland, valuations are looking very attractive, with the market currently trading at similar levels to where it was in 2003.

PORTFOLIO PERFORMANCE

For the year ended 30 September 2022, the Company’s NAV returned -10.9%, compared with a Benchmark Index return of -7.3% in US Dollar terms. In British Pound Sterling terms, the Company’s NAV was up 7.7%, relative to a Benchmark Index return of 12.0%. The underperformance relative to our benchmark was due largely to our overweight positions at the outset in Kazakhstan and other east European countries which were affected by the unexpected onset of war in Ukraine and which offset generally good stock selection elsewhere.

The Company had a strong year in the UAE. Real estate developer, Emaar Properties (+45%), was the top performer as property transaction values hit a nine-year high in September 2022 due to rising demand. The company has been able to sell down historic inventories and generate significant cash flows as the market has boomed. As we have noted before, this is a reflection of a longer-term rebranding of Dubai and the UAE as an expatriate hub, be it for finance professionals or for crypto enthusiasts. Fertiglobe (+117%), the UAE’s biggest nitrogen fertilizer and ammonia producer and distributor, has been an outstanding performer since its IPO in October 2021. UAE airline , Air Arabia (+62%), was another stand-out performer as the country was one of the first to fully reopen its borders post COVID-19.

Elsewhere, Greek utility Terna Energy (+26%) benefited as the transition to renewable energy continued. Qatar Gas Transport Company (+37%) was another strong performer, as the tight energy environment meant that the company was able to raise rental pricing for its fleet. Saudi Arabian banks had a very strong year, and the Company benefited from positions including Riyad Bank (+20%) and Saudi British Bank (+20%). These banks have seen substantial increases in earnings due to strong loan growth and rising margins. Saudi grocery store operator Abdullah Al Othaim Markets (+12%) also did well as the Saudi domestic landscape evolves from mom-and-pop stores to a more premium supermarket ecosystem.

Indonesian clothing retailer, Mitra Adiperkasa (+27%) benefited from a strong recovery as the economy reopened post COVID-19 and the company has continued to take market share. Auto retailer, Astra International (+16%) benefited from the same trends, showing strong recovery through the year. September 2022 retail unit sales volumes were up 31% year-on-year and the company has also achieved an increase in market share from 51% to 56%.

While we have no direct exposure to Russia in the Trust, we did see a significant impact to our portfolio in the aftermath of the Ukraine invasion. Our positioning in Eastern Europe saw some outsized losses. Hungarian bank OTP (-67%) hurt returns, falling as 15% of its business was in Russia and Ukraine. Eastern Europe has seen significant pressure on inflation as gas prices have risen and inflation in Hungary hit 20% in September. Given the actions that we have seen from the government and central bank in looking to rein in spending and liquidity over the past few months, we believe there is value here. Polish clothing retailer LPP (-47%) also suffered, given Russia represented around 30% of revenues and had been expected to represent approximately half of the expansion plan for 2022. We also had some exposure to Ukraine via iron ore producer Ferrexpo (-70%). Interestingly the company has been able to continue exporting product albeit at a lower rate through the year. Hungarian budget airline, Wizz Air Holdings (-68%), was among the worst performers as the stock was impacted by recessionary fears and rising fuel costs with OPEC+ recently agreeing to cut production from August 2022 levels by two million barrels, representing around 2% of global oil supply.

INVESTMENT ACTIVITY

We have continued increasing our exposure to Southeast Asia on expectations of a pickup in economic activity as border controls are relaxed and mobility improves. Within the region, Indonesia is one of our most preferred countries over the medium to long term, with steady GDP growth expectations of 5+% over the next decade, and structural market reform which should boost potential GDP. Tactically, it has benefited from the huge boom in coal and palm oil prices over the past year and continues to report an impressive current account surplus. We have exposure via a range of stocks – auto-conglomerate Astra International, retailer Mitra Adiperkasa, and cement producer Indocement Tunggal Prakarsa.

However, Thailand is one part of the region where we find ourselves more bearish – we exited convenience store chain CP ALL, oil and gas giants PTT Global Chemical and Thai Oil, and Kasikornbank, concerned about the macro environment as noted above.

In the Middle East we initiated an investment in Qatar Gas Transport Company, which we think will benefit from expansion of Qatar’s north fields in a bid to increase domestic gas production. We also bought Qatar National Bank early in the year, expecting a re-acceleration of loan growth. The stock has been a relative laggard in Qatar and compared to other financials in the region. In Saudi Arabia, we added to domestics, such as grocery operator Abdullah Al Othaim Markets and participated in the IPO of pharmacy chain Al Nahdi Medical.

We have moved some capital into Latin America, namely Colombia and Chile. We initiated a position in Colombian oil exporter Ecopetrol where free cash flow yields look quite attractive under a higher-for-longer oil price regime. In Chile, we bought Banco Santander Chile on a macro view that interest rates are likely near peak. We also have a sizeable position in regional carrier Copa Airlines which continues to benefit from the tourism rebound.

In Eastern Europe, despite the macro challenges, we have added where we see compelling risk/reward. Greece started the year as our top pick given the tourist revival we saw over summer 2022. We have trimmed exposure somewhat through the year given strong performance of Terna Energy and National Bank of Greece. Positions have been rotated into Poland and Hungary. With the Polish stock market currently trading at the lowest level since 2003, we believe that a lot is discounted in the price.

OUTLOOK

We believe that frontier and smaller emerging markets are very well-positioned as global inflation starts to peak out. We have started seeing early lead indicators of this with circa 30%+ decreases in memory chip (DRAM) pricing and shipping freight rates. That said, many countries in the developed world have seen more than two years of excess money creation which is only just starting to drain from the system. That adjustment period still has some ways to go. In contrast, countries in our investment universe have shown commendable fiscal and monetary discipline which creates relative opportunity.

Broadly speaking, our portfolio is positioned in three key areas:

1) Post-pandemic reopening

2) Energy price beneficiaries

3) Macro recovery opportunities

Through a country lens, we continue to like the Middle East, Indonesia, Malaysia, Kazakhstan and Chile. We also see stock specific opportunities in parts of Eastern Europe. Overall, we find significant value in currencies and equity markets across our investment universe. We are optimistic over the long-term in the under-researched frontier markets, which should allow for compelling alpha opportunities.

SAM VECHT and EMILY FLETCHER

BlackRock Investment Management (UK) Limited

7 December 2022

TEN LARGEST INVESTMENTS1 AS AT 30 SEPTEMBER 2022

1 + Emaar Properties (2021: 7th)

Real Estate (United Arab Emirates)

Portfolio value: $14,158,000

Percentage of net assets: 4.7% (2021: 3.1%)

Emaar Properties is a real estate development company located in the United Arab Emirates. It operates internationally providing both development and property management services. It is diversified across several property types, including commercial and residential, as well as malls and hospitality.

2 - Saudi National Bank2 (2021: 1st)

Financials (Saudi Arabia)

Portfolio value: $14,017,000

Percentage of net assets: 4.6% (2021: 4.8%)

Saudi National Bank is the largest financial institution in Saudi Arabia, created following the merger of National Commercial Bank and Samba Financial Group in April 2021. It provides a range of financial services from personal banking, corporate banking to brokerage and investment banking in Saudi Arabia. It also has an international presence in the Middle East, South Asia and Turkey.

3 - Bank Rakyat (2021: 2nd)

Financials (Indonesia)

Portfolio value: $13,856,000

Percentage of net assets: 4.6% (2021: 3.8%)

Bank Rakyat is one of the largest banks in Indonesia. It specialises in small scale and microfinance style borrowing from and lending to its approximately 30 million retail clients through over 4,000 branches, units and rural service posts.

4 + JSC Kaspi (2021: 5th)

Financials (Kazakhstan)

Portfolio value: $10,335,000

Percentage of net assets: 3.4% (2021: 3.4%)

JSC Kaspi is the largest payments, marketplace and fintech ecosystem in Kazakhstan. The company has seen strong growth particularly in its marketplace and payments business. The company began as a bank but expanded into peer-to-peer payments and online marketplaces, particularly proving vital for businesses during the lockdowns of 2020. The company is working on expanding into other markets in Central Asia.

5 + Abdullah Al Othaim Markets2 (2021: n/a)

Consumer Staples (Saudi Arabia)

Portfolio value: $9,783,000

Percentage of net assets: 3.2% (2021: nil%)

Abdullah Al Othaim Markets is a large retailer in Saudi Arabia, operating supermarkets, hypermarkets, convenience stores, and wholesale outlets. They also have a small presence in Egypt. The company is looking to disrupt the current landscape which is largely dominated by mom-and-pop stores.

6 + Qatar Gas Transport Company (2021: n/a)

Energy (Qatar)

Portfolio value: $9,367,000

Percentage of net assets: 3.1% (2021: nil%)

Qatar Gas Transport Company, also known as Nakilat, is a shipping and maritime company based in Qatar, holding the world’s largest liquefied natural gas (LNG) shipping fleet comprised of 69 LNG carriers. In addition to its core shipping activities, Nakilat also provides ship repair and offshore fabrication services.

7 + PKO Bank Polski (2021: n/a)

Financials (Poland)

Portfolio value: $9,254,000

Percentage of net assets: 3.1% (2021: nil%)

PKO Bank Polski is Poland’s largest bank founded in 1919. It is primarily focused on retail banking, operating over 1,100 branches in Poland and abroad.

8 + Saudi Telecom2 (2021: n/a)

Communication Services (Saudi Arabia)

Portfolio value: $9,209,000

Percentage of net assets: 3.0% (2021: nil%)

Saudi Telecom is a telecommunications operator in Saudi Arabia, offering landline and fixed infrastructure, mobile and data services, broadband and cloud computing.

9 + Genting (2021: 18th)

Consumer Discretionary (Malaysia)

Portfolio value: $8,919,000

Percentage of net assets: 2.9% (2021: 2.2%)

Genting is a multinational resort and hotel operator with integrated resorts and entertainment facilities in Malaysia but also abroad, including the UK, the US and the Bahamas.

10 - Saudi British Bank2 (2021: 6th)

Financials (Saudi Arabia)

Portfolio value: $7,945,000

Percentage of portfolio: 2.6% (2021: 3.2%)

Saudi British Bank is an associate of HSBC Group and the leading international bank in Saudi Arabia. The company has been an active partner in supporting Saudi Arabia’s economic growth and social development by offering an array of corporate, institutional, retail banking and wealth management services since 1978.

1 Gross market exposure as a % of net assets.

2 Exposure gained via contracts for difference only.

The Company’s ten largest investments represented 35.2% of the Company’s portfolio as at 30 September 2022 (30 September 2021: 34.1%).

Percentages in brackets represent the portfolio holding as at 30 September 2021.

Symbols indicate the change in the relative ranking of the position in the portfolio compared to its ranking as at 30 September 2021.

PORTFOLIO ANALYSIS AS AT 30 SEPTEMBER 2022

COUNTRY ALLOCATION: ABSOLUTE WEIGHTS (GROSS MARKET EXPOSURE AS A % OF NET ASSETS)1

COUNTRY ALLOCATION RELATIVE TO THE BENCHMARK INDEX (%)1

SECTOR ALLOCATION: ABSOLUTE WEIGHTS (GROSS MARKET EXPOSURE AS A % OF NET ASSETS)1

SECTOR ALLOCATION RELATIVE TO THE BENCHMARK INDEX (%)1

1 Includes exposure gained through equity positions and long and short CFD positions.

Sources: BlackRock and Datastream.

INVESTMENTS AS AT 30 SEPTEMBER 2022

EQUITY PORTFOLIO

CFD portfolio

FAIR VALUE AND GROSS MARKET EXPOSURE OF INVESTMENTS AS AT 30 SEPTEMBER 2022

The Company was geared through the use of long and short CFD positions and gross and net gearing as at 30 September 2022 was 11.3% and 1.0% respectively (30 September 2021: 8.5% and 7.6%). Gross and net gearing are Alternative Performance Measures, see Glossary in the Company’s Annual Report for the year ended 30 September 2022.

1 Fair value is determined as follows:

– Listed investments are valued at bid prices where available, otherwise at latest market traded quoted prices.

– The sum of the fair value column for the CFD contracts totalling US$(3,858,000) represents the net fair valuation of all the CFD contracts, which is determined based on the difference between the notional transaction price and market value of the underlying shares in the contract (in effect the unrealised gains/(losses) on the exposed long and short CFD positions). The cost of purchasing the securities held through long CFD positions directly in the market would have amounted to US$99,046,000 at the time of purchase, and subsequent movement in market prices have resulted in unrealised losses on the long CFD positions of US$4,267,000 resulting in the value of the total long CFD market exposure to the underlying securities decreasing to US$94,779,000 as at 30 September 2022. If the long positions had been closed on 30 September 2022 this would have resulted in a loss of US$4,267,000 for the Company. The notional price of selling the securities to which exposure was gained via the short CFD positions would have been US$16,033,000 at the time of entering into the contract, and subsequent movement in market prices have resulted in unrealised gains on the short CFD positions of US$409,000 resulting in the value of the total short CFD market exposure of these investments decreasing to US$15,624,000 at 30 September 2022. If the short positions had been closed on 30 September 2022 this would have resulted in a gain of US$409,000 for the Company.

2 The gross market exposure column for cash and cash equivalents has been adjusted to assume the Company purchased/sold direct holdings rather than exposure being gained through long and short CFDs and forward currency positions.

3 Market exposure in the case of equity investments is the same as fair value. In the case of long and short CFDs it is the market value of the underlying shares to which the portfolio is exposed via the contract. Market exposure in the case of forward currency positions is the value of the receivable portion of the forward currency contracts.

STRATEGIC REPORT

The Directors present the Strategic Report of the Company for the year ended 30 September 2022.

PRINCIPAL ACTIVITY

The Company carries on business as an investment trust and its principal activity is portfolio investment.

INVESTMENT OBJECTIVE

The Company’s investment objective is to achieve long-term capital growth by investing in companies domiciled or listed in or exercising the predominant part of their economic activity in, less developed countries. These countries (the “Frontiers Universe”) are any country which is neither part of the MSCI World Index of developed markets, nor one of the eight largest countries by market capitalisation in the MSCI Emerging Markets Index: being Brazil, China, India, South Korea, Mexico, Russia, South Africa and Taiwan (the “Selected Countries”).

STRATEGY, BUSINESS MODEL AND INVESTMENT POLICY

Strategy

To achieve its objective, the Company invests globally in the securities of companies domiciled or listed in or exercising the predominant part of their economic activity in, the Frontiers Universe.

BUSINESS MODEL

The Company’s business model follows that of an externally managed investment trust; therefore the Company does not have any employees and outsources its activities to third-party service providers, including BlackRock Fund Managers Ltd (BlackRock or BFM) (‘the Manager’) which is the principal service provider.

The management of the investment portfolio and the administration of the Company have been contractually delegated to the Manager. The Manager has delegated certain investment management and other ancillary services to BlackRock Investment Management (UK) Limited (BIM (UK)) (‘the Investment Manager’). The contractual arrangements with, and assessment of, the Manager are summarised in the Company’s Annual Report for the year ended 30 September 2022. The Investment Manager, operating under guidelines determined by the Board, has direct responsibility for the decisions relating to the day-to-day running of the Company and is accountable to the Board for the investment, financial and operating performance of the Company. Other service providers include the Depositary and the Fund Accountant, The Bank of New York Mellon (International) Limited (BNYM), and the Registrar, Computershare Investor Services PLC (Computershare). Details of the contractual terms with third-party service providers are set out in the Directors’ Report in the Company's Annual Report for the year ended 30 September 2022.

INVESTMENT POLICY

The Company will seek to maximise total return and will invest globally in the securities of companies domiciled or listed in or exercising the predominant part of their economic activity in, the Frontiers Universe. Performance is measured against the Company’s Benchmark Index, which is a composite of the MSCI Emerging Markets Index ex Selected Countries + MSCI Frontier Markets Index + MSCI Saudi Arabia Index (net total return, USD). The Investment Manager is not constrained by the geographical weightings of the Benchmark Index and the Company’s portfolio may frequently be overweight or underweight any particular country relative to the Benchmark Index. The Company will exit any investment as soon as reasonably practicable following the relevant company ceasing to be domiciled or listed in or exercising the predominant part of its economic activity in, the Frontiers Universe.

In order to achieve the Company’s investment objective, the Investment Manager selects investments through a process of fundamental and geopolitical analysis, seeking long-term appreciation from mispriced value or growth. The Investment Manager employs both a top-down and bottom-up approach to investing. It is expected that the Company will have exposure to between 35 to 65 holdings.

Where possible, investment will generally be made directly in the stock markets of the Frontiers Universe. Where the Investment Manager determines it appropriate, investment may be made through collective investment schemes, although such investments are not likely to be significant. Investment in other closed-ended investment funds admitted to the Official List will not exceed more than 10%, in aggregate, of the value of the Gross Assets (calculated at the time of any relevant investment). It is intended that the Company will generally be invested in equity investments; however, the Investment Manager may invest in equity-related investments, such as derivatives or convertibles, and, to a lesser extent, in bonds or other fixed-income securities, including high risk debt securities. These securities may be below investment grade.

Due to national and/or international regulation, excessive operational risk, prohibitive costs and/or the time period involved in establishing trading and custody accounts in certain countries in the Frontiers Universe, the Company may be unable to invest (whether directly or through nominees) in companies in certain countries in the Frontiers Universe or, in the opinion of the Company and/or the Investment Manager, it may not be advisable to do so. In such circumstances, or in countries where acceptable custodial and other arrangements are not in place to safeguard the Company’s investments, the Company intends to gain economic exposure to companies in such countries by investing indirectly through derivatives. Derivatives are financial instruments linked to the performance of another asset or security, such as promissory notes, contracts for difference, futures or traded options. Save as provided below, there is no restriction on the Company investing in derivatives in such circumstances or for efficient portfolio management purposes.

The Company may be geared through borrowings and/or by entering into derivative transactions (taking both long and short positions) that have the effect of gearing the Company’s portfolio to enhance performance. The Company may also use borrowings for the settlement of transactions, to facilitate share repurchases (where applicable) and to meet on-going expenses.

The respective limits on gearing (whether through the use of derivatives, borrowings or a combination of both) are set out below:

· Maximum gearing through the use of derivatives or borrowings to gain exposure to long positions in securities: 140% of net assets

· Maximum exposure to short positions (for shorting purposes the Company may use indices or individual stocks): 10% of net assets

· Maximum gross exposure (total long exposure plus total short exposure): 150% of net assets

· Maximum net exposure (total long exposure minus total short exposure): 130% of net assets

In normal circumstances, the Company will typically have net exposure of between 95% and 120% of net assets.

When investing via derivatives, the Company will seek to mitigate and/or spread its counterparty risk exposure by collateralisation and/or contracting with a potential range of counterparty banks, as appropriate, each of which shall, at the time of entering into such derivatives, have a Standard & Poor’s credit rating of at least A- on its long-term senior unsecured debt.

The Company may invest up to 5% of its Gross Assets (at the time of such investment) in unquoted securities. The Company will invest so as not to hold more than 15% of its Gross Assets in any one stock or derivative position at the time of investment (excluding cash management activities).

No material change will be made to the investment policy without the approval of shareholders by ordinary resolution.

A detailed analysis of the Company’s portfolio has been provided in the Company’s Annual Report for the year ended 30 September 2022.

INVESTMENT APPROACH AND PROCESS

Portfolio construction is a continuous process, with the Investment Manager analysing constantly the impact of new ideas and information on the portfolio as a whole. The approach is flexible, varying through market and economic cycles to create a portfolio appropriate to the focused and unconstrained strategy of the Company. The macro environment is factored into all portfolio decisions. In general, macro analysis is a more dominant factor in investment decision making when the outlook is negative. The macro process is comprised of three parts: political assessment, macroeconomic analysis and appraisal of the valuation of a country’s market, which can only take place with thorough analysis of stock specific opportunities.

The Investment Manager’s research team generates ideas from a diverse range of sources. When permitted, these include frequent travel to the markets in which the Company invests and regular conversations with contacts that allow the Frontiers team to assess the entire eco system around a company, namely competitors, suppliers, financiers, customers and regulators. The team leverages the internal research network sharing information between BlackRock’s investment teams using a proprietary research application and database and develops insights from macroeconomic analysis. The Board believes that BlackRock’s research platform is a significant competitive advantage, both in terms of information specific to emerging and frontier market equities and through its global insights across asset classes. Access to companies is extremely good given BlackRock’s market presence, which makes it possible to develop a detailed knowledge of a company and its management.

The research process focuses on cash flow and future earnings growth, as the investment team believes that this is ultimately the driver of share prices over time. The process is designed with the aim of identifying companies that can translate top line revenue growth to free cash flow and investing in these companies when the analysis suggests that the cash flow stream is undervalued. Financial models are developed focusing on company financials, particularly cash flow statements, rather than relying on third party research.

ESG INTEGRATION

The Manager defines Environmental, Social and Governance (ESG) integration as the practice of incorporating material ESG information and consideration of sustainability risks into investment decisions in order to enhance risk-adjusted returns. Inclusion of this statement does not imply that the Company has an ESG-aligned investment objective or constrain the Investment Manager’s investable universe and does not mean that an ESG or impact focused investment strategy or any exclusionary screens have been or will be adopted by the Company, but rather describes how ESG information is considered as part of the overall investment process.

In making investment decisions, the Manager assesses a variety of economic and financial indicators which include ESG considerations in combination with other information in the research phase of the investment process to make investment decisions appropriate to their client’s objectives. This may also include relevant third party insight, as well as internal engagement commentary and input from BlackRock Investment Stewardship (BIS) on governance issues. The portfolio managers conduct regular portfolio reviews with the BlackRock Risk and Quantitative Analysis (RQA) team. These reviews include discussion of the portfolio’s exposure to material ESG risks, as well as exposure to sustainability related business involvements, climate related metrics, traditional financial risks and other factors.

The portfolio managers’ approach to ESG integration is to broaden the total amount of information its investment professionals consider in order to improve investment analysis, seeking to meet or exceed economic return and financial risk targets. ESG factors can be useful and relevant indicators for investment purposes and can help portfolio managers with their decision making through identifying potentially negative events or corporate behaviour. The Portfolio Manager works closely with BIS to assess the governance quality of companies and investigate any potential issues, risks or opportunities.

The Manager’s research team monitors differing levels of risk throughout the process and believes that avoiding major downside events can generate significant outperformance over the long term. Inputs from the RQA team are an integral part of the investment process. The RQA team analyse market and portfolio risk factors including stress tests, correlations, factor returns, cross sectional volatility and attributions. The Manager’s evaluation procedures and financial analysis of the companies within the portfolio also take into account environmental, social and governance matters and other business issues.

The Company does not meet the criteria for Article 8 or 9 products under the EU Sustainable Finance Disclosure Regulation (“SFDR”) and the investments underlying this financial product do not take into account the EU criteria for environmentally sustainable economic activities.

Further information on the Manager’s approach to ESG and Socially Responsible Investing can be found in the Strategic Report in the Company’s Annual Report for the year ended 30 September 2022.

PERFORMANCE

Details of the Company’s performance for the year are given in the Chairman’s Statement above. The Investment Manager’s Report includes a review of the main developments during the period, together with information on investment activity within the Company’s portfolio.

RESULTS AND DIVIDENDS

The results for the Company are set out in the Statement of Comprehensive Income. The total loss for the year, after taxation, was US$36,869,000 (2021: profit of US$149,472,000) of which the revenue return amounted to US$12,013,000 (2021: US$14,904,000) and the capital loss amounted to US$48,882,000 (2021: profit of US$134,568,000).

The Directors are recommending the payment of a final dividend of 4.25 cents per ordinary share in respect of the year ended 30 September 2022 (2021: final dividend of 4.25 cents) as set out in the Chairman’s Statement.

KEY PERFORMANCE INDICATORS

The Directors consider a number of performance measures to assess the Company’s success in achieving its objectives. The key performance indicators (KPIs) used to measure the progress and performance of the Company over time and which are comparable to those reported by other investment trusts are set out below.

PERFORMANCE MEASURED AGAINST THE BENCHMARK INDEX

At each meeting the Board reviews the performance of the portfolio as well as the net asset value and share price for the Company and compares this to the return of the Company’s benchmark. The Board considers this to be an important key performance indicator and has determined that it should also be used to calculate whether a performance fee is payable to BlackRock. The Company’s absolute and relative performance is set out in the performance record table in the Company’s Annual Report for the year ended 30 September 2022.

SHARE RATING AND DISCOUNT

The Directors recognise the importance to investors that the Company’s share price should not trade at a significant discount or premium to NAV. Accordingly, the Directors monitor the share rating closely and will consider share repurchases in the market if the discount widens significantly, or the issue of shares to the market to meet demand to the extent that the Company’s shares are trading at a premium. In addition, in accordance with the Directors’ commitment at launch the Company will formulate and submit to shareholders proposals to provide them with an opportunity at each five year anniversary since launch, to realise the value of their ordinary shares at the prevailing NAV per share less applicable costs. Such an opportunity took place in the year ended 30 September 2021. The next opportunity will take place on or around the date of the Company’s AGM in February 2026.

For the year under review the Company’s shares traded at an average discount to the cum-income NAV of 9.2% and were trading at a discount of 10.4% on a cum-income basis at 5 December 2022. The Directors have the authority to buy back up to 14.99% of the Company’s issued share capital (excluding treasury shares). The Directors sought and received shareholder authority at the last AGM to issue up to 10% of the Company’s issued share capital (via the issue of new shares or sale of shares from treasury) on a non pre-emptive basis. Further information can be found in the Directors’ Report in the Company's Annual Report for the year ended 30 September 2022.

ONGOING CHARGES

The ongoing charges reflect those expenses which are likely to recur in the foreseeable future, whether charged to capital or revenue, and which relate to the operation of the investment company as a collective investment fund, excluding the costs of acquisition or disposal of investments, financing charges and gains or losses arising on investments and performance fees. The ongoing charges are based on actual costs incurred in the year as being the best estimate of future costs. The Board reviews the ongoing charges and monitors the expenses incurred by the Company.

KEY PERFORMANCE INDICATORS (SEE GLOSSARY IN THE COMPANY’S ANNUAL REPORT FOR THE YEAR ENDED 30 SEPTEMBER 2022)

The table below sets out the key KPIs for the Company.

1 Based on an exchange rate of US$1.1163 to £1 at 30 September 2022 and US$1.3484 to £1 at 30 September 2021.

2 Calculated with dividends reinvested.

3 Calculated on a mid to mid basis with dividends reinvested.

4 The Benchmark Index is a composite of the MSCI Emerging Markets Index ex Selected Countries + MSCI Frontier Markets Index + MSCI Saudi Arabia Index. Benchmark Index return calculates the reinvestment of dividends net of withholding taxes.

5 Ongoing charges represent the management fee and all other operating expenses, excluding performance fees, finance costs, direct transaction costs, custody transaction charges, VAT recovered, taxation, write back of prior year expenses and certain non-recurring items, as a % of average daily net assets.

The Board regularly reviews a number of indices and ratios to understand the impact on the Company’s relative performance of the various components such as asset allocation and stock selection. The Board also reviews the performance of the Company against a peer group of frontier market open and closed-ended funds.

PRINCIPAL RISKS

As required by the 2018 UK Code of Corporate Governance, the Board has in place a robust, ongoing process to identify, assess and monitor the principal and emerging risks of the Company, including those that they consider would threaten its business model, future performance, solvency or liquidity. Emerging risks are considered by the Board as they come into view and are incorporated into the Company’s risk register where applicable. Additionally, the Manager considers emerging risks in numerous forums and the Risk and Quantitative Analysis team produces an annual risk survey. Any material risks of relevance to the Company identified through the annual risk survey will be communicated to the Board.

A core element of this is the Company’s risk register, which identifies the risks facing the Company and assesses the likelihood and potential impact of each risk, and the quality of the controls operating to mitigate the risk. A residual risk rating is then calculated for each risk based on the outcome of this assessment. This approach allows the effect of any mitigating procedures to be reflected in the final assessment.

The risk register, its method of preparation and the operation of the key controls in BlackRock’s and other third-party service providers’ systems of internal control are reviewed on a regular basis by the Company’s Audit and Management Engagement Committee. In order to gain a more comprehensive understanding of BlackRock’s and other third party service providers’ risk management processes and how these apply to the Company’s business, the Audit and Management Engagement Committee periodically receives presentations from BlackRock’s Internal Audit and Risk & Quantitative Analysis teams, and reviews Service Organisation Control (SOC 1) reports from BlackRock and the Company’s Custodian and Fund Accountant, The Bank of New York Mellon (International) Limited (BNYM).

The current risk register includes a range of risks spread between performance risk, income/dividend risk, legal and regulatory risk, counterparty risk, operational risk, market risk, political risk and financial risk.

The principal risks and uncertainties faced by the Company during the year, together with the potential effects, controls and mitigating factors, are set out below.

VIABILITY STATEMENT

In accordance with the provisions of the UK Corporate Governance Code, the Directors have assessed the prospects of the Company over a longer period than the twelve months referred to by the ‘Going Concern’ guidelines. The Board is cognisant of the uncertainty surrounding the potential duration of the Russia-Ukraine conflict, its impact on the global economy, and the prospects for many of the Company’s portfolio holdings. Notwithstanding this crisis, and given the factors stated below, the Board expects the Company to continue to meet its liabilities as they fall due for the foreseeable future and has therefore conducted this review for a period of five years. This is generally the investment holding period investors consider while investing in the frontier market universe. The Board conducted this review for the period up to the AGM in 2028.

In determining this period, the Board took into account the Company’s investment objective to achieve long-term capital growth and the Company’s projected income and expenditure. The Directors believe that five years is an appropriate investment horizon to assess the viability of the Company. It is satisfied that the Company has adequate resources to continue in operational existence for the foreseeable future and is financially sound.

When the Company was launched in late 2010, the Board made a commitment that before the Company’s fifth AGM and at five yearly intervals thereafter, it would formulate and submit to shareholders proposals to provide shareholders with an opportunity to realise the value of their ordinary shares at the applicable NAV per ordinary share less applicable costs. The Board put proposals to shareholders last year. The Company received elections to tender representing 21.5% of the Company, with the vast majority of shareholders choosing to retain their investment. The Board believes this is indicative of the ongoing attractiveness of the Company’s investment strategy and offering.

In making the longer-term viability assessment the Board has considered the following factors:

the Company’s principal risks as set out in the Company’s Annual Report for the year ended 30 September 2022;

the level of ongoing demand for the Company’s ordinary shares;

the impact of a significant fall in Frontier equity markets on the value of the Company’s investment portfolio;

the ongoing relevance of the Company’s investment objective, business model and investment policy in the current environment;

the operational resilience of the Company and its key service providers and their ability to continue to provide a good level of service for the foreseeable future; and

the effectiveness of business continuity plans in place for the Company and key service providers.

The Board has also considered a number of financial metrics, including:

the level of current and historic ongoing charges incurred by the Company;

the Company’s borrowings and its ability to meet its liabilities as they fall due;

the premium or discount to NAV;

the level of income generated by the Company;

future income forecasts; and

the liquidity of the Company’s portfolio.

The Company is an investment company with a relatively liquid equity portfolio (as at 30 September 2022, 81.5% of the equity portfolio was capable of being realised in less than 20 days in normal market conditions) and largely fixed overheads (excluding performance fees) which comprise a very small percentage of net assets (1.36%). In addition, any performance fees are capped at 1% of gross assets in years where the NAV per share has fallen or 2.5% of gross assets in years where the NAV per share has increased. Therefore, the Board has concluded that even in exceptionally stressed operating conditions, the Company would comfortably be able to meet its ongoing operating costs as they fall due.

However, investment companies may face other challenges, such as regulatory changes and the tax treatment of investment trusts, or a significant decrease in size due to substantial share buy-back activity or market falls, which may result in the Company no longer being of sufficient market capitalisation to represent viable investment propositions or no longer being able to continue in operation.

The Board has determined that the factors considered are applicable to the period up to the AGM in 2028 and beyond.

In addition, the Board’s assessment of the Company’s ability to operate in the foreseeable future is included in the Going Concern Statement which can be found in the Directors’ Report in the Company's Annual Report for the year ended 30 September 2022.

Based on the results of their analysis, the Directors have a reasonable expectation that the Company will be able to continue in operation and meet its liabilities as they fall due over the period of their assessment.

SECTION 172 STATEMENT: PROMOTING THE SUCCESS OF THE BLACKROCK FRONTIERS INVESTMENT TRUST PLC

The Companies (Miscellaneous Reporting) Regulations 2018 require directors to explain more fully how they have discharged their duties under Section 172(1) of the Companies Act 2006 in promoting the success of their companies for the benefit of members as a whole. This enhanced disclosure covers how the Board has engaged with and understands the views of stakeholders and how stakeholders’ needs have been taken into account, the outcome of this engagement and the impact that it has had on the Board’s decisions.

As the Company is an externally managed investment company and does not have any employees or customers, the Board considers the main stakeholders in the Company to be the shareholders, key service providers (being the Manager and Investment Manager, the Custodian, Depositary, Registrar and Broker) and investee companies.

A summary of the principal areas of engagement undertaken by the Board with its key stakeholders in the year under review and how Directors have acted upon this to promote the long-term success of the Company is set out in the tables below.

STAKEHOLDERS

AREA OF ENGAGEMENT

THE BOARD’S APPROACH TO ESG CONSIDERATIONS

Environmental, social and governance (ESG) issues can present both opportunities and threats to long-term investment performance. The securities within the Company’s investment remit may involve significant additional risk due to the political volatility and ESG concerns facing many of the countries in the Company’s investment universe. While the Company does not have an ESG investment objective or exclude investments based only on ESG criteria, these ethical and sustainability issues are a consideration of the Board, and your Board is committed to a diligent oversight of the activities of the Manager in these areas. The Board believes effective engagement with management is, in most cases, the most effective way of driving meaningful positive change in the behaviour of investee company management. This is particularly true for the Company’s Manager given the extent of BlackRock’s shareholder engagement and BlackRock’s capacity to vote against management when they fall short of its expectations. As well as the influence afforded by its sheer scale, the Board believes that BlackRock is well placed as Manager to fulfil these requirements due to the integration of ESG into its investment processes, the emphasis it places on sustainability, its collaborative approach in its investment stewardship activities and its position in the industry as one of the largest suppliers of sustainable investment products in the global market. More information on BlackRock’s approach to sustainable investing is set out above.

FUTURE PROSPECTS

The Board’s main focus is on the achievement of capital growth and the future of the Company is dependent upon the success of the investment strategy. The outlook for the Company is discussed in both the Chairman’s Statement and in the Investment Manager’s Report.

SOCIAL, COMMUNITY AND HUMAN RIGHTS ISSUES

As an investment trust, the Company has no direct social or community responsibilities. However, the Company believes that it is in shareholders’ interests to consider environmental, social and governance factors and human rights issues when selecting and retaining investments. Details of the Company’s policy on socially responsible investment are set out in the Company's Annual Report for the year ended 30 September 2022 and the Manager’s approach is described in the Company’s Annual Report for the year ended 30 September 2022.

MODERN SLAVERY

As an investment vehicle the Company does not provide goods or services in the normal course of business and does not have customers. Accordingly, the Directors consider that the Company is not required to make any slavery or human trafficking statement under the Modern Slavery Act 2015. In any event, the Board considers the Company’s supply chain, dealing predominantly with professional advisers and service providers in the financial services industry, to be low risk in relation to this matter.

DIRECTORS, GENDER REPRESENTATION AND EMPLOYEES

The Directors of the Company on 30 September 2022 are set out in the Directors’ biographies section in the Company’s Annual Report for the year ended 30 September 2022. As at 7 December 2022, the Board consisted of three men and three women constituting 50% female Board representation. The Company does not have any employees.

By order of the Board

KEVIN MAYGER

For and on behalf of BlackRock Investment Management (UK) Limited

Company Secretary

7 December 2022

RELATED PARTY TRANSACTIONS

BlackRock Fund Managers Limited (BFM) provides management and administration services to the Company under a contract which is terminable on six months’ notice. BFM has (with the Company’s consent) delegated certain portfolio and risk management services, and other ancillary services, to BlackRock Investment Management (UK) Limited (BIM (UK)). Further details of the investment management contract are disclosed in the Directors’ Report in the Company’s Annual Report for the year ended 30 September 2022.

The investment management fee due for the year ended 30 September 2022 amounted to US$3,785,000 (2021: US$3,884,000). No performance fee is payable for the year (2021: US$3,815,000). At the year end, US$882,000 was outstanding in respect of management fees (2021: US$1,867,000) and US$nil (2021: US$3,815,000) was outstanding in respect of performance fees.

In addition to the above services, BIM (UK) has provided the Company with marketing services. The total fees paid or payable for these services for the year ended 30 September 2022 amounted to US$76,000 excluding VAT (2021: US$101,000). Marketing fees of US$53,000 excluding VAT (2021: US$64,000) were outstanding at the year end.

The Company has an investment in the BlackRock Institutional Cash Series plc – US Dollar Liquid Environmentally Aware Fund of US$71,415,000 (2021: US$96,269,000) at the year end, which is a fund managed by a company within the BlackRock Group.

Disclosures of the Directors’ interests in the ordinary shares of the Company and fees and expenses payable to the Directors are set out in the Directors’ Remuneration Report in the Company’s Annual Report for the year ended 30 September 2022. At 30 September 2022, US$17,000 (£15,000) (2021: US$15,000 (£11,000)) was outstanding in respect of Directors’ fees.

STATEMENT OF DIRECTORS’ RESPONSIBILITIES IN RESPECT OF THE ANNUAL REPORT AND FINANCIAL STATEMENTS

The Directors are responsible for preparing the Annual Report, the Directors’ Remuneration Report and the financial statements in accordance with applicable United Kingdom law and regulations.

Company law requires the Directors to prepare financial statements for each financial year. Under that law, the Directors are required to prepare the financial statements under international accounting standards in conformity with UK-adopted international accounting standards (“IASs”). Under Company law the Directors must not approve the financial statements unless they are satisfied that they give a true and fair view of the state of affairs of the Company and of the profit or loss of the Company for that period.

In preparing these financial statements, the Directors are required to:

present fairly the financial position, financial performance and cash flows of the Company;

select suitable accounting policies in accordance with IAS 8: Accounting Policies, Changes in Accounting Estimates and Errors and then apply them consistently;

present information, including accounting policies, in a manner that provides relevant, reliable, comparable and understandable information;

make judgements and estimates that are reasonable and prudent;

state whether the financial statements have been prepared in accordance with IASs, subject to any material departures disclosed and explained in the financial statements;

provide additional disclosures when compliance with the specific requirements in IASs is insufficient to enable users to understand the impact of particular transactions, other events and conditions on the Company’s financial position and financial performance; and

prepare the financial statements on the going concern basis unless it is inappropriate to presume that the Company will continue in business.

The Directors are responsible for keeping adequate accounting records that are sufficient to show and explain the Company’s transactions and disclose with reasonable accuracy at any time the financial position of the Company and enable them to ensure that the financial statements comply with the Companies Act 2006.

They are also responsible for safeguarding the assets of the Company and hence for taking reasonable steps for the prevention and detection of fraud and other irregularities. The Directors are also responsible for preparing the Strategic Report, the Directors’ Report, the Directors’ Remuneration Report, Corporate Governance Statement and the Report of the Audit and Management Engagement Committee in accordance with the Companies Act 2006 and applicable regulations, including the requirements of the Listing Rules and the Disclosure Guidance and Transparency Rules. The Directors have delegated responsibility to the Investment Manager and the AIFM for the maintenance and integrity of the Company’s corporate and financial information included on BlackRock’s website. Legislation in the United Kingdom governing the preparation and dissemination of financial statements may differ from legislation in other jurisdictions.

Each of the Directors, who were appointed as at the date of the Annual Report, confirms to the best of their knowledge that:

the financial statements, which have been prepared in accordance with IASs, give a true and fair view of the assets, liabilities, financial position and loss of the Company; and

the Strategic Report contained in the Annual Report and Financial Statements includes a fair review of the development and performance of the business and the position of the Company, together with a description of the principal risks and uncertainties that it faces.

The 2018 UK Corporate Governance Code also requires Directors to ensure that the Annual Report and Financial Statements are fair, balanced and understandable. In order to reach a conclusion on this matter, the Board has requested that the Audit and Management Engagement Committee advise on whether it considers that the Annual Report and Financial Statements fulfil these requirements. The process by which the Committee has reached these conclusions is set out in the Audit and Management Engagement Committee’s report. As a result, the Board has concluded that the Annual Report and Financial Statements for the year ended 30 September 2022, taken as a whole, is fair, balanced and understandable and provides the information necessary for shareholders to assess the Company’s position and performance, business model and strategy.

For and on behalf of the Board

AUDLEY TWISTON-DAVIES

Chairman

7 December 2022

STATEMENT OF COMPREHENSIVE INCOME FOR THE YEAR ENDED 30 SEPTEMBER 2022

The total column of this statement represents the Company’s Statement of Comprehensive Income, prepared in accordance with UK-adopted International Accounting Standards (IASs). The supplementary revenue and capital accounts are both prepared under guidance published by the Association of Investment Companies (AIC). All items in the above statement derive from continuing operations. No operations were acquired or discontinued during the year. All income is attributable to the equity holders of the Company.

The Company does not have any other comprehensive income. The net profit/(loss) for the year disclosed above represents the Company’s total comprehensive income/(loss).

STATEMENT OF CHANGES IN EQUITY FOR THE YEAR ENDED 30 SEPTEMBER 2022

1 Final dividend of 4.25 cents per share for the year ended 30 September 2021, declared on 1 December 2021 and paid on 11 February 2022 and interim dividend paid in respect of the year ended 30 September 2022 of 2.75 cents per share, declared on 26 May 2022 and paid on 24 June 2022.

2 Share premium account was cancelled pursuant to Court approval on 11 March 2021 and US$166.0m was transferred to the special reserve. Please refer to note 9.

3 Final dividend of 4.25 cents per share for the year ended 30 September 2020, declared on 11 December 2020 and paid on 12 February 2021 and interim dividend paid in respect of the year ended 30 September 2021 of 2.75 cents per share, declared on 1 June 2021 and paid on 25 June 2021.

For information on the Company’s distributable reserves please refer to note 9.

STATEMENT OF FINANCIAL POSITION AS AT 30 SEPTEMBER 2022

CASH FLOW STATEMENT FOR THE YEAR ENDED 30 SEPTEMBER 2022

1 Cash Fund represents investment in the BlackRock Institutional Cash Series plc - US Dollar Liquid Environmentally Aware Fund.

NOTES TO THE FINANCIAL STATEMENTS FOR THE YEAR ENDED 30 SEPTEMBER 2022

1. PRINCIPAL ACTIVITY

The principal activity of the Company is that of an investment trust company within the meaning of Section 1158 of the Corporation Tax Act 2010. The Company was incorporated on 15 October 2010, and this is the twelfth Annual Report.

2. ACCOUNTING POLICIES

The principal accounting policies adopted by the Company have been applied consistently, other than where new policies have been adopted and are set out below.

(a) Basis of preparation

On 31 December 2020, International Financial Reporting Standards (IAS) as adopted by the European Union at that date was brought into UK law and became UK-adopted International Accounting Standards, with future changes being subject to endorsement by the UK Endorsement Board. The Company transitioned to UK-adopted International Accounting Standards in its financial statements with effect from 1 October 2021. There was no impact or changes in accounting policies from the transition.

The financial statements have been prepared under the historic cost convention modified by the revaluation of certain financial assets and financial liabilities held at fair value through profit or loss and in accordance with UK-adopted International Accounting Standards (IASs). All of the Company’s operations are of a continuing nature.

Insofar as the Statement of Recommended Practice (SORP) for investment trust companies and venture capital trusts, issued by the Association of Investment Companies (AIC) in October 2019 and updated in July 2022, is compatible with UK-adopted International Accounting Standards, the financial statements have been prepared in accordance with the guidance set out in the SORP.

Substantially, all of the assets of the Company consist of securities that are readily realisable and, accordingly, the Directors are satisfied that the Company has adequate resources to continue in operational existence for the foreseeable future, for the period to 30 September 2024, being a period of at least twelve months from the date of approval of the financial statements, and therefore consider the going concern assumption to be appropriate. The Directors have reviewed the income and expense projections and the liquidity of the investment portfolio in making their assessment.

The Directors have considered the impact of climate change on the value of the investments included in the Financial Statements and have concluded that:

· there was no further impact of climate change to be considered as the investments are valued based on market pricing as required by IFRS 13; and

· the risk is adequately captured in the assumptions and inputs used in measurement of Level 3 assets, if any, as noted in note 17 of the Company's Annual Report for the year ended 30 September 2022.

None of the Company’s other assets and liabilities were considered to be potentially impacted by climate change.

The Company’s financial statements are presented in US Dollars, which is the functional currency of the Company and the currency of the primary economic environment in which the Company operates. All values are rounded to the nearest thousand dollars (US$’000) except where otherwise indicated.

Relevant International Accounting Standards that have yet to be adopted:

IFRS 17 – Insurance contracts (effective 1 January 2023). This standard replaces IFRS 4, which currently permits a wide range of accounting practices in accounting for insurance contracts. IFRS 17 will fundamentally change the accounting by all entities that issue insurance contracts and investment contracts with discretionary participation features.

This standard is unlikely to have any impact on the Company as it has no insurance contracts.

IAS 12 – Deferred tax related to assets and liabilities arising from a single transaction (effective 1 January 2023). The International Accounting Standards Board (IASB) has amended IAS 12 Income Taxes to require companies to recognise deferred tax on particular transactions that, on initial recognition, give rise to equal amounts of taxable and deductible temporary differences. According to the amended guidance, a temporary difference that arises on initial recognition of an asset or liability is not subject to the initial recognition exemption if that transaction gave rise to equal amounts of taxable and deductible temporary differences. These amendments might have a significant impact on the preparation of financial statements by companies that have substantial balances of right-of-use assets, lease liabilities, decommissioning, restoration and similar liabilities. The impact for those affected would be the recognition of additional deferred tax assets and liabilities.

The amendment of this standard is unlikely to have any significant impact on the Company.

None of the standards that have been issued but are not yet effective are expected to have a material impact on the Company.

(b) Presentation of the Statement of Comprehensive Income

In order to better reflect the activities of an investment trust company and in accordance with guidance issued by the AIC, supplementary information which analyses the Statement of Comprehensive Income between items of a revenue and a capital nature has been presented alongside the Statement of Comprehensive Income.

(c) Segmental reporting

The Directors are of the opinion that the Company is engaged in a single segment of business being investment business.

(d) Income

Dividends receivable on equity shares are recognised as revenue for the year on an ex-dividend basis. Where no ex-dividend date is available, dividends receivable on or before the year end are treated as revenue for the year. Provision is made for any dividends and interest income not expected to be received. Special dividends, if any, are treated as a capital or a revenue receipt depending on the facts or circumstances of each particular case. The return on a debt security is recognised on a time apportionment basis so as to reflect the effective yield on the debt security. Interest income and deposit interest are accounted for on an accruals basis.

Where the Company has elected to receive its dividends in the form of additional shares rather than in cash, the cash equivalent of the dividend is recognised as income. Any excess in the value of the shares received over the amount of the cash dividend is recognised in capital.

(e) Expenses

All expenses, including finance costs, are accounted for on an accruals basis. Expenses have been charged wholly to the revenue account of the Statement of Comprehensive Income, except as follows:

· expenses which are incidental to the acquisition or sale of an investment are charged to the capital account of the Statement of Comprehensive Income. Details of transaction costs on the purchases and sales of investments are disclosed within note 10 to the financial statements in the Company's Annual Report for the year ended 30 September 2022;

· expenses are treated as capital where a connection with the maintenance or enhancement of the value of the investments can be demonstrated;

· the investment management fee and finance costs have been allocated 80% to the capital account and 20% to the revenue account of the Statement of Comprehensive Income in line with the Board’s expected long term split of returns, in the form of capital gains and income, respectively, from the investment portfolio; and

· performance fees are allocated 100% to the capital account of the Statement of Comprehensive Income as fees are generated in connection with enhancing the value of the investment portfolio.

(f) Taxation

The tax expense represents the sum of the tax currently payable and deferred tax. The tax currently payable is based on the taxable profit for the year. Taxable profit differs from net profit as reported in the Statement of Comprehensive Income because it excludes items of income or expenses that are taxable or deductible in other years and it further excludes items that are never taxable or deductible. The Company’s liability for current tax is calculated using tax rates that were applicable at the balance sheet date.

Where expenses are allocated between capital and revenue accounts, any tax relief in respect of the expenses is allocated between capital and revenue returns on the marginal basis using the Company’s effective rate of corporation tax for the accounting period.

Deferred taxation is recognised in respect of all temporary differences that have originated but not reversed at the financial reporting date, where transactions or events that result in an obligation to pay more taxation in the future or right to pay less taxation in the future have occurred at the financial reporting date. This is subject to deferred taxation assets only being recognised if it is considered more likely than not that there will be suitable profits from which the future reversal of the temporary differences can be deducted. Deferred taxation assets and liabilities are measured at the rates applicable to the legal jurisdictions in which they arise.

(g) Investments held at fair value through profit or loss

In accordance with IFRS 9, the Company classifies its investments at initial recognition as held at fair value through profit or loss and are managed and evaluated on a fair value basis in accordance with its investment strategy and business model.

All investments are measured initially and subsequently at fair value through profit or loss. Purchases of investments are recognised on a trade date basis. Sales of investments are recognised at the trade date of the disposal.

The fair value of the financial investments is based on their quoted bid price at the financial reporting date, without deduction for the estimated future selling costs. This policy applies to all current and non-current asset investments held by the Company. The fair value of the P-Notes are, when held, based on the quoted bid price of the underlying equity to which they relate.

Changes in the value of investments held at fair value through profit or loss and gains and losses on disposal are recognised in the Statement of Comprehensive Income as “Net profit/(loss) on investments held at fair value through profit or loss”. Also included within the heading are transaction costs in relation to the purchase or sale of investments.

For all financial instruments not traded in an active market, the fair value is determined by using various valuation techniques. Valuation techniques include market approach (i.e., using recent arm’s length market transactions adjusted as necessary and reference to the current market value of another instrument that is substantially the same) and the income approach (i.e., discounted cash flow analysis and option pricing models making as much use of available and supportable market data where possible). See note 2(o) below.

(h) Derivatives

The Company can hold long and short positions in contracts for difference (CFDs) which are held at fair value based on the bid prices of the underlying securities in respect of long positions, and the offer prices of the underlying securities in respect of short positions.

Profits and losses on derivative transactions are recognised in the Statement of Comprehensive Income. They are shown in the capital account of the Statement of Comprehensive Income if they are of a capital nature and are shown in the revenue account of the Statement of Comprehensive Income if they are of a revenue nature. To the extent that any profits or losses are of a mixed revenue and capital nature, they are apportioned between revenue and capital accordingly.

(i) Other receivables and other payables

Other receivables and other payables do not carry any interest and are short term in nature and are accordingly stated on an amortised cost basis.

(j) Dividends payable

Under IASs, final dividends should not be accrued in the financial statements unless they have been approved by shareholders before the financial reporting date. Interim dividends should not be recognised in the financial statements unless they have been paid.

Dividends payable to equity shareholders are recognised in the Statement of Changes in Equity.

(k) Foreign currency translation

Transactions involving foreign currencies are converted at the rate ruling at the date of the transaction. Foreign currency monetary assets and liabilities and non-monetary assets held at fair value are translated into US Dollars at the rate ruling on the financial reporting date. Foreign exchange differences arising on translation are recognised in the Statement of Comprehensive Income as a revenue or capital item depending on the income or expense to which they relate. For investment transactions and investments held at the year end, denominated in a foreign currency, the resulting gains or losses are included in the profit/(loss) on investments held at fair value through profit or loss in the Statement of Comprehensive Income.

(l) Cash and cash equivalents

Cash comprises cash in hand, bank overdrafts and on demand deposits. Cash equivalents are short term, highly liquid investments that are readily convertible to known amounts of cash and that are subject to an insignificant risk of changes in value.

The Company’s investment in the Cash Fund is managed as part of the Company’s investment policy and, accordingly, this investment along with purchases and sales of this investment has been classified in the Statement of Financial Position as an investment and not as a cash equivalent as defined under IAS 7.

(m) Bank borrowings

Bank overdrafts and loans are recorded as the proceeds received. Finance charges, including any premium payable on settlement or redemption and direct issue costs, are accounted for on an accruals basis in the Statement of Comprehensive Income using the effective interest rate method and are added to the carrying amount of the instrument to the extent that they are not settled in the period in which they arise.

(n) Share repurchases/tendered and share reissues

Shares repurchased and subsequently cancelled – share capital is reduced by the nominal value of the shares repurchased and the capital redemption reserve is correspondingly increased in accordance with Section 733 of the Companies Act 2006. The full cost of the repurchase is charged to the special reserve.

Shares repurchased/tendered and held in treasury – the full cost of the repurchase is charged to the special reserve.

Where treasury shares are subsequently re-issued:

· amounts received to the extent of the repurchase/tender price are credited to the special reserve and capital reserves based on a weighted average basis of amounts utilised from these reserves on repurchases; and

· any surplus received in excess of the repurchase/tender price is taken to the share premium account.

Where new shares are issued, amounts received to the extent of any surplus received in excess of the par value are taken to the share premium account.

Share issue costs are charged to the share premium account. Costs on share reissues are charged to the special reserve and capital reserves.

(o) Critical accounting estimates and judgements

The Company makes estimates and assumptions concerning the future. The resulting accounting estimates and assumptions will, by definition, seldom equal the related actual results. Estimates and judgements are regularly evaluated and are based on historical experience and other factors, including expectations of future events that are believed to be reasonable under the circumstances. The Directors do not believe that any accounting judgements or estimates have a significant risk of causing a material adjustment to the carrying amount of assets and liabilities within the next financial year.

3. INCOME

Dividends and interest received in cash during the year amounted to US$13,766,000 and US$591,000 (2021: US$11,549,000 and US$129,000).

Special dividends of US$74,000 have been recognised in capital (2021: US$nil).

4. INVESTMENT MANAGEMENT AND PERFORMANCE FEES

An investment management fee equivalent to 1.10% per annum of the Company’s gross assets (defined as the aggregate net assets of the long equity and CFD portfolios of the Company) is payable to the Manager. In addition, the Manager is entitled to receive a performance fee at a rate of 10% of any increase in the NAV at the end of a performance period over and above what would have been achieved had the NAV since launch increased in line with the Benchmark Index, which, since 1 April 2018, is a composite of the MSCI Emerging Markets Index ex Selected Countries + MSCI Frontier Markets Index + MSCI Saudi Arabia Index.

For the purposes of the calculation of the performance fee, the performance of the Net Asset Value total return was measured against the performance of the Benchmark Index on a blended basis.

For the year ended 30 September 2022, the Company’s NAV underperformed the Benchmark Index by 3.6% (2021: outperformed the Benchmark Index by 25.7%) on a US Dollar basis, and as a result, a performance fee of US$nil (2021: US$3,815,000) has been accrued at 30 September 2022. The performance fee payable in any year is capped at an amount equal to 2.5% or 1.0% of the gross assets if there is any increase or decrease in the NAV per share at the end of the relevant performance period, respectively. Any capped excess outperformance for a period may be carried forward to the next two performance periods, subject to the then applicable annual cap. The performance fee is also subject to a high watermark such that any performance fee is only payable to the extent that the cumulative relative outperformance of the NAV is greater than what would have been achieved had the NAV increased in line with the Benchmark Index since the last date in relation to which a performance fee had been paid.

There is no additional fee for company secretarial and administration services.

5. OTHER OPERATING EXPENSES

1 For the year ended 30 September 2021, fees for audit services excluded £10,000 (US$14,000) (excluding VAT) paid in respect of the additional audit work on the Company’s tender offer. These fees are included within tender offer costs on the Statement of Changes in Equity.

2 Fees for other assurance services of £6,500 (US$7,000) (2021: £6,500 (US$9,000)) relate to the review of the interim financial statements.

3 Further information on Directors’ emoluments can be found in the Directors’ Remuneration Report. The Company has no employees.

4 All expenses other than depositary fees are paid in British Pound Sterling and are therefore subject to exchange rate fluctuations.

5 Relates to Directors’ expenses and miscellaneous fees written back during the year (2021: Directors’ search fees, legal fees, Directors’ expenses and AIC fees).

6 For the year ended 30 September 2022, expenses of £70,000 (US$78,000) (2021: £45,000 (US$60,000)) were charged to the capital account of the Statement of Comprehensive Income. These relate to transaction costs charged by the custodian on sale and purchase trades.

7 Alternative Performance Measures, see Glossary in the Company’s Annual Report for the year ended 30 September 2022.

No fees were payable in 2022 or 2021 in relation to investing in new markets.

6. DIVIDENDS

The total dividends payable in respect of the year ended 30 September 2022 which form the basis of Section 1158 of the Corporation Tax Act 2010 and Section 833 of the Companies Act 2006, and the amounts proposed, meet the relevant requirements as set out in this legislation.

1 Based on 189,325,748 ordinary shares in issue on 7 December 2022.

7. EARNINGS AND NET ASSET VALUE PER ORDINARY SHARE

Total revenue, capital (loss)/earnings and net asset value per ordinary share are shown below and have been calculated using the following:

1 The Company’s share price is quoted in British Pound Sterling and the above represents the US Dollar equivalent based on an exchange rate of US$1.1163 to £1 as at 30 September 2022 (30 September 2021: US$1.3484 to £1).

2 Based on an exchange rate of US$1.1163 to £1 at 30 September 2022 and US$1.3484 to £1 at 30 September 2021.

8. CALLED UP SHARE CAPITAL

During the year, the Company did not issue any ordinary shares (2021: nil). Additionally, during the year, there was no tender offer and no shares were transferred into treasury (2021: 51,884,770 shares for a total gross consideration of US$87,220,000).

Since 30 September 2022 and up to the date of this report, no ordinary shares have been issued or bought back.

9. RESERVES

For the year ended 30 September 2022

For the year ended 30 September 2021

The share premium account and capital redemption reserve are not distributable reserves under the Companies Act 2006. In accordance with ICAEW Technical Release 02/17BL on Guidance on Realised and Distributable Profits under the Companies Act 2006, the special reserve and capital reserves may be used as distributable reserves for all purposes and, in particular, the repurchase by the Company of its ordinary shares and for payments as dividends. In accordance with the Company’s Articles of Association, the special reserve, capital reserves and the revenue reserve may be distributed by way of dividend. For the year ended 30 September 2022, the loss on capital reserve arising on the revaluation of investments was £44,579,000. For the year ended 30 September 2021, this was a gain of £13,092,000 which was subject to fair value movements. The investments are subject to financial risks, as such capital reserves (arising on investments sold) and the revenue reserve may not be entirely distributable if a loss occurred during the realisation of these investments.

The Company’s share premium account was cancelled in the prior period pursuant to shareholders’ approval of a special resolution at the Company’s Annual General Meeting on 2 February 2021 and Court approval on 11 March 2021. The share premium account which totalled US$165,984,000 was transferred to a special reserve.

10. VALUATION OF FINANCIAL INSTRUMENTS

Financial assets and financial liabilities are either carried in the Statement of Financial Position at their fair value (investments and derivatives) or at an amount which is a reasonable approximation of fair value (due from brokers, dividends and interest receivable, due to brokers, accruals, cash at bank and bank overdrafts). IFRS 13 requires the Company to classify fair value measurements using a fair value hierarchy that reflects the significance of inputs used in making the measurements. The valuation techniques used by the Company are explained in the accounting policies note 2(g) to the Financial Statements.

Categorisation within the hierarchy has been determined on the basis of the lowest level of input that is significant to the fair value measurement of the relevant asset.

The fair value hierarchy has the following levels:

Level 1 – Quoted market price for identical instruments in active markets

A financial instrument is regarded as quoted in an active market if quoted prices are readily and regularly available from an exchange, dealer, broker, industry group, pricing service or regulatory agency and those prices represent actual and regularly occurring market transactions on an arm’s length basis. The Company does not adjust the quoted price for these instruments.

Level 2 – Valuation techniques using observable inputs

This category includes instruments valued using quoted prices for similar instruments in markets that are considered less than active, or other valuation techniques where all significant inputs are directly or indirectly observable from market data.

Valuation techniques used for non-standardised financial instruments such as options, currency swaps and other over-the-counter derivatives include the use of comparable recent arm’s length transactions, reference to other instruments that are substantially the same, discounted cash flow analysis, option pricing models and other valuation techniques commonly used by market participants making the maximum use of market inputs and relying as little as possible on entity specific inputs.

As at the year end the CFDs were valued using the underlying equity bid price and the inputs to the valuation were the exchange rates used to convert the CFD valuation from the relevant local currency in which the underlying equity was priced to US Dollars at the year end date. There have been no changes to the valuation technique since the previous year or as at the date of this report.

Level 3 – Valuation techniques using significant unobservable inputs

This category includes all instruments where the valuation technique includes inputs not based on market data and these inputs could have a significant impact on the instrument’s valuation.

This category also includes instruments that are valued based on quoted prices for similar instruments where significant entity determined adjustments or assumptions are required to reflect differences between the instruments and instruments for which there is no active market. The Investment Manager considers observable data to be that market data that is readily available, regularly distributed or updated, reliable and verifiable, not proprietary, and provided by independent sources that are actively involved in the relevant market.

The level in the fair value hierarchy within which the fair value measurement is categorised in its entirety is determined on the basis of the lowest level input that is significant to the fair value measurement. If a fair value measurement uses observable inputs that require significant adjustment based on unobservable inputs, that measurement is a Level 3 measurement.

Assessing the significance of a particular input to the fair value measurement in its entirety requires judgement, considering factors specific to the asset or liability. The determination of what constitutes ‘observable’ inputs requires significant judgement by the Investment Manager.

Contracts for difference and forward currency contracts have all been classified as Level 2 investments as their valuation has been based on market observable inputs represented by the market prices of the underlying quoted securities and exchange rates to which these contracts expose the Company.

Fair values of financial assets and financial liabilities

The table below sets out fair value measurements using IFRS 13 fair value hierarchy.

There were no transfers between levels of financial assets and financial liabilities during the year recorded at fair value as at 30 September 2022. The Company held no Level 3 assets or liabilities during the year ended 30 September 2022. The Company held one Level 3 long CFD security during the year ended 30 September 2021 which was disposed of prior to 30 September 2021.

A reconciliation of fair value measurement in Level 3 is set out below.

1 During the year the Company disposed of a contract for difference in Kuwait Food (Americana).

For exchange listed equity investments, the quoted price is the bid price. Substantially, all investments are valued based on unadjusted quoted market prices. Where such quoted prices are readily available in an active market, such prices are not required to be assessed or adjusted for any business risks, including climate change risk, in accordance with the fair value related requirements of the Company’s financial reporting framework.

11. RELATED PARTY DISCLOSURE

Directors’ emoluments

At the date of this report, the Board consists of six non-executive Directors, all of whom are considered to be independent of the Manager by the Board.

Disclosures of the Directors’ interests in the ordinary shares of the Company and fees and expenses payable to the Directors are set out in the Directors’ Remuneration Report in the Company's Annual Report for the year ended 30 September 2022. At 30 September 2022, US$17,000 (£15,000) (2021: US$15,000 (£11,000)) was outstanding in respect of Directors’ fees.

Significant holdings

The following investors are:

a. funds managed by the BlackRock Group or are affiliates of BlackRock Inc. (“Related BlackRock Funds”); or

b. investors (other than those listed in (a) above) who held more than 20% of the voting shares in issue in the Company and are as a result, considered to be related parties to the Company (“Significant Investors”).

As at 30 September 2022

As at 30 September 2021

12. TRANSACTIONS WITH INVESTMENT MANAGER AND AIFM

BlackRock Fund Managers Limited (BFM) provides management and administration services to the Company under a contract which is terminable on six months’ notice. BFM has (with the Company’s consent) delegated certain portfolio and risk management services, and other ancillary services, to BlackRock Investment Management (UK) Limited (BIM (UK)). Further details of the investment management contract are disclosed in the Directors’ Report in the Company's Annual Report for the year ended 30 September 2022.

The investment management fee due for the year ended 30 September 2022 amounted to US$3,785,000 (2021: US$3,884,000). No performance fee is payable for the year (2021: US$3,815,000). At the year end, US$882,000 was outstanding in respect of management fees (2021: US$1,867,000) and US$nil (2021: US$3,815,000) was outstanding in respect of performance fees.

In addition to the above services, BIM (UK) has provided the Company with marketing services. The total fees paid or payable for these services for the year ended 30 September 2022 amounted to US$76,000 excluding VAT (2021: US$101,000). Marketing fees of US$53,000 excluding VAT (2021: US$64,000) were outstanding at the year end.

The Company has an investment in the BlackRock Institutional Cash Series plc – US Dollar Liquid Environmentally Aware Fund of US$71,415,000 (2021: US$96,269,000) at the year end, which is a fund managed by a company within the BlackRock Group.

The ultimate holding company of the Manager and the Investment Manager is BlackRock, Inc., a company incorporated in Delaware, USA.

13. CONTINGENT LIABILITIES

There were no contingent liabilities at 30 September 2022 (2021: nil).

14. PUBLICATION OF NON STATUTORY ACCOUNTS

The financial information contained in this announcement does not constitute statutory accounts as defined in the Companies Act 2006. The 2022 Annual Report and Financial Statements will be filed with the Registrar of Companies shortly.

The report of the Auditor for the year ended 30 September 2022 contains no qualification or statement under Section 498(2) or (3) of the Companies Act 2006.

The comparative figures are extracts from the audited financial statements of BlackRock Frontiers Investment Trust plc for the year ended 30 September 2021, which have been filed with the Registrar of Companies. The report of the Auditor on those financial statements contained no qualification or statement under Section 498 of the Companies Act.

This announcement was approved by the Board of Directors on 7 December 2022.

15. ANNUAL REPORT

Copies of the annual report will be sent to members shortly and will be available from the registered office, c/o The Company Secretary, BlackRock Frontiers Investment Trust plc, 12 Throgmorton Avenue, London EC2N 2DL.

16. ANNUAL GENERAL MEETING

The Annual General Meeting of the Company will be held at 12 Throgmorton Avenue, London EC2N 2DL on Tuesday, 7 February 2023 at 12:30 p.m.

The Annual Report will also be available on the BlackRock website at blackrock.com/uk/brfi. Neither the contents of the Manager’s website nor the contents of any website accessible from hyperlinks on the Manager’s website (or any other website) is incorporated into, or forms part of, this announcement.

FOR FURTHER INFORMATION, PLEASE CONTACT:

Melissa Gallagher, Managing Director, Investment Trusts, BlackRock Investment Management (UK) Limited

Tel: 020 7743 3000

Press enquiries:

Lansons Communications

Email: [email protected]

Tel: 020 7490 8828

7 December 2022

12 Throgmorton Avenue

London EC2N 2DL

END

As at

30 September

2022 As at

30 September

2021
US Dollar
Net assets (US$’000) 1 302,656 352,778
Net asset value per ordinary share (cents) 159.86 186.33
Ordinary share price (mid-market) 2 (cents) 142.61 165.18
---------------- ----------------
British Pound Sterling
Net assets (£’000) 1,2 271,124 261,627
Net asset value per ordinary share 2 (pence) 143.21 138.19
Ordinary share price (mid-market) (pence) 127.75 122.50
Discount 3 10.8% 11.4%
========== ==========

Performance For the year

ended

30 September

2022

% For the year

ended

30 September

2021

%

Since

inception 4

%
US Dollar
Net asset value per share (with dividends reinvested) 3 -10.9 +53.0 +59.8
Benchmark Index (NR) 5,6 -7.3 +27.3 +35.3
MSCI Frontier Markets Index (NR) 6 -25.2 +32.2 +24.7
MSCI Emerging Markets Index (NR) 6 -28.1 +18.2 +5.1
Ordinary share price (with dividends reinvested) 3 -10.0 +42.8 +40.6
---------------- ---------------- ----------------
British Pound Sterling
Net asset value per share (with dividends reinvested) 3 +7.7 +46.7 +122.6
Benchmark Index (NR) 6 +12.0 +22.1 +87.5
MSCI Frontier Markets Index (NR) 6 -9.6 +26.8 +74.2
MSCI Emerging Markets Index (NR) 6 -13.2 +13.3 +46.7
Ordinary share price (with dividends reinvested) 3 +8.7 +36.9 +95.6
========== ========== ==========

%
Saudi Arabia 26.1
Indonesia 13.2
Malaysia 8.4
Kazakhstan 7.3
Vietnam 7.0
United Arab Emirates 6.7
Thailand 6.7
Chile 5.7
Qatar 4.6
Greece 4.3
Hungary 3.7
Poland 3.1
Romania 2.2
Philippines 2.0
Panama 1.9
Egypt 1.8
Kuwait 1.5
Peru 1.5
Colombia 1.4
Kenya 0.9
Multi-International 0.9
Ukraine 0.4

%
Kazakhstan 6.8
Vietnam 4.7
Greece 2.9
Hungary 2.9
Chile 2.6
Panama 1.9
Romania 1.8
Egypt 1.4
Indonesia 1.4
Multi-International 0.9
Colombia 0.6
Saudi Arabia 0.6
Kenya 0.5
Ukraine 0.4
Poland 0.3
Malaysia 0.3
Peru 0.2
Lithuania -0.1
Pakistan -0.1
Estonia -0.1
Croatia -0.1
Jordan -0.1
Mauritius -0.2
Oman -0.2
Slovenia -0.2
Bangladesh -0.3
Nigeria -0.4
Other -0.6
Morocco -0.7
United Arab Emirates -0.7
Bahrain -0.8
Czech Republic -0.8
Philippines -1.7
Turkey -2.0
Qatar -2.1
Kuwait -3.2
Thailand -4.6

%
Financials 41.7
Materials 14.0
Consumer Discretionary 10.3
Industrials 9.4
Consumer Staples 8.5
Energy 7.9
Information Technology 4.9
Real Estate 4.7
Communication Services 4.5
Utilities 4.1
Health Care 1.3

%
Consumer Discretionary 6.4
Industrials 4.4
Information Technology 4.1
Consumer Staples 2.6
Materials 2.2
Real Estate 0.9
Energy 0.8
Utilities -0.2
Health Care -1.7
Financials -3.1
Communication Services -5.2

Company Principal

country of

operation

Sector

Fair value 1

US$’000 Gross market

exposure as a

% of net assets 3
Bank Rakyat Indonesia Financials 13,856 4.6
Astra International Indonesia Consumer Discretionary 7,850 2.6
Indocement Tunggal Prakarsa Indonesia Materials 7,713 2.5
Bank Mandiri Indonesia Financials 6,027 2.0
Mitra Adiperkasa Indonesia Consumer Discretionary 4,499 1.5
---------------- ----------------
39,945 13.2
========== ==========
Genting Malaysia Consumer Discretionary 8,919 2.9
RHB Bank Malaysia Financials 7,642 2.5
Frontken Corp Malaysia Industrials 4,573 1.5
Malayan Banking Malaysia Financials 4,450 1.5
---------------- ----------------
25,584 8.4
========== ==========
JSC Kaspi Kazakhstan Financials 10,335 3.4
Kazatomprom Kazakhstan Energy 6,824 2.2
Halyk Savings Bank Kazakhstan Financials 5,078 1.7
---------------- ----------------
22,237 7.3
========== ==========
Emaar Properties United Arab Emirates Real Estate 14,158 4.7
Air Arabia United Arab Emirates Industrials 6,105 2.0
---------------- ----------------
20,263 6.7
========== ==========
Banco Santander Chile Chile Financials 6,429 2.1
Albemarle Chile Materials 6,056 2.0
Empresas CMPC Chile Materials 4,758 1.6
---------------- ----------------
17,243 5.7
========== ==========
PTT Global Chemical Thailand Materials 5,611 1.9
Airports of Thailand Thailand Industrials 5,573 1.8
Bangkok Dusit Medical Services Thailand Health Care 5,079 1.7
---------------- ----------------
16,263 5.4
========== ==========
Qatar Gas Transport Company Qatar Energy 9,367 3.1
Qatar National Bank Qatar Financials 4,576 1.5
---------------- ----------------
13,943 4.6
========== ==========
OTP Bank Hungary Financials 4,045 1.3
MOL Group Hungary Energy 3,627 1.2
Wizz Air Holdings Hungary Industrials 2,971 1.0
---------------- ----------------
10,643 3.5
========== ==========
National Bank of Greece Greece Financials 4,694 1.6
Terna Energy Greece Utilities 4,025 1.3
Titan Cement International Greece Materials 1,516 0.5
---------------- ----------------
10,235 3.4
========== ==========
PKO Bank Polski Poland Financials 9,254 3.1
---------------- ----------------
9,254 3.1
========== ==========
BRD – Groupe Société Générale Romania Financials 6,564 2.2
---------------- ----------------
6,564 2.2
========== ==========
Jollibee Foods Philippines Consumer Discretionary 2,944 1.0
LT Group Philippines Industrials 2,921 1.0
---------------- ----------------
5,865 2.0
========== ==========
Copa Airlines Panama Industrials 5,742 1.9
---------------- ----------------
5,742 1.9
========== ==========
Eastern Company Egypt Consumer Staples 4,483 1.5
EFG Hermes Holdings Egypt Financials 859 0.3
---------------- ----------------
5,342 1.8
========== ==========
Credicorp Peru Financials 4,680 1.5
---------------- ----------------
4,680 1.5
========== ==========
Mobile Telecommunications Kuwait Communication Services 4,655 1.5
---------------- ----------------
4,655 1.5
========== ==========
Ecopetrol Colombia Energy 4,196 1.4
---------------- ----------------
4,196 1.4
========== ==========
Equity Group Kenya Financials 2,946 0.9
---------------- ----------------
2,946 0.9
========== ==========
Ferrexpo Ukraine Materials 930 0.3
---------------- ----------------
930 0.3
========== ==========
Equity investments 226,530 74.8
========== ==========
BlackRock’s Institutional Cash Series plc – US Dollar Liquid Environmentally Aware Fund (Cash Fund) 71,415 23.6
---------------- ----------------
Total equity investments (including Cash Fund) 297,945 98.4
========== ==========

Company Principal

country of

operation

Sector

Fair value 1

US$’000 Gross Market

exposure 2

US$’000 Gross market

exposure as a

% of net assets 3
Long positions
Saudi National Bank Saudi Arabia Financials 14,017 4.6
Abdullah Al Othaim Markets Saudi Arabia Consumer Staples 9,783 3.2
Saudi Telecom Saudi Arabia Communication Services 9,209 3.0
Saudi British Bank Saudi Arabia Financials 7,945 2.6
Yanbu National Petrochemical Saudi Arabia Materials 7,650 2.6
Elm Company Saudi Arabia Information Technology 6,890 2.3
Riyad Bank Saudi Arabia Financials 5,581 1.8
Leejam Sports Saudi Arabia Consumer Discretionary 4,768 1.6
Al Nahdi Medical Saudi Arabia Consumer Staples 4,255 1.4
---------------- ----------------
70,098 23.1
========== ==========
FPT Vietnam Information Technology 7,933 2.6
Vietnam Dairy Products Vietnam Consumer Staples 7,072 2.4
Vietnam Technological & Commercial Vietnam Financials 3,919 1.3
Mobile World Vietnam Consumer Discretionary 2,209 0.7
---------------- ----------------
21,133 7.0
========== ==========
Titan Cement International Greece Materials 1,735 0.6
National Bank of Greece Greece Financials 925 0.3
---------------- ----------------
2,660 0.9
========== ==========
Wizz Air Holdings Hungary Industrials 531 0.2
---------------- ----------------
531 0.2
========== ==========
Ferrexpo Ukraine Materials 357 0.1
---------------- ----------------
357 0.1
========== ==========
Total long CFD positions (4,267) 94,779 31.3
========== ========== ==========
Total short CFD positions 409 (15,624) (5.2)
========== ========== ==========
Total CFD portfolio (3,858) 79,155 26.1
========== ========== ==========

Portfolio

Fair value 1 Gross market

exposure 3 Gross market exposure as

a % of net assets 3
US$’000 US$’000 2022 2021
Equity investments 226,530 226,530 74.8 73.1
Total long CFD positions (4,267) 94,779 31.3 35.0
Total short CFD positions 409 (15,624) (5.2) (0.4)
Forward currency positions – – 0.0 4.6
------------------ ------------------ ------------------ ------------------
Total gross exposure 222,672 305,685 100.9 112.3
========== ========== ========== ==========
Cash Fund 71,415 71,415 23.6 27.3
------------------ ------------------ ------------------ ------------------
Total investments and derivatives 294,087 377,100 124.5 139.6
========== ========== ========== ==========
Cash and cash equivalents 1,2 4,901 (78,112) (25.7) (35.9)
Other net current assets/(liabilities) 3,687 3,687 1.2 (3.7)
Non-current liabilities (19) (19) 0.0 0.0
------------------ ------------------ ------------------ ------------------
Net assets 302,656 302,656 100.0 100.0
========== ========== ========== ==========

Year ended

30 September 2022 1 Year ended

30 September 2021 1
£% US$% £% US$%
Net asset value total return 2 +7.7 -10.9 +46.7 +53.0
Share price total return 3 +8.7 -10.0 +36.9 +42.8
Benchmark Index return 4 +12.0 -7.3 +22.1 +27.3
Discount to cum income NAV 10.8 11.4
Ongoing charges 5 1.36 1.36
Ongoing charges including performance fees 1.36 2.44
========== ========== ========== ==========

Principal Risk Mitigation/Control
Investment Performance Risk

The Board is responsible for:

· setting the investment policy to fulfil the Company’s objectives; and

· monitoring the performance of the Company’s Investment Manager and the strategy adopted.

An inappropriate policy or strategy may lead to:

· poor performance compared to the Company’s benchmark peer group or shareholder expectations;

· a widening discount to NAV;

· a reduction or permanent loss of capital; and

· dissatisfied shareholders and reputational damage.

The Board is also cognisant of the long-term risk to performance from inadequate attention to ESG issues and in particular the impact of climate change.

To manage this risk the Board:

- regularly reviews the Company’s investment mandate and long term strategy;
- has set, and regularly reviews, the investment guidelines and has put in place appropriate limits on levels of gearing and the use of derivatives;
- receives from the Investment Manager a regular explanation of stock selection decisions, portfolio gearing and any changes in gearing and the rationale for the composition of the investment portfolio;
- receives from the Investment Manager regular reporting on the portfolio’s exposure through derivatives, including the extent to which the portfolio is geared in this manner and the value of any short positions;
- monitors the maintenance of an adequate spread of investments in order to minimise the risks associated with particular countries or factors specific to particular sectors, based on the diversification requirements inherent in the Company’s investment policy; and
- regularly reviews detailed performance attribution analysis.

ESG analysis is integrated into the Manager’s investment process, as set out on pages 35 and 36 of the Annual Report and Financial Statements. This is monitored by the Board.
Income/Dividend Risk

The amount of dividends and future dividend growth will depend on the Company’s underlying portfolio. In addition, any change in the tax treatment of the dividends or interest received by the Company (including as a result of withholding taxes or exchange controls imposed by jurisdictions in which the Company invests) may reduce the level of dividends received by shareholders.

Although the Company does not have a policy of actively seeking income, the Board monitors this risk through the receipt of detailed income forecasts and considers the level of income at each meeting. The Company also has a revenue reserve and powers to pay dividends from capital which can be used to support the Company’s dividend if required.
Legal and Regulatory Risk

The Company has been approved by HM Revenue & Customs as an investment trust, subject to continuing to meet the relevant eligibility conditions, and operates as an investment trust in accordance with Chapter 4 of Part 24 of the Corporation Tax Act 2010. As such, the Company is exempt from capital gains tax on the profits realised from the sale of its investments.

Any breach of the relevant eligibility conditions could lead to the Company losing its investment trust status and being subject to corporation tax on capital gains realised within the Company’s portfolio.

In such event the investment returns of the Company may be adversely affected. Any serious breach could result in the Company and/or the Directors being fined or the subject of criminal proceedings or the suspension of the Company’s shares which would in turn lead to a breach of the Corporation Tax Act 2010. Amongst other relevant laws and regulations, the Company is required to comply with the provisions of the Companies Act 2006, the Alternative Investment Fund Managers’ Directive, the Market Abuse Act, the UK Listing Rules and the Disclosure Guidance & Transparency Rules.

The Investment Manager monitors investment movements, the level of forecast income and expenditure and the amount of proposed dividends, if any, to ensure that the provisions of Chapter 4 of Part 24 of the Corporation Tax Act 2010 are not breached, and the results are reported to the Board at each meeting.

Following authorisation under the Alternative Investment Fund Managers’ Directive (AIFMD), the Company and its appointed Alternative Investment Fund Manager (AIFM) are subject to the risks that the requirements of this Directive are not correctly complied with. The Board and the AIFM also monitor changes in government policy and legislation which may have an impact on the Company.

Compliance with the accounting standards applicable to quoted companies and those applicable to investment trusts are also regularly monitored to ensure compliance.

The Company Secretary and the Company’s professional advisers monitor developments in relevant laws and regulations and provide regular reports to the Board in respect of the Company’s compliance.

Counterparty Risk

The Company’s investment policy also permits the use of both exchange-traded and over-the-counter derivatives (including contracts for difference). The potential loss that the Company could incur if a counterparty is unable (or unwilling) to perform on its commitments.

Due diligence is undertaken before contracts are entered into and exposures are diversified across a number of counterparties. The Board reviews the controls put in place by the Investment Manager to monitor and to minimise counterparty exposure, which include intra-day monitoring of exposures to ensure that these are within set limits.
Operational Risk

In common with most other investment trust companies, the Company has no employees. The Company therefore relies upon the services provided by third parties and is dependent on the control systems of BlackRock (the Investment Manager and AIFM), and of The Bank of New York Mellon (International) Limited (the Custodian, Depositary and Fund Accountant), which ensures safe custody of the Company’s assets and maintains the Company’s accounting records. The Company’s share register is maintained by the Registrar, Computershare.

Failure by any service provider to carry out its obligations to the Company could have a material adverse effect on the Company’s performance. Disruption to the accounting, payment systems or custody records, as a result of a cyberattack or otherwise, could impact the monitoring and reporting of the Company’s financial position.

The security of the Company’s assets, dealing procedures, accounting records and maintenance of regulatory and legal requirements, depend on the effective operation of these systems.

The Board reviews the overall performance of the Manager, Investment Manager and all other third-party service providers and compliance with the investment management agreement on a regular basis.

The Fund Accountant’s and the Manager’s internal control processes are regularly tested and monitored throughout the year and are evidenced through their Service Organisation Control (SOC 1) reports, which are subject to review by an Independent Service Assurance Auditor. The SOC 1 reports provide assurance in respect of the effective operation of internal controls.

The Company’s assets are subject to a strict liability regime and in the event of a loss of financial assets held in custody, the Depositary must return assets of an identical type or the corresponding amount, unless able to demonstrate that the loss was a result of an event beyond its reasonable control.

The Board considers succession arrangements for key employees of the Manager and the Board also considers the business continuity arrangements of the Company’s key service providers on an ongoing basis and reviews these as part of its review of the Company’s risk register.

The Board also receives regular reports from BlackRock’s internal audit function.
Political Risk

Investments in the Frontiers Universe may include a higher element of risk compared to more developed markets due to greater political instability. Political and diplomatic events in the Frontiers Universe where the Company invests (for example, governmental instability, corruption, adverse changes in legislation or other diplomatic developments such as the outbreak of war or imposition of sanctions) could substantially and adversely affect the economies of such countries or the value of the Company’s investments in those countries.

The Investment Manager mitigates this risk by applying stringent controls over where investments are made and through close monitoring of political risks. The Investment Manager’s approach to filtering the investment universe takes account of the political background to regions and is backed up by rigorous stock specific research and risk analysis, individually and collectively, in constructing the portfolio. The management team has a wide network of business and political contacts which provides economic insights with public and private bodies. This enables the Investment Manager to assess potential investments in an informed and disciplined way, as well as being able to conduct regular monitoring of investments once made. However, given the nature of political risk, all investments will be exposed to a degree of risk and the Investment Manager will ensure that the portfolio remains diversified across countries to mitigate the risk.
Financial Risk

The Company’s investment activities expose it to a variety of financial risks which include foreign currency risk, liquidity risk, currency risk and interest rate risk.

Details of these risks are disclosed in note 17 to the financial statements in the Company's Annual Report for the year ended 30 September 2022, together with a summary of the policies for managing these risks.
Market Risk

Market risk arises from volatility in the prices of the Company’s investments. It represents the potential loss the Company might suffer through realising investments in the face of negative market movements. The securities markets of the Frontiers Universe are not as large as the more established securities markets and have substantially less trading volume, which may result in a lack of liquidity and higher price volatility. There are fewer attractive investment opportunities in frontier markets, and this may lead to a delay in investment and may affect the price at which such investments may be made and reduce potential investment returns for the Company.

There is also exposure to currency, market and political risk due to the location of the operation of the businesses in which the Company may invest. As a consequence of this and other market factors the Company may invest in a concentrated portfolio of shares and this focus may result in higher risk when compared to a portfolio that has spread or diversified investments more broadly.

Corruption also remains a significant issue across the Frontiers Universe and the effects of corruption could have a material adverse effect on the Company’s performance. Accounting, auditing and financial reporting standards and practices and disclosure requirements applicable to many companies in developing countries may be less rigorous than in developed markets. As a result, there may be less information available publicly to investors in these securities, and such information as is available is often less reliable.

The Company may also gain exposure to the Frontiers Universe by investing indirectly through Participatory Notes (P-Notes) which presents additional risk to the Company as P-Notes are uncollateralised resulting in the Company being subject to full counterparty risk via the P-Note issuer. P-Notes also present liquidity issues as the Company, being a captive client of a P-Note issuer, may only be able to realise its investment through the P-Note issuer and this may have a negative impact on the liquidity of the P-Notes which does not correlate to the liquidity of the underlying security.

The Portfolio Managers seek to understand the environmental, social and governance (ESG) risks and opportunities facing companies and industries in the portfolio. The Company does not exclude investment in stocks based on ESG criteria, but the Portfolio Managers consider ESG information when conducting research and due diligence on new investments and again when monitoring investments in the portfolio.

Market risk represents the risks of investment in a particular market, country or geographic region. Therefore, this is largely outside of the scope of the Board’s control. However, the Board carefully considers asset allocation, stock selection and levels of gearing on a regular basis and has set investment restrictions and guidelines which are monitored and reported on by the Investment Manager. Market risk is also mitigated through portfolio diversification across countries and regions. The Board monitors the implementation and results of the investment process with the Investment Manager regularly.

The Investment Manager regularly reports to the Board on relative market risks associated with investment in such regions. Further information is provided under ‘Political Risk’.

The Board recognises the benefits of a closed-end fund structure in extremely volatile markets such as those affected by the COVID-19 pandemic, and more recently the Russia-Ukraine conflict. Unlike open-ended counterparts, closed-end funds are not obliged to sell-down portfolio holdings at low valuations to meet liquidity requirements for redemptions. During times of elevated volatility and market stress, the ability of a closed-end fund structure to remain invested for the long term enables the Investment Manager to adhere to disciplined fundamental analysis from a bottom-up perspective and be ready to respond to dislocations in the market as opportunities present themselves.

Companies operating in the sectors in which the Company invests may be impacted by new legislation governing climate change and environmental issues, which may have a negative impact on their valuation and share price.

Shareholders Manager and Investment Manager Other key service providers Investee companies
Continued shareholder support and engagement are critical to the continued existence of the Company and the successful delivery of its long-term strategy. The Board is focused on fostering good working relationships with shareholders and on understanding the views of shareholders in order to incorporate them into the Board’s strategy and objectives in delivering long-term growth and income. The Board’s main working relationship is with the Manager, who is responsible for the Company’s portfolio management (including asset allocation, stock and sector selection) and risk management, as well as ancillary functions such as administration, secretarial, accounting and marketing services. The Manager has sub-delegated portfolio management to the Investment Manager. Successful management of shareholders’ assets by the Investment Manager is critical for the Company to successfully deliver its investment strategy and meet its objective. The Company is also reliant on the Manager as AIFM to provide support in meeting relevant regulatory obligations under the AIFMD and other relevant legislation. In order for the Company to function as an investment trust with a listing on the premium segment of the official list of the Financial Conduct Authority (FCA) and trade on the London Stock Exchange’s (LSE) main market for listed securities, the Board relies on a diverse range of advisors for support in meeting relevant obligations and safeguarding the Company’s assets. For this reason, the Board considers the Company’s Custodian, Depositary, Registrar and Broker to be stakeholders. The Board maintains regular contact with its key external providers and receives regular reporting from them through the Board and committee meetings, as well as outside of the regular meeting cycle. Portfolio holdings are ultimately shareholders’ assets, and the Board recognises the importance of good stewardship and communication with investee companies in meeting the Company’s investment objective and strategy. The Board monitors the Manager’s stewardship arrangements and receives regular feedback from the Manager in respect of meetings with the management of portfolio companies.

Issue Engagement Impact
Responsible investing The Board is committed to promoting the role and success of the Company in delivering on its investment mandate to shareholders over the long term. However, the Board recognises that securities within the Company’s investment remit may involve significant additional risk due to the political volatility and environmental, social and governance concerns facing many of the countries in the Company’s investment universe. While the Company does not have an ESG investment objective or exclude investments based only on ESG criteria, these ethical and sustainability issues should be a consideration of our Manager’s research. More than ever, consideration of sustainable investment is a key part of the investment process and should be factored in when making investment decisions. The Board also have responsibility to shareholders to ensure that the Company’s portfolio of assets is invested in line with the stated investment objective and in a way that ensures an appropriate balance between spread of risk and portfolio returns.

The Board believes that responsible investment and sustainability are important to the longer-term delivery of growth in capital and income and has worked very closely with the Manager throughout the year to regularly review the Company’s performance, investment strategy to understand how ESG considerations are integrated into the investment process.

The Manager’s approach to the consideration of ESG factors in respect of the Company’s portfolio, as well as its engagement with investee companies to encourage the adoption of sustainable business practices which support long-term value creation, are kept under review by the Board. The Manager reports to the Board in respect of its consideration of ESG factors and how these are integrated into the investment process; a summary of BlackRock’s approach to ESG and sustainability is set out in the Company’s Annual Report for the year ended 30 September 2022. The Investment Manager’s engagement and voting policy is detailed in the Company’s Annual Report for the year ended 30 September 2022 and on the BlackRock website. The Board and the Manager believe there is a positive correlation between strong ESG practices and investment performance. Details regarding the Company’s NAV and share price performance can be found in the Chairman’s Statement. The portfolio activities undertaken by the Manager, can be found in the Investment Manager’s Report.
Discount Strategy The Board believes that the Company’s unique investment offering, strong performance and an attractive dividend yield enhances demand for the Company’s shares, which should help to maintain the Company’s discount at as close to the underlying NAV as possible.

The Company has also put in place a 5-yearly mechanism which provides shareholders with a periodic opportunity to exit at NAV less costs. The Manager reports total return performance statistics to the Board on a regular basis, along with the portfolio yield and the impact of dividends paid on brought forward distributable reserves.

The Board reviews the Company’s discount/premium to NAV on a regular basis and holds regular discussions with the Manager and the Company’s broker regarding the discount/premium level.

The Board also seeks shareholder authority each year to buy back up to 14.99% of the Company’s issued share capital for cancellation or to be held in treasury for the potential re-issue. Buying back the Company’s shares can, in certain circumstances, help to narrow the discount and/ or reduce the volatility in the share rating.

The average discount for the year to 30 September 2022 was 9.2%. During the year the Company’s share price has traded at a maximum discount of 13.7% and a minimum discount of 3.5%.
Service levels of third party providers The Board acknowledges the importance of ensuring that the Company’s principal suppliers are providing a suitable level of service: including the Manager in respect of investment performance and delivering on the Company’s investment mandate; the Custodian and Depositary in respect of their duties towards safeguarding the Company’s assets; the Registrar in its maintenance of the Company’s share register and dealing with investor queries and the Company’s Brokers in respect of the provision of advice and acting as a market maker for the Company’s shares. The Manager reports to the Board on the Company’s performance on out a robust annual evaluation of the Manager’s performance, their commitment and available resources.

The Board performs an annual review of the service levels of all third-party service providers and concludes on their suitability to continue in their role.

The Board receives regular updates from the AIFM, Depositary, Registrar and Brokers on an ongoing basis.

The Board has worked closely with the Manager to gain comfort that relevant business continuity plans are operating effectively for all of the Company’s service providers.

All performance evaluations were performed on a timely basis and the Board concluded that all third-party service providers, including the Manager, Custodian, Depositary and Fund Accountant were operating effectively and providing a good level of service.

The Board has received updates in respect of business continuity planning from the Company’s Manager, Custodian, Depositary, Fund Accountant, Broker, Registrar and printer, and is confident that arrangements are in place to ensure that a good level of service will continue to be provided
Board composition The Board is committed to ensuring that its own composition brings an appropriate balance of knowledge, experience and skills, and that it is compliant with best corporate governance practice under the UK Code, including guidance on tenure and the composition of the Board’s committees. The Board recognises the benefits of diversity and regular refreshment but does not believe tenure alone should determine whether a Director remains independent.

As it does each year, the Board, discharging the duties of a Nomination Committee, considers the composition of the Board to ensure that it is suitably aligned with the activities and needs of the Company. Following this review, and in accordance with corporate governance best practice, the Board has resolved to appoint Katrina Hart as Senior Independent Director.

The Board will continue to keep the composition of the Board under regular review. If it is determined that a new appointment to the Board is required, it will agree the selection criteria, which will take into account the need to maintain a suitable balance of skills, knowledge, independence and diversity, including that of gender.

All Directors are subject to a formal evaluation process on an annual basis (more details and the conclusions in respect of the 2022 evaluation process are given in the Company’s Annual Report for the year ended 30 September 2022). All Directors stand for re-election by shareholders annually. Shareholders may attend the AGM and raise any queries in respect of Board composition or individual Directors in person or may contact the Company Secretary or the Chairman using the details provided in the Company's Annual Report for the year ended 30 September 2022 if they wish to raise any issues.

The Directors are not aware of any issues that have been raised directly by shareholders in respect of Board composition in 2022. Details for the proxy voting results in favour and against individual Directors’ re-election at the 2022 AGM are given on the Company’s website at www.blackrock.com/uk/ brfi.
Shareholders Continued shareholder support and engagement are critical to the continued existence of the Company and the successful delivery of its long-term strategy The Board is committed to maintaining open channels of communication and engaging with shareholders. The Company welcomes and encourages attendance and participation from shareholders at its Annual General Meetings. Shareholders therefore have the opportunity to meet the Directors and Investment Manager and to address questions to them directly.

The Annual Report and Half-yearly Financial Report are available on the BlackRock website and are also circulated to shareholders either in printed copy or via electronic communications. In addition, regular updates on performance, monthly factsheets, the daily NAV and other information are also published on the website at www.blackrock.com/uk/brfi.

The Board also works closely with the Manager to develop the Company’s marketing strategy, with the aim of ensuring effective communication with shareholders in respect of the investment mandate and objective. Unlike trading companies, one-to-one shareholder meetings usually take the form of a meeting with the Investment Manager as opposed to members of the Board. As well as attending regular investor meetings the Investment Manager holds regular discussions with wealth management desks and offices to build on the case for, and understanding of, long-term investment opportunities in frontier markets.

The Manager also coordinates public relations activity, including meetings between the Investment Manager and relevant industry publications to set out their vision for the portfolio strategy and outlook for the region.

The Manager releases monthly portfolio updates to the market to ensure that investors are kept up to date in respect of performance and other portfolio developments and maintains a website on behalf of the Company that contains relevant information in respect of the Company’s investment mandate and objective.

If shareholders wish to raise issues or concerns with the Board, they are welcome to do so at any time. The Chairman is available to meet directly with shareholders periodically to understand their views on governance and the Company’s performance where they wish to do so. He may be contacted via the Company Secretary whose details are given in the Company's Annual Report for the year ended 30 September 2022. The Board values any feedback and questions from shareholders ahead of and during Annual General Meetings in order to gain an understanding of their views and will take action when and as appropriate. Feedback and questions will also help the Company evolve its reporting, aiming to make reports more transparent and understandable.

Feedback from all substantive meetings between the Investment Manager and shareholders is shared with the Board. The Directors also receive updates from the Company’s broker on any feedback from shareholders, as well as share trading activity, share price performance and an update from the Investment Manager.

2022 2021

Notes Revenue

US$’000 Capital

US$’000 Total

US$’000 Revenue

US$’000 Capital

US$’000 Total

US$’000
Income from investments held at fair value through profit or loss 3 12,369 74 12,443 10,973 – 10,973
Net income from contracts for difference 3 2,328 – 2,328 7,966 – 7,966
Other income 3 55 – 55 – – –
--------------- --------------- --------------- --------------- --------------- ---------------
Total income 14,752 74 14,826 18,939 – 18,939
========= ========= ========= ========= ========= =========
Net (loss)/profit on investments held at fair value through profit or loss – (41,473) (41,473) – 88,376 88,376
Net loss on foreign exchange – (205) (205) – (1,399) (1,399)
Net (loss)/profit from derivatives – (4,425) (4,425) – 53,428 53,428
--------------- --------------- --------------- --------------- --------------- ---------------
Total 14,752 (46,029) (31,277) 18,939 140,405 159,344
========= ========= ========= ========= ========= =========
Expenses
Investment management and performance fees 4 (757) (3,028) (3,785) (777) (6,922) (7,699)
Other operating expenses 5 (899) (78) (977) (891) (60) (951)
--------------- --------------- --------------- --------------- --------------- ---------------
Total operating expenses (1,656) (3,106) (4,762) (1,668) (6,982) (8,650)
========= ========= ========= ========= ========= =========
Net profit/(loss) on ordinary activities before finance costs and taxation 13,096 (49,135) (36,039) 17,271 133,423 150,694
Finance costs (3) (14) (17) (2) (8) (10)
--------------- --------------- --------------- --------------- --------------- ---------------
Net profit/(loss) on ordinary activities before taxation 13,093 (49,149) (36,056) 17,269 133,415 150,684
Taxation (charge)/credit (1,080) 267 (813) (2,365) 1,153 (1,212)
--------------- --------------- --------------- --------------- --------------- ---------------
Profit/(loss) for the year 12,013 (48,882) (36,869) 14,904 134,568 149,472
========= ========= ========= ========= ========= =========
Earnings/(loss) per ordinary share (cents) 7 6.35 (25.82) (19.47) 7.09 64.06 71.15
========= ========= ========= ========= ========= =========

Notes Called

up share

capital

US$’000 Share

premium

account

US$’000 Capital

redemption

reserve

US$’000

Special

reserve

US$’000

Capital

reserves

US$’000

Revenue

reserve

US$’000

Total

US$’000
For the year ended 30 September 2022
At 30 September 2021 2,418 – 5,798 308,804 26,051 9,707 352,778
Total comprehensive (loss)/income:
Net (loss)/profit for the year – – – – (48,882) 12,013 (36,869)
Transactions with owners, recorded directly to equity:
Dividends paid 1 6 – – – – – (13,253) (13,253)
--------------- --------------- --------------- --------------- --------------- --------------- ---------------
At 30 September 2022 2,418 – 5,798 308,804 (22,831) 8,467 302,656
========= ========= ========= ========= ========= ========= =========
For the year ended 30 September 2021
At 30 September 2020 2,418 165,984 5,798 230,040 (108,517) 10,261 305,984
Total comprehensive income:
Net profit for the year – – – – 134,568 14,904 149,472
Transactions with owners, recorded directly to equity:
Cancellation of share premium account 2 9 – (165,984) – 165,984 – – –
Tender offer – – – (86,434) – – (86,434)
Tender offer costs – – – (786) – – (786)
Dividends paid 3 6 – – – – – (15,458) (15,458)
--------------- --------------- --------------- --------------- --------------- --------------- ---------------
At 30 September 2021 2,418 – 5,798 308,804 26,051 9,707 352,778
========= ========= ========= ========= ========= ========= =========

Notes 2022

US$’000 2021

US$’000
Non current assets
Investments held at fair value through profit or loss 297,945 354,075
Current assets
Current tax asset 446 418
Other receivables 1,345 3,878
Derivative financial assets held at fair value through profit or loss – contracts for difference 755 7,725
Derivative financial assets held at fair value through profit or loss – forward currency contracts – 346
Cash and cash equivalents 4,901 5,717
Cash collateral pledged with brokers 7,404 330
--------------- ---------------
Total current assets 14,851 18,414
========= =========
Total assets 312,796 372,489
========= =========
Current liabilities
Other payables (4,858) (11,597)
Derivative financial liabilities held at fair value through profit or loss - contracts for difference (4,613) (1,908)
Liability for cash collateral received (650) (6,187)
--------------- ---------------
Total current liabilities (10,121) (19,692)
========= =========
Total assets less current liabilities 302,675 352,797
========= =========
Non current liabilities
Management shares of £1.00 each (one quarter paid) (19) (19)
--------------- ---------------
Net assets 302,656 352,778
========= =========
Equity attributable to equity holders
Called up share capital 8 2,418 2,418
Capital redemption reserve 9 5,798 5,798
Special reserve 9 308,804 308,804
Capital reserves 9 (22,831) 26,051
Revenue reserve 9 8,467 9,707
--------------- ---------------
Total equity 302,656 352,778
========= =========
Net asset value per ordinary share (cents) 7 159.86 186.33
========= =========

2022

US$’000 2021

US$’000
Operating activities
Net (loss)/profit on ordinary activities before taxation (36,056) 150,684
Add back finance costs 17 10
Net loss/(profit) on investments held at fair value through profit or loss (including transaction costs) 41,473 (88,376)
Net loss/(profit) from derivatives (including transaction costs) 4,425 (53,428)
Financing costs on derivatives (1,450) (929)
Net loss on foreign exchange 205 1,399
Sales of investments held at fair value through profit or loss 193,129 253,543
Purchases of investments held at fair value through profit or loss (203,288) (182,331)
Sales of Cash Fund 1 214,616 176,807
Purchases of Cash Fund 1 (189,800) (208,621)
Amounts paid for losses on closure of derivatives (62,302) (22,372)
Amounts received on profit on closure of derivatives 69,002 70,902
Decrease/(increase) in other receivables 862 (661)
(Decrease)/increase in other payables (4,680) 3,780
Decrease in amounts due from brokers 2,017 437
(Decrease)/increase in amounts due to brokers (2,059) 5,452
Net cash collateral (pledged)/received (12,611) 3,605
Taxation paid (841) (1,566)
--------------- ---------------
Net cash inflow from operating activities 12,659 108,335
========= =========
Financing activities
Interest paid (17) (10)
Tender offer – (86,434)
Tender costs paid – (786)
Dividends paid (13,253) (15,458)
--------------- ---------------
Net cash outflow from financing activities (13,270) (102,688)
========= =========
(Decrease)/increase in cash and cash equivalents (611) 5,647
Effect of foreign exchange rate changes (205) (1,399)
--------------- ---------------
Change in cash and cash equivalents (816) 4,248
Cash and cash equivalents at the start of the year 5,717 1,469
--------------- ---------------
Cash and cash equivalents at the end of the year 4,901 5,717
========= =========
Comprised of:
Cash at bank 4,901 5,717
--------------- ---------------
4,901 5,717
========= =========

2022

US$’000 2021

US$’000
Investment income:
UK dividends – 166
Overseas dividends 10,327 9,344
Overseas special dividends 1,329 1,340
Interest from Cash Fund 713 123
--------------- ---------------
Total investment income 12,369 10,973
========= =========
Net income from contracts for difference 2,328 7,966
Deposit interest 55 –
--------------- ---------------
Total income 14,752 18,939
========= =========

2022 2021

Revenue

US$’000 Capital

US$’000 Total

US$’000 Revenue

US$’000 Capital

US$’000 Total

US$’000
Investment management fee 757 3,028 3,785 777 3,107 3,884
Performance fee – – – – 3,815 3,815
--------------- --------------- --------------- --------------- --------------- ---------------
Total 757 3,028 3,785 777 6,922 7,699
========= ========= ========= ========= ========= =========

2022

US$’000 2021

US$’000
Allocated to revenue:
Custody fee 274 212
Auditor’s remuneration:
– audit services 1 52 72
– other assurance services 2 7 9
Registrar’s fee 38 45
Directors’ emoluments 3 196 183
Broker fees 36 40
Depositary fees 4 29 32
Marketing fees 76 101
AIC fees 22 19
FCA fees 16 17
Printing and postage fees 35 57
Employer NI contributions 22 17
Stock exchange listings 12 12
Legal and professional fees 18 18
Write back of prior year expenses 5 (6) (4)
Other administrative costs 72 61
--------------- ---------------
899 891
========= =========
Allocated to capital:
Custody transaction charges 6 78 60
--------------- ---------------
977 951
========= =========
The Company’s ongoing charges 7 , calculated as a percentage of average daily net assets and using the management fee and all other operating expenses, excluding performance fees, finance costs, direct transaction costs, custody transaction charges, VAT recovered, taxation, prior year expenses written back and certain non-recurring items, were: 1.36% 1.36%
--------------- ---------------
The Company’s ongoing charges 7 , calculated as a percentage of average daily net assets and using the management fee and all other operating expenses and including performance fees but excluding finance costs, direct transaction costs, custody transaction charges, VAT recovered, taxation, prior year expenses written back and certain non-recurring items, were: 1.36% 2.44%
========= =========

Dividends paid on equity shares

Record date

Payment date 2022

US$’000 2021

US$’000
2021 final of 4.25 cents (2020: 4.25 cents) per ordinary share 6 January 2022 11 February 2022 8,046 10,251
2022 interim of 2.75 cents (2021: 2.75 cents) per ordinary share 1 June 2022 24 June 2022 5,207 5,207
--------------- ---------------
13,253 15,458
========= =========

Dividends paid, proposed or declared on equity shares 2022

US$’000 2021

US$’000
Interim dividend of 2.75 cents per ordinary share (2021: 2.75 cents) 5,207 5,207
Final proposed dividend of 4.25 cents per ordinary share (2021: 4.25 cents)¹ 8,046 8,046
--------------- ---------------
13,253 13,253
========= =========

Year ended

30 September

2022 Year ended

30 September

2021
Net revenue profit attributable to ordinary shareholders (US$’000) 12,013 14,904
Net capital (loss)/profit attributable to ordinary shareholders (US$’000) (48,882) 134,568
--------------- ---------------
Total (loss)/profit attributable to ordinary shareholders (US$’000) (36,869) 149,472
========= =========
Total shareholders’ funds (US$’000) 302,656 352,778
========= =========
The weighted average number of ordinary shares in issue during the year on which the earnings per ordinary share was calculated was: 189,325,748 210,079,656
The actual number of ordinary shares in issue at the year end on which the net asset value per ordinary share was calculated was: 189,325,748 189,325,748
Earnings per ordinary share
Revenue earnings per share (cents) – basic and diluted 6.35 7.09
Capital (loss)/earnings per share (cents) – basic and diluted (25.82) 64.06
--------------- ---------------
Total (loss)/earnings per share (cents) – basic and diluted (19.47) 71.15
========= =========

As at

30 September

2022 As at

30 September

2021
Net asset value per ordinary share (cents) 159.86 186.33
Ordinary share price (cents) 1 142.61 165.18
Net asset value per ordinary share (pence) 2 143.21 138.19
Ordinary share price (pence) 127.75 122.50
========= =========

Ordinary

shares

in issue

number

Treasury

shares

number

Total

shares

number

Nominal

value

US$’000
Allotted, called up and fully paid share capital comprised:
Ordinary shares of 1 cent each:
At 30 September 2021 189,325,748 52,497,053 241,822,801 2,418
------------------- ------------------- ------------------- -------------------
At 30 September 2022 189,325,748 52,497,053 241,822,801 2,418
============ ============ ============ ============

Distributable reserves

Share

premium

account

US$’000

Capital

redemption

reserve

US$’000

Special

reserve

US$’000

Capital

reserve

arising on

investments

sold

US$’000 Capital

reserve

arising on

revaluation of

investments

held

US$’000

Revenue

reserve

US$’000
At 30 September 2021 – 5,798 308,804 12,959 13,092 9,707
Movement during the year:
Total comprehensive (loss)/income:
Net (loss)/profit for the year – – – 8,789 (57,671) 12,013
Transactions with owners, recorded directly to equity:
Dividends paid – – – – – (13,253)
--------------- --------------- --------------- --------------- --------------- ---------------
At 30 September 2022 – 5,798 308,804 21,748 (44,579) 8,467
========= ========= ========= ========= ========= =========

Distributable reserves

Share

premium

account

US$’000

Capital

redemption

reserve

US$’000

Special

reserve

US$’000

Capital

reserve

arising on

investments

sold

US$’000 Capital

reserve

arising on

revaluation of

investments

held

US$’000

Revenue

reserve

US$’000
At 30 September 2020 165,984 5,798 230,040 (56,612) (51,905) 10,261
Movement during the year:
Total comprehensive income:
Net profit for the year – – – 69,571 64,997 14,904
Transactions with owners, recorded directly to equity:
Cancellation of share premium account (165,984) – 165,984 – – –
Tender offer – – (86,434) – – –
Tender offer costs – – (786) – – –
Dividends paid – – – – – (15,458)
--------------- --------------- --------------- --------------- --------------- ---------------
At 30 September 2021 – 5,798 308,804 12,959 13,092 9,707
========= ========= ========= ========= ========= =========

Financial assets/(liabilities) at fair value through profit or loss at 30 September 2022 Level 1

US$’000 Level 2

US$’000 Level 3

US$’000 Total

US$’000
Assets:
Equity investments 226,530 – – 226,530
Cash Fund 71,415 – – 71,415
Contracts for difference (fair value) – 755 – 755
Liabilities:
Contracts for difference (fair value) – (4,613) – (4,613)
--------------- --------------- --------------- ---------------
297,945 (3,858) – 294,087
========= ========= ========= =========

Financial assets/(liabilities) at fair value through profit or loss at 30 September 2021 Level 1

US$’000 Level 2

US$’000 Level 3

US$’000 Total

US$’000
Assets:
Equity investments 257,806 – – 257,806
Cash Fund 96,269 – – 96,269
Contracts for difference (fair value) – 7,725 – 7,725
Forward currency contracts (fair value) – 346 – 346
Liabilities:
Contracts for difference (fair value) – (1,908) – (1,908)
--------------- --------------- --------------- ---------------
354,075 6,163 – 360,238
========= ========= ========= =========

Level 3 Financial assets at fair value through profit or loss at 30 September 2022

US$’000 2021

US$’000
Opening fair value – 3
Disposal of contract for difference (fair value) 1 – (3)
--------------- ---------------
Closing fair value – –
========= =========

Total % of shares held by Related BlackRock Funds Total % of shares held by Significant Investors who are not affiliates of BlackRock Group or BlackRock, Inc. Number of Significant Investors who are not affiliates of BlackRock Group or BlackRock, Inc.
8.4 n/a n/a

Total % of shares held by Related BlackRock Funds Total % of shares held by Significant Investors who are not affiliates of BlackRock Group or BlackRock, Inc. Number of Significant Investors who are not affiliates of BlackRock Group or BlackRock, Inc.
8.4 n/a n/a
Tables attached :
Table1
Table2
Table3
Table4
Table5
Table6
Table7
Table8
Table9
Table10
Table11
Table12
Table13
Table14
Table15
Table16
Table17
Table18
Table19
Table20
Table21
Table22
Table23
Table24
Table25
Table26
Table27
Table28
Table29
Table30
Table31
Table32
Blogs - Finance (blog ref.) - Canadian Insider
November 10, 2023 12444 mots
Mineros Reports Third Quarter 2023 Financial and Operational Results

Mineros Reports Third Quarter 2023 Financial and Operational Results Canada NewsWire MEDELLIN, Colombia, Nov. 9, 2023 (all dollar amounts other than per share amounts are expressed in thousands of U.S... Voir l'article

Ce document référence un lien URL de site non hébergé par Cision.

The Star (Nairobi, Kenya)
Saturday, December 2, 2023 983 mots, p. NA

What future for newspapers?

How often do you read the traditional, printed newspaper? Seems a strange question to ask because you are probably reading this article in a newspaper, or an online version of the Star.

Perhaps we can put the question another way. How often do you buy the print version of the Star or any other newspaper? The answer to that question has implications for the future of newspapers not only in Kenya but across the world.

There is a huge appetite for news and updates on current events. There is a lot of demand for business news, celebrity happenings, human-interest stories and sports news. People love stories and the media industry exists precisely to satisfy the hunger for stories, but the means of distributing those stories is evolving.

Now in his 70s, retired civil servant Andrew Mwaiseghe has been a regular newspaper reader for almost 50 years. He buys newspapers three to four times a week. Mwaiseghe can be seen carrying a newspaper wherever he goes, whether it's to a business meeting, the local pub or to the motor vehicle garage where he gets his car repaired. The newspaper keeps him busy any time he has to wait for something and, by the end of the day, he will have read a large part of it.

Mwaiseghe is also active on social media, especially WhatsApp groups. He takes photos of interesting articles in newspapers and shares them with friends and relatives on WhatsApp groups. Mwaiseghe has integrated his love for newspapers with digital technology but, lately, he's questioning whether newspapers are any better than social media.

"Nowadays, I find newspapers with the same stories I saw on social media the previous day. I'm wondering whether newspapers are giving me fresh information I haven't already found out," Mwaiseghe says.

ELECTRONIC REVOLUTION

A survey by Radio Africa Group shows that television and radio are the main source of news for most Kenyans. The two types of media are also the most trusted information sources across all age groups, according to the Kenya Media Research Survey, whose results were published on November 13.

Kenyans are spending more time getting news on social media than from traditional media. Social media includes social networking platforms such as Facebook, Instagram, LinkedIn and X (formerly Twitter), as well as instant messaging services WhatsApp and Telegram. On average, Kenyans spend 2 hours and 24 minutes on social media each day, compared to 2 hours 10 minutes on radio.

The survey found that social media is the most trusted source of news and information for Kenyans aged 18-34 (the youth). Kenyans in that age group buy newspapers mostly on days they know job vacancies are published. To the youth, newspaper purchases are part of job hunting.

The latest findings on Kenyans' media preferences confirm a long-established swing towards electronic media. In February, the Media Council of Kenya published its state of the media report for 2022, which showed that TV and radio were the main sources of news in Kenya. They both tied at 33 per cent each.

Social media was the third-most popular source of news in 2022, coming in at 18 per cent. Newspapers as an exclusive source of news came fourth at 6 per cent. According to an MCK editorial, just 30 per cent of survey respondents said they read printed newspapers at least once a week.

"Prime time news is King," MCK CEO David Omwoyo said during the report's release. 75 per cent of Kenyans get their news from TV bulletins between 4pm and midnight. This may be attributed to the fact that adults are usually at home from work, hence the increased preference for prime time news to get updates on current affairs.

The bright spark for journalists is that 70 per cent of respondents in the MCK report said they trust the media. This shows that mainstream media remains highly popular among Kenyans. 51 per cent of Kenyans said they visited news websites, a huge improvement over the 12 per cent recorded in 2021.

Interestingly, bloggers are the least popular source of news. Only one per cent of Kenyans told MCK that they visited blogging channels at least once a week. This finding implies that bloggers are not an effective way for advertisers to reach audiences.

Digital-only news outlets (those that don't have print newspapers, radio and TV) have lower operating costs compared to mainstream media. They are much more flexible at adapting to change but, like mainstream media, they face intense competition for consumers and advertisers.

SOCIAL MEDIA SPAGHETTI

Edward Mwasi, CEO of the Kenya Yearbook Editorial Board, says fears of electronic media overrunning printed newspapers began in the 1940s. Mwasi believes that social media by itself cannot satisfy the human desire for deep stories. Successful newspapers are those that have easy-to-read content and excellent packaging.

"Journalism takes time to explain stories, while providing multiple perspectives. Social media is like a quick spaghetti alternative to a five-course meal," Mwasi wrote in a Daily Nation opinion piece.

Despite the changes in technology, the demand for news is not declining but increasing. Leo Kemboi of the Institute of Economic Affairs contends that the number of daily visits to newspaper websites is on the increase. It is only the mode of consuming news that is changing.

"My argument is: That the changing dynamics of the industry will bring new sectors and opportunities that the Kenya industry players can tap into," Kemboi surmised in a blog post for the institution.

Official data proves the consumer shift towards online news. The Economic Survey 2023 - published by the Kenya National Bureau for Statistics - shows that as newspaper circulation dropped between 2018 and 2022, the number of visitors to online news websites grew from 2.8 million per day to 4.7 million. That represents a 65 per cent increase in online traffic over the five years.